@@ -456,14 +456,15 @@ linphonec_parse_command_line(LinphoneCore *lc, char *cl)
 char *
 linphonec_command_generator(const char *text, int state)
 {
-	static int index, len, adv;
+	static size_t len;
+	static int index, adv;
 	char *name;
 
 	if ( ! state )
 	{
 		index=0;
 		adv=0;
-		len=(int)strlen(text);
+		len=strlen(text);
 	}
 	/*
  	 * Return the next name which partially matches
@@ -665,8 +666,8 @@ lpc_cmd_transfer(LinphoneCore *lc, char *args)
 		const char *refer_to=NULL;
 		char arg1[256]={0};
 		char arg2[266]={0};
-		long id2=0;
-		int n=sscanf(args,"%255s %265s %li",arg1,arg2,&id2);
+		int id2=0;
+		int n=sscanf(args,"%255s %265s %d",arg1,arg2,&id2);
 		if (n==1 || isalpha(*arg1)){
 			call=linphone_core_get_current_call(lc);
 			if (call==NULL && bctbx_list_size(linphone_core_get_calls(lc))==1){
@@ -679,13 +680,13 @@ lpc_cmd_transfer(LinphoneCore *lc, char *args)
 			}
 			linphone_call_transfer(call, refer_to);
 		}else if (n==2){
-			long id=atoi(arg1);
+			int id=atoi(arg1);
 			refer_to=args+strlen(arg1)+1;
 			call=linphonec_get_call(id);
 			if (call==NULL) return 0;
 			linphone_call_transfer(call, refer_to);
 		}else if (n==3){
-			long id=atoi(arg1);
+			int id=atoi(arg1);
 			call=linphonec_get_call(id);
 			call2=linphonec_get_call(id2);
 			if (call==NULL || call2==NULL) return 0;
@@ -723,7 +724,7 @@ lpc_cmd_terminate(LinphoneCore *lc, char *args)
 		return 1;
 	}else{
 		/*the argument is a linphonec call id */
-		long id=atoi(args);
+		int id=atoi(args);
 		LinphoneCall *call=linphonec_get_call(id);
 		if (call){
 			if (linphone_call_terminate(call)==-1){
@@ -764,9 +765,9 @@ lpc_cmd_redirect(LinphoneCore *lc, char *args){
 		}
 	} else {
 		char space;
-		long id;
+		int id;
 		int charRead;
-		if ( sscanf(args, "%li%c%n", &id, &space, &charRead) == 2 && space == ' ') {
+		if ( sscanf(args, "%d%c%n", &id, &space, &charRead) == 2 && space == ' ') {
 			LinphoneCall * call = linphonec_get_call(id);
 			if ( call != NULL ) {
 				if (linphone_call_get_state(call)!=LinphoneCallIncomingReceived) {
@@ -799,8 +800,8 @@ lpc_cmd_answer(LinphoneCore *lc, char *args){
 		}
 		return 1;
 	}else{
-		long id;
-		if (sscanf(args,"%li",&id)==1){
+		int id;
+		if (sscanf(args,"%d",&id)==1){
 			LinphoneCall *call=linphonec_get_call (id);
 			if (linphone_call_accept(call)==-1){
 				linphonec_out("Fail to accept call %i\n",id);
@@ -929,6 +930,7 @@ lpc_cmd_firewall(LinphoneCore *lc, char *args)
 				return 1;
 			}
 			linphone_core_set_firewall_policy(lc,LinphonePolicyUseNatAddress);
+			setting = linphone_core_get_nat_address(lc);
 		}
 	}
 
@@ -1003,14 +1005,14 @@ lpc_cmd_friend(LinphoneCore *lc, char *args)
 	{
 		args+=4;
 		if ( ! *args ) return 0;
-		friend_num = strtol(args, NULL, 10);
+		friend_num = (int)strtol(args, NULL, 10);
 #ifndef _WIN32_WCE
 		if ( errno == ERANGE ) {
 			linphonec_out("Invalid friend number\n");
 			return 0;
 		}
 #endif /*_WIN32_WCE*/
-		linphonec_friend_call(lc, friend_num);
+		linphonec_friend_call(lc, (unsigned int)friend_num);
 		return 1;
 	}
 	else if ( !strncmp(args, "delete", 6) )
@@ -1025,7 +1027,7 @@ lpc_cmd_friend(LinphoneCore *lc, char *args)
 		}
 		else
 		{
-			friend_num = strtol(args, NULL, 10);
+			friend_num = (int)strtol(args, NULL, 10);
 #ifndef _WIN32_WCE
 			if ( errno == ERANGE ) {
 				linphonec_out("Invalid friend number\n");
@@ -1144,7 +1146,7 @@ lpc_cmd_proxy(LinphoneCore *lc, char *args)
 			else linphonec_out("Current default proxy is %d.\n", proxynum);
 		}
 	}else if (strcmp(arg1, "unuse")==0){
-		linphone_core_set_default_proxy(lc, NULL);
+		linphone_core_set_default_proxy_config(lc, NULL);
 		linphonec_out("Use no proxy.\n");
 	}
 
@@ -1286,11 +1288,11 @@ static int lpc_cmd_soundcard(LinphoneCore *lc, char *args)
 		if (strcmp(arg2, "files")==0)
 		{
 			linphonec_out("Using wav files instead of soundcard.\n");
-			linphone_core_use_files(lc,TRUE);
+			linphone_core_set_use_files(lc,TRUE);
 			return 1;
 		}
 
-		linphone_core_use_files(lc,FALSE);
+		linphone_core_set_use_files(lc,FALSE);
 
 		dev=linphone_core_get_sound_devices(lc);
 		index=atoi(arg2); /* FIXME: handle not-a-number */
@@ -1470,10 +1472,10 @@ static int lpc_cmd_resume(LinphoneCore *lc, char *args){
 	}
 	if (args)
 	{
-		long id;
-		int n = sscanf(args, "%li", &id);
+		int id;
+		int n = sscanf(args, "%d", &id);
 		if (n == 1){
-			LinphoneCall *call=linphonec_get_call (id);
+			LinphoneCall *call=linphonec_get_call(id);
 			if (call){
 				if(linphone_call_resume(call)==-1){
 					linphonec_out("There was a problem to resume the call check the remote address you gave %s\n",args);
@@ -1505,11 +1507,11 @@ static int lpc_cmd_resume(LinphoneCore *lc, char *args){
 }
 
 static int lpc_cmd_conference(LinphoneCore *lc, char *args){
-	long id;
+	int id;
 	char subcommand[32]={0};
 	int n;
 	if (args==NULL) return 0;
-	n=sscanf(args, "%31s %li", subcommand,&id);
+	n=sscanf(args, "%31s %d", subcommand,&id);
 	if (n == 2){
 		LinphoneCall *call=linphonec_get_call(id);
 		if (call==NULL) return 1;
@@ -1570,7 +1572,7 @@ linphonec_proxy_add(LinphoneCore *lc)
 		{
 			linphonec_out("Invalid sip address (sip:sip.domain.tld).\n");
 			free(input);
-			linphone_proxy_config_destroy(cfg);
+			linphone_proxy_config_unref(cfg);
 			continue;
 		}
 		free(input);
@@ -1587,7 +1589,7 @@ linphonec_proxy_add(LinphoneCore *lc)
 
 		if ( ! input ) {
 			linphonec_out("Aborted.\n");
-			linphone_proxy_config_destroy(cfg);
+			linphone_proxy_config_unref(cfg);
 			return;
 		}
 
@@ -1598,13 +1600,15 @@ linphonec_proxy_add(LinphoneCore *lc)
 			continue;
 		}
 
-		linphone_proxy_config_set_identity(cfg, clean);
+		LinphoneAddress *identity = linphone_address_new(clean);
+		linphone_proxy_config_set_identity_address(cfg, identity);
 		if ( ! linphone_proxy_config_get_identity (cfg))
 		{
 			linphonec_out("Invalid identity (sip:name@sip.domain.tld).\n");
 			free(input);
 			continue;
 		}
+		if (identity) linphone_address_unref(identity);
 		free(input);
 		break;
 	}
@@ -1619,7 +1623,7 @@ linphonec_proxy_add(LinphoneCore *lc)
 
 		if ( ! input ) {
 			linphonec_out("Aborted.\n");
-			linphone_proxy_config_destroy(cfg);
+			linphone_proxy_config_unref(cfg);
 			return;
 		}
 
@@ -1655,7 +1659,7 @@ linphonec_proxy_add(LinphoneCore *lc)
 
 			if ( ! input ) {
 				linphonec_out("Aborted.\n");
-				linphone_proxy_config_destroy(cfg);
+				linphone_proxy_config_unref(cfg);
 				return;
 			}
 
@@ -1680,7 +1684,7 @@ linphonec_proxy_add(LinphoneCore *lc)
 
 		if ( ! input ) {
 			linphonec_out("Aborted.\n");
-			linphone_proxy_config_destroy(cfg);
+			linphone_proxy_config_unref(cfg);
 			return;
 		}
 
@@ -1720,7 +1724,7 @@ linphonec_proxy_add(LinphoneCore *lc)
 
 		if ( ! input ) {
 			linphonec_out("Aborted.\n");
-			linphone_proxy_config_destroy(cfg);
+			linphone_proxy_config_unref(cfg);
 			return;
 		}
 
@@ -1735,7 +1739,7 @@ linphonec_proxy_add(LinphoneCore *lc)
 		else if ( ! strcmp(clean, "no") )
 		{
 			linphonec_out("Declined.\n");
-			linphone_proxy_config_destroy(cfg);
+			linphone_proxy_config_unref(cfg);
 			free(input);
 			return;
 		}
@@ -1749,7 +1753,7 @@ linphonec_proxy_add(LinphoneCore *lc)
 	linphone_core_add_proxy_config(lc,cfg);
 
 	/* automatically set the last entered proxy as the default one */
-	linphone_core_set_default_proxy(lc,cfg);
+	linphone_core_set_default_proxy_config(lc,cfg);
 
 	linphonec_out("Proxy added.\n");
 }
@@ -1758,14 +1762,15 @@ static void
 linphonec_proxy_display(LinphoneProxyConfig *cfg)
 {
 	const char *route=linphone_proxy_config_get_route(cfg);
-	const char *identity=linphone_proxy_config_get_identity(cfg);
+	char *identity=linphone_address_as_string(linphone_proxy_config_get_identity_address(cfg));
 	linphonec_out("sip address: %s\nroute: %s\nidentity: %s\nregister: %s\nexpires: %i\nregistered: %s\n",
 			linphone_proxy_config_get_addr(cfg),
 			(route!=NULL)? route:"",
 			(identity!=NULL)?identity:"",
 			linphone_proxy_config_register_enabled (cfg)?"yes":"no",
 			linphone_proxy_config_get_expires (cfg),
-			linphone_proxy_config_is_registered(cfg) ? "yes" : "no");
+			linphone_proxy_config_get_state(cfg) == LinphoneRegistrationOk ? "yes" : "no");
+	ms_free(identity);
 }
 
 static void linphonec_proxy_show(LinphoneCore *lc, int index)
@@ -1826,7 +1831,7 @@ linphonec_proxy_use(LinphoneCore *lc, int index)
 		linphonec_out("No such proxy (try 'proxy list').");
 		return 0;
 	}
-	linphone_core_set_default_proxy(lc,cfg);
+	linphone_core_set_default_proxy_config(lc,cfg);
 	return 1;
 }
 
@@ -1957,7 +1962,7 @@ static int lpc_cmd_register(LinphoneCore *lc, char *args){
 			LinphoneProxyConfig *cfg = linphone_core_get_default_proxy_config(lc);
 			if (cfg)
 			{
-				if(!linphone_proxy_config_is_registered(cfg)) {
+				if(linphone_proxy_config_get_state(cfg) != LinphoneRegistrationOk) {
 				linphone_proxy_config_enable_register(cfg,TRUE);
 				linphone_proxy_config_done(cfg);
 			}else{
@@ -1991,18 +1996,20 @@ static int lpc_cmd_register(LinphoneCore *lc, char *args){
 		linphone_proxy_config_edit(cfg);
 	}
 	else cfg=linphone_core_create_proxy_config(lc);
-	linphone_proxy_config_set_identity(cfg,identity);
+	LinphoneAddress *addr = linphone_address_new(identity);
+	linphone_proxy_config_set_identity_address(cfg,addr);
+	if (addr) linphone_address_unref(addr);
 	linphone_proxy_config_set_server_addr(cfg,proxy);
 	linphone_proxy_config_enable_register(cfg,TRUE);
 	if (elem) linphone_proxy_config_done(cfg);
 	else linphone_core_add_proxy_config(lc,cfg);
-	linphone_core_set_default_proxy(lc,cfg);
+	linphone_core_set_default_proxy_config(lc,cfg);
 	return 1;
 }
 
 static int lpc_cmd_unregister(LinphoneCore *lc, char *args){
 	LinphoneProxyConfig *cfg = linphone_core_get_default_proxy_config(lc);
-	if (cfg && linphone_proxy_config_is_registered(cfg)) {
+	if (cfg && linphone_proxy_config_get_state(cfg) == LinphoneRegistrationOk) {
 		linphone_proxy_config_edit(cfg);
 		linphone_proxy_config_enable_register(cfg,FALSE);
 		linphone_proxy_config_done(cfg);
@@ -2034,7 +2041,7 @@ static int lpc_cmd_status(LinphoneCore *lc, char *args)
 	{
 		if (cfg)
 		{
-			if (linphone_proxy_config_is_registered(cfg)){
+			if (linphone_proxy_config_get_state(cfg) == LinphoneRegistrationOk){
 				linphonec_out("registered, identity=%s duration=%i\n",
 					linphone_proxy_config_get_identity(cfg),
 					linphone_proxy_config_get_expires(cfg));
@@ -2046,7 +2053,7 @@ static int lpc_cmd_status(LinphoneCore *lc, char *args)
 	}
 	else if (strstr(args,"autoanswer"))
 	{
-		if (cfg && linphone_proxy_config_is_registered(cfg))
+		if (cfg && linphone_proxy_config_get_state(cfg) == LinphoneRegistrationOk)
 			linphonec_out("autoanswer=%i\n",linphonec_get_autoanswer());
 		else linphonec_out("unregistered\n");
 	}
@@ -2126,12 +2133,12 @@ static int lpc_cmd_param(LinphoneCore *lc, char *args)
 	switch (sscanf(args,"%19s %19s %49s",section,param,value)) {
 		// case 1 might show all current settings under a section
 		case 2:
-			string = lp_config_get_string(linphone_core_get_config(lc), section, param, "(undef)");
+			string = linphone_config_get_string(linphone_core_get_config(lc), section, param, "(undef)");
 			linphonec_out("current value: %s\n", string);
 			break;
 		case 3:
-			if (lp_config_get_string(linphone_core_get_config(lc), section, param, NULL) != NULL) {
-				lp_config_set_string(linphone_core_get_config(lc), section, param, value);
+			if (linphone_config_get_string(linphone_core_get_config(lc), section, param, NULL) != NULL) {
+				linphone_config_set_string(linphone_core_get_config(lc), section, param, value);
 			// no indication of existence
 				linphonec_out("updated value: %s\n", value);
 			} else {
@@ -2148,7 +2155,7 @@ static int lpc_cmd_speak(LinphoneCore *lc, char *args){
 #ifndef _WIN32
 	char voice[64];
 	char *sentence;
-	char cl[128];
+	char cl[256];
 	char wavfile[128]="/tmp/linphonec-espeak-XXXXXX";
 	int status;
 	FILE *file;
@@ -2327,16 +2334,16 @@ static int lpc_cmd_echocancellation(LinphoneCore *lc, char *args){
             n = sscanf(arg2, "%d %d %d", &delay, &tail_len, &frame_size);
 
             if (n == 1) {
-                lp_config_set_int(config,"sound","ec_delay",delay);
+                linphone_config_set_int(config,"sound","ec_delay",delay);
             }
             else if (n == 2) {
-                lp_config_set_int(config,"sound","ec_delay",delay);
-                lp_config_set_int(config,"sound","ec_tail_len",tail_len);
+                linphone_config_set_int(config,"sound","ec_delay",delay);
+                linphone_config_set_int(config,"sound","ec_tail_len",tail_len);
             }
             else if (n == 3) {
-                lp_config_set_int(config,"sound","ec_delay",delay);
-                lp_config_set_int(config,"sound","ec_tail_len",tail_len);
-                lp_config_set_int(config,"sound","ec_framesize",frame_size);
+                linphone_config_set_int(config,"sound","ec_delay",delay);
+                linphone_config_set_int(config,"sound","ec_tail_len",tail_len);
+                linphone_config_set_int(config,"sound","ec_framesize",frame_size);
             }
         }
     }
@@ -2346,9 +2353,9 @@ static int lpc_cmd_echocancellation(LinphoneCore *lc, char *args){
     else if (strcmp(arg1,"show")==0){
         linphonec_out("echo cancellation is %s; delay %d, tail length %d, frame size %d\n",
             linphone_core_echo_cancellation_enabled(lc) ? "on" : "off",
-            lp_config_get_int(config,"sound","ec_delay",0),
-            lp_config_get_int(config,"sound","ec_tail_len",0),
-            lp_config_get_int(config,"sound","ec_framesize",0));
+            linphone_config_get_int(config,"sound","ec_delay",0),
+            linphone_config_get_int(config,"sound","ec_tail_len",0),
+            linphone_config_get_int(config,"sound","ec_framesize",0));
     }
     else {
         return 0;
@@ -2411,12 +2418,12 @@ static int lpc_cmd_rtp_no_xmit_on_audio_mute(LinphoneCore *lc, char *args)
 #ifdef VIDEO_ENABLED
 static int _lpc_cmd_video_window(LinphoneCore *lc, char *args, bool_t is_preview){
 	char subcommand[64];
-	long a,b;
+	int a,b;
 	int err;
 	VideoParams *params=is_preview ? &lpc_preview_params : &lpc_video_params;
 
 	if (!args) return 0;
-	err=sscanf(args,"%63s %ld %ld",subcommand,&a,&b);
+	err=sscanf(args,"%63s %d %d",subcommand,&a,&b);
 	if (err>=1){
 		if (strcmp(subcommand,"pos")==0){
 			if (err<3) return 0;
@@ -2442,11 +2449,11 @@ static int _lpc_cmd_video_window(LinphoneCore *lc, char *args, bool_t is_preview
 				              linphone_core_get_native_video_window_id (lc));
 				return 1;
 			} else if (err != 2) return 0;
-			params->wid=(void *)a;
+			params->wid=(void *)(long)a;
 			if (is_preview)
-				linphone_core_set_native_preview_window_id(lc, (void *)a);
+				linphone_core_set_native_preview_window_id(lc, (void *)(long)a);
 			else
-				linphone_core_set_native_video_window_id(lc, (void *)a);
+				linphone_core_set_native_video_window_id(lc, (void *)(long)a);
 		}else if (is_preview==TRUE){
 			if (strcmp(subcommand,"integrated")==0){
 				linphone_core_use_preview_window (lc,FALSE);
@@ -2491,7 +2498,7 @@ static void lpc_display_call_states(LinphoneCore *lc){
 			tmp=linphone_call_get_remote_address_as_string (call);
 			flag=in_conference ? "conferencing" : "";
 			flag=linphone_call_has_transfer_pending(call) ? "transfer pending" : flag;
-			linphonec_out("%-2i | %-35s | %-15s | %s\n",VOIDPTR_TO_INT(linphone_call_get_user_pointer(call)),
+			linphonec_out("%-2i | %-35s | %-15s | %s\n",VOIDPTR_TO_INT(linphone_call_get_user_data(call)),
 						  tmp,linphone_call_state_to_string(linphone_call_get_state(call))+strlen("LinphoneCall"),flag);
 			ms_free(tmp);
 		}
