@@ -28,7 +28,6 @@
 #include <sys/types.h>
 #include <errno.h>
 #include <signal.h>
-#include "private.h" /*coreapi/private.h, needed for LINPHONE_VERSION */
 #endif /*_WIN32_WCE*/
 #include <limits.h>
 #include <ctype.h>
@@ -111,9 +110,6 @@ static char **linephonec_readline_completion(const char *text,
 /* These are callback for linphone core */
 static void linphonec_prompt_for_auth(LinphoneCore *lc, const char *realm, const char *username, const char *domain);
 static void linphonec_display_refer (LinphoneCore * lc, const char *refer_to);
-static void linphonec_display_something (LinphoneCore * lc, const char *something);
-static void linphonec_display_url (LinphoneCore * lc, const char *something, const char *url);
-static void linphonec_display_warning (LinphoneCore * lc, const char *something);
 static void linphonec_transfer_state_changed(LinphoneCore *lc, LinphoneCall *call, LinphoneCallState new_call_state);
 
 static void linphonec_notify_presence_received(LinphoneCore *lc,LinphoneFriend *fid);
@@ -122,7 +118,6 @@ static void linphonec_new_unknown_subscriber(LinphoneCore *lc,
 
 static void linphonec_text_received(LinphoneCore *lc, LinphoneChatRoom *cr,
 		const LinphoneAddress *from, const char *msg);
-static void linphonec_display_status (LinphoneCore * lc, const char *something);
 static void linphonec_dtmf_received(LinphoneCore *lc, LinphoneCall *call, int dtmf);
 static void print_prompt(LinphoneCore *opm);
 void linphonec_out(const char *fmt,...);
@@ -175,7 +170,7 @@ bool_t linphonec_camera_enabled=TRUE;
 
 void linphonec_call_identify(LinphoneCall* call){
 	static int callid=1;
-	linphone_call_set_user_pointer (call,INT_TO_VOIDPTR(callid));
+	linphone_call_set_user_data (call,INT_TO_VOIDPTR(callid));
 	callid++;
 }
 
@@ -183,7 +178,7 @@ LinphoneCall *linphonec_get_call(int id){
 	const MSList *elem=linphone_core_get_calls(linphonec);
 	for (;elem!=NULL;elem=elem->next){
 		LinphoneCall *call=(LinphoneCall*)elem->data;
-		if (VOIDPTR_TO_INT(linphone_call_get_user_pointer(call))==id){
+		if (VOIDPTR_TO_INT(linphone_call_get_user_data(call))==id){
 			return call;
 		}
 	}
@@ -206,45 +201,6 @@ linphonec_display_refer (LinphoneCore * lc, const char *refer_to)
 	linphonec_out("Receiving out of call refer to %s\n", refer_to);
 }
 
-/*
- * Linphone core callback
- */
-static void
-linphonec_display_something (LinphoneCore * lc, const char *something)
-{
-	fprintf (stdout, "%s\n%s", something,prompt);
-	fflush(stdout);
-}
-
-/*
- * Linphone core callback
- */
-static void
-linphonec_display_status (LinphoneCore * lc, const char *something)
-{
-	fprintf (stdout, "%s\n%s", something,prompt);
-	fflush(stdout);
-}
-
-/*
- * Linphone core callback
- */
-static void
-linphonec_display_warning (LinphoneCore * lc, const char *something)
-{
-	fprintf (stdout, "Warning: %s\n%s", something,prompt);
-	fflush(stdout);
-}
-
-/*
- * Linphone core callback
- */
-static void
-linphonec_display_url (LinphoneCore * lc, const char *something, const char *url)
-{
-	fprintf (stdout, "%s : %s\n", something, url);
-}
-
 /*
  * Linphone core callback
  */
@@ -279,7 +235,7 @@ linphonec_transfer_state_changed(LinphoneCore *lc, LinphoneCall *call, LinphoneC
 	char *remote=linphone_call_get_remote_address_as_string(call);
 	if (new_call_state==LinphoneCallConnected){
 		linphonec_out("The distant endpoint %s of call %i has been transfered, you can safely close the call.\n",
-		              remote,VOIDPTR_TO_INT(linphone_call_get_user_pointer(call)));
+		              remote,VOIDPTR_TO_INT(linphone_call_get_user_data(call)));
 	}
 	ms_free(remote);
 }
@@ -322,7 +278,7 @@ static void linphonec_call_updated(LinphoneCall *call){
 }
 
 static void linphonec_call_encryption_changed(LinphoneCore *lc, LinphoneCall *call, bool_t encrypted, const char *auth_token) {
-	int id=VOIDPTR_TO_INT(linphone_call_get_user_pointer(call));
+	int id=VOIDPTR_TO_INT(linphone_call_get_user_data(call));
 	if (!encrypted) {
 		linphonec_out("Call %i is not fully encrypted and auth token is %s.\n", id,
 				(auth_token != NULL) ? auth_token : "absent");
@@ -334,7 +290,7 @@ static void linphonec_call_encryption_changed(LinphoneCore *lc, LinphoneCall *ca
 
 static void linphonec_call_state_changed(LinphoneCore *lc, LinphoneCall *call, LinphoneCallState st, const char *msg){
 	char *from=linphone_call_get_remote_address_as_string(call);
-	int id=VOIDPTR_TO_INT(linphone_call_get_user_pointer(call));
+	int id=VOIDPTR_TO_INT(linphone_call_get_user_data(call));
 	switch(st){
 		case LinphoneCallEnd:
 			linphonec_out("Call %i with %s ended (%s).\n", id, from, linphone_reason_to_string(linphone_call_get_reason(call)));
@@ -357,7 +313,7 @@ static void linphonec_call_state_changed(LinphoneCore *lc, LinphoneCall *call, L
 		case LinphoneCallIncomingReceived:
 			linphonec_call_identify(call);
 			linphone_call_enable_camera (call,linphonec_camera_enabled);
-			id=VOIDPTR_TO_INT(linphone_call_get_user_pointer(call));
+			id=VOIDPTR_TO_INT(linphone_call_get_user_data(call));
 			linphonec_set_caller(from);
 			linphonec_out("Receiving new incoming call from %s, assigned id %i\n", from,id);
 			if ( auto_answer)  {
@@ -373,7 +329,7 @@ static void linphonec_call_state_changed(LinphoneCore *lc, LinphoneCall *call, L
 		break;
 		case LinphoneCallOutgoingInit:
 			linphonec_call_identify(call);
-			id=VOIDPTR_TO_INT(linphone_call_get_user_pointer(call));
+			id=VOIDPTR_TO_INT(linphone_call_get_user_data(call));
 			linphonec_out("Establishing call id to %s, assigned id %i\n", from,id);
 		break;
 		case LinphoneCallUpdatedByRemote:
@@ -637,10 +593,6 @@ main (int argc, char *argv[]) {
 	linphonec_vtable.notify_presence_received = linphonec_notify_presence_received;
 	linphonec_vtable.new_subscription_requested = linphonec_new_unknown_subscriber;
 	linphonec_vtable.auth_info_requested = linphonec_prompt_for_auth;
-	linphonec_vtable.display_status = linphonec_display_status;
-	linphonec_vtable.display_message=linphonec_display_something;
-	linphonec_vtable.display_warning=linphonec_display_warning;
-	linphonec_vtable.display_url=linphonec_display_url;
 	linphonec_vtable.text_received=linphonec_text_received;
 	linphonec_vtable.dtmf_received=linphonec_dtmf_received;
 	linphonec_vtable.refer_received=linphonec_display_refer;
@@ -837,7 +789,7 @@ linphonec_prompt_for_auth_final(LinphoneCore *lc)
 	pending_auth=auth_stack.elem[auth_stack.nitems-1];
 
 	snprintf(auth_prompt, 256, "Password for %s on %s: ",
-		pending_auth->username, pending_auth->realm);
+		linphone_auth_info_get_username(pending_auth), linphone_auth_info_get_realm(pending_auth));
 
 	printf("\n");
 #ifdef HAVE_READLINE
@@ -1023,7 +975,7 @@ linphonec_idle_call ()
 	linphone_core_iterate(opm);
 	if (answer_call){
 		fprintf (stdout, "-------auto answering to call-------\n" );
-		linphone_core_accept_call(opm,NULL);
+		linphone_core_accept_call(opm, linphone_core_get_current_call(opm));
 		answer_call=FALSE;
 	}
 	/* auto call handling */
