@@ -1,41 +1,40 @@
 /*
-linphone
-Copyright (C) 2010-2014  Belledonne Communications SARL
-
-This program is free software; you can redistribute it and/or
-modify it under the terms of the GNU General Public License
-as published by the Free Software Foundation; either version 2
-of the License, or (at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-*/
+ * Copyright (c) 2010-2019 Belledonne Communications SARL.
+ *
+ * This file is part of Liblinphone.
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ */
 
+#ifndef __APPLE__ /*XOPEN_SOURCE icompilation issue  with xcode9 https://github.com/eclipse/omr/pull/1721*/
 #define _XOPEN_SOURCE 700 /*required for strptime of GNU libc*/
+#endif
 
 #include <time.h>
-#include "private.h"
 
-#ifdef SQLITE_STORAGE_ENABLED
-#ifndef _WIN32
-#if !defined(__ANDROID__) && !defined(__QNXNTO__)
-#	include <langinfo.h>
-#	include <iconv.h>
-#	include <string.h>
-#endif
-#else
-#include <Windows.h>
-#endif
+#if !defined(_WIN32) && !defined(__ANDROID__) && !defined(__QNXNTO__)
+	#include <langinfo.h>
+	#include <iconv.h>
+	#include <string.h>
+#endif // if !defined(_WIN32) && !defined(__ANDROID__) && !defined(__QNXNTO__)
 
 #define MAX_PATH_SIZE 1024
-#include "sqlite3.h"
-#endif
+
+#include "c-wrapper/c-wrapper.h"
+
+// TODO: From coreapi. Remove me later.
+#include "private.h"
 
 typedef struct _CallLogStorageResult {
 	LinphoneCore *core;
@@ -86,37 +85,37 @@ void call_logs_write_to_config_file(LinphoneCore *lc){
 	LpConfig *cfg=lc->config;
 
 	if (linphone_core_get_global_state (lc)==LinphoneGlobalStartup) return;
-	
+
 	if (lc->max_call_logs == LINPHONE_MAX_CALL_HISTORY_UNLIMITED) return;
 
 	for(i=0,elem=lc->call_logs;elem!=NULL;elem=elem->next,++i){
 		LinphoneCallLog *cl=(LinphoneCallLog*)elem->data;
 		snprintf(logsection,sizeof(logsection),"call_log_%i",i);
-		lp_config_clean_section(cfg,logsection);
-		lp_config_set_int(cfg,logsection,"dir",cl->dir);
-		lp_config_set_int(cfg,logsection,"status",cl->status);
+		linphone_config_clean_section(cfg,logsection);
+		linphone_config_set_int(cfg,logsection,"dir",cl->dir);
+		linphone_config_set_int(cfg,logsection,"status",cl->status);
 		tmp=linphone_address_as_string(cl->from);
-		lp_config_set_string(cfg,logsection,"from",tmp);
+		linphone_config_set_string(cfg,logsection,"from",tmp);
 		ms_free(tmp);
 		tmp=linphone_address_as_string(cl->to);
-		lp_config_set_string(cfg,logsection,"to",tmp);
+		linphone_config_set_string(cfg,logsection,"to",tmp);
 		ms_free(tmp);
 		if (cl->start_date_time)
-			lp_config_set_int64(cfg,logsection,"start_date_time",(int64_t)cl->start_date_time);
-		else lp_config_set_string(cfg,logsection,"start_date",cl->start_date);
-		lp_config_set_int(cfg,logsection,"duration",cl->duration);
-		if (cl->refkey) lp_config_set_string(cfg,logsection,"refkey",cl->refkey);
-		lp_config_set_float(cfg,logsection,"quality",cl->quality);
-		lp_config_set_int(cfg,logsection,"video_enabled", cl->video_enabled);
-		lp_config_set_string(cfg,logsection,"call_id",cl->call_id);
+			linphone_config_set_int64(cfg,logsection,"start_date_time",(int64_t)cl->start_date_time);
+		else linphone_config_set_string(cfg,logsection,"start_date",cl->start_date);
+		linphone_config_set_int(cfg,logsection,"duration",cl->duration);
+		if (cl->refkey) linphone_config_set_string(cfg,logsection,"refkey",cl->refkey);
+		linphone_config_set_float(cfg,logsection,"quality",cl->quality);
+		linphone_config_set_int(cfg,logsection,"video_enabled", cl->video_enabled);
+		linphone_config_set_string(cfg,logsection,"call_id",cl->call_id);
 	}
 	for(;i<lc->max_call_logs;++i){
 		snprintf(logsection,sizeof(logsection),"call_log_%i",i);
-		lp_config_clean_section(cfg,logsection);
+		linphone_config_clean_section(cfg,logsection);
 	}
 }
 
-bctbx_list_t * call_logs_read_from_config_file(LinphoneCore *lc){
+bctbx_list_t * linphone_core_read_call_logs_from_config_file(LinphoneCore *lc){
 	char logsection[32];
 	int i;
 	const char *tmp;
@@ -126,35 +125,36 @@ bctbx_list_t * call_logs_read_from_config_file(LinphoneCore *lc){
 
 	for(i=0;;++i){
 		snprintf(logsection,sizeof(logsection),"call_log_%i",i);
-		if (lp_config_has_section(cfg,logsection)){
+		if (linphone_config_has_section(cfg,logsection)){
 			LinphoneCallLog *cl;
 			LinphoneAddress *from=NULL,*to=NULL;
-			tmp=lp_config_get_string(cfg,logsection,"from",NULL);
+			tmp=linphone_config_get_string(cfg,logsection,"from",NULL);
 			if (tmp) from=linphone_address_new(tmp);
-			tmp=lp_config_get_string(cfg,logsection,"to",NULL);
+			tmp=linphone_config_get_string(cfg,logsection,"to",NULL);
 			if (tmp) to=linphone_address_new(tmp);
 			if (!from || !to)
 				continue;
-			cl=linphone_call_log_new(lp_config_get_int(cfg,logsection,"dir",0),from,to);
-			cl->status=lp_config_get_int(cfg,logsection,"status",0);
-			sec=lp_config_get_int64(cfg,logsection,"start_date_time",0);
+			cl=linphone_call_log_new(static_cast<LinphoneCallDir>(linphone_config_get_int(cfg,logsection,"dir",0)),from,to);
+			cl->status=static_cast<LinphoneCallStatus>(linphone_config_get_int(cfg,logsection,"status",0));
+			sec=(uint64_t)linphone_config_get_int64(cfg,logsection,"start_date_time",0);
 			if (sec) {
 				/*new call log format with date expressed in seconds */
 				cl->start_date_time=(time_t)sec;
 				set_call_log_date(cl,cl->start_date_time);
 			}else{
-				tmp=lp_config_get_string(cfg,logsection,"start_date",NULL);
+				tmp=linphone_config_get_string(cfg,logsection,"start_date",NULL);
 				if (tmp) {
 					strncpy(cl->start_date,tmp,sizeof(cl->start_date));
+					cl->start_date[sizeof(cl->start_date) - 1] = '\0';
 					cl->start_date_time=string_to_time(cl->start_date);
 				}
 			}
-			cl->duration=lp_config_get_int(cfg,logsection,"duration",0);
-			tmp=lp_config_get_string(cfg,logsection,"refkey",NULL);
+			cl->duration=linphone_config_get_int(cfg,logsection,"duration",0);
+			tmp=linphone_config_get_string(cfg,logsection,"refkey",NULL);
 			if (tmp) cl->refkey=ms_strdup(tmp);
-			cl->quality=lp_config_get_float(cfg,logsection,"quality",-1);
-			cl->video_enabled=lp_config_get_int(cfg,logsection,"video_enabled",0);
-			tmp=lp_config_get_string(cfg,logsection,"call_id",NULL);
+			cl->quality=linphone_config_get_float(cfg,logsection,"quality",-1);
+			cl->video_enabled=!!linphone_config_get_int(cfg,logsection,"video_enabled",0);
+			tmp=linphone_config_get_string(cfg,logsection,"call_id",NULL);
 			if (tmp) cl->call_id=ms_strdup(tmp);
 			call_logs=bctbx_list_append(call_logs,cl);
 		}else break;
@@ -167,19 +167,41 @@ bctbx_list_t * call_logs_read_from_config_file(LinphoneCore *lc){
  * Public functions                                                            *
  ******************************************************************************/
 
+LinphoneCallLog *linphone_core_create_call_log(LinphoneCore *lc, LinphoneAddress *from, LinphoneAddress *to, LinphoneCallDir dir,
+		int duration, time_t start_time, time_t connected_time, LinphoneCallStatus status, bool_t video_enabled, float quality) {
+	LinphoneCallLog *log = linphone_call_log_new(dir, linphone_address_ref(from), linphone_address_ref(to));
+
+	log->duration = duration;
+	log->start_date_time = start_time;
+	set_call_log_date(log,log->start_date_time);
+	log->connected_date_time = connected_time;
+	log->status = status;
+	log->video_enabled = video_enabled;
+	log->quality = quality;
+
+	linphone_core_store_call_log(lc, log);
+
+	return log;
+}
+
 const char *linphone_call_log_get_call_id(const LinphoneCallLog *cl){
 	return cl->call_id;
 }
 
-LinphoneCallDir linphone_call_log_get_dir(LinphoneCallLog *cl){
+void linphone_call_log_set_call_id(LinphoneCallLog *cl, const char *call_id) {
+	if (cl->call_id) bctbx_free(cl->call_id);
+	cl->call_id = call_id ? bctbx_strdup(call_id) : NULL;
+}
+
+LinphoneCallDir linphone_call_log_get_dir(const LinphoneCallLog *cl){
 	return cl->dir;
 }
 
-int linphone_call_log_get_duration(LinphoneCallLog *cl){
+int linphone_call_log_get_duration(const LinphoneCallLog *cl){
 	return cl->duration;
 }
 
-LinphoneAddress *linphone_call_log_get_from_address(LinphoneCallLog *cl){
+const LinphoneAddress *linphone_call_log_get_from_address(const LinphoneCallLog *cl){
 	return cl->from;
 }
 
@@ -187,7 +209,7 @@ const rtp_stats_t *linphone_call_log_get_local_stats(const LinphoneCallLog *cl){
 	return &cl->local_stats;
 }
 
-float linphone_call_log_get_quality(LinphoneCallLog *cl){
+float linphone_call_log_get_quality(const LinphoneCallLog *cl){
 	return cl->quality;
 }
 
@@ -195,23 +217,36 @@ const char *linphone_call_log_get_ref_key(const LinphoneCallLog *cl){
 	return cl->refkey;
 }
 
-LinphoneAddress *linphone_call_log_get_remote_address(LinphoneCallLog *cl){
+const LinphoneAddress *linphone_call_log_get_local_address(const LinphoneCallLog *cl) {
+	return (cl->dir == LinphoneCallIncoming) ? cl->to : cl->from;
+}
+
+const LinphoneAddress *linphone_call_log_get_remote_address(const LinphoneCallLog *cl){
 	return (cl->dir == LinphoneCallIncoming) ? cl->from : cl->to;
 }
 
+void linphone_call_log_set_remote_address(LinphoneCallLog *cl, LinphoneAddress * addr){
+	LinphoneAddress ** addrToChange = &cl->to;
+	linphone_address_ref(addr);
+	if (cl->dir == LinphoneCallIncoming)
+		addrToChange = &cl->from;
+	if (*addrToChange!=NULL) linphone_address_unref(*addrToChange);
+	*addrToChange = addr;
+}
+
 const rtp_stats_t *linphone_call_log_get_remote_stats(const LinphoneCallLog *cl){
 	return &cl->remote_stats;
 }
 
-time_t linphone_call_log_get_start_date(LinphoneCallLog *cl){
+time_t linphone_call_log_get_start_date(const LinphoneCallLog *cl){
 	return cl->start_date_time;
 }
 
-LinphoneCallStatus linphone_call_log_get_status(LinphoneCallLog *cl){
+LinphoneCallStatus linphone_call_log_get_status(const LinphoneCallLog *cl){
 	return cl->status;
 }
 
-LinphoneAddress *linphone_call_log_get_to_address(LinphoneCallLog *cl){
+const LinphoneAddress *linphone_call_log_get_to_address(const LinphoneCallLog *cl){
 	return cl->to;
 }
 
@@ -223,26 +258,32 @@ void linphone_call_log_set_ref_key(LinphoneCallLog *cl, const char *refkey){
 	if (refkey) cl->refkey=ms_strdup(refkey);
 }
 
-char * linphone_call_log_to_str(LinphoneCallLog *cl){
-	char *status;
+char * linphone_call_log_to_str(const LinphoneCallLog *cl){
+	const char *status;
 	char *tmp;
 	char *from=linphone_address_as_string (cl->from);
 	char *to=linphone_address_as_string (cl->to);
 	switch(cl->status){
 		case LinphoneCallAborted:
-			status=_("aborted");
+			status="aborted";
 			break;
 		case LinphoneCallSuccess:
-			status=_("completed");
+			status="completed";
 			break;
 		case LinphoneCallMissed:
-			status=_("missed");
+			status="missed";
+			break;
+		case LinphoneCallAcceptedElsewhere:
+			status="answered elsewhere";
+			break;
+		case LinphoneCallDeclinedElsewhere:
+			status="declined elsewhere";
 			break;
 		default:
-			status=_("unknown");
+			status="unknown";
 	}
-	tmp=ms_strdup_printf(_("%s at %s\nFrom: %s\nTo: %s\nStatus: %s\nDuration: %i mn %i sec\n"),
-			(cl->dir==LinphoneCallIncoming) ? _("Incoming call") : _("Outgoing call"),
+	tmp=ms_strdup_printf("%s at %s\nFrom: %s\nTo: %s\nStatus: %s\nDuration: %i mn %i sec\n",
+			(cl->dir==LinphoneCallIncoming) ? "Incoming call" : "Outgoing call",
 			cl->start_date,
 			from,
 			to,
@@ -254,15 +295,15 @@ char * linphone_call_log_to_str(LinphoneCallLog *cl){
 	return tmp;
 }
 
-bool_t linphone_call_log_video_enabled(LinphoneCallLog *cl) {
+bool_t linphone_call_log_video_enabled(const LinphoneCallLog *cl) {
 	return cl->video_enabled;
 }
 
-bool_t linphone_call_log_was_conference(LinphoneCallLog *cl) {
+bool_t linphone_call_log_was_conference(const LinphoneCallLog *cl) {
 	return cl->was_conference;
 }
 
-const LinphoneErrorInfo *linphone_call_log_get_error_info(LinphoneCallLog *cl){
+const LinphoneErrorInfo *linphone_call_log_get_error_info(const LinphoneCallLog *cl){
 	return cl->error_info;
 }
 
@@ -309,7 +350,9 @@ LinphoneCallLog * linphone_call_log_new(LinphoneCallDir dir, LinphoneAddress *fr
 	cl->start_date_time=time(NULL);
 	set_call_log_date(cl,cl->start_date_time);
 	cl->from=from;
+
 	cl->to=to;
+
 	cl->status=LinphoneCallAborted; /*default status*/
 	cl->quality=-1;
 	cl->storage_id=0;
@@ -341,8 +384,6 @@ BELLE_SIP_INSTANCIATE_VPTR(LinphoneCallLog, belle_sip_object_t,
  * SQL storage related functions                                               *
  ******************************************************************************/
 
-#ifdef SQLITE_STORAGE_ENABLED
-
 static void linphone_create_call_log_table(sqlite3* db) {
 	char* errmsg=NULL;
 	int ret;
@@ -395,7 +436,7 @@ void linphone_core_call_log_storage_init(LinphoneCore *lc) {
 	ret=_linphone_sqlite3_open(lc->logs_db_file, &db);
 	if(ret != SQLITE_OK) {
 		errmsg = sqlite3_errmsg(db);
-		ms_error("Error in the opening: %s.\n", errmsg);
+		ms_error("Error in the opening call_history_db_file(%s): %s.\n", lc->logs_db_file, errmsg);
 		sqlite3_close(db);
 		return;
 	}
@@ -418,7 +459,7 @@ void linphone_core_call_log_storage_close(LinphoneCore *lc) {
 static LinphoneCallLog * find_call_log_by_storage_id(bctbx_list_t *call_logs, unsigned int storage_id) {
 	bctbx_list_t *item;
 	for (item = call_logs; item != NULL; item = bctbx_list_next(item)) {
-		LinphoneCallLog *call_log = bctbx_list_get_data(item);
+		LinphoneCallLog *call_log = reinterpret_cast<LinphoneCallLog *>(bctbx_list_get_data(item));
 		if (call_log->storage_id == storage_id) return call_log;
 	}
 	return NULL;
@@ -455,9 +496,9 @@ static int create_call_log(void *data, int argc, char **argv, char **colName) {
 
 	from = linphone_address_new(argv[1]);
 	to = linphone_address_new(argv[2]);
-	
+
 	if (from == NULL || to == NULL) goto error;
-	
+
 	dir = (LinphoneCallDir) atoi(argv[3]);
 	log = linphone_call_log_new(dir, from, to);
 
@@ -481,7 +522,7 @@ static int create_call_log(void *data, int argc, char **argv, char **colName) {
 
 	clsres->result = bctbx_list_append(clsres->result, log);
 	return 0;
-	
+
 error:
 	if (from){
 		linphone_address_unref(from);
@@ -516,11 +557,11 @@ static int linphone_sql_request_generic(sqlite3* db, const char *stmt) {
 
 void linphone_core_store_call_log(LinphoneCore *lc, LinphoneCallLog *log) {
 	if (lc && lc->logs_db){
-		char *from, *to;
-		char *buf;
+		char *from = NULL, *to = NULL;
+		char *buf = NULL;
 
-		from = linphone_address_as_string(log->from);
-		to = linphone_address_as_string(log->to);
+		if (log->from) from = linphone_address_as_string(log->from);
+		if (log->to) to = linphone_address_as_string(log->to);
 		buf = sqlite3_mprintf("INSERT INTO call_history VALUES(NULL,%Q,%Q,%i,%i,%lld,%lld,%i,%i,%f,%Q,%Q);",
 						from,
 						to,
@@ -536,8 +577,8 @@ void linphone_core_store_call_log(LinphoneCore *lc, LinphoneCallLog *log) {
 					);
 		linphone_sql_request_generic(lc->logs_db, buf);
 		sqlite3_free(buf);
-		ms_free(from);
-		ms_free(to);
+		if (from) ms_free(from);
+		if (to) ms_free(to);
 
 		log->storage_id = (unsigned int)sqlite3_last_insert_rowid(lc->logs_db);
 	}
@@ -553,7 +594,7 @@ const bctbx_list_t *linphone_core_get_call_history(LinphoneCore *lc) {
 	CallLogStorageResult clsres;
 
 	if (!lc || lc->logs_db == NULL) return NULL;
-    if (lc->call_logs != NULL) return lc->call_logs;
+	if (lc->call_logs != NULL) return lc->call_logs;
 
 	if (lc->max_call_logs != LINPHONE_MAX_CALL_HISTORY_UNLIMITED){
 		buf = sqlite3_mprintf("SELECT * FROM call_history ORDER BY id DESC LIMIT %i", lc->max_call_logs);
@@ -581,6 +622,11 @@ void linphone_core_delete_call_history(LinphoneCore *lc) {
 	buf = sqlite3_mprintf("DELETE FROM call_history");
 	linphone_sql_request_generic(lc->logs_db, buf);
 	sqlite3_free(buf);
+
+	if (lc->call_logs) {
+		bctbx_list_free_with_data(lc->call_logs, (bctbx_list_free_func) linphone_call_log_unref);
+		lc->call_logs = NULL;
+	}
 }
 
 void linphone_core_delete_call_log(LinphoneCore *lc, LinphoneCallLog *log) {
@@ -591,6 +637,11 @@ void linphone_core_delete_call_log(LinphoneCore *lc, LinphoneCallLog *log) {
 	buf = sqlite3_mprintf("DELETE FROM call_history WHERE id = %u", log->storage_id);
 	linphone_sql_request_generic(lc->logs_db, buf);
 	sqlite3_free(buf);
+
+	if (lc->call_logs) {
+		bctbx_list_free_with_data(lc->call_logs, (bctbx_list_free_func) linphone_call_log_unref);
+		lc->call_logs = NULL;
+	}
 }
 
 int linphone_core_get_call_history_size(LinphoneCore *lc) {
@@ -599,7 +650,10 @@ int linphone_core_get_call_history_size(LinphoneCore *lc) {
 	sqlite3_stmt *selectStatement;
 	int returnValue;
 
-	if (!lc || lc->logs_db == NULL) return 0;
+	if (!lc)
+		return 0;
+	if (!lc->logs_db)
+		return (int)bctbx_list_size(lc->call_logs);
 
 	buf = sqlite3_mprintf("SELECT count(*) FROM call_history");
 	returnValue = sqlite3_prepare_v2(lc->logs_db, buf, -1, &selectStatement, NULL);
@@ -638,6 +692,45 @@ bctbx_list_t * linphone_core_get_call_history_for_address(LinphoneCore *lc, cons
 	return clsres.result;
 }
 
+bctbx_list_t *linphone_core_get_call_history_2(
+	LinphoneCore *lc,
+	const LinphoneAddress *peer_addr,
+	const LinphoneAddress *local_addr
+) {
+	char *buf;
+	char *peer_addr_str;
+	char *local_addr_str;
+	uint64_t begin, end;
+	CallLogStorageResult clsres;
+
+	if (!lc || !lc->logs_db || !peer_addr || !local_addr) return NULL;
+
+	peer_addr_str = bctbx_strdup(L_GET_CPP_PTR_FROM_C_OBJECT(peer_addr)->asStringUriOnly().c_str());
+	local_addr_str = bctbx_strdup(L_GET_CPP_PTR_FROM_C_OBJECT(local_addr)->asStringUriOnly().c_str());
+	buf = sqlite3_mprintf(
+		"SELECT * FROM call_history WHERE "
+		"(caller LIKE '%%%q%%' AND callee LIKE '%%%q%%' AND direction = 0) OR "
+		"(caller LIKE '%%%q%%' AND callee LIKE '%%%q%%' AND direction = 1) "
+		"ORDER BY id DESC",
+		local_addr_str,
+		peer_addr_str,
+		peer_addr_str,
+		local_addr_str
+	);
+
+	clsres.core = lc;
+	clsres.result = NULL;
+	begin = ortp_get_cur_time_ms();
+	linphone_sql_request_call_log(lc->logs_db, buf, &clsres);
+	end = ortp_get_cur_time_ms();
+	bctbx_message("%s(): completed in %i ms", __FUNCTION__, (int)(end - begin));
+	sqlite3_free(buf);
+	bctbx_free(peer_addr_str);
+	bctbx_free(local_addr_str);
+
+	return clsres.result;
+}
+
 LinphoneCallLog * linphone_core_get_last_outgoing_call_log(LinphoneCore *lc) {
 	char *buf;
 	uint64_t begin,end;
@@ -664,16 +757,30 @@ LinphoneCallLog * linphone_core_get_last_outgoing_call_log(LinphoneCore *lc) {
 	return result;
 }
 
-LinphoneCallLog * linphone_core_find_call_log_from_call_id(LinphoneCore *lc, const char *call_id) {
+LinphoneCallLog * linphone_core_find_call_log(LinphoneCore *lc, const char *call_id, int limit) {
 	char *buf;
 	uint64_t begin,end;
 	CallLogStorageResult clsres;
 	LinphoneCallLog* result = NULL;
 
-	if (!lc || lc->logs_db == NULL) return NULL;
+	if (!lc) return NULL;
+	if (!lc->logs_db) {
+		long i;
+		bctbx_list_t *item;
+		for (item =  lc->call_logs, i=0; item != NULL && (limit < 1 || i < limit); item = bctbx_list_next(item), i++) {
+			LinphoneCallLog *call_log = reinterpret_cast<LinphoneCallLog *>(bctbx_list_get_data(item));
+			if ( (strcmp(call_log->call_id ,call_id) == 0))
+				return linphone_call_log_ref(call_log);
+		}
+		return NULL;
+	}
 
 	/*since we want to append query parameters depending on arguments given, we use malloc instead of sqlite3_mprintf*/
-	buf = sqlite3_mprintf("SELECT * FROM call_history WHERE call_id = '%q' ORDER BY id DESC LIMIT 1", call_id);
+	if (limit > 0)  {
+		buf = sqlite3_mprintf( "WITH temp AS (SELECT * FROM call_history ORDER BY id DESC LIMIT %i) SELECT * FROM temp WHERE call_id = '%q' LIMIT 1",  limit, call_id);
+	} else {
+		buf = sqlite3_mprintf( "SELECT * FROM call_history WHERE call_id = '%q' ORDER BY id DESC LIMIT 1", call_id);
+	}
 
 	clsres.core = lc;
 	clsres.result = NULL;
@@ -690,41 +797,6 @@ LinphoneCallLog * linphone_core_find_call_log_from_call_id(LinphoneCore *lc, con
 	return result;
 }
 
-#else
-
-void linphone_core_call_log_storage_init(LinphoneCore *lc) {
-}
-
-void linphone_core_call_log_storage_close(LinphoneCore *lc) {
-}
-
-void linphone_core_store_call_log(LinphoneCore *lc, LinphoneCallLog *log) {
-}
-
-const bctbx_list_t *linphone_core_get_call_history(LinphoneCore *lc) {
-	return NULL;
-}
-
-void linphone_core_delete_call_history(LinphoneCore *lc) {
-}
-
-void linphone_core_delete_call_log(LinphoneCore *lc, LinphoneCallLog *log) {
-}
-
-int linphone_core_get_call_history_size(LinphoneCore *lc) {
-	return 0;
-}
-
-bctbx_list_t * linphone_core_get_call_history_for_address(LinphoneCore *lc, const LinphoneAddress *addr) {
-	return NULL;
-}
-
-LinphoneCallLog * linphone_core_get_last_outgoing_call_log(LinphoneCore *lc) {
-	return NULL;
-}
-
 LinphoneCallLog * linphone_core_find_call_log_from_call_id(LinphoneCore *lc, const char *call_id) {
-	return NULL;
+	return linphone_core_find_call_log(lc, call_id, -1);
 }
-
-#endif
