@@ -113,43 +113,35 @@ static void call_received(SalCallOp *h) {
 			if (chatRoom) {
 				L_GET_PRIVATE(static_pointer_cast<ServerGroupChatRoom>(chatRoom))->confirmJoining(h);
 			} else if (_linphone_core_is_conference_creation(lc, toAddr)) {
-#ifdef HAVE_ADVANCED_IM
 				linphone_address_unref(toAddr);
 				linphone_address_unref(fromAddr);
-				if (sal_address_has_param(h->getRemoteContactAddress(), "text")) {
-					string oneToOneChatRoom = L_C_TO_STRING(sal_custom_header_find(h->getRecvCustomHeaders(), "One-To-One-Chat-Room"));
-					if (oneToOneChatRoom == "true") {
-						bool_t oneToOneChatRoomEnabled = linphone_config_get_bool(linphone_core_get_config(lc), "misc", "enable_one_to_one_chat_room", TRUE);
-						if (!oneToOneChatRoomEnabled) {
-							h->decline(SalReasonNotAcceptable);
-							h->release();
-							return;
-						}
-						IdentityAddress from(h->getFrom());
-						list<IdentityAddress> identAddresses = ServerGroupChatRoom::parseResourceLists(h->getRemoteBody());
-						if (identAddresses.size() != 1) {
-							h->decline(SalReasonNotAcceptable);
-							h->release();
-							return;
-						}
-						const char *endToEndEncryptedStr = sal_custom_header_find(h->getRecvCustomHeaders(), "End-To-End-Encrypted");
-						bool encrypted = endToEndEncryptedStr && strcmp(endToEndEncryptedStr, "true") == 0;
+				string oneToOneChatRoom = L_C_TO_STRING(sal_custom_header_find(h->getRecvCustomHeaders(), "One-To-One-Chat-Room"));
+				if (oneToOneChatRoom == "true") {
+					bool_t oneToOneChatRoomEnabled = linphone_config_get_bool(linphone_core_get_config(lc), "misc", "enable_one_to_one_chat_room", TRUE);
+					if (!oneToOneChatRoomEnabled) {
+						h->decline(SalReasonNotAcceptable);
+						h->release();
+						return;
+					}
+					IdentityAddress from(h->getFrom());
+					list<IdentityAddress> identAddresses = ServerGroupChatRoom::parseResourceLists(h->getRemoteBody());
+					if (identAddresses.size() != 1) {
+						h->decline(SalReasonNotAcceptable);
+						h->release();
+						return;
+					}
+					const char *endToEndEncryptedStr = sal_custom_header_find(h->getRecvCustomHeaders(), "End-To-End-Encrypted");
+					bool encrypted = endToEndEncryptedStr && strcmp(endToEndEncryptedStr, "true") == 0;
 
-						ConferenceAddress confAddr = L_GET_PRIVATE_FROM_C_OBJECT(lc)->mainDb->findOneToOneConferenceChatRoomAddress(from, identAddresses.front(), encrypted);
-						if (confAddr.isValid()) {
-							shared_ptr<AbstractChatRoom> chatRoom = L_GET_CPP_PTR_FROM_C_OBJECT(lc)->findChatRoom(ConferenceId(confAddr, confAddr));
-							L_GET_PRIVATE(static_pointer_cast<ServerGroupChatRoom>(chatRoom))->confirmRecreation(h);
-							return;
-						}
+					ConferenceAddress confAddr = L_GET_PRIVATE_FROM_C_OBJECT(lc)->mainDb->findOneToOneConferenceChatRoomAddress(from, identAddresses.front(), encrypted);
+					if (confAddr.isValid()) {
+						shared_ptr<AbstractChatRoom> chatRoom = L_GET_CPP_PTR_FROM_C_OBJECT(lc)->findChatRoom(ConferenceId(confAddr, confAddr));
+						L_GET_PRIVATE(static_pointer_cast<ServerGroupChatRoom>(chatRoom))->confirmRecreation(h);
+						return;
 					}
-					_linphone_core_create_server_group_chat_room(lc, h);
 				}
-				// TODO: handle media conference creation if the "text" feature tag is not present
+				_linphone_core_create_server_group_chat_room(lc, h);
 				return;
-#else
-				ms_warning("Advanced IM such as group chat is disabled!");
-				return;
-#endif
 			} else {
 				//invite is for an unknown chatroom
 				h->decline(SalReasonNotFound);
@@ -157,6 +149,11 @@ static void call_received(SalCallOp *h) {
 			}
 		} else {
 			string endToEndEncrypted = L_C_TO_STRING(sal_custom_header_find(h->getRecvCustomHeaders(), "End-To-End-Encrypted"));
+			string ephemerable = L_C_TO_STRING(sal_custom_header_find(h->getRecvCustomHeaders(), "Ephemerable"));
+			string ephemeralLifeTime = L_C_TO_STRING(sal_custom_header_find(h->getRecvCustomHeaders(), "Ephemeral-Life-Time"));
+			long parsedEphemeralLifeTime = linphone_core_get_default_ephemeral_lifetime(lc);
+			if ((ephemerable == "true") && (!ephemeralLifeTime.empty())) parsedEphemeralLifeTime = stol(ephemeralLifeTime, nullptr);
+
 			const char *oneToOneChatRoomStr = sal_custom_header_find(h->getRecvCustomHeaders(), "One-To-One-Chat-Room");
 			if (oneToOneChatRoomStr && (strcmp(oneToOneChatRoomStr, "true") == 0)) {
 				list<IdentityAddress> participantList = Conference::parseResourceLists(h->getRemoteBody());
@@ -192,7 +189,9 @@ static void call_received(SalCallOp *h) {
 					h->getSubject(),
 					ConferenceId(ConferenceAddress(Address(h->getRemoteContact())), ConferenceAddress(Address(h->getTo()))),
 					h->getRemoteBody(),
-					endToEndEncrypted == "true"
+					endToEndEncrypted == "true",
+					((ephemerable == "true") && (!ephemeralLifeTime.empty())) ? AbstractChatRoom::EphemeralMode::AdminManaged : AbstractChatRoom::EphemeralMode::DeviceManaged,
+					parsedEphemeralLifeTime
 				);
 			}
 
@@ -284,7 +283,7 @@ static void call_received(SalCallOp *h) {
 		LinphonePrivate::Call::toCpp(call)->initiateIncoming();
 	} else {
 		LinphoneCallLog *calllog = linphone_core_find_call_log(lc, h->getCallId().c_str(), linphone_config_get_int(linphone_core_get_config(lc), "misc", "call_logs_search_limit", 5));
-		if (calllog && calllog->error_info && linphone_error_info_get_reason(calllog->error_info) == LinphoneReasonDeclined) {
+		if (calllog && linphone_call_log_get_status(calllog) == LinphoneCallDeclined) {
 			/* Before create a new call, check if the call log with the same callid is created.
 			   If yes, that means the call is already declined by callkit. */
 			lInfo() << "The call " << h->getCallId() <<" is already declined by callkit";
@@ -782,6 +781,7 @@ static void notify(SalSubscribeOp *op, SalSubscribeStatus st, const char *eventn
 		lev = linphone_event_new_with_out_of_dialog_op(lc,op,LinphoneSubscriptionOutgoing,eventname);
 		lev->unref_when_terminated = TRUE;
 	}
+	linphone_event_ref(lev);
 	{
 		LinphoneContent *ct = linphone_content_from_sal_body_handler(body_handler);
 		if (ct) {
@@ -798,6 +798,7 @@ static void notify(SalSubscribeOp *op, SalSubscribeStatus st, const char *eventn
 			linphone_event_set_state(lev,linphone_subscription_state_from_sal(st));
 		}
 	}
+	linphone_event_unref(lev);
 }
 
 static void subscribe_received(SalSubscribeOp *op, const char *eventname, const SalBodyHandler *body_handler){
