@@ -75,7 +75,6 @@ Conference::Conference(
 }
 
 Conference::~Conference() {
-	bctbx_list_free_with_data(mCallbacks, (void(*)(void *))belle_sip_object_unref);
 }
 
 void Conference::setInputAudioDevice(AudioDevice *audioDevice) {
@@ -237,7 +236,6 @@ bool Conference::addParticipantDevice(std::shared_ptr<LinphonePrivate::Call> cal
 			if (p->findDevice(*remoteContact, false) == nullptr) {
 				lInfo() << "Adding device with address " << remoteContact->asString() << " to participant " << p->getAddress();
 				shared_ptr<ParticipantDevice> device = p->addDevice(*remoteContact);
-				call->setConference(toC());
 				device->setSession(call->getActiveSession());
 
 				time_t creationTime = time(nullptr);
@@ -367,6 +365,10 @@ void Conference::checkIfTerminated() {
 			setState(ConferenceInterface::State::Terminated);
 		} else {
 			setState(ConferenceInterface::State::TerminationPending);
+			bool_t eventLogEnabled = linphone_config_get_bool(linphone_core_get_config(getCore()->getCCore()), "misc", "conference_event_log_enabled", TRUE );
+			if (!eventLogEnabled) {
+				setState(ConferenceInterface::State::Terminated);
+			}
 		}
 	}
 }
@@ -386,7 +388,7 @@ void Conference::setState (LinphonePrivate::ConferenceInterface::State state) {
 		LinphonePrivate::Conference::setState(state);
 		if (previousState != state) {
 			if (mStateChangedCb) {
-				mStateChangedCb(toC(), (LinphoneConferenceState)state, mUserData);
+				mStateChangedCb(toC(), (LinphoneConferenceState)state, mCbUserData);
 			}
 		}
 	}
@@ -431,35 +433,6 @@ bool Conference::removeParticipants (const std::list<std::shared_ptr<LinphonePri
 	return soFarSoGood;
 }
 
-bctbx_list_t *Conference::getCallbacksList () const {
-	return mCallbacks;
-}
-
-LinphoneConferenceCbs *Conference::getCurrentCallbacks () const{
-	return mCurrentCbs;
-}
-
-void Conference::setCurrentCallbacks (LinphoneConferenceCbs *cbs) {
-	mCurrentCbs = cbs;
-}
-
-void Conference::addCallbacks (LinphoneConferenceCbs *cbs) {
-	mCallbacks = bctbx_list_append(mCallbacks, belle_sip_object_ref(cbs));
-}
-
-void Conference::removeCallbacks (LinphoneConferenceCbs *cbs) {
-	mCallbacks = bctbx_list_remove(mCallbacks, cbs);
-	belle_sip_object_unref(cbs);
-}
-
-void *Conference::getUserData () const{
-	return userData;
-}
-
-void Conference::setUserData (void *ud) {
-	userData = ud;
-}
-
 LocalConference::LocalConference (
 	const shared_ptr<Core> &core,
 	const IdentityAddress &myAddress,
@@ -467,8 +440,8 @@ LocalConference::LocalConference (
 	const std::shared_ptr<LinphonePrivate::ConferenceParams> params) :
 	Conference(core, myAddress, listener, params){
 
-#ifdef HAVE_ADVANCED_IM
 	bool_t eventLogEnabled = linphone_config_get_bool(linphone_core_get_config(getCore()->getCCore()), "misc", "conference_event_log_enabled", TRUE );
+#ifdef HAVE_ADVANCED_IM
 	if (eventLogEnabled) {
 		eventHandler = std::make_shared<LocalAudioVideoConferenceEventHandler>(this);
 		addListener(eventHandler);
@@ -500,6 +473,10 @@ LocalConference::LocalConference (
 	setState(ConferenceInterface::State::CreationPending);
 	getMe()->setAdmin(true);
 	getMe()->setFocus(true);
+
+	if (!eventLogEnabled) {
+		setConferenceId(ConferenceId(contactAddress, contactAddress));
+	}
 }
 
 LocalConference::~LocalConference() {
@@ -534,9 +511,15 @@ void LocalConference::finalizeCreation() {
 void LocalConference::subscribeReceived (LinphoneEvent *event) {
 #ifdef HAVE_ADVANCED_IM
 	if (eventHandler) {
-		eventHandler->subscribeReceived(event, false);
+		eventHandler->subscribeReceived(event);
+		return;
+	} else {
+#endif // HAVE_ADVANCED_IM
+		lInfo() << "Unable to accept SUBSCRIBE because conference event package (RFC 4575) is disabled or the SDK was not compiled with ENABLE_ADVANCED_IM flag set to on";
+#ifdef HAVE_ADVANCED_IM
 	}
 #endif // HAVE_ADVANCED_IM
+	linphone_event_deny_subscription(event, LinphoneReasonNotAcceptable);
 }
 
 void LocalConference::setParticipantAdminStatus (const shared_ptr<Participant> &participant, bool isAdmin) {
@@ -708,6 +691,17 @@ bool LocalConference::addParticipants (const std::list<IdentityAddress> &address
 	return Conference::addParticipants(addresses);
 }
 
+int LocalConference::getParticipantDeviceVolume(const std::shared_ptr<LinphonePrivate::ParticipantDevice> & device) {
+	MS2AudioMixer * mixer = dynamic_cast<MS2AudioMixer*> (mMixerSession->getMixerByType(SalAudio));
+
+	if (mixer) {
+		MSAudioConference *conf = mixer->getAudioConference();
+		return ms_audio_conference_get_participant_volume(conf, device->getSsrc());
+	}
+
+	return AUDIOSTREAMVOLUMES_NOT_FOUND;
+}
+
 bool LocalConference::addParticipant (std::shared_ptr<LinphonePrivate::Call> call) {
 	const auto & remoteAddress = call->getRemoteAddress();
 	if (linphone_call_params_get_in_conference(linphone_call_get_current_params(call->toC()))) {
@@ -814,6 +808,14 @@ bool LocalConference::addParticipant (const IdentityAddress &participantAddress)
 	return success;
 }
 
+bool LocalConference::addParticipantDevice(std::shared_ptr<LinphonePrivate::Call> call) {
+	bool success = Conference::addParticipantDevice(call);
+	if (success) {
+		call->setConference(toC());
+	}
+	return success;
+}
+
 int LocalConference::removeParticipant (const std::shared_ptr<LinphonePrivate::CallSession> & session, const bool preserveSession) {
 	int err = 0;
 
@@ -977,6 +979,13 @@ int LocalConference::removeParticipant (const std::shared_ptr<LinphonePrivate::C
 			setState(ConferenceInterface::State::Terminated);
 		} else {
 			setState(ConferenceInterface::State::TerminationPending);
+#ifdef HAVE_ADVANCED_IM
+			if (!eventHandler) {
+#endif // HAVE_ADVANCED_IM
+				setState(ConferenceInterface::State::Terminated);
+#ifdef HAVE_ADVANCED_IM
+			}
+#endif // HAVE_ADVANCED_IM
 		}
 	}
 	
@@ -1039,6 +1048,14 @@ int LocalConference::terminate () {
 		}
 	}
 
+#ifdef HAVE_ADVANCED_IM
+	if (!eventHandler) {
+#endif // HAVE_ADVANCED_IM
+		setState(ConferenceInterface::State::Terminated);
+#ifdef HAVE_ADVANCED_IM
+	}
+#endif // HAVE_ADVANCED_IM
+
 	return 0;
 }
 
@@ -1356,6 +1373,16 @@ int RemoteConference::participantDeviceMediaChanged(const std::shared_ptr<Linpho
 	return -1;
 }
 
+int RemoteConference::getParticipantDeviceVolume(const std::shared_ptr<LinphonePrivate::ParticipantDevice> & device) {
+	AudioStream *as = getAudioStream();
+
+	if (as != nullptr) {
+		return audio_stream_get_participant_volume(as, device->getSsrc());
+	}
+
+	return AUDIOSTREAMVOLUMES_NOT_FOUND;
+}
+
 bool RemoteConference::addParticipant (const IdentityAddress &participantAddress) {
 	// Search call that matches participant session
 	const std::list<std::shared_ptr<Call>> &coreCalls = getCore()->getCalls();
@@ -1405,7 +1432,10 @@ bool RemoteConference::addParticipant (std::shared_ptr<LinphonePrivate::Call> ca
 				return true;
 			case ConferenceInterface::State::Created:
 				Conference::addParticipant(call);
-				transferToFocus(call);
+				if(focusIsReady())
+					transferToFocus(call);
+				else
+					m_pendingCalls.push_back(call);
 				return true;
 			default:
 				lError() << "Could not add call " << call << " to the conference. Bad conference state (" << Utils::toString(state) << ")";
@@ -1551,22 +1581,21 @@ bool RemoteConference::isIn () const {
 
 bool RemoteConference::focusIsReady () const {
 	LinphoneCallState focusState;
-	if (!m_focusCall)
+	if (!m_focusCall || m_focusCall->getRemoteContact().empty())
 		return false;
 	focusState = static_cast<LinphoneCallState>(m_focusCall->getState());
 	return (focusState == LinphoneCallStreamsRunning) || (focusState == LinphoneCallPaused);
 }
 
 bool RemoteConference::transferToFocus (std::shared_ptr<LinphonePrivate::Call> call) {
-	Address referToAddr(m_focusContact);
-	//std::string referToAddr(m_focusCall->getRemoteContact());
+	Address referToAddr(m_focusCall->getRemoteContact());
 	std::shared_ptr<Participant> participant = findParticipant(call->getActiveSession());
 	referToAddr.setParam("admin", Utils::toString(participant->isAdmin()));
 	if (call->transfer(referToAddr.asString()) == 0) {
 		m_transferingCalls.push_back(call);
 		return true;
 	} else {
-		lError() << "Conference: could not transfer call " << call << " to " << m_focusContact;
+		lError() << "Conference: could not transfer call " << call << " to " << referToAddr;
 		return false;
 	}
 	return false;
@@ -1714,10 +1743,20 @@ AudioStream *RemoteConference::getAudioStream(){
 	return stream ? (AudioStream*)stream->getMediaStream() : nullptr;
 }
 
-void RemoteConference::notifyReceived (const string &body) {
+void RemoteConference::multipartNotifyReceived (const Content &content) {
 #ifdef HAVE_ADVANCED_IM
 	if (eventHandler) {
-		eventHandler->notifyReceived(body);
+		eventHandler->multipartNotifyReceived(content);
+	}
+#else
+	lInfo() << "Advanced IM such as conferencing events is disabled!";
+#endif // HAVE_ADVANCED_IM
+}
+
+void RemoteConference::notifyReceived (const Content &content) {
+#ifdef HAVE_ADVANCED_IM
+	if (eventHandler) {
+		eventHandler->notifyReceived(content);
 	}
 #else
 	lInfo() << "Advanced IM such as conferencing events is disabled!";
@@ -1742,7 +1781,7 @@ void RemoteConference::onStateChanged(LinphonePrivate::ConferenceInterface::Stat
 			if (getMe()->isAdmin() && (subject.empty() == false)) {
 				session = m_focusCall->getActiveSession();
 				if (session) {
-					session->update(nullptr, subject);
+					session->update(nullptr, CallSession::UpdateMethod::Default, subject);
 				}
 			}
 			break;
@@ -1799,7 +1838,7 @@ void RemoteConference::setSubject (const std::string &subject) {
 
 	shared_ptr<CallSession> session = m_focusCall->getActiveSession();
 	if (session) {
-		session->update(nullptr, subject);
+		session->update(nullptr, CallSession::UpdateMethod::Default, subject);
 	}
 }
 
