@@ -217,6 +217,8 @@ LinphoneFriend * linphone_friend_new(void){
 	obj->vcard = NULL;
 	obj->storage_id = 0;
 	obj->rc_index = -1;
+	obj->is_starred = FALSE;
+	obj->native_uri = NULL;
 	return obj;
 }
 
@@ -459,6 +461,25 @@ void linphone_friend_add_phone_number(LinphoneFriend *lf, const char *phone) {
 	}
 }
 
+void linphone_friend_add_phone_number_with_label(LinphoneFriend *lf, LinphoneFriendPhoneNumber *phoneNumber) {
+	if (!lf || !phoneNumber) return;
+
+	const char *phone = linphone_friend_phone_number_get_phone_number(phoneNumber);
+	if (!phone) return;
+
+	if (lf->friend_list) {
+		const char *uri = linphone_friend_phone_number_to_sip_uri(lf, phone);
+		add_friend_to_list_map_if_not_in_it_yet(lf, uri);
+	}
+
+	if (linphone_core_vcard_supported()) {
+		if (!lf->vcard) {
+			linphone_friend_create_vcard(lf, phone);
+		}
+		linphone_vcard_add_phone_number_with_label(lf->vcard, phoneNumber);
+	}
+}
+
 bctbx_list_t* linphone_friend_get_phone_numbers(const LinphoneFriend *lf) {
 	if (!lf || !lf->vcard) return NULL;
 
@@ -468,10 +489,19 @@ bctbx_list_t* linphone_friend_get_phone_numbers(const LinphoneFriend *lf) {
 	return NULL;
 }
 
+bctbx_list_t* linphone_friend_get_phone_numbers_with_label(const LinphoneFriend *lf) {
+	if (!lf || !lf->vcard) return NULL;
+
+	if (linphone_core_vcard_supported()) {
+		return linphone_vcard_get_phone_numbers_with_label(lf->vcard);
+	}
+	return NULL;
+}
+
 bool_t linphone_friend_has_phone_number(const LinphoneFriend *lf, const char *phoneNumber) {
 	if (!lf || !phoneNumber) return FALSE;
 
-	LinphoneAccount *account = linphone_core_get_default_account(lf->lc); 
+	LinphoneAccount *account = linphone_core_get_default_account(lf->lc);
 	// Account can be null, both linphone_account_is_phone_number and linphone_account_normalize_phone_number can handle it
 	if (phoneNumber == NULL || !linphone_account_is_phone_number(account, phoneNumber)) {
 		ms_warning("Phone number [%s] isn't valid", phoneNumber);
@@ -523,6 +553,24 @@ void linphone_friend_remove_phone_number(LinphoneFriend *lf, const char *phone)
 	}
 }
 
+void linphone_friend_remove_phone_number_with_label(LinphoneFriend *lf, const LinphoneFriendPhoneNumber *phoneNumber) {
+	if (!lf || !phoneNumber || !lf->vcard) return;
+
+	const char *phone = linphone_friend_phone_number_get_phone_number(phoneNumber);
+	if (!phone) return;
+
+	if (lf->friend_list) {
+		const char *uri = linphone_friend_phone_number_to_sip_uri(lf, phone);
+		if (uri) {
+			remove_friend_from_list_map_if_already_in_it(lf, uri);
+		}
+	}
+
+	if (linphone_core_vcard_supported()) {
+		linphone_vcard_remove_phone_number_with_label(lf->vcard, phoneNumber);
+	}
+}
+
 LinphoneStatus linphone_friend_set_name(LinphoneFriend *lf, const char *name) {
 	if (linphone_core_vcard_supported()) {
 		if (!lf->vcard) linphone_friend_create_vcard(lf, name);
@@ -646,6 +694,7 @@ static void _linphone_friend_destroy(LinphoneFriend *lf){
 	if (lf->info!=NULL) buddy_info_free(lf->info);
 	if (lf->vcard != NULL) linphone_vcard_unref(lf->vcard);
 	if (lf->refkey != NULL) ms_free(lf->refkey);
+	if (lf->native_uri != NULL) ms_free(lf->native_uri);
 }
 
 static belle_sip_error_code _linphone_friend_marshall(belle_sip_object_t *obj, char* buff, size_t buff_size, size_t *offset) {
@@ -1168,6 +1217,7 @@ LinphoneFriend * linphone_friend_new_from_config_file(LinphoneCore *lc, int inde
 	lf->rc_index = index;
 
 	linphone_friend_set_ref_key(lf,linphone_config_get_string(config,item,"refkey",NULL));
+	linphone_friend_set_starred(lf,linphone_config_get_bool(config,item,"starred",FALSE));
 	return lf;
 }
 
@@ -1190,7 +1240,7 @@ void linphone_friend_remove(LinphoneFriend *lf) {
 				char section[50];
 				sprintf(section, "friend_%i", lf->rc_index);
 				linphone_config_clean_section(config, section);
-				linphone_config_sync(config);
+				linphone_core_config_sync(lc);
 				lf->rc_index = -1;
 			}
 		}
@@ -1402,7 +1452,6 @@ void linphone_core_friends_storage_init(LinphoneCore *lc) {
 	int ret;
 	const char *errmsg;
 	sqlite3 *db;
-	bctbx_list_t *friends_lists = NULL;
 
 	linphone_core_friends_storage_close(lc);
 
@@ -1423,18 +1472,54 @@ void linphone_core_friends_storage_init(LinphoneCore *lc) {
 
 	lc->friends_db = db;
 
+	linphone_core_friends_storage_resync_friends_lists(lc);
+}
+
+static int linphone_sql_request_generic(sqlite3* db, const char *stmt) {
+	char* errmsg = NULL;
+	int ret;
+	ret = sqlite3_exec(db, stmt, NULL, NULL, &errmsg);
+	if (ret != SQLITE_OK) {
+		ms_error("linphone_sql_request: statement %s -> error sqlite3_exec(): %s.", stmt, errmsg);
+		sqlite3_free(errmsg);
+	}
+	return ret;
+}
+
+int linphone_core_friends_storage_resync_friends_lists(LinphoneCore *lc) {
+	bctbx_list_t *friends_lists = NULL;
+	int synced_friends_lists = 0;
+
+	/**
+	 * First lets remove all the orphan friends from the DB
+	 */
+	char *buf = sqlite3_mprintf("delete from friends where friend_list_id not in (select id from friends_lists)");
+	linphone_sql_request_generic(lc->friends_db, buf);
+	sqlite3_free(buf);
+
 	friends_lists = linphone_core_fetch_friends_lists_from_db(lc);
 	if (friends_lists) {
 		const bctbx_list_t *it;
 		ms_warning("Replacing current default friend list by the one(s) from the database");
 		lc->friends_lists = bctbx_list_free_with_data(lc->friends_lists, (bctbx_list_free_func)linphone_friend_list_unref);
 
+		const char *url = linphone_config_get_string(lc->config, "misc", "contacts-vcard-list", NULL);
+
 		for (it=friends_lists;it!=NULL;it=bctbx_list_next(it)) {
 			LinphoneFriendList *list = (LinphoneFriendList *)bctbx_list_get_data(it);
+
+			const char *list_name = linphone_friend_list_get_display_name(list);
+			if (list_name && url && strcmp(url, list_name) == 0) {
+				linphone_friend_list_set_type(list, LinphoneFriendListTypeVCard4);
+			}
+
 			linphone_core_add_friend_list(lc, list);
+			synced_friends_lists++;
 		}
 		friends_lists = bctbx_list_free_with_data(friends_lists, (bctbx_list_free_func)linphone_friend_list_unref);
 	}
+
+	return synced_friends_lists;
 }
 
 void linphone_core_friends_storage_close(LinphoneCore *lc) {
@@ -1547,17 +1632,6 @@ static int linphone_sql_request_friends_list(sqlite3* db, const char *stmt, bctb
 	return ret;
 }
 
-static int linphone_sql_request_generic(sqlite3* db, const char *stmt) {
-	char* errmsg = NULL;
-	int ret;
-	ret = sqlite3_exec(db, stmt, NULL, NULL, &errmsg);
-	if (ret != SQLITE_OK) {
-		ms_error("linphone_sql_request: statement %s -> error sqlite3_exec(): %s.", stmt, errmsg);
-		sqlite3_free(errmsg);
-	}
-	return ret;
-}
-
 void linphone_core_store_friend_in_db(LinphoneCore *lc, LinphoneFriend *lf) {
 	if (lc && lc->friends_db) {
 		char *buf;
@@ -1575,6 +1649,9 @@ void linphone_core_store_friend_in_db(LinphoneCore *lc, LinphoneFriend *lf) {
 			return;
 		}
 
+		/**
+		 * The friends_list store logic is hidden into the friend store logic
+		 */
 		if (lf->friend_list->storage_id == 0) {
 			ms_warning("Trying to add a friend in db, but friend list isn't, let's do that first");
 			linphone_core_store_friends_list_in_db(lc, lf->friend_list);
@@ -1678,6 +1755,10 @@ void linphone_core_remove_friends_list_from_db(LinphoneCore *lc, LinphoneFriendL
 			return;
 		}
 
+		buf = sqlite3_mprintf("DELETE FROM friends WHERE friend_list_id in (select id from friends_lists where id = %u)", list->storage_id);
+		linphone_sql_request_generic(lc->friends_db, buf);
+		sqlite3_free(buf);
+
 		buf = sqlite3_mprintf("DELETE FROM friends_lists WHERE id = %u", list->storage_id);
 		linphone_sql_request_generic(lc->friends_db, buf);
 		sqlite3_free(buf);
@@ -1726,8 +1807,13 @@ bctbx_list_t* linphone_core_fetch_friends_from_db(LinphoneCore *lc, LinphoneFrie
 	bctbx_list_t *result = NULL;
 	bctbx_list_t *elem = NULL;
 
-	if (!lc || lc->friends_db == NULL || list == NULL) {
-		ms_warning("Either lc (or list) is NULL or friends database wasn't initialized with linphone_core_friends_storage_init() yet");
+	if (!lc) {
+		ms_warning("lc is NULL");
+		return NULL;
+	}
+
+	if (lc->friends_db == NULL) {
+		ms_warning("Friends database wasn't initialized with linphone_core_friends_storage_init() yet");
 		return NULL;
 	}
 
@@ -1758,8 +1844,13 @@ bctbx_list_t* linphone_core_fetch_friends_lists_from_db(LinphoneCore *lc) {
 	bctbx_list_t *result = NULL;
 	bctbx_list_t *elem = NULL;
 
-	if (!lc || lc->friends_db == NULL) {
-		ms_warning("Either lc is NULL or friends database wasn't initialized with linphone_core_friends_storage_init() yet");
+	if (!lc) {
+		ms_warning("lc is NULL");
+		return NULL;
+	}
+
+	if (lc->friends_db == NULL) {
+		ms_warning("Friends database wasn't initialized with linphone_core_friends_storage_init() yet");
 		return NULL;
 	}
 
@@ -1781,7 +1872,7 @@ bctbx_list_t* linphone_core_fetch_friends_lists_from_db(LinphoneCore *lc) {
 }
 
 void linphone_core_set_friends_database_path(LinphoneCore *lc, const char *path) {
-	if (!linphone_core_conference_server_enabled(lc))
+	if (!linphone_core_conference_server_enabled(lc) && L_GET_PRIVATE(lc->cppPtr)->mainDb)
 		L_GET_PRIVATE(lc->cppPtr)->mainDb->import(LinphonePrivate::MainDb::Sqlite3, path);
 
 	// TODO: Remove me later.
@@ -1969,3 +2060,60 @@ float linphone_friend_get_capability_version(const LinphoneFriend *lf, const Lin
 
 	return version;
 }
+
+void linphone_friend_set_photo(LinphoneFriend *lf, const char *picture_uri) {
+	if (!lf) return;
+
+	if (linphone_core_vcard_supported()) {
+		linphone_vcard_set_photo(lf->vcard, picture_uri);
+	}
+}
+
+const char * linphone_friend_get_photo(const LinphoneFriend *lf) {
+	if (!lf) return NULL;
+
+	if (linphone_core_vcard_supported()) {
+		return linphone_vcard_get_photo(lf->vcard);
+	}
+
+	return NULL;
+}
+
+void linphone_friend_set_starred(LinphoneFriend *lf, bool_t is_starred) {
+	if (lf) lf->is_starred = is_starred;
+}
+
+bool_t linphone_friend_get_starred(const LinphoneFriend *lf) {
+	if (!lf) return FALSE;
+	return lf->is_starred;
+}
+
+void linphone_friend_set_native_uri(LinphoneFriend *lf, const char *native_uri) {
+	if (!lf) return;
+	if (lf->native_uri) {
+		ms_free(lf->native_uri);
+		lf->native_uri = NULL;
+	}
+	if (native_uri) {
+		lf->native_uri = ms_strdup(native_uri);
+	}
+}
+
+const char * linphone_friend_get_native_uri(const LinphoneFriend *lf) {
+	if (!lf) return NULL;
+	return lf->native_uri;
+}
+
+void linphone_friend_set_organization(LinphoneFriend *lf, const char *organization) {
+	if (!lf) return;
+	if (linphone_core_vcard_supported() && lf->vcard) {
+		linphone_vcard_set_organization(lf->vcard, organization);
+	}
+}
+
+const char * linphone_friend_get_organization(const LinphoneFriend *lf) {
+	if (lf && linphone_core_vcard_supported() && lf->vcard) {
+		return linphone_vcard_get_organization(lf->vcard);
+	}
+	return NULL;
+}
\ No newline at end of file
