@@ -183,6 +183,10 @@ const LinphoneAudioDevice* linphone_conference_get_output_audio_device(const Lin
 	return NULL;
 }
 
+int linphone_conference_get_participant_device_volume(LinphoneConference *conference, LinphoneParticipantDevice *device) {
+	return MediaConference::Conference::toCpp(conference)->getParticipantDeviceVolume(ParticipantDevice::toCpp(device)->getSharedFromThis());
+}
+
 int linphone_conference_mute_microphone (LinphoneConference *conference, bool_t val) {
 	AudioControlInterface *aci = MediaConference::Conference::toCpp(conference)->getAudioControlInterface();
 	if (!aci) return -1;
@@ -346,42 +350,82 @@ LinphoneConferenceParams *linphone_conference_params_clone (const LinphoneConfer
 }
 
 void linphone_conference_params_set_audio_enabled (LinphoneConferenceParams *params, bool_t enable) {
-	ConferenceParams::toCpp(params)->enableVideo(enable ? true : false);
+	linphone_conference_params_enable_audio(params, enable);
+}
+
+void linphone_conference_params_enable_audio(LinphoneConferenceParams *params, bool_t enable) {
+	ConferenceParams::toCpp(params)->enableAudio(enable ? true : false);
 }
 
 bool_t linphone_conference_params_is_audio_enabled (const LinphoneConferenceParams *params) {
+	return linphone_conference_params_audio_enabled(params);
+}
+
+bool_t linphone_conference_params_audio_enabled(const LinphoneConferenceParams *params) {
 	return ConferenceParams::toCpp(params)->audioEnabled() ? TRUE : FALSE;
 }
 
 void linphone_conference_params_set_video_enabled (LinphoneConferenceParams *params, bool_t enable) {
+	linphone_conference_params_enable_video(params, enable);
+}
+
+void linphone_conference_params_enable_video(LinphoneConferenceParams *params, bool_t enable) {
 	ConferenceParams::toCpp(params)->enableVideo(enable ? true : false);
 }
 
 bool_t linphone_conference_params_is_video_enabled (const LinphoneConferenceParams *params) {
+	return linphone_conference_params_video_enabled(params);
+}
+
+bool_t linphone_conference_params_video_enabled(const LinphoneConferenceParams *params) {
 	return ConferenceParams::toCpp(params)->videoEnabled() ? TRUE : FALSE;
 }
 
 void linphone_conference_params_set_chat_enabled (LinphoneConferenceParams *params, bool_t enable) {
-	ConferenceParams::toCpp(params)->enableVideo(enable ? true : false);
+	linphone_conference_params_enable_chat(params, enable);
+}
+
+void linphone_conference_params_enable_chat(LinphoneConferenceParams *params, bool_t enable) {
+	ConferenceParams::toCpp(params)->enableChat(enable ? true : false);
 }
 
 bool_t linphone_conference_params_is_chat_enabled (const LinphoneConferenceParams *params) {
+	return linphone_conference_params_chat_enabled(params);
+}
+
+bool_t linphone_conference_params_chat_enabled(const LinphoneConferenceParams *params) {
 	return ConferenceParams::toCpp(params)->chatEnabled() ? TRUE : FALSE;
 }
 
 void linphone_conference_params_set_local_participant_enabled(LinphoneConferenceParams *params, bool_t enable){
+	linphone_conference_params_enable_local_participant(params, enable);
+}
+
+void linphone_conference_params_enable_local_participant(LinphoneConferenceParams *params, bool_t enable) {
 	ConferenceParams::toCpp(params)->enableLocalParticipant(!!enable);
 }
 
 bool_t linphone_conference_params_is_local_participant_enabled(const LinphoneConferenceParams *params){
+	return linphone_conference_params_local_participant_enabled(params);
+}
+
+bool_t linphone_conference_params_local_participant_enabled(const LinphoneConferenceParams *params) {
 	return ConferenceParams::toCpp(params)->localParticipantEnabled();
 }
 
 void linphone_conference_params_set_one_participant_conference_enabled(LinphoneConferenceParams *params, bool_t enable){
+	linphone_conference_params_enable_one_participant_conference(params, enable);
+}
+
+void linphone_conference_params_enable_one_participant_conference(LinphoneConferenceParams *params, bool_t enable) {
 	ConferenceParams::toCpp(params)->enableOneParticipantConference(!!enable);
 }
 
 bool_t linphone_conference_params_is_one_participant_conference_enabled(const LinphoneConferenceParams *params){
+	return linphone_conference_params_one_participant_conference_enabled(params);
+}
+
+bool_t linphone_conference_params_one_participant_conference_enabled(const LinphoneConferenceParams *params) {
 	return ConferenceParams::toCpp(params)->oneParticipantConferenceEnabled();
 }
 
