@@ -1,22 +1,21 @@
 /*
-linphone
-Copyright (C) 2012 Belledonne Communications SARL
-Yann DIORCET (yann.diorcet@linphone.org)
-
-This program is free software; you can redistribute it and/or
-modify it under the terms of the GNU General Public License
-as published by the Free Software Foundation; either version 2
-of the License, or (at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-*/
+ * Copyright (c) 2010-2019 Belledonne Communications SARL.
+ *
+ * This file is part of Liblinphone.
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ */
 
 #include "lpc2xml.h"
 #include <string.h>
@@ -31,9 +30,9 @@ static xmlChar* convert_iso_to_utf8(const char *in) {
 	int ret, size, out_size, temp;
 	xmlCharEncodingHandlerPtr handler;
 
-	size = (int)strlen(in) + 1; 
-	out_size = size * 2 - 1; 
-	out = ms_malloc((size_t)out_size); 
+	size = (int)strlen(in) + 1;
+	out_size = size * 2 - 1;
+	out = reinterpret_cast<xmlChar *>(ms_malloc((size_t)out_size));
 
 	if (out) {
 		handler = xmlFindCharEncodingHandler(ISO_ENCODING);
@@ -41,19 +40,19 @@ static xmlChar* convert_iso_to_utf8(const char *in) {
 			ms_free(out);
 			return NULL;
 		}
-		
+
 		temp = size-1;
 		ret = handler->input(out, &out_size, (const xmlChar *)in, &temp);
 		if (ret < 0 || temp - size + 1) {
 			ms_free(out);
 			return NULL;
 		} else {
-			out = ms_realloc(out, out_size + 1); 
+			out = reinterpret_cast<xmlChar *>(ms_realloc(out, (size_t)out_size + 1));
 			out[out_size] = '\0';
 		}
 	}
 	return out;
-}	
+}
 
 struct _lpc2xml_context {
 	const LpConfig *lpc;
@@ -93,7 +92,7 @@ static void lpc2xml_context_clear_logs(lpc2xml_context *ctx) {
 	ctx->warningBuffer[0]='\0';
 }
 
-static void lpc2xml_log(lpc2xml_context *xmlCtx, int level, const char *fmt, ...) {
+static void lpc2xml_log(lpc2xml_context *xmlCtx, lpc2xml_log_level level, const char *fmt, ...) {
 	va_list args;
 	va_start(args, fmt);
 	if(xmlCtx->cbf != NULL) {
@@ -123,7 +122,7 @@ static void lpc2xml_genericxml_warning(void *ctx, const char *fmt, ...) {
 */
 
 static int processEntry(const char *section, const char *entry, xmlNode *node, lpc2xml_context *ctx) {
-	const char *content = lp_config_get_string(ctx->lpc, section, entry, NULL);
+	const char *content = linphone_config_get_string(ctx->lpc, section, entry, NULL);
 	xmlChar *converted_content = NULL;
 	if (content == NULL) {
 		lpc2xml_log(ctx, LPC2XML_ERROR, "Issue when reading the lpc");
@@ -131,7 +130,7 @@ static int processEntry(const char *section, const char *entry, xmlNode *node, l
 	}
 	lpc2xml_log(ctx, LPC2XML_MESSAGE, "Set %s|%s = %s", section, entry, content);
 	converted_content = convert_iso_to_utf8(content);
-	
+
 	if (converted_content) {
 		// xmlNodeSetContent expects special characters to be escaped, xmlNodeAddContent doesn't (and escapes what needs to be)
 		xmlNodeSetContent(node, (const xmlChar *) "");
@@ -142,8 +141,8 @@ static int processEntry(const char *section, const char *entry, xmlNode *node, l
 		xmlNodeSetContent(node, (const xmlChar *) "");
 		xmlNodeAddContent(node, (const xmlChar *) content);
 	}
-	
-	if (lp_config_get_overwrite_flag_for_entry(ctx->lpc, section, entry) || lp_config_get_overwrite_flag_for_section(ctx->lpc, section)) {
+
+	if (linphone_config_get_overwrite_flag_for_entry(ctx->lpc, section, entry) || linphone_config_get_overwrite_flag_for_section(ctx->lpc, section)) {
 		xmlSetProp(node, (const xmlChar *)"overwrite", (const xmlChar *) "true");
 	}
 	return 0;
@@ -166,8 +165,8 @@ static void processSection_cb(const char *entry, struct __processSectionCtx *ctx
 			ctx->ret = 0;
 			return;
 		}
-		
-		if (lp_config_get_skip_flag_for_entry(ctx->ctx->lpc, ctx->section, entry)) {
+
+		if (linphone_config_get_skip_flag_for_entry(ctx->ctx->lpc, ctx->section, entry)) {
 			lpc2xml_log(ctx->ctx, LPC2XML_WARNING, "Skipped entry %s", entry);
 			ctx->ret = 0;
 			return;
@@ -192,7 +191,7 @@ static void processSection_cb(const char *entry, struct __processSectionCtx *ctx
 
 static int processSection(const char *section, xmlNode *node, lpc2xml_context *ctx) {
 	struct __processSectionCtx pc_ctx = {0, section, node, ctx};
-	lp_config_for_each_entry(ctx->lpc, section, (void (*)(const char *, void *))processSection_cb, (void*)&pc_ctx);
+	linphone_config_for_each_entry(ctx->lpc, section, (void (*)(const char *, void *))processSection_cb, (void*)&pc_ctx);
 	return pc_ctx.ret;
 }
 
@@ -208,13 +207,13 @@ static void processConfig_cb(const char *section, struct __processConfigCtx *ctx
 	if(ctx->ret == 0) {
 		xmlNode *node;
 		xmlAttr *name_attr;
-		
-		if (lp_config_get_skip_flag_for_section(ctx->ctx->lpc, section)) {
+
+		if (linphone_config_get_skip_flag_for_section(ctx->ctx->lpc, section)) {
 			lpc2xml_log(ctx->ctx, LPC2XML_WARNING, "Skipped section %s", section);
 			ctx->ret = 0;
 			return;
 		}
-		
+
 		node = xmlNewChild(ctx->node, NULL, (const xmlChar *)"section", NULL);
 		if(node == NULL) {
 			lpc2xml_log(ctx->ctx, LPC2XML_ERROR, "Can't create \"section\" element");
@@ -233,7 +232,7 @@ static void processConfig_cb(const char *section, struct __processConfigCtx *ctx
 
 static int processConfig(xmlNode *node, lpc2xml_context *ctx) {
 	struct __processConfigCtx pc_ctx = {0, node, ctx};
-	lp_config_for_each_section(ctx->lpc, (void (*)(const char *, void *))processConfig_cb, (void*)&pc_ctx);
+	linphone_config_for_each_section(ctx->lpc, (void (*)(const char *, void *))processConfig_cb, (void*)&pc_ctx);
 	return pc_ctx.ret;
 }
 
@@ -299,7 +298,7 @@ int lpc2xml_convert_file(lpc2xml_context* context, const char *filename) {
 	if(save_ctx != NULL) {
 		ret = internal_convert_lpc2xml(context);
 		if(ret == 0) {
-			ret = xmlSaveDoc(save_ctx, context->doc);
+			ret = (int)xmlSaveDoc(save_ctx, context->doc);
 			if(ret != 0) {
 				lpc2xml_log(context, LPC2XML_ERROR, "Can't save document");
 				lpc2xml_log(context, LPC2XML_ERROR, "%s", context->errorBuffer);
@@ -322,7 +321,7 @@ int lpc2xml_convert_fd(lpc2xml_context* context, int fd) {
 	if(save_ctx != NULL) {
 		ret = internal_convert_lpc2xml(context);
 		if(ret == 0) {
-			ret = xmlSaveDoc(save_ctx, context->doc);
+			ret = (int)xmlSaveDoc(save_ctx, context->doc);
 			if(ret != 0) {
 				lpc2xml_log(context, LPC2XML_ERROR, "Can't save document");
 				lpc2xml_log(context, LPC2XML_ERROR, "%s", context->errorBuffer);
@@ -346,7 +345,7 @@ int lpc2xml_convert_string(lpc2xml_context* context, char **content) {
 	if(save_ctx != NULL) {
 		ret = internal_convert_lpc2xml(context);
 		if(ret == 0) {
-			ret = xmlSaveDoc(save_ctx, context->doc);
+			ret = (int)xmlSaveDoc(save_ctx, context->doc);
 			if(ret != 0) {
 				lpc2xml_log(context, LPC2XML_ERROR, "Can't save document");
 				lpc2xml_log(context, LPC2XML_ERROR, "%s", context->errorBuffer);
