@@ -57,6 +57,7 @@ struct _LinphoneCallLog{
 	LinphoneErrorInfo *error_info;
 	bool_t video_enabled;
 	bool_t was_conference; /**<That call was a call with a conference server */
+	bool_t early_aborted;
 };
 
 BELLE_SIP_DECLARE_VPTR_NO_EXPORT(LinphoneCallLog);
@@ -122,6 +123,8 @@ struct _LinphoneFriend{
 	LinphoneSubscriptionState out_sub_state;
 	int capabilities;
 	int rc_index;
+	bool_t is_starred;
+	char *native_uri;
 };
 
 BELLE_SIP_DECLARE_VPTR_NO_EXPORT(LinphoneFriend);
@@ -160,6 +163,7 @@ struct _LinphoneFriendList {
 	LinphoneFriendListCbs *currentCbs;
 	bool_t enable_subscriptions;
 	bool_t bodyless_subscription;
+	LinphoneFriendListType type;
 };
 
 BELLE_SIP_DECLARE_VPTR_NO_EXPORT(LinphoneFriendList);
@@ -259,6 +263,7 @@ struct sound_config
 	bool_t ea;
 	bool_t agc;
 	bool_t disable_record_on_mute;
+	bool_t mic_enabled;
 };
 
 struct codecs_config
@@ -362,7 +367,7 @@ struct _LinphoneEvent{
 	LinphoneAddress *to_address;
 	LinphoneAddress *from_address;
 	LinphoneAddress *remote_contact_address;
-	
+
 	int expires;
 	bool_t terminating;
 	bool_t is_out_of_dialog_op; /*used for out of dialog notify*/
@@ -569,6 +574,8 @@ struct _LinphonePlayer{
 	void (*destroy)(LinphonePlayer *player);
 	void (*set_window_id)(LinphonePlayer *player, void* window_id);
 	bool_t (*is_video_available)(LinphonePlayer *player);
+	void (*set_volume_gain)(LinphonePlayer *player, float gain);
+	float (*get_volume_gain)(const LinphonePlayer *player);
 	void *impl;
 	LinphonePlayerCbs *callbacks; // Deprecated, use a list of Cbs instead
 	LinphoneCore *core;
@@ -776,6 +783,8 @@ namespace LinphonePrivate {
 	belle_http_provider_t *http_provider; \
 	belle_tls_crypto_config_t *http_crypto_config; \
 	belle_http_request_listener_t *provisioning_http_listener; \
+	belle_http_request_listener_t *base_contacts_list_http_listener; \
+	LinphoneFriendList *base_contacts_list_for_synchronization; \
 	MSList *tones; \
 	LinphoneReason chat_deny_code; \
 	char *file_transfer_server; \
@@ -787,6 +796,8 @@ namespace LinphonePrivate {
 	bool_t zrtp_not_available_simulation; \
 	char *tls_cert; \
 	char *tls_key; \
+	char *ephemeral_version; \
+	char *groupchat_version; \
 	LinphoneAddress *default_rls_addr; \
 	LinphoneImEncryptionEngine *im_encryption_engine; \
 	struct _LinphoneAccountCreatorService *default_ac_service; \
@@ -801,7 +812,11 @@ namespace LinphonePrivate {
 	bool_t has_already_started_once; \
 	bool_t send_imdn_if_unregistered; \
 	LinphonePushNotificationConfig *push_config;\
-	unsigned long iterate_thread_id;
+	bool_t auto_download_incoming_voice_recordings; \
+	bool_t auto_download_incoming_icalendars; \
+	unsigned long iterate_thread_id; \
+	bool_t record_aware; \
+	bool_t auto_send_ringing;
 
 #define LINPHONE_CORE_STRUCT_FIELDS \
 	LINPHONE_CORE_STRUCT_BASE_FIELDS \
