@@ -1,28 +1,32 @@
 /*
-linphone
-Copyright (C) 2014 - Belledonne Communications, Grenoble, France
-
-This program is free software; you can redistribute it and/or
-modify it under the terms of the GNU General Public License
-as published by the Free Software Foundation; either version 2
-of the License, or (at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-*/
+ * Copyright (c) 2010-2019 Belledonne Communications SARL.
+ *
+ * This file is part of Liblinphone.
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
+#include "linphone/api/c-content.h"
 #include "linphone/core.h"
+
 #include "private.h"
+#include "c-wrapper/internal/c-sal.h"
+#include "sal/sal_media_description.h"
 #include "sal/sal.h"
 #include "ortp/rtpsession.h"
 
@@ -32,19 +36,29 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include <sys/sysctl.h>
 #endif
 
+#include <memory>
+
+// For migration purpose.
+#include "address/address.h"
+#include "c-wrapper/c-wrapper.h"
+#include "call/call.h"
+#include "conference/session/media-session-p.h"
+
 #define STR_REASSIGN(dest, src) {\
 	if (dest != NULL) \
 		ms_free(dest); \
 	dest = src; \
 }
 
+using namespace LinphonePrivate;
+
 /*since printf family functions are LOCALE dependent, float separator may differ
 depending on the user's locale (LC_NUMERIC environment var).*/
 static char * float_to_one_decimal_string(float f) {
 	float rounded_f = floorf(f * 10 + .5f) / 10;
 
 	int floor_part = (int) rounded_f;
-	int one_decimal_part = (int)floorf(10 * (rounded_f - floor_part) + .5f);
+	int one_decimal_part = (int)floorf(10 * (rounded_f - (float)floor_part) + .5f);
 
 	return ms_strdup_printf("%d.%d", floor_part, one_decimal_part);
 }
@@ -150,20 +164,24 @@ static uint8_t are_metrics_filled(const reporting_content_metrics_t *rm) {
 }
 
 static bool_t quality_reporting_enabled(const LinphoneCall * call) {
-	return (call->dest_proxy != NULL && linphone_proxy_config_quality_reporting_enabled(call->dest_proxy));
+	return (Call::toCpp(call)->getDestProxy()
+		&& linphone_proxy_config_quality_reporting_enabled(Call::toCpp(call)->getDestProxy()));
 }
 
 static bool_t media_report_enabled(LinphoneCall * call, int stats_type){
-	if (! quality_reporting_enabled(call))
+	if (!quality_reporting_enabled(call))
 		return FALSE;
 
-	if (stats_type == LINPHONE_CALL_STATS_VIDEO && !linphone_call_params_video_enabled(linphone_call_get_current_params(call)))
-		return FALSE;
+	if (stats_type == LINPHONE_CALL_STATS_VIDEO){
+		if (!(Call::toCpp(call)->getLog()->reporting.was_video_running
+			|| linphone_call_params_video_enabled(linphone_call_get_current_params(call))) )
+			return FALSE;
+	}
 
 	if (stats_type == LINPHONE_CALL_STATS_TEXT && !linphone_call_params_realtime_text_enabled(linphone_call_get_current_params(call)))
 		return FALSE;
 
-	return (call->log->reporting.reports[stats_type] != NULL);
+	return (Call::toCpp(call)->getLog()->reporting.reports[stats_type] != NULL);
 }
 
 static void append_metrics_to_buffer(char ** buffer, size_t * size, size_t * offset, const reporting_content_metrics_t *rm) {
@@ -272,6 +290,7 @@ static int send_report(LinphoneCall* call, reporting_session_report_t * report,
 	LinphoneAddress *request_uri;
 	const char* collector_uri;
 	char *collector_uri_allocated = NULL;
+	const SalAddress *salAddress;
 
 	/*if we are on a low bandwidth network, do not send reports to not overload it*/
 	if (linphone_call_params_low_bandwidth_enabled(linphone_call_get_current_params(call))){
@@ -337,40 +356,40 @@ static int send_report(LinphoneCall* call, reporting_session_report_t * report,
 		size_t namesize;
 		char *machine;
 		sysctlbyname("hw.machine", NULL, &namesize, NULL, 0);
-		machine = malloc(namesize);
+		machine = reinterpret_cast<char *>(malloc(namesize));
 		sysctlbyname("hw.machine", machine, &namesize, NULL, 0);
 		APPEND_IF_NOT_NULL_STR(&buffer, &size, &offset, "Device: %s\r\n", machine);
 	}
 #endif
 
-	linphone_content_set_buffer(content, buffer, strlen(buffer));
+	linphone_content_set_buffer(content, (uint8_t *)buffer, strlen(buffer));
 	ms_free(buffer);
 
-	if (call->log->reporting.on_report_sent != NULL) {
-		SalStreamType type = report == call->log->reporting.reports[0] ? LINPHONE_CALL_STATS_AUDIO : report == call->log->reporting.reports[1] ? LINPHONE_CALL_STATS_VIDEO : LINPHONE_CALL_STATS_TEXT;
-		call->log->reporting.on_report_sent(call, type, content);
+	if (linphone_call_get_call_log(call)->reporting.on_report_sent != NULL) {
+		SalStreamType type = report == linphone_call_get_call_log(call)->reporting.reports[0] ? SalAudio : report == linphone_call_get_call_log(call)->reporting.reports[1] ? SalVideo : SalText;
+		linphone_call_get_call_log(call)->reporting.on_report_sent(call, type, content);
 	}
 
 
-	collector_uri = linphone_proxy_config_get_quality_reporting_collector(call->dest_proxy);
+	collector_uri = linphone_proxy_config_get_quality_reporting_collector(linphone_call_get_dest_proxy(call));
 	if (!collector_uri){
-		collector_uri = collector_uri_allocated = ms_strdup_printf("sip:%s", linphone_proxy_config_get_domain(call->dest_proxy));
+		collector_uri = collector_uri_allocated = ms_strdup_printf("sip:%s", linphone_proxy_config_get_domain(linphone_call_get_dest_proxy(call)));
 	}
 	request_uri = linphone_address_new(collector_uri);
-	lev = linphone_core_create_one_shot_publish(call->core, request_uri, "vq-rtcpxr");
+	lev = linphone_core_create_one_shot_publish(linphone_call_get_core(call), request_uri, "vq-rtcpxr");
 	/* Special exception for quality report PUBLISH: if the collector_uri has any transport related parameters
 	 * (port, transport, maddr), then it is sent directly.
 	 * Otherwise it is routed as any LinphoneEvent publish, following proxy config policy.
 	 **/
-	if (sal_address_has_uri_param((SalAddress*)request_uri, "transport") || 
-		sal_address_has_uri_param((SalAddress*)request_uri, "maddr") ||
+	salAddress = L_GET_CPP_PTR_FROM_C_OBJECT(request_uri)->getInternalAddress();
+	if (sal_address_has_uri_param(salAddress, "transport") ||
+		sal_address_has_uri_param(salAddress, "maddr") ||
 		linphone_address_get_port(request_uri) != 0) {
 		ms_message("Publishing report with custom route %s", collector_uri);
-		sal_op_set_route(lev->op, collector_uri);
+		lev->op->setRoute(collector_uri);
 	}
 
 	if (linphone_event_send_publish(lev, content) != 0){
-		lev=NULL;
 		ret=4;
 	} else {
 		reset_avg_metrics(report);
@@ -380,7 +399,7 @@ static int send_report(LinphoneCall* call, reporting_session_report_t * report,
 		STR_REASSIGN(report->qos_analyzer.output_leg, NULL);
 		STR_REASSIGN(report->qos_analyzer.output, NULL);
 	}
-
+	linphone_event_unref(lev);
 	linphone_address_unref(request_uri);
 	linphone_content_unref(content);
 	if (collector_uri_allocated) ms_free(collector_uri_allocated);
@@ -395,12 +414,11 @@ static int send_report(LinphoneCall* call, reporting_session_report_t * report,
 	return ret;
 }
 
-static const SalStreamDescription * get_media_stream_for_desc(const SalMediaDescription * smd, SalStreamType sal_stream_type) {
-	int count;
+static const LinphonePrivate::SalStreamDescription * get_media_stream_for_desc(const std::shared_ptr<LinphonePrivate::SalMediaDescription> & smd, SalStreamType sal_stream_type) {
 	if (smd != NULL) {
-		for (count = 0; count < SAL_MEDIA_DESCRIPTION_MAX_STREAMS; ++count) {
-			if (sal_stream_description_active(&smd->streams[count]) && smd->streams[count].type == sal_stream_type) {
-				return &smd->streams[count];
+		for (const auto & stream : smd->streams) {
+			if (stream.enabled() && stream.type == sal_stream_type) {
+				return &stream;
 			}
 		}
 	}
@@ -409,27 +427,28 @@ static const SalStreamDescription * get_media_stream_for_desc(const SalMediaDesc
 
 static void update_ip(LinphoneCall * call, int stats_type) {
 	SalStreamType sal_stream_type = stats_type == LINPHONE_CALL_STATS_AUDIO ? SalAudio : stats_type == LINPHONE_CALL_STATS_VIDEO ? SalVideo : SalText;
-	const SalStreamDescription * local_desc = get_media_stream_for_desc(call->localdesc, sal_stream_type);
-	const SalStreamDescription * remote_desc = get_media_stream_for_desc(sal_call_get_remote_media_description(call->op), sal_stream_type);
+	const LinphonePrivate::SalStreamDescription * local_desc = get_media_stream_for_desc(Call::toCpp(call)->getOp()->getLocalMediaDescription(), sal_stream_type);
+	const LinphonePrivate::SalStreamDescription * remote_desc = get_media_stream_for_desc(Call::toCpp(call)->getOp()->getRemoteMediaDescription(), sal_stream_type);
+	LinphoneCallLog *log = Call::toCpp(call)->getLog();
 
 	if (local_desc != NULL) {
 		/*since this function might be called for video stream AFTER it has been uninitialized, local description might
 		be invalid. In any other case, IP/port should be always filled and valid*/
-		if (strlen(local_desc->rtp_addr) > 0) {
-			call->log->reporting.reports[stats_type]->info.local_addr.port = local_desc->rtp_port;
-			STR_REASSIGN(call->log->reporting.reports[stats_type]->info.local_addr.ip, ms_strdup(local_desc->rtp_addr));
+		if (local_desc->rtp_addr.empty() == false) {
+			log->reporting.reports[stats_type]->info.local_addr.port = local_desc->rtp_port;
+			STR_REASSIGN(log->reporting.reports[stats_type]->info.local_addr.ip, ms_strdup(L_STRING_TO_C(local_desc->rtp_addr)));
 		}
 	}
 
 	if (remote_desc != NULL) {
 		/*port is always stored in stream description struct*/
-		call->log->reporting.reports[stats_type]->info.remote_addr.port = remote_desc->rtp_port;
+		log->reporting.reports[stats_type]->info.remote_addr.port = remote_desc->rtp_port;
 
 		/*for IP it can be not set if we are using a direct route*/
-		if (strlen(remote_desc->rtp_addr) > 0) {
-			STR_REASSIGN(call->log->reporting.reports[stats_type]->info.remote_addr.ip, ms_strdup(remote_desc->rtp_addr));
+		if (remote_desc->rtp_addr.empty() == false) {
+			STR_REASSIGN(log->reporting.reports[stats_type]->info.remote_addr.ip, ms_strdup(L_STRING_TO_C(remote_desc->rtp_addr)));
 		} else {
-			STR_REASSIGN(call->log->reporting.reports[stats_type]->info.remote_addr.ip, ms_strdup(sal_call_get_remote_media_description(call->op)->addr));
+			STR_REASSIGN(log->reporting.reports[stats_type]->info.remote_addr.ip, ms_strdup(L_STRING_TO_C(Call::toCpp(call)->getOp()->getRemoteMediaDescription()->addr)));
 		}
 	}
 }
@@ -443,7 +462,7 @@ static void qos_analyzer_on_action_suggested(void *user_data, int datac, const c
 	int bitrate[3] = {-1, -1, -1};
 	int up_bw[3] = {-1, -1, -1};
 	int down_bw[3] = {-1, -1, -1};
-	MediaStream *streams[3] = { (MediaStream*) call->audiostream, (MediaStream *) call->videostream, (MediaStream *) call->textstream };
+	MediaStream *streams[3] = { linphone_call_get_stream(call, LinphoneStreamTypeAudio), linphone_call_get_stream(call, LinphoneStreamTypeVideo), linphone_call_get_stream(call, LinphoneStreamTypeText) };
 	for (i = 0; i < 3; i++){
 		if (streams[i] != NULL){
 			if (streams[i]->encoder != NULL){
@@ -456,15 +475,16 @@ static void qos_analyzer_on_action_suggested(void *user_data, int datac, const c
 			down_bw[i] = (int)(media_stream_get_down_bw(streams[i])/1000.f);
 		}
 	}
-	if (call->audiostream!=NULL){
-		if (call->audiostream->ms.encoder!=NULL){
-			if(ms_filter_has_method(call->audiostream->ms.encoder,MS_AUDIO_ENCODER_GET_PTIME)){
-				ms_filter_call_method(call->audiostream->ms.encoder,MS_AUDIO_ENCODER_GET_PTIME,&ptime);
+	AudioStream *astream = reinterpret_cast<AudioStream *>(linphone_call_get_stream(call, LinphoneStreamTypeAudio));
+	if (astream!=NULL){
+		if (astream->ms.encoder!=NULL){
+			if(ms_filter_has_method(astream->ms.encoder,MS_AUDIO_ENCODER_GET_PTIME)){
+				ms_filter_call_method(astream->ms.encoder,MS_AUDIO_ENCODER_GET_PTIME,&ptime);
 			}
 		}
 	}
 
-	appendbuf=ms_strdup_printf("%s%d;", report->qos_analyzer.timestamp?report->qos_analyzer.timestamp:"", ms_time(0));
+	appendbuf=ms_strdup_printf("%s%llu;", report->qos_analyzer.timestamp?report->qos_analyzer.timestamp:"", (unsigned long long)ms_time(0));
 	STR_REASSIGN(report->qos_analyzer.timestamp,appendbuf);
 
 	STR_REASSIGN(report->qos_analyzer.input_leg, ms_strdup_printf("%s aenc_ptime aenc_br a_dbw a_ubw venc_br v_dbw v_ubw tenc_br t_dbw t_ubw", datav[0]));
@@ -487,67 +507,67 @@ void linphone_reporting_update_media_info(LinphoneCall * call, int stats_type) {
 	const PayloadType * local_payload = NULL;
 	const PayloadType * remote_payload = NULL;
 	const LinphoneCallParams * current_params = linphone_call_get_current_params(call);
-	reporting_session_report_t * report = call->log->reporting.reports[stats_type];
-	char * dialog_id;
+	LinphoneCallLog *log = Call::toCpp(call)->getLog();
+	reporting_session_report_t * report = log->reporting.reports[stats_type];
 
 	// call->op might be already released if hanging up in state LinphoneCallOutgoingInit
-	if (!media_report_enabled(call, stats_type) || call->op == NULL)
+	if (!media_report_enabled(call, stats_type) || !Call::toCpp(call)->getOp())
 		return;
 
-	dialog_id = sal_op_get_dialog_id(call->op);
+	std::string dialogId = Call::toCpp(call)->getOp()->getDialogId();
 
-	STR_REASSIGN(report->info.call_id, ms_strdup(call->log->call_id));
+	STR_REASSIGN(report->info.call_id, ms_strdup(log->call_id));
 
-	STR_REASSIGN(report->local_metrics.user_agent, ms_strdup(linphone_core_get_user_agent(call->core)));
+	STR_REASSIGN(report->local_metrics.user_agent, ms_strdup(linphone_core_get_user_agent(linphone_call_get_core(call))));
 	STR_REASSIGN(report->remote_metrics.user_agent, ms_strdup(linphone_call_get_remote_user_agent(call)));
 
 	// RFC states: "LocalGroupID provides the identification for the purposes
 	// of aggregation for the local endpoint.".
 	STR_REASSIGN(report->info.local_addr.group, ms_strdup_printf("%s-%s-%s"
-		, dialog_id ? dialog_id : ""
+		, dialogId.c_str()
 		, "local"
 		, report->local_metrics.user_agent ? report->local_metrics.user_agent : ""
 		)
 	);
 	STR_REASSIGN(report->info.remote_addr.group, ms_strdup_printf("%s-%s-%s"
-		, dialog_id ? dialog_id : ""
+		, dialogId.c_str()
 		, "remote"
 		, report->remote_metrics.user_agent ? report->remote_metrics.user_agent : ""
 		)
 	);
 
 
-	if (call->dir == LinphoneCallIncoming) {
-		STR_REASSIGN(report->info.remote_addr.id, linphone_address_as_string(call->log->from));
-		STR_REASSIGN(report->info.local_addr.id, linphone_address_as_string(call->log->to));
+	if (Call::toCpp(call)->getDirection() == LinphoneCallIncoming) {
+		STR_REASSIGN(report->info.remote_addr.id, linphone_address_as_string(log->from));
+		STR_REASSIGN(report->info.local_addr.id, linphone_address_as_string(log->to));
 		STR_REASSIGN(report->info.orig_id, ms_strdup(report->info.remote_addr.id));
 	} else {
-		STR_REASSIGN(report->info.remote_addr.id, linphone_address_as_string(call->log->to));
-		STR_REASSIGN(report->info.local_addr.id, linphone_address_as_string(call->log->from));
+		STR_REASSIGN(report->info.remote_addr.id, linphone_address_as_string(log->to));
+		STR_REASSIGN(report->info.local_addr.id, linphone_address_as_string(log->from));
 		STR_REASSIGN(report->info.orig_id, ms_strdup(report->info.local_addr.id));
 	}
 
 
-	report->local_metrics.timestamps.start = call->log->start_date_time;
-	report->local_metrics.timestamps.stop = call->log->start_date_time + linphone_call_get_duration(call);
+	report->local_metrics.timestamps.start = log->start_date_time;
+	report->local_metrics.timestamps.stop = log->start_date_time + linphone_call_get_duration(call);
 
 	/*we use same timestamps for remote too*/
-	report->remote_metrics.timestamps.start = call->log->start_date_time;
-	report->remote_metrics.timestamps.stop = call->log->start_date_time + linphone_call_get_duration(call);
+	report->remote_metrics.timestamps.start = log->start_date_time;
+	report->remote_metrics.timestamps.stop = log->start_date_time + linphone_call_get_duration(call);
 
 
 	/*yet we use the same payload config for local and remote, since this is the largest use case*/
-	if (stats_type == LINPHONE_CALL_STATS_AUDIO && call->audiostream != NULL) {
-		stream = &call->audiostream->ms;
-		local_payload = current_params->audio_codec;
+	if (stats_type == LINPHONE_CALL_STATS_AUDIO && Call::toCpp(call)->getMediaStream(LinphoneStreamTypeAudio)) {
+		stream = Call::toCpp(call)->getMediaStream(LinphoneStreamTypeAudio);
+		local_payload = linphone_call_params_get_used_audio_codec(current_params);
 		remote_payload = local_payload;
-	} else if (stats_type == LINPHONE_CALL_STATS_VIDEO && call->videostream != NULL) {
-		stream = &call->videostream->ms;
-		local_payload = current_params->video_codec;
+	} else if (stats_type == LINPHONE_CALL_STATS_VIDEO && Call::toCpp(call)->getMediaStream(LinphoneStreamTypeVideo)) {
+		stream = Call::toCpp(call)->getMediaStream(LinphoneStreamTypeVideo);
+		local_payload = linphone_call_params_get_used_video_codec(current_params);
 		remote_payload = local_payload;
-	} else if (stats_type == LINPHONE_CALL_STATS_TEXT && call->textstream != NULL) {
-		stream = &call->textstream->ms;
-		local_payload = current_params->text_codec;
+	} else if (stats_type == LINPHONE_CALL_STATS_TEXT && Call::toCpp(call)->getMediaStream(LinphoneStreamTypeText)) {
+		stream = Call::toCpp(call)->getMediaStream(LinphoneStreamTypeText);
+		local_payload = linphone_call_params_get_used_text_codec(current_params);
 		remote_payload = local_payload;
 	}
 
@@ -565,7 +585,7 @@ void linphone_reporting_update_media_info(LinphoneCall * call, int stats_type) {
 		}
 	}
 
-	STR_REASSIGN(report->dialog_id, ms_strdup_printf("%s;%u", dialog_id ? dialog_id : "", report->info.local_addr.ssrc));
+	STR_REASSIGN(report->dialog_id, ms_strdup_printf("%s;%u", dialogId.c_str(), report->info.local_addr.ssrc));
 
 	if (local_payload != NULL) {
 		report->local_metrics.session_description.payload_type = local_payload->type;
@@ -580,41 +600,39 @@ void linphone_reporting_update_media_info(LinphoneCall * call, int stats_type) {
 		report->remote_metrics.session_description.sample_rate = remote_payload->clock_rate;
 		STR_REASSIGN(report->remote_metrics.session_description.fmtp, ms_strdup(remote_payload->recv_fmtp));
 	}
-
-	ms_free(dialog_id);
 }
 
 /* generate random float in interval ] 0.9 t ; 1.1 t [*/
 static float reporting_rand(float t){
-	return t * (.2f * (rand() / (RAND_MAX * 1.0f)) + 0.9f);
+	return t * (.2f * ((float)rand() / (float)RAND_MAX) + 0.9f);
 }
 
 void linphone_reporting_on_rtcp_update(LinphoneCall *call, SalStreamType stats_type) {
-	reporting_session_report_t * report = call->log->reporting.reports[stats_type];
+	reporting_session_report_t * report = Call::toCpp(call)->getLog()->reporting.reports[stats_type];
 	reporting_content_metrics_t * metrics = NULL;
 	LinphoneCallStats *stats = NULL;
 	mblk_t *block = NULL;
 	int report_interval;
 
 	if (stats_type == 0) {
-		stats = call->audio_stats;
+		stats = Call::toCpp(call)->getPrivateStats(LinphoneStreamTypeAudio);
 	} else if (stats_type == 1) {
-		stats = call->video_stats;
+		stats = Call::toCpp(call)->getPrivateStats(LinphoneStreamTypeVideo);
 	} else {
-		stats = call->text_stats;
+		stats = Call::toCpp(call)->getPrivateStats(LinphoneStreamTypeText);
 	}
 
 	if (! media_report_enabled(call,stats_type))
 		return;
 
-	report_interval = linphone_proxy_config_get_quality_reporting_interval(call->dest_proxy);
+	report_interval = linphone_proxy_config_get_quality_reporting_interval(Call::toCpp(call)->getDestProxy());
 
-	if (stats->updated == LINPHONE_CALL_STATS_RECEIVED_RTCP_UPDATE) {
+	if (_linphone_call_stats_get_updated(stats) == LINPHONE_CALL_STATS_RECEIVED_RTCP_UPDATE) {
 		metrics = &report->remote_metrics;
-		block = stats->received_rtcp;
-	} else if (stats->updated == LINPHONE_CALL_STATS_SENT_RTCP_UPDATE) {
+		block = _linphone_call_stats_get_received_rtcp(stats);
+	} else if (_linphone_call_stats_get_updated(stats) == LINPHONE_CALL_STATS_SENT_RTCP_UPDATE) {
 		metrics = &report->local_metrics;
-		block = stats->sent_rtcp;
+		block = _linphone_call_stats_get_sent_rtcp(stats);
 	}
 	do{
 		if (rtcp_is_XR(block) && (rtcp_XR_get_block_type(block) == RTCP_XR_VOIP_METRICS)){
@@ -625,7 +643,7 @@ void linphone_reporting_on_rtcp_update(LinphoneCall *call, SalStreamType stats_t
 
 			// for local mos rating, we'll use the quality indicator directly
 			// because rtcp XR might not be enabled
-			if (stats->updated == LINPHONE_CALL_STATS_RECEIVED_RTCP_UPDATE){
+			if (_linphone_call_stats_get_updated(stats) == LINPHONE_CALL_STATS_RECEIVED_RTCP_UPDATE){
 				metrics->quality_estimates.moslq = (rtcp_XR_voip_metrics_get_mos_lq(block)==127) ?
 					127 : rtcp_XR_voip_metrics_get_mos_lq(block) / 10.f;
 				metrics->quality_estimates.moscq = (rtcp_XR_voip_metrics_get_mos_cq(block)==127) ?
@@ -643,7 +661,9 @@ void linphone_reporting_on_rtcp_update(LinphoneCall *call, SalStreamType stats_t
 
 			metrics->delay.round_trip_delay += rtcp_XR_voip_metrics_get_round_trip_delay(block);
 		}else if (rtcp_is_SR(block)){
-			MediaStream *ms=(stats_type==0 ? &call->audiostream->ms : &call->videostream->ms);
+			MediaStream *ms = (stats_type == 0)
+				? Call::toCpp(call)->getMediaStream(LinphoneStreamTypeAudio)
+			: Call::toCpp(call)->getMediaStream(LinphoneStreamTypeVideo);
 			float rtt = rtp_session_get_round_trip_propagation(ms->sessions.rtp_session);
 
 			if (rtt > 1e-6){
@@ -663,25 +683,24 @@ void linphone_reporting_on_rtcp_update(LinphoneCall *call, SalStreamType stats_t
 
 static int publish_report(LinphoneCall *call, const char *event_type){
 	int ret = 0;
-	int i;
-	for (i = 0; i < SAL_MEDIA_DESCRIPTION_MAX_STREAMS; i++){
-		int stream_index = i == call->main_audio_stream_index ? LINPHONE_CALL_STATS_AUDIO : call->main_video_stream_index ? LINPHONE_CALL_STATS_VIDEO : LINPHONE_CALL_STATS_TEXT;
+	for (const auto & idx : { _linphone_call_get_main_audio_stream_index(call), _linphone_call_get_main_video_stream_index(call), _linphone_call_get_main_text_stream_index(call) }) {
+		int stream_index = idx == _linphone_call_get_main_audio_stream_index(call) ? LINPHONE_CALL_STATS_AUDIO : _linphone_call_get_main_video_stream_index(call) ? LINPHONE_CALL_STATS_VIDEO : LINPHONE_CALL_STATS_TEXT;
 		if (media_report_enabled(call, stream_index)) {
 			int sndret;
 			linphone_reporting_update_media_info(call, stream_index);
-			sndret=send_report(call, call->log->reporting.reports[stream_index], event_type);
+			sndret=send_report(call, Call::toCpp(call)->getLog()->reporting.reports[stream_index], event_type);
 			if (sndret>0){
-				ret += 10+(i+1)*sndret;
+				ret += 10+(idx+1)*sndret;
 			}
 		} else{
-			ret += i+1;
+			ret += idx+1;
 		}
 	}
 	return ret;
 }
 
 int linphone_reporting_publish_session_report(LinphoneCall* call, bool_t call_term) {
-	char * session_type = call_term?"VQSessionReport: CallTerm":"VQSessionReport";
+	const char * session_type = call_term?"VQSessionReport: CallTerm":"VQSessionReport";
 	return publish_report(call, session_type);
 }
 
@@ -704,32 +723,35 @@ static bool_t set_on_action_suggested_cb(MediaStream *stream,void (*on_action_su
 
 void linphone_reporting_call_state_updated(LinphoneCall *call){
 	LinphoneCallState state=linphone_call_get_state(call);
+	LinphoneCallLog *log = Call::toCpp(call)->getLog();
 	if (state == LinphoneCallReleased||!quality_reporting_enabled(call)){
 		return;
 	}
 	switch (state){
 		case LinphoneCallStreamsRunning:{
-			int i = 0;
-			MediaStream *streams[3] = { (MediaStream*) call->audiostream, (MediaStream *) call->videostream, (MediaStream *) call->textstream };
-			for (i = 0; i < SAL_MEDIA_DESCRIPTION_MAX_STREAMS; i++) {
-				int stream_index = i == call->main_audio_stream_index ? LINPHONE_CALL_STATS_AUDIO : call->main_video_stream_index ? LINPHONE_CALL_STATS_VIDEO : LINPHONE_CALL_STATS_TEXT;
+			MediaStream *streams[3] = {
+				Call::toCpp(call)->getMediaStream(LinphoneStreamTypeAudio),
+				Call::toCpp(call)->getMediaStream(LinphoneStreamTypeVideo),
+				Call::toCpp(call)->getMediaStream(LinphoneStreamTypeText)
+			};
+			for (const auto & stream_index : { LINPHONE_CALL_STATS_AUDIO, LINPHONE_CALL_STATS_VIDEO, LINPHONE_CALL_STATS_TEXT }) {
 				bool_t enabled = media_report_enabled(call, stream_index);
-				if (enabled && set_on_action_suggested_cb(streams[stream_index], qos_analyzer_on_action_suggested, call->log->reporting.reports[stream_index])) {
-					call->log->reporting.reports[stream_index]->call=call;
-					STR_REASSIGN(call->log->reporting.reports[stream_index]->qos_analyzer.name, ms_strdup(ms_qos_analyzer_get_name(ms_bitrate_controller_get_qos_analyzer(streams[stream_index]->rc))));
+				if (enabled && set_on_action_suggested_cb(streams[stream_index], qos_analyzer_on_action_suggested, log->reporting.reports[stream_index])) {
+					log->reporting.reports[stream_index]->call=call;
+					STR_REASSIGN(log->reporting.reports[stream_index]->qos_analyzer.name, ms_strdup(ms_qos_analyzer_get_name(ms_bitrate_controller_get_qos_analyzer(streams[stream_index]->rc))));
 				}
 			}
 			linphone_reporting_update_ip(call);
-			if (!media_report_enabled(call, LINPHONE_CALL_STATS_VIDEO) && call->log->reporting.was_video_running){
-				send_report(call, call->log->reporting.reports[LINPHONE_CALL_STATS_VIDEO], "VQSessionReport");
+			if (media_report_enabled(call, LINPHONE_CALL_STATS_VIDEO) && log->reporting.was_video_running){
+				send_report(call, log->reporting.reports[LINPHONE_CALL_STATS_VIDEO], "VQSessionReport");
 			}
-			call->log->reporting.was_video_running=media_report_enabled(call, LINPHONE_CALL_STATS_VIDEO);
+			log->reporting.was_video_running = linphone_call_params_video_enabled(linphone_call_get_current_params(call));
 			break;
 		}
 		case LinphoneCallEnd:{
-			set_on_action_suggested_cb(&call->audiostream->ms, NULL, NULL);
-			set_on_action_suggested_cb(&call->videostream->ms, NULL, NULL);
-			if (call->log->status==LinphoneCallSuccess || call->log->status==LinphoneCallAborted){
+			set_on_action_suggested_cb(Call::toCpp(call)->getMediaStream(LinphoneStreamTypeAudio), NULL, NULL);
+			set_on_action_suggested_cb(Call::toCpp(call)->getMediaStream(LinphoneStreamTypeVideo), NULL, NULL);
+			if (log->status==LinphoneCallSuccess || log->status==LinphoneCallAborted){
 				linphone_reporting_publish_session_report(call, TRUE);
 			}
 			break;
@@ -802,5 +824,5 @@ void linphone_reporting_destroy(reporting_session_report_t * report) {
 
 
 void linphone_reporting_set_on_report_send(LinphoneCall *call, LinphoneQualityReportingReportSendCb cb){
-	call->log->reporting.on_report_sent = cb;
+	linphone_call_get_call_log(call)->reporting.on_report_sent = cb;
 }
