@@ -1,25 +1,25 @@
 /*
-sqlite3_bctbx_vfs.c
-Copyright (C) 2016 Belledonne Communications SARL
+ * Copyright (c) 2010-2019 Belledonne Communications SARL.
+ *
+ * This file is part of Liblinphone.
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ */
 
-This program is free software; you can redistribute it and/or
-modify it under the terms of the GNU General Public License
-as published by the Free Software Foundation; either version 2
-of the License, or (at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-*/
-
-#ifdef SQLITE_STORAGE_ENABLED
 #include "private.h"
 
+#include "bctoolbox/charconv.h"
 #include "sqlite3_bctbx_vfs.h"
 #include <sqlite3.h>
 
@@ -28,17 +28,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #endif /*_WIN32_WCE*/
 
 
-#ifndef _WIN32
-#if !defined(__QNXNTO__) && !defined(__ANDROID__)
-#	include <langinfo.h>
-#	include <locale.h>
-#	include <iconv.h>
-#	include <string.h>
-#endif
-
-#endif
-
-
 /**
  * Closes the file whose file descriptor is stored in the file handle p.
  * @param  p 	sqlite3_file file handle pointer.
@@ -77,13 +66,13 @@ static int sqlite3bctbx_Read(sqlite3_file *p, void *buf, int count, sqlite_int64
 	int ret;
 	sqlite3_bctbx_file_t *pFile = (sqlite3_bctbx_file_t*) p;
 	if (pFile){
-		ret = bctbx_file_read(pFile->pbctbx_file, buf, count, (off_t)offset);
+		ret = (int)bctbx_file_read(pFile->pbctbx_file, buf, (size_t)count, (off_t)offset);
 		if( ret==count ){
 			return SQLITE_OK;
 		}
 		else if( ret >= 0 ){
 			/*fill in unread portion of buffer, as requested by sqlite3 documentation*/
-			memset(((uint8_t*)buf) + ret, 0, count-ret);
+			memset(((uint8_t*)buf) + ret, 0, (size_t)(count-ret));
 			return SQLITE_IOERR_SHORT_READ;
 		}else {
 
@@ -106,7 +95,7 @@ static int sqlite3bctbx_Write(sqlite3_file *p, const void *buf, int count, sqlit
 	sqlite3_bctbx_file_t *pFile = (sqlite3_bctbx_file_t*) p;
 	int ret;
 	if (pFile ){
-		ret = bctbx_file_write(pFile->pbctbx_file, buf, count, (off_t)offset);
+		ret = (int)bctbx_file_write(pFile->pbctbx_file, buf, (size_t)count, (off_t)offset);
 		if(ret > 0 ) return SQLITE_OK;
 		else {
 			return SQLITE_IOERR_WRITE;
@@ -119,11 +108,11 @@ static int sqlite3bctbx_Write(sqlite3_file *p, const void *buf, int count, sqlit
  * TRuncates or extends a file depending on the size provided.
  * @param  p    sqlite3_file file handle pointer.
  * @param  size New file size.
- * @return  SQLITE_OK on success, SQLITE_IOERR_TRUNCATE if an error occurred during truncate,	
- *          SQLITE_ERROR if ther was a problem on the file descriptor.    
+ * @return  SQLITE_OK on success, SQLITE_IOERR_TRUNCATE if an error occurred during truncate,
+ *          SQLITE_ERROR if ther was a problem on the file descriptor.
  */
 static int sqlite3bctbx_Truncate(sqlite3_file *p, sqlite_int64 size){
-	int rc;                        
+	int rc;
 	sqlite3_bctbx_file_t *pFile = (sqlite3_bctbx_file_t*) p;
 	if (pFile->pbctbx_file){
 		rc = bctbx_file_truncate(pFile->pbctbx_file, size);
@@ -240,73 +229,12 @@ static int sqlite3bctbx_nolockUnlock(sqlite3_file *pUnused, int unused){
  */
 static int sqlite3bctbx_Sync(sqlite3_file *p, int flags){
 	sqlite3_bctbx_file_t *pFile = (sqlite3_bctbx_file_t*)p;
-#if _WIN32
-	int ret;
-	ret = FlushFileBuffers((HANDLE)_get_osfhandle(pFile->pbctbx_file->fd));
-	return (ret!=0 ? SQLITE_OK : SQLITE_IOERR_FSYNC);
-#else
-	int rc = fsync(pFile->pbctbx_file->fd);
-	return (rc==0 ? SQLITE_OK : SQLITE_IOERR_FSYNC);
-#endif
+	int ret = bctbx_file_sync(pFile->pbctbx_file);
+	return (ret==BCTBX_VFS_OK ? SQLITE_OK : SQLITE_IOERR_FSYNC);
 }
 
 /************************ END OF PLACE HOLDER FUNCTIONS ***********************/
 
-
-
-static char* ConvertFromUtf8Filename(const char* fName){
-#if _WIN32
-	char* convertedFilename;
-	int nChar, nb_byte;
-	LPWSTR wideFilename;
-	
-	nChar = MultiByteToWideChar(CP_UTF8, 0, fName, -1, NULL, 0);
-	if (nChar == 0) return NULL;
-	wideFilename = bctbx_malloc(nChar*sizeof(wideFilename[0]));
-	if (wideFilename == NULL) return NULL;
-	nChar = MultiByteToWideChar(CP_UTF8, 0, fName, -1, wideFilename, nChar);
-	if (nChar == 0) {
-		bctbx_free(wideFilename);
-		wideFilename = 0;
-	}
-	
-	nb_byte = WideCharToMultiByte(CP_ACP, 0, wideFilename, -1, 0, 0, 0, 0);
-	if (nb_byte == 0) return NULL;
-	convertedFilename = bctbx_malloc(nb_byte);
-	if (convertedFilename == NULL) return NULL;
-	nb_byte = WideCharToMultiByte(CP_ACP, 0, wideFilename, -1, convertedFilename, nb_byte, 0, 0);
-	if (nb_byte == 0) {
-		bctbx_free(convertedFilename);
-		convertedFilename = 0;
-	}
-	bctbx_free(wideFilename);
-	return convertedFilename;
-#elif defined(__QNXNTO__) || defined(__ANDROID__)
-	return bctbx_strdup(fName);
-#else
-	#define MAX_PATH_SIZE 1024
-	char db_file_utf8[MAX_PATH_SIZE] = {'\0'};
-	char db_file_locale[MAX_PATH_SIZE] = "";
-	char *outbuf=db_file_locale, *inbuf=db_file_utf8;
-	size_t inbyteleft = MAX_PATH_SIZE, outbyteleft = MAX_PATH_SIZE;
-	iconv_t cb;
-	
-	if (strcasecmp("UTF-8", nl_langinfo(CODESET)) == 0) {
-		strncpy(db_file_locale, fName, MAX_PATH_SIZE - 1);
-	} else {
-		strncpy(db_file_utf8, fName, MAX_PATH_SIZE-1);
-		cb = iconv_open(nl_langinfo(CODESET), "UTF-8");
-		if (cb != (iconv_t)-1) {
-			int ret;
-			ret = iconv(cb, &inbuf, &inbyteleft, &outbuf, &outbyteleft);
-			if(ret == -1) db_file_locale[0] = '\0';
-			iconv_close(cb);
-		}
-	}
-	return bctbx_strdup(db_file_locale);
-#endif
-}
-
 /**
  * Opens the file fName and populates the structure pointed by p
  * with the necessary io_methods
@@ -346,7 +274,7 @@ static  int sqlite3bctbx_Open(sqlite3_vfs *pVfs, const char *fName, sqlite3_file
 	if (pFile == NULL || fName == NULL){
 		return SQLITE_IOERR;
 	}
-	
+
 	/* Set flags  to open the file with */
 	if( flags&SQLITE_OPEN_EXCLUSIVE ) openFlags  |= O_EXCL;
 	if( flags&SQLITE_OPEN_CREATE )    openFlags |= O_CREAT;
@@ -356,14 +284,14 @@ static  int sqlite3bctbx_Open(sqlite3_vfs *pVfs, const char *fName, sqlite3_file
 #if defined(_WIN32)
 	openFlags |= O_BINARY;
 #endif
-	wFname = ConvertFromUtf8Filename(fName);
+	wFname = bctbx_utf8_to_locale(fName);
 	if (wFname != NULL) {
 		pFile->pbctbx_file = bctbx_file_open2(bctbx_vfs_get_default(), wFname, openFlags);
 		bctbx_free(wFname);
 	} else {
 		pFile->pbctbx_file = NULL;
 	}
-	
+
 	if( pFile->pbctbx_file == NULL){
 		return SQLITE_CANTOPEN;
 	}
@@ -384,7 +312,7 @@ sqlite3_vfs *sqlite3_bctbx_vfs_create(void){
     sizeof(sqlite3_bctbx_file_t),	/* szOsFile */
     MAXPATHNAME,					/* mxPathname */
     NULL,							/* pNext */
-    LINPHONE_SQLITE3_VFS,			/* zName */
+    BCTBX_SQLITE3_VFS,			/* zName */
     NULL,							/* pAppData */
     sqlite3bctbx_Open,				/* xOpen */
     NULL,							/* xDelete */
@@ -445,7 +373,7 @@ void sqlite3_bctbx_vfs_register( int makeDefault){
 	sqlite3_vfs* pDefault = sqlite3_vfs_find("unix-none");
 	#endif
 	pVfsToUse->xCurrentTime = pDefault->xCurrentTime;
-	
+
 	pVfsToUse->xAccess =  pDefault->xAccess;
 	pVfsToUse->xFullPathname = pDefault->xFullPathname;
 
@@ -470,8 +398,6 @@ void sqlite3_bctbx_vfs_register( int makeDefault){
 
 void sqlite3_bctbx_vfs_unregister(void)
 {
-	sqlite3_vfs* pVfs = sqlite3_vfs_find(LINPHONE_SQLITE3_VFS);
+	sqlite3_vfs* pVfs = sqlite3_vfs_find(BCTBX_SQLITE3_VFS);
 	sqlite3_vfs_unregister(pVfs);
 }
-
-#endif /*SQLITE_STORAGE_ENABLED*/
