@@ -298,6 +298,11 @@ void linphone_core_notify_network_reachable(LinphoneCore *lc, bool_t reachable)
 	cleanup_dead_vtable_refs(lc);
 }
 
+void linphone_core_notify_notify_sent(LinphoneCore *lc, LinphoneEvent *lev, const LinphoneContent *body) {
+	NOTIFY_IF_EXIST(notify_sent, lc, lev, body);
+	cleanup_dead_vtable_refs(lc);
+}
+
 void linphone_core_notify_notify_received(LinphoneCore *lc, LinphoneEvent *lev, const char *notified_event, const LinphoneContent *body) {
 	NOTIFY_IF_EXIST_INTERNAL(notify_received, linphone_event_is_internal(lev), lc, lev, notified_event, body);
 	cleanup_dead_vtable_refs(lc);
@@ -398,6 +403,21 @@ void linphone_core_notify_chat_room_exhumed(LinphoneCore *lc, LinphoneChatRoom *
 	cleanup_dead_vtable_refs(lc);
 }
 
+void linphone_core_notify_conference_info_on_participant_sent(LinphoneCore *lc, const LinphoneConferenceInfo *conference_info, const LinphoneAddress *address) {
+	NOTIFY_IF_EXIST(conference_info_on_participant_sent, lc, conference_info, address);
+	cleanup_dead_vtable_refs(lc);
+}
+
+void linphone_core_notify_conference_info_on_participant_error(LinphoneCore *lc, const LinphoneConferenceInfo *conference_info, const LinphoneAddress *address, LinphoneConferenceInfoError error) {
+	NOTIFY_IF_EXIST(conference_info_on_participant_error, lc, conference_info, address, error);
+	cleanup_dead_vtable_refs(lc);
+}
+
+void linphone_core_notify_conference_info_on_sent(LinphoneCore *lc, const LinphoneConferenceInfo *conference_info) {
+	NOTIFY_IF_EXIST(conference_info_on_sent, lc, conference_info);
+	cleanup_dead_vtable_refs(lc);
+}
+
 static VTableReference * v_table_reference_new(LinphoneCoreCbs *cbs, bool_t internal){
 	VTableReference *ref=ms_new0(VTableReference,1);
 	ref->valid=TRUE;
