@@ -1,30 +1,34 @@
 /*
-linphone
-Copyright (C) 2010-2015 Belledonne Communications SARL
-
-This program is free software; you can redistribute it and/or
-modify it under the terms of the GNU General Public License
-as published by the Free Software Foundation; either version 2
-of the License, or (at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-*/
-
-#include "linphone/core.h"
-#include "private.h"
+ * Copyright (c) 2010-2019 Belledonne Communications SARL.
+ *
+ * This file is part of Liblinphone.
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ */
 
 #include <string.h>
 #include <libxml/tree.h>
 #include <libxml/xmlwriter.h>
 
+#include "linphone/core.h"
 
+#include "c-wrapper/c-wrapper.h"
+#include "linphone/api/c-auth-info.h"
+
+
+// TODO: From coreapi. Remove me later.
+#include "private.h"
 
 BELLE_SIP_DECLARE_NO_IMPLEMENTED_INTERFACES(LinphoneXmlRpcRequestCbs);
 
@@ -35,7 +39,7 @@ BELLE_SIP_INSTANCIATE_VPTR(LinphoneXmlRpcRequestCbs, belle_sip_object_t,
 	FALSE
 );
 
-static LinphoneXmlRpcRequestCbs * linphone_xml_rpc_request_cbs_new(void) {
+LinphoneXmlRpcRequestCbs * linphone_xml_rpc_request_cbs_new(void) {
 	return belle_sip_object_new(LinphoneXmlRpcRequestCbs);
 }
 
@@ -64,6 +68,16 @@ void linphone_xml_rpc_request_cbs_set_response(LinphoneXmlRpcRequestCbs *cbs, Li
 	cbs->response = cb;
 }
 
+#define NOTIFY_IF_EXIST(cbName, functionName, ...) \
+	bctbx_list_t *callbacksCopy = bctbx_list_copy(linphone_xml_rpc_request_get_callbacks_list(request)); \
+	for (bctbx_list_t *it = callbacksCopy; it; it = bctbx_list_next(it)) { \
+		linphone_xml_rpc_request_set_current_callbacks(request, reinterpret_cast<LinphoneXmlRpcRequestCbs *>(bctbx_list_get_data(it))); \
+		LinphoneXmlRpcRequestCbs ## cbName ## Cb cb = linphone_xml_rpc_request_cbs_get_ ## functionName (linphone_xml_rpc_request_get_current_callbacks(request)); \
+		if (cb) \
+			cb(__VA_ARGS__); \
+	} \
+	linphone_xml_rpc_request_set_current_callbacks(request, nullptr); \
+	bctbx_list_free(callbacksCopy);
 
 static void format_request(LinphoneXmlRpcRequest *request) {
 	char si[64];
@@ -112,6 +126,9 @@ static void format_request(LinphoneXmlRpcRequest *request) {
 		switch (arg->type) {
 			case LinphoneXmlRpcArgNone:
 				break;
+			case LinphoneXmlRpcArgStringStruct:
+				ms_error("String struct not yet supported as argument");
+				break;
 			case LinphoneXmlRpcArgInt:
 				memset(si, 0, sizeof(si));
 				snprintf(si, sizeof(si), "%i", arg->data.i);
@@ -171,23 +188,24 @@ static void process_io_error_from_post_xml_rpc_request(void *data, const belle_s
 	ms_error("I/O Error during XML-RPC request sending");
 	if (!linphone_xml_rpc_request_aborted(request)){
 		request->status = LinphoneXmlRpcStatusFailed;
-			if (request->callbacks->response != NULL) {
+		if (request->callbacks->response != NULL) {
 			request->callbacks->response(request);
 		}
+		NOTIFY_IF_EXIST(Response, response, request)
 	}
 	linphone_xml_rpc_request_unref(request);
 }
 
 static void process_auth_requested_from_post_xml_rpc_request(void *data, belle_sip_auth_event_t *event) {
 	LinphoneXmlRpcRequest *request = (LinphoneXmlRpcRequest *)data;
-	ms_error("Authentication error during XML-RPC request sending");
-	if (!linphone_xml_rpc_request_aborted(request)){
-		request->status = LinphoneXmlRpcStatusFailed;
-		if (request->callbacks->response != NULL) {
-			request->callbacks->response(request);
-		}
-	}
-	linphone_xml_rpc_request_unref(request);
+
+	const char *realm = belle_sip_auth_event_get_realm(event);
+	const char *username = belle_sip_auth_event_get_username(event);
+	const char *domain = belle_sip_auth_event_get_domain(event);
+	const char *algorithm = belle_sip_auth_event_get_algorithm(event);
+
+	const LinphoneAuthInfo *auth_info = _linphone_core_find_auth_info(request->core, realm, username, domain, algorithm, TRUE);
+	linphone_auth_info_fill_belle_sip_event(auth_info, event);
 }
 
 static void parse_valid_xml_rpc_response(LinphoneXmlRpcRequest *request, const char *response_body) {
@@ -196,7 +214,7 @@ static void parse_valid_xml_rpc_response(LinphoneXmlRpcRequest *request, const c
 	request->status = LinphoneXmlRpcStatusFailed;
 	xml_ctx->doc = xmlReadDoc((const unsigned char*)response_body, 0, NULL, 0);
 	if (xml_ctx->doc != NULL) {
-		const char *response_str = NULL;
+		char *response_str = NULL;
 		if (linphone_create_xml_xpath_context(xml_ctx) < 0) goto end;
 		switch (request->response.type) {
 			case LinphoneXmlRpcArgInt:
@@ -213,6 +231,43 @@ static void parse_valid_xml_rpc_response(LinphoneXmlRpcRequest *request, const c
 					request->status = LinphoneXmlRpcStatusOk;
 				}
 				break;
+			case LinphoneXmlRpcArgStringStruct:
+			{
+				response_str = linphone_get_xml_text_content(xml_ctx, "/methodResponse/params/param/value/string");
+				if (response_str != NULL) {
+					request->response.data.s = belle_sip_strdup(response_str);
+				} else {
+					xmlXPathObjectPtr responses = linphone_get_xml_xpath_object_for_node_list(xml_ctx, "/methodResponse/params/param/value/struct/member");
+					if (responses != NULL && responses->nodesetval != NULL) {
+						//request->response.data.m = bctbx_mmap_cchar_new();
+						request->response.data.l = NULL;
+						request->status = LinphoneXmlRpcStatusOk;
+
+						xmlNodeSetPtr responses_nodes = responses->nodesetval;
+						if (responses_nodes->nodeNr >= 1) {
+							int i;
+							for (i = 0; i < responses_nodes->nodeNr; i++) {
+								xmlNodePtr response_node = responses_nodes->nodeTab[i];
+								xml_ctx->xpath_ctx->node = response_node;
+								{
+									char *name = linphone_get_xml_text_content(xml_ctx, "name");
+									char *value =  linphone_get_xml_text_content(xml_ctx, "value/string");
+									ms_message("Found pair with key=[%s] and value=[%s]", name, value);
+									request->response.data.l = bctbx_list_append(request->response.data.l, bctbx_strdup(value));
+
+									/*bctbx_pair_t *pair = (bctbx_pair_t*) bctbx_pair_cchar_new(name, (void *)bctbx_strdup(value));
+									bctbx_map_cchar_insert_and_delete(request->response.data.m, pair);*/
+
+									linphone_free_xml_text_content(name);
+									linphone_free_xml_text_content(value);
+								}
+							}
+						}
+						xmlXPathFreeObject(responses);
+					}
+				}
+				break;
+			}
 			default:
 				break;
 		}
@@ -225,6 +280,7 @@ end:
 	if (request->callbacks->response != NULL) {
 		request->callbacks->response(request);
 	}
+	NOTIFY_IF_EXIST(Response, response, request)
 }
 
 static void notify_xml_rpc_error(LinphoneXmlRpcRequest *request) {
@@ -232,6 +288,7 @@ static void notify_xml_rpc_error(LinphoneXmlRpcRequest *request) {
 	if (request->callbacks->response != NULL) {
 		request->callbacks->response(request);
 	}
+	NOTIFY_IF_EXIST(Response, response, request)
 }
 
 static void process_response_from_post_xml_rpc_request(void *data, const belle_http_response_event_t *event) {
@@ -241,9 +298,15 @@ static void process_response_from_post_xml_rpc_request(void *data, const belle_h
 	if (!linphone_xml_rpc_request_aborted(request) && event->response) {
 		int code = belle_http_response_get_status_code(event->response);
 		if (code == 200) { /* Valid response from the server. */
-			parse_valid_xml_rpc_response(request, belle_sip_message_get_body((belle_sip_message_t *)event->response));
+			const char * body = belle_sip_message_get_body((belle_sip_message_t *)event->response);
+			if (body) request->raw_response = bctbx_strdup(body);
+			parse_valid_xml_rpc_response(request, body);
 		} else {
-			ms_error("process_response_from_post_xml_rpc_request(): error code = %i", code);
+			if (code == 401) {
+				ms_error("Authentication error during XML-RPC request sending");
+			} else {
+				ms_error("process_response_from_post_xml_rpc_request(): error code = %i", code);
+			}
 			notify_xml_rpc_error(request);
 		}
 	}
@@ -261,14 +324,14 @@ static LinphoneXmlRpcRequest * _linphone_xml_rpc_request_new(LinphoneXmlRpcArgTy
 }
 
 static void _linphone_xml_rpc_request_add_int_arg(LinphoneXmlRpcRequest *request, int value) {
-	LinphoneXmlRpcArg *arg = belle_sip_malloc0(sizeof(LinphoneXmlRpcArg));
+	LinphoneXmlRpcArg *arg = reinterpret_cast<LinphoneXmlRpcArg *>(belle_sip_malloc0(sizeof(LinphoneXmlRpcArg)));
 	arg->type = LinphoneXmlRpcArgInt;
 	arg->data.i = value;
 	request->arg_list = belle_sip_list_append(request->arg_list, arg);
 }
 
 static void _linphone_xml_rpc_request_add_string_arg(LinphoneXmlRpcRequest *request, const char *value) {
-	LinphoneXmlRpcArg *arg = belle_sip_malloc0(sizeof(LinphoneXmlRpcArg));
+	LinphoneXmlRpcArg *arg = reinterpret_cast<LinphoneXmlRpcArg *>(belle_sip_malloc0(sizeof(LinphoneXmlRpcArg)));
 	arg->type = LinphoneXmlRpcArgString;
 	arg->data.s = belle_sip_strdup(value);
 	request->arg_list = belle_sip_list_append(request->arg_list, arg);
@@ -278,10 +341,29 @@ static void _linphone_xml_rpc_request_destroy(LinphoneXmlRpcRequest *request) {
 	belle_sip_list_free_with_data(request->arg_list, (void (*)(void*))free_arg);
 	if ((request->response.type == LinphoneXmlRpcArgString) && (request->response.data.s != NULL)) {
 		belle_sip_free(request->response.data.s);
+	} else if (request->response.type == LinphoneXmlRpcArgStringStruct) {
+		if (request->status == LinphoneXmlRpcStatusOk) {
+			/*if (request->response.data.m != NULL) {
+				bctbx_mmap_cchar_delete_with_data(request->response.data.m, bctbx_free);
+				request->response.data.m = NULL;
+			}*/
+
+			if (request->response.data.l) {
+				bctbx_list_free_with_data(request->response.data.l, bctbx_free);
+				request->response.data.l = NULL;
+			}
+		} else if (request->status == LinphoneXmlRpcStatusFailed && request->response.data.s != NULL) {
+			belle_sip_free(request->response.data.s);
+		}
 	}
 	if (request->content) belle_sip_free(request->content);
 	belle_sip_free(request->method);
 	linphone_xml_rpc_request_cbs_unref(request->callbacks);
+	bctbx_list_free_with_data(request->callbacks_list, (bctbx_list_free_func)linphone_xml_rpc_request_cbs_unref);
+	request->callbacks_list = nullptr;
+	if (request->raw_response)
+		bctbx_free(request->raw_response);
+
 }
 
 static void _linphone_xml_rpc_session_destroy(LinphoneXmlRpcSession *session) {
@@ -312,31 +394,6 @@ LinphoneXmlRpcRequest * linphone_xml_rpc_request_new(LinphoneXmlRpcArgType retur
 	return request;
 }
 
-LinphoneXmlRpcRequest * linphone_xml_rpc_request_new_with_args(LinphoneXmlRpcArgType return_type, const char *method, ...) {
-	bool_t cont = TRUE;
-	va_list args;
-	LinphoneXmlRpcArgType arg_type;
-	LinphoneXmlRpcRequest *request = _linphone_xml_rpc_request_new(return_type, method);
-	va_start(args, method);
-	while (cont) {
-		arg_type = va_arg(args, LinphoneXmlRpcArgType);
-		switch (arg_type) {
-			case LinphoneXmlRpcArgNone:
-				cont = FALSE;
-				break;
-			case LinphoneXmlRpcArgInt:
-				_linphone_xml_rpc_request_add_int_arg(request, va_arg(args, int));
-				break;
-			case LinphoneXmlRpcArgString:
-				_linphone_xml_rpc_request_add_string_arg(request, va_arg(args, char *));
-				break;
-		}
-	}
-	va_end(args);
-	format_request(request);
-	return request;
-}
-
 LinphoneXmlRpcRequest * linphone_xml_rpc_request_ref(LinphoneXmlRpcRequest *request) {
 	belle_sip_object_ref(request);
 	return request;
@@ -368,6 +425,27 @@ LinphoneXmlRpcRequestCbs * linphone_xml_rpc_request_get_callbacks(const Linphone
 	return request->callbacks;
 }
 
+void linphone_xml_rpc_request_add_callbacks(LinphoneXmlRpcRequest *request, LinphoneXmlRpcRequestCbs *cbs) {
+	request->callbacks_list = bctbx_list_append(request->callbacks_list, linphone_xml_rpc_request_cbs_ref(cbs));
+}
+
+void linphone_xml_rpc_request_remove_callbacks(LinphoneXmlRpcRequest *request, LinphoneXmlRpcRequestCbs *cbs) {
+	request->callbacks_list = bctbx_list_remove(request->callbacks_list, cbs);
+	linphone_xml_rpc_request_cbs_unref(cbs);
+}
+
+LinphoneXmlRpcRequestCbs *linphone_xml_rpc_request_get_current_callbacks(const LinphoneXmlRpcRequest *request) {
+	return request->currentCbs;
+}
+
+void linphone_xml_rpc_request_set_current_callbacks(LinphoneXmlRpcRequest *request, LinphoneXmlRpcRequestCbs *cbs) {
+	request->currentCbs = cbs;
+}
+
+const bctbx_list_t *linphone_xml_rpc_request_get_callbacks_list(const LinphoneXmlRpcRequest *request) {
+	return request->callbacks_list;
+}
+
 const char * linphone_xml_rpc_request_get_content(const LinphoneXmlRpcRequest *request) {
 	return request->content;
 }
@@ -384,6 +462,18 @@ const char * linphone_xml_rpc_request_get_string_response(const LinphoneXmlRpcRe
 	return request->response.data.s;
 }
 
+const char * linphone_xml_rpc_request_get_raw_response(const LinphoneXmlRpcRequest *request) {
+	return request->raw_response;
+}
+
+const bctbx_map_t* linphone_xml_rpc_request_get_string_struct_response(const LinphoneXmlRpcRequest *request) {
+	return NULL;
+	//return request->response.data.m;
+}
+
+const bctbx_list_t *linphone_xml_rpc_request_get_list_response(const LinphoneXmlRpcRequest *request) {
+	return request->response.data.l;
+}
 
 LinphoneXmlRpcSession * linphone_xml_rpc_session_new(LinphoneCore *core, const char *url) {
 	LinphoneXmlRpcSession *session = belle_sip_object_new(LinphoneXmlRpcSession);
@@ -409,6 +499,12 @@ void linphone_xml_rpc_session_set_user_data(LinphoneXmlRpcSession *session, void
 	session->user_data = ud;
 }
 
+LinphoneXmlRpcRequest * linphone_xml_rpc_session_create_request(LinphoneXmlRpcSession *session, LinphoneXmlRpcArgType return_type, const char *method) {
+	LinphoneXmlRpcRequest *request = linphone_xml_rpc_request_new(return_type, method);
+	request->core = session->core;
+	return request;
+}
+
 void linphone_xml_rpc_session_send_request(LinphoneXmlRpcSession *session, LinphoneXmlRpcRequest *request) {
 	belle_http_request_listener_callbacks_t cbs = { 0 };
 	belle_http_request_listener_t *l;
@@ -418,13 +514,29 @@ void linphone_xml_rpc_session_send_request(LinphoneXmlRpcSession *session, Linph
 	const char *data;
 	linphone_xml_rpc_request_ref(request);
 
+	if (request->core == NULL)
+		request->core = session->core;
+
 	uri = belle_generic_uri_parse(session->url);
 	if (!uri) {
 		ms_error("Could not send request, URL %s is invalid", session->url);
 		process_io_error_from_post_xml_rpc_request(request, NULL);
 		return;
 	}
-	req = belle_http_request_create("POST", uri, belle_sip_header_content_type_create("text", "xml"), NULL);
+
+	LinphoneProxyConfig *cfg = linphone_core_get_default_proxy_config(session->core);
+	if (cfg) {
+		char *addr = linphone_address_as_string_uri_only(linphone_proxy_config_get_identity_address(cfg));
+		req = belle_http_request_create("POST", uri,
+			belle_sip_header_content_type_create("text", "xml"),
+			belle_http_header_create("From", addr),
+			NULL);
+		bctbx_free(addr);
+	} else {
+		req = belle_http_request_create("POST", uri,
+			belle_sip_header_content_type_create("text", "xml"),
+			NULL);
+	}
 	if (!req) {
 		belle_sip_object_unref(uri);
 		process_io_error_from_post_xml_rpc_request(request, NULL);
@@ -437,6 +549,7 @@ void linphone_xml_rpc_session_send_request(LinphoneXmlRpcSession *session, Linph
 	cbs.process_io_error = process_io_error_from_post_xml_rpc_request;
 	cbs.process_auth_requested = process_auth_requested_from_post_xml_rpc_request;
 	l = belle_http_request_listener_create_from_callbacks(&cbs, request);
+
 	belle_http_provider_send_request(session->core->http_provider, req, l);
 	/*ensure that the listener object will be destroyed with the request*/
 	belle_sip_object_data_set(BELLE_SIP_OBJECT(request), "listener", l, belle_sip_object_unref);
@@ -448,4 +561,3 @@ void linphone_xml_rpc_session_release(LinphoneXmlRpcSession *session){
 	session->released = TRUE;
 	belle_sip_object_unref(session);
 }
-
