@@ -1,21 +1,21 @@
 /*
-audio-codec-get.cc
-Copyright (C) 2016 Belledonne Communications, Grenoble, France 
-
-This library is free software; you can redistribute it and/or modify it
-under the terms of the GNU Lesser General Public License as published by
-the Free Software Foundation; either version 2.1 of the License, or (at
-your option) any later version.
-
-This library is distributed in the hope that it will be useful, but WITHOUT
-ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
-License for more details.
-
-You should have received a copy of the GNU Lesser General Public License
-along with this library; if not, write to the Free Software Foundation,
-Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
-*/
+ * Copyright (c) 2010-2019 Belledonne Communications SARL.
+ *
+ * This file is part of Liblinphone.
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ */
 
 #include "audio-codec-get.h"
 
@@ -25,7 +25,7 @@ AudioCodecGetCommand::AudioCodecGetCommand() :
 		DaemonCommand("audio-codec-get", "audio-codec-get <payload_type_number>|<mime_type>",
 				"Get an audio codec if a parameter is given, otherwise return the audio codec list.\n"
 				"<mime_type> is of the form mime/rate/channels, eg. speex/16000/1") {
-	addExample(new DaemonCommandExample("audio-codec-get 9",
+	addExample(make_unique<DaemonCommandExample>("audio-codec-get 9",
 						"Status: Ok\n\n"
 						"Index: 9\n"
 						"Payload-type-number: 9\n"
@@ -36,7 +36,7 @@ AudioCodecGetCommand::AudioCodecGetCommand() :
 						"Recv-fmtp: \n"
 						"Send-fmtp: \n"
 						"Enabled: false"));
-	addExample(new DaemonCommandExample("audio-codec-get G722/8000/1",
+	addExample(make_unique<DaemonCommandExample>("audio-codec-get G722/8000/1",
 						"Status: Ok\n\n"
 						"Index: 9\n"
 						"Payload-type-number: 9\n"
@@ -47,7 +47,7 @@ AudioCodecGetCommand::AudioCodecGetCommand() :
 						"Recv-fmtp: \n"
 						"Send-fmtp: \n"
 						"Enabled: false"));
-	addExample(new DaemonCommandExample("audio-codec-get 2",
+	addExample(make_unique<DaemonCommandExample>("audio-codec-get 2",
 						"Status: Error\n"
 						"Reason: Audio codec not found."));
 }
