@@ -1,21 +1,21 @@
 /*
-audio-codec-set.cc
-Copyright (C) 2016 Belledonne Communications, Grenoble, France 
-
-This library is free software; you can redistribute it and/or modify it
-under the terms of the GNU Lesser General Public License as published by
-the Free Software Foundation; either version 2.1 of the License, or (at
-your option) any later version.
-
-This library is distributed in the hope that it will be useful, but WITHOUT
-ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
-License for more details.
-
-You should have received a copy of the GNU Lesser General Public License
-along with this library; if not, write to the Free Software Foundation,
-Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
-*/
+ * Copyright (c) 2010-2019 Belledonne Communications SARL.
+ *
+ * This file is part of Liblinphone.
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ */
 
 #include "audio-codec-set.h"
 
@@ -31,7 +31,7 @@ AudioCodecSetCommand::AudioCodecSetCommand() :
 		DaemonCommand("audio-codec-set", "audio-codec-set <payload_type_number>|<mime_type> <property> <value>",
 				"Set a property (number, clock_rate, recv_fmtp, send_fmtp, bitrate (in kbps/s)) of a codec. Numbering of payload type is automatically performed at startup, any change will be lost after restart.\n"
 				"<mime_type> is of the form mime/rate/channels, eg. speex/16000/1") {
-	addExample(new DaemonCommandExample("audio-codec-set 9 number 18",
+	addExample(make_unique<DaemonCommandExample>("audio-codec-set 9 number 18",
 						"Status: Ok\n\n"
 						"Index: 10\n"
 						"Payload-type-number: 18\n"
@@ -42,7 +42,7 @@ AudioCodecSetCommand::AudioCodecSetCommand() :
 						"Recv-fmtp: \n"
 						"Send-fmtp: \n"
 						"Enabled: false"));
-	addExample(new DaemonCommandExample("audio-codec-set G722/8000/1 number 9",
+	addExample(make_unique<DaemonCommandExample>("audio-codec-set G722/8000/1 number 9",
 						"Status: Ok\n\n"
 						"Index: 10\n"
 						"Payload-type-number: 9\n"
@@ -53,7 +53,7 @@ AudioCodecSetCommand::AudioCodecSetCommand() :
 						"Recv-fmtp: \n"
 						"Send-fmtp: \n"
 						"Enabled: false"));
-	addExample(new DaemonCommandExample("audio-codec-set 9 clock_rate 16000",
+	addExample(make_unique<DaemonCommandExample>("audio-codec-set 9 clock_rate 16000",
 						"Status: Ok\n\n"
 						"Index: 10\n"
 						"Payload-type-number: 9\n"
