@@ -1,21 +1,21 @@
 /*
-audio-codec-toggle.cc
-Copyright (C) 2016 Belledonne Communications, Grenoble, France 
-
-This library is free software; you can redistribute it and/or modify it
-under the terms of the GNU Lesser General Public License as published by
-the Free Software Foundation; either version 2.1 of the License, or (at
-your option) any later version.
-
-This library is distributed in the hope that it will be useful, but WITHOUT
-ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
-License for more details.
-
-You should have received a copy of the GNU Lesser General Public License
-along with this library; if not, write to the Free Software Foundation,
-Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
-*/
+ * Copyright (c) 2010-2019 Belledonne Communications SARL.
+ *
+ * This file is part of Liblinphone.
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ */
 
 #include "audio-codec-toggle.h"
 #include "audio-codec-get.h"
@@ -69,7 +69,7 @@ AudioCodecEnableCommand::AudioCodecEnableCommand() :
 		AudioCodecToggleCommand("audio-codec-enable", "audio-codec-enable <payload_type_number>|<mime_type>|ALL",
 					"Enable an audio codec.\n"
 					"<mime_type> is of the form mime/rate/channels, eg. speex/16000/1", true) {
-	addExample(new DaemonCommandExample("audio-codec-enable G722/8000/1",
+	addExample(make_unique<DaemonCommandExample>("audio-codec-enable G722/8000/1",
 						"Status: Ok\n\n"
 						"Index: 9\n"
 						"Payload-type-number: 9\n"
@@ -80,7 +80,7 @@ AudioCodecEnableCommand::AudioCodecEnableCommand() :
 						"Recv-fmtp: \n"
 						"Send-fmtp: \n"
 						"Enabled: true"));
-	addExample(new DaemonCommandExample("audio-codec-enable 9",
+	addExample(make_unique<DaemonCommandExample>("audio-codec-enable 9",
 						"Status: Ok\n\n"
 						"Index: 9\n"
 						"Payload-type-number: 9\n"
@@ -97,7 +97,7 @@ AudioCodecDisableCommand::AudioCodecDisableCommand() :
 		AudioCodecToggleCommand("audio-codec-disable", "audio-codec-disable <payload_type_number>|<mime_type>|ALL",
 					"Disable an audio codec.\n"
 					"<mime_type> is of the form mime/rate/channels, eg. speex/16000/1", false) {
-	addExample(new DaemonCommandExample("audio-codec-disable G722/8000/1",
+	addExample(make_unique<DaemonCommandExample>("audio-codec-disable G722/8000/1",
 						"Status: Ok\n\n"
 						"Index: 9\n"
 						"Payload-type-number: 9\n"
@@ -108,7 +108,7 @@ AudioCodecDisableCommand::AudioCodecDisableCommand() :
 						"Recv-fmtp: \n"
 						"Send-fmtp: \n"
 						"Enabled: false"));
-	addExample(new DaemonCommandExample("audio-codec-disable 9",
+	addExample(make_unique<DaemonCommandExample>("audio-codec-disable 9",
 						"Status: Ok\n\n"
 						"Index: 9\n"
 						"Payload-type-number: 9\n"
