@@ -1,21 +1,21 @@
 /*
-audio-stream-stats.cc
-Copyright (C) 2016 Belledonne Communications, Grenoble, France 
-
-This library is free software; you can redistribute it and/or modify it
-under the terms of the GNU Lesser General Public License as published by
-the Free Software Foundation; either version 2.1 of the License, or (at
-your option) any later version.
-
-This library is distributed in the hope that it will be useful, but WITHOUT
-ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
-License for more details.
-
-You should have received a copy of the GNU Lesser General Public License
-along with this library; if not, write to the Free Software Foundation,
-Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
-*/
+ * Copyright (c) 2010-2019 Belledonne Communications SARL.
+ *
+ * This file is part of Liblinphone.
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ */
 
 #include "audio-stream-stats.h"
 
@@ -23,7 +23,7 @@ using namespace std;
 
 AudioStreamStatsCommand::AudioStreamStatsCommand() :
 		DaemonCommand("audio-stream-stats", "audio-stream-stats <stream_id>", "Return stats of a given audio stream.") {
-	addExample(new DaemonCommandExample("audio-stream-stats 1",
+	addExample(make_unique<DaemonCommandExample>("audio-stream-stats 1",
 						"Status: Ok\n\n"
 						"Audio-ICE state: Not activated\n"
 						"Audio-RoundTripDelay: 0.0859833\n"
@@ -40,7 +40,7 @@ AudioStreamStatsCommand::AudioStreamStatsCommand() :
 						"Audio-Channels: 1\n"
 						"Audio-Recv-fmtp: vbr=on\n"
 						"Audio-Send-fmtp: vbr=on"));
-	addExample(new DaemonCommandExample("audio-stream-stats 2",
+	addExample(make_unique<DaemonCommandExample>("audio-stream-stats 2",
 						"Status: Error\n"
 						"Reason: No audio stream with such id."));
 }
@@ -61,5 +61,8 @@ void AudioStreamStatsCommand::exec(Daemon *app, const string& args) {
 		return;
 	}
 
-	app->sendResponse(Response(AudioStreamStatsResponse(app, stream->stream, stream->stats, false).getBody(), Response::Ok));
+	Response resp;
+	AudioStreamStatsEvent ev(app, stream->stream, stream->stats);
+	resp.setBody(ev.getBody());
+	app->sendResponse(resp);
 }
