@@ -1,21 +1,21 @@
 /*
-auth-infos-clear.cc
-Copyright (C) 2016 Belledonne Communications, Grenoble, France 
-
-This library is free software; you can redistribute it and/or modify it
-under the terms of the GNU Lesser General Public License as published by
-the Free Software Foundation; either version 2.1 of the License, or (at
-your option) any later version.
-
-This library is distributed in the hope that it will be useful, but WITHOUT
-ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
-License for more details.
-
-You should have received a copy of the GNU Lesser General Public License
-along with this library; if not, write to the Free Software Foundation,
-Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
-*/
+ * Copyright (c) 2010-2019 Belledonne Communications SARL.
+ *
+ * This file is part of Liblinphone.
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ */
 
 #include "auth-infos-clear.h"
 
@@ -23,13 +23,13 @@ using namespace std;
 
 AuthInfosClearCommand::AuthInfosClearCommand() :
 		DaemonCommand("auth-infos-clear", "auth-infos-clear <auth_infos_id>|ALL", "Remove auth infos context for the given id, or all.") {
-	addExample(new DaemonCommandExample("auth-infos-clear 1",
+	addExample(make_unique<DaemonCommandExample>("auth-infos-clear 1",
 						"Status: Ok\n"
 						"Reason: Successfully cleared auth info 1."));
-	addExample(new DaemonCommandExample("auth-infos-clear ALL",
+	addExample(make_unique<DaemonCommandExample>("auth-infos-clear ALL",
 						"Status: Ok\n"
 						"Reason: Successfully cleared 5 auth infos."));
-	addExample(new DaemonCommandExample("auth-infos-clear 3",
+	addExample(make_unique<DaemonCommandExample>("auth-infos-clear 3",
 						"Status: Error\n"
 						"Reason: No auth info with such id."));
 }
