@@ -1,21 +1,21 @@
 /*
-call-mute.cc
-Copyright (C) 2016 Belledonne Communications, Grenoble, France 
-
-This library is free software; you can redistribute it and/or modify it
-under the terms of the GNU Lesser General Public License as published by
-the Free Software Foundation; either version 2.1 of the License, or (at
-your option) any later version.
-
-This library is distributed in the hope that it will be useful, but WITHOUT
-ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
-License for more details.
-
-You should have received a copy of the GNU Lesser General Public License
-along with this library; if not, write to the Free Software Foundation,
-Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
-*/
+ * Copyright (c) 2010-2019 Belledonne Communications SARL.
+ *
+ * This file is part of Liblinphone.
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ */
 
 #include "call-mute.h"
 
@@ -24,16 +24,16 @@ using namespace std;
 CallMuteCommand::CallMuteCommand() :
 	DaemonCommand("call-mute", "call-mute 0|1", "Mute/unmute the microphone (1 to mute, 0 to unmute). No argument means MUTE.")
 {
-	addExample(new DaemonCommandExample("call-mute 1",
+	addExample(make_unique<DaemonCommandExample>("call-mute 1",
 										"Status: Ok\n\n"
 										"Microphone Muted"));
-	addExample(new DaemonCommandExample("call-mute",
+	addExample(make_unique<DaemonCommandExample>("call-mute",
 										"Status: Ok\n\n"
 										"Microphone Muted"));
-	addExample(new DaemonCommandExample("call-mute 0",
+	addExample(make_unique<DaemonCommandExample>("call-mute 0",
 										"Status: Ok\n\n"
 										"Microphone Unmuted"));
-	addExample(new DaemonCommandExample("call-mute 1",
+	addExample(make_unique<DaemonCommandExample>("call-mute 1",
 										"Status: Error\n\n"
 										"Reason: No call in progress. Can't mute."));
 }
