@@ -1,21 +1,21 @@
 /*
-call-stats.cc
-Copyright (C) 2016 Belledonne Communications, Grenoble, France 
-
-This library is free software; you can redistribute it and/or modify it
-under the terms of the GNU Lesser General Public License as published by
-the Free Software Foundation; either version 2.1 of the License, or (at
-your option) any later version.
-
-This library is distributed in the hope that it will be useful, but WITHOUT
-ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
-License for more details.
-
-You should have received a copy of the GNU Lesser General Public License
-along with this library; if not, write to the Free Software Foundation,
-Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
-*/
+ * Copyright (c) 2010-2019 Belledonne Communications SARL.
+ *
+ * This file is part of Liblinphone.
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ */
 
 #include "call-stats.h"
 
@@ -23,7 +23,7 @@ using namespace std;
 
 CallStatsCommand::CallStatsCommand() :
 		DaemonCommand("call-stats", "call-stats [<call_id>]", "Return all stats of a call.") {
-	addExample(new DaemonCommandExample("call-stats 1",
+	addExample(make_unique<DaemonCommandExample>("call-stats 1",
 						"Status: Ok\n\n"
 						"Audio-ICE state: Not activated\n"
 						"Audio-RoundTripDelay: 0.0859833\n"
@@ -44,10 +44,10 @@ CallStatsCommand::CallStatsCommand() :
 						"Video-RoundTripDelay: 0\n"
 						"Video-Jitter: 0\n"
 						"Video-JitterBufferSizeMs: 0State: disabled"));
-	addExample(new DaemonCommandExample("call-stats 2",
+	addExample(make_unique<DaemonCommandExample>("call-stats 2",
 						"Status: Error\n"
 						"Reason: No call with such id."));
-	addExample(new DaemonCommandExample("call-stats",
+	addExample(make_unique<DaemonCommandExample>("call-stats",
 						"Status: Error\n"
 						"Reason: No current call available."));
 }
@@ -73,7 +73,7 @@ void CallStatsCommand::exec(Daemon *app, const string& args) {
 	}
 
 	ostringstream ostr;
-	ostr << CallStatsResponse(app, call, linphone_call_get_audio_stats(call), false).getBody();
-	ostr << CallStatsResponse(app, call, linphone_call_get_video_stats(call), false).getBody();
+	ostr << CallStatsEvent(app, call, linphone_call_get_audio_stats(call)).getBody();
+	ostr << CallStatsEvent(app, call, linphone_call_get_video_stats(call)).getBody();
 	app->sendResponse(Response(ostr.str(), Response::Ok));
 }
