@@ -1,21 +1,21 @@
 /*
-call-status.cc
-Copyright (C) 2016 Belledonne Communications, Grenoble, France 
-
-This library is free software; you can redistribute it and/or modify it
-under the terms of the GNU Lesser General Public License as published by
-the Free Software Foundation; either version 2.1 of the License, or (at
-your option) any later version.
-
-This library is distributed in the hope that it will be useful, but WITHOUT
-ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
-License for more details.
-
-You should have received a copy of the GNU Lesser General Public License
-along with this library; if not, write to the Free Software Foundation,
-Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
-*/
+ * Copyright (c) 2010-2019 Belledonne Communications SARL.
+ *
+ * This file is part of Liblinphone.
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ */
 
 #include "call-status.h"
 
@@ -23,16 +23,16 @@ using namespace std;
 
 CallStatusCommand::CallStatusCommand() :
 		DaemonCommand("call-status", "call-status [<call_id>]", "Return status of a call.") {
-	addExample(new DaemonCommandExample("call-status 1",
+	addExample(make_unique<DaemonCommandExample>("call-status 1",
 						"Status: Ok\n\n"
 						"State: LinphoneCallStreamsRunning\n"
 						"From: <sip:daemon-test@sip.linphone.org>\n"
 						"Direction: out\n"
 						"Duration: 6"));
-	addExample(new DaemonCommandExample("call-status 2",
+	addExample(make_unique<DaemonCommandExample>("call-status 2",
 						"Status: Error\n"
 						"Reason: No call with such id."));
-	addExample(new DaemonCommandExample("call-status",
+	addExample(make_unique<DaemonCommandExample>("call-status",
 						"Status: Error\n"
 						"Reason: No current call available."));
 }
