@@ -1,21 +1,21 @@
 /*
-call-transfer.cc
-Copyright (C) 2016 Belledonne Communications, Grenoble, France 
-
-This library is free software; you can redistribute it and/or modify it
-under the terms of the GNU Lesser General Public License as published by
-the Free Software Foundation; either version 2.1 of the License, or (at
-your option) any later version.
-
-This library is distributed in the hope that it will be useful, but WITHOUT
-ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
-License for more details.
-
-You should have received a copy of the GNU Lesser General Public License
-along with this library; if not, write to the Free Software Foundation,
-Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
-*/
+ * Copyright (c) 2010-2019 Belledonne Communications SARL.
+ *
+ * This file is part of Liblinphone.
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ */
 
 #include "call-transfer.h"
 
@@ -26,16 +26,16 @@ CallTransferCommand::CallTransferCommand() :
 				  "call-transfer <call_to_transfer_id> <call_to_transfer_to_id>|<sip_url_to_transfer_to>",
 				  "Transfer a call that you aswered to another party")
 {
-	addExample(new DaemonCommandExample("call-transfer 1 sip:john",
+	addExample(make_unique<DaemonCommandExample>("call-transfer 1 sip:john",
 										"Status: Ok\n\n"
 										"Call ID: 1\n"
 										"Transfer to: sip:john"));
 
-	addExample(new DaemonCommandExample("call-transfer 2 sip:john",
+	addExample(make_unique<DaemonCommandExample>("call-transfer 2 sip:john",
 										"Status: Error\n"
 										"Reason: No call with such id."));
 
-	addExample(new DaemonCommandExample("call-transfer 1 2",
+	addExample(make_unique<DaemonCommandExample>("call-transfer 1 2",
 										"Status: Ok\n\n"
 										"Call ID: 1\n"
 										"Transfer to: 2"));
@@ -85,7 +85,7 @@ void CallTransferCommand::exec(Daemon* app, const string& args)
 			return;
 		}
 		if (linphone_call_transfer_to_another(call_to_transfer, call_to_transfer_to) == 0) {
-			std::ostringstream ostr;
+			ostringstream ostr;
 			ostr << "Call ID: " << call_to_transfer_id << "\n";
 			ostr << "Transfer to: " << call_to_transfer_to_id << "\n";
 			app->sendResponse(Response(ostr.str(), Response::Ok));
@@ -93,7 +93,7 @@ void CallTransferCommand::exec(Daemon* app, const string& args)
 		}
 	} else {
 		if (linphone_call_transfer(call_to_transfer, sip_uri_to_transfer_to.c_str()) == 0) {
-			std::ostringstream ostr;
+			ostringstream ostr;
 			ostr << "Call ID: " << call_to_transfer_id << "\n";
 			ostr << "Transfer to: " << sip_uri_to_transfer_to << "\n";
 			app->sendResponse(Response(ostr.str(), Response::Ok));
