@@ -1,21 +1,21 @@
 /*
-call.cc
-Copyright (C) 2016 Belledonne Communications, Grenoble, France 
-
-This library is free software; you can redistribute it and/or modify it
-under the terms of the GNU Lesser General Public License as published by
-the Free Software Foundation; either version 2.1 of the License, or (at
-your option) any later version.
-
-This library is distributed in the hope that it will be useful, but WITHOUT
-ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
-License for more details.
-
-You should have received a copy of the GNU Lesser General Public License
-along with this library; if not, write to the Free Software Foundation,
-Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
-*/
+ * Copyright (c) 2010-2019 Belledonne Communications SARL.
+ *
+ * This file is part of Liblinphone.
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ */
 
 #include "call.h"
 
@@ -23,14 +23,14 @@ using namespace std;
 
 CallCommand::CallCommand() :
 		DaemonCommand("call", "call <sip_address> [--early-media]", "Place a call.") {
-	addExample(new DaemonCommandExample("call daemon-test@sip.linphone.org",
+	addExample(make_unique<DaemonCommandExample>("call daemon-test@sip.linphone.org",
 						"Status: Ok\n\n"
 						"Id: 1"));
-	addExample(new DaemonCommandExample("call daemon-test@sip.linphone.org --early-media",
+	addExample(make_unique<DaemonCommandExample>("call daemon-test@sip.linphone.org --early-media",
 						"Status: Ok\n\n"
 						"Early media: Ok\n"
 						"Id: 1"));
-	addExample(new DaemonCommandExample("call daemon-test@sip.linphone.org",
+	addExample(make_unique<DaemonCommandExample>("call daemon-test@sip.linphone.org",
 						"Status: Error\n"
 						"Reason: Call creation failed."));
 }
