@@ -1,21 +1,21 @@
 /*
-cn.cc
-Copyright (C) 2016 Belledonne Communications, Grenoble, France 
-
-This library is free software; you can redistribute it and/or modify it
-under the terms of the GNU Lesser General Public License as published by
-the Free Software Foundation; either version 2.1 of the License, or (at
-your option) any later version.
-
-This library is distributed in the hope that it will be useful, but WITHOUT
-ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
-License for more details.
-
-You should have received a copy of the GNU Lesser General Public License
-along with this library; if not, write to the Free Software Foundation,
-Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
-*/
+ * Copyright (c) 2010-2019 Belledonne Communications SARL.
+ *
+ * This file is part of Liblinphone.
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ */
 
 #include "cn.h"
 
@@ -42,13 +42,13 @@ CNResponse::CNResponse(LinphoneCore *core) : Response() {
 CNCommand::CNCommand() :
 		DaemonCommand("cn", "cn [enable|disable]",
 				"Enable or disable generic comfort noice (CN payload type) with the 'enable' and 'disable' parameters, return the status of the use of comfort noise without parameter.") {
-	addExample(new DaemonCommandExample("cn enable",
+	addExample(make_unique<DaemonCommandExample>("cn enable",
 						"Status: Ok\n\n"
 						"State: enabled"));
-	addExample(new DaemonCommandExample("cn disable",
+	addExample(make_unique<DaemonCommandExample>("cn disable",
 						"Status: Ok\n\n"
 						"State: disabled"));
-	addExample(new DaemonCommandExample("cn",
+	addExample(make_unique<DaemonCommandExample>("cn",
 						"Status: Ok\n\n"
 						"State: disabled"));
 }
