@@ -1,21 +1,21 @@
 /*
-conference.cc
-Copyright (C) 2016 Belledonne Communications, Grenoble, France 
-
-This library is free software; you can redistribute it and/or modify it
-under the terms of the GNU Lesser General Public License as published by
-the Free Software Foundation; either version 2.1 of the License, or (at
-your option) any later version.
-
-This library is distributed in the hope that it will be useful, but WITHOUT
-ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
-License for more details.
-
-You should have received a copy of the GNU Lesser General Public License
-along with this library; if not, write to the Free Software Foundation,
-Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
-*/
+ * Copyright (c) 2010-2019 Belledonne Communications SARL.
+ *
+ * This file is part of Liblinphone.
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ */
 
 #include "conference.h"
 
@@ -30,18 +30,18 @@ ConferenceCommand::ConferenceCommand() :
 				  "- leave : temporarily leave the current conference.\n"
 				  "- enter : re-join the conference after leaving it.")
 {
-	addExample(new DaemonCommandExample("conference add 1",
+	addExample(make_unique<DaemonCommandExample>("conference add 1",
 										"Status: Ok\n\n"
 										"Call Id: 1\n"
 										"Conference: add OK"));
-	addExample(new DaemonCommandExample("conference leave 1",
+	addExample(make_unique<DaemonCommandExample>("conference leave 1",
 										"Status: Ok\n\n"
 										"Call Id: 1\n"
 										"Conference: leave OK"));
-	addExample(new DaemonCommandExample("conference azerty 1",
+	addExample(make_unique<DaemonCommandExample>("conference azerty 1",
 										"Status: Error\n\n"
 										"Reason: Invalid command format"));
-	addExample(new DaemonCommandExample("conference leave 2",
+	addExample(make_unique<DaemonCommandExample>("conference leave 2",
 										"Status: Error\n\n"
 										"Reason: No call with such id."));
 }
@@ -79,7 +79,7 @@ void ConferenceCommand::exec(Daemon* app, const string& args) {
 	}
 
 	if (ret == 0) {
-		std::ostringstream ostr;
+		ostringstream ostr;
 		ostr << "Call ID: " << id << "\n";
 		ostr << "Conference: " << subcommand << " OK" << "\n";
 		app->sendResponse(Response(ostr.str(), Response::Ok));
