@@ -1,21 +1,21 @@
 /*
-firewall-policy.cc
-Copyright (C) 2016 Belledonne Communications, Grenoble, France 
-
-This library is free software; you can redistribute it and/or modify it
-under the terms of the GNU Lesser General Public License as published by
-the Free Software Foundation; either version 2.1 of the License, or (at
-your option) any later version.
-
-This library is distributed in the hope that it will be useful, but WITHOUT
-ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
-License for more details.
-
-You should have received a copy of the GNU Lesser General Public License
-along with this library; if not, write to the Free Software Foundation,
-Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
-*/
+ * Copyright (c) 2010-2019 Belledonne Communications SARL.
+ *
+ * This file is part of Liblinphone.
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ */
 
 #include "firewall-policy.h"
 
@@ -58,14 +58,14 @@ FirewallPolicyCommand::FirewallPolicyCommand() :
 				"Set the firewall policy if type is set, otherwise return the used firewall policy.\n"
 				"<address> must be specified for the 'nat' and 'stun' types. "
 				"It represents the public address of the gateway for the 'nat' type and the STUN server address for the 'stun' and 'ice' types.") {
-	addExample(new DaemonCommandExample("firewall-policy stun stun.linphone.org",
+	addExample(make_unique<DaemonCommandExample>("firewall-policy stun stun.linphone.org",
 						"Status: Ok\n\n"
 						"Type: stun\n"
 						"Address: stun.linphone.org"));
-	addExample(new DaemonCommandExample("firewall-policy none",
+	addExample(make_unique<DaemonCommandExample>("firewall-policy none",
 						"Status: Ok\n\n"
 						"Type: none"));
-	addExample(new DaemonCommandExample("firewall-policy",
+	addExample(make_unique<DaemonCommandExample>("firewall-policy",
 						"Status: Ok\n\n"
 						"Type: none"));
 }
