@@ -1,21 +1,21 @@
 /*
-ipv6.cc
-Copyright (C) 2016 Belledonne Communications, Grenoble, France 
-
-This library is free software; you can redistribute it and/or modify it
-under the terms of the GNU Lesser General Public License as published by
-the Free Software Foundation; either version 2.1 of the License, or (at
-your option) any later version.
-
-This library is distributed in the hope that it will be useful, but WITHOUT
-ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
-License for more details.
-
-You should have received a copy of the GNU Lesser General Public License
-along with this library; if not, write to the Free Software Foundation,
-Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
-*/
+ * Copyright (c) 2010-2019 Belledonne Communications SARL.
+ *
+ * This file is part of Liblinphone.
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ */
 
 #include "ipv6.h"
 
@@ -41,13 +41,13 @@ IPv6Response::IPv6Response(LinphoneCore *core) : Response() {
 IPv6Command::IPv6Command() :
 		DaemonCommand("ipv6", "ipv6 [enable|disable]",
 				"Enable or disable IPv6 respectively with the 'enable' and 'disable' parameters, return the status of the use of IPv6 without parameter.") {
-	addExample(new DaemonCommandExample("ipv6 enable",
+	addExample(make_unique<DaemonCommandExample>("ipv6 enable",
 						"Status: Ok\n\n"
 						"State: enabled"));
-	addExample(new DaemonCommandExample("ipv6 disable",
+	addExample(make_unique<DaemonCommandExample>("ipv6 disable",
 						"Status: Ok\n\n"
 						"State: disabled"));
-	addExample(new DaemonCommandExample("ipv6",
+	addExample(make_unique<DaemonCommandExample>("ipv6",
 						"Status: Ok\n\n"
 						"State: disabled"));
 }
