@@ -1,21 +1,21 @@
 /*
-jitterbuffer.cc
-Copyright (C) 2016 Belledonne Communications, Grenoble, France 
-
-This library is free software; you can redistribute it and/or modify it
-under the terms of the GNU Lesser General Public License as published by
-the Free Software Foundation; either version 2.1 of the License, or (at
-your option) any later version.
-
-This library is distributed in the hope that it will be useful, but WITHOUT
-ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
-License for more details.
-
-You should have received a copy of the GNU Lesser General Public License
-along with this library; if not, write to the Free Software Foundation,
-Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
-*/
+ * Copyright (c) 2010-2019 Belledonne Communications SARL.
+ *
+ * This file is part of Liblinphone.
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ */
 
 #include "jitterbuffer.h"
 #include <iostream>
@@ -43,11 +43,11 @@ JitterBufferCommand::JitterBufferCommand() : DaemonCommand("jitter-buffer",
 	"jitter-buffer [audio|video] size <milliseconds>: sets the nominal jitter buffer size in milliseconds. Has no effect in a running call.\n"
 	"jitter-buffer [audio|video]: gets the nominal jitter buffer size."
 	){
-	addExample(new DaemonCommandExample("jitter-buffer","Status: Ok\n\n"
+	addExample(make_unique<DaemonCommandExample>("jitter-buffer","Status: Ok\n\n"
 				"audio-jitter-buffer-size: 60\nvideo-jitter-buffer-size: 60\n"));
-	addExample(new DaemonCommandExample("jitter-buffer audio","Status: Ok\n\n"
+	addExample(make_unique<DaemonCommandExample>("jitter-buffer audio","Status: Ok\n\n"
 				"audio-jitter-buffer-size: 60\n"));
-	addExample(new DaemonCommandExample("jitter-buffer audio size 80","Status: Ok\n\n"
+	addExample(make_unique<DaemonCommandExample>("jitter-buffer audio size 80","Status: Ok\n\n"
 				"audio-jitter-buffer-size: 80\n"));
 }
 
@@ -89,9 +89,9 @@ JitterBufferResetCommand::JitterBufferResetCommand() : DaemonCommand("jitter-buf
 	"jitter-buffer-reset call|stream <id> [audio|video]" ,
 	"Reset the RTP jitter buffer for a given call or stream id and stream type."
 	){
-	addExample(new DaemonCommandExample("jitter-buffer-reset call 3 audio",
+	addExample(make_unique<DaemonCommandExample>("jitter-buffer-reset call 3 audio",
 		"Status: Ok\n"));
-	addExample(new DaemonCommandExample("jitter-buffer-reset stream 12",
+	addExample(make_unique<DaemonCommandExample>("jitter-buffer-reset stream 12",
 		"Status: Ok\n"));
 }
 
@@ -124,9 +124,11 @@ void JitterBufferResetCommand::exec(Daemon *app, const string& args) {
 		}
 		istr >> streamtype;
 		if (streamtype == "video") {
-			rtprecv = call->videostream ? call->videostream->ms.rtprecv : NULL;
+			VideoStream *vstream = reinterpret_cast<VideoStream *>(linphone_call_get_stream(call, LinphoneStreamTypeVideo));
+			rtprecv = vstream ? vstream->ms.rtprecv : NULL;
 		} else {
-			rtprecv = call->audiostream ? call->audiostream->ms.rtprecv : NULL;
+			AudioStream *astream = reinterpret_cast<AudioStream *>(linphone_call_get_stream(call, LinphoneStreamTypeAudio));
+			rtprecv = astream ? astream->ms.rtprecv : NULL;
 		}
 	} else {
 		AudioStream *stream = app->findAudioStream(arg2);
