@@ -1,21 +1,21 @@
 /*
-netsim.cc
-Copyright (C) 2016 Belledonne Communications, Grenoble, France 
-
-This library is free software; you can redistribute it and/or modify it
-under the terms of the GNU Lesser General Public License as published by
-the Free Software Foundation; either version 2.1 of the License, or (at
-your option) any later version.
-
-This library is distributed in the hope that it will be useful, but WITHOUT
-ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
-License for more details.
-
-You should have received a copy of the GNU Lesser General Public License
-along with this library; if not, write to the Free Software Foundation,
-Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
-*/
+ * Copyright (c) 2010-2019 Belledonne Communications SARL.
+ *
+ * This file is part of Liblinphone.
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ */
 
 #include "netsim.h"
 
@@ -57,13 +57,13 @@ NetsimCommand::NetsimCommand(): DaemonCommand("netsim","netsim [enable|disable|p
 	"\tjitter_strength (percentage of max_bandwidth artifically consumed during bursts events)\n"
 	"\tmode (inbound, outbound, outbound-controlled)\n")
 {
-	addExample(new DaemonCommandExample("netsim",
+	addExample(make_unique<DaemonCommandExample>("netsim",
 						"Status: Ok\n\n"
 						"State: disabled\nmax_bandwidth: 384000\nmax_buffer_size: 384000\nloss_rate: 2"));
-	addExample(new DaemonCommandExample("netsim enable",
+	addExample(make_unique<DaemonCommandExample>("netsim enable",
 						"Status: Ok\n\n"
 						"State: enabled\nmax_bandwidth: 384000\nmax_buffer_size: 384000\nloss_rate: 2"));
-	addExample(new DaemonCommandExample("netsim parameters loss_rate=5;consecutive_loss_probability=0.5",
+	addExample(make_unique<DaemonCommandExample>("netsim parameters loss_rate=5;consecutive_loss_probability=0.5",
 						"Status: Ok\n\n"
 						"State: enabled\nmax_bandwidth: 384000\nmax_buffer_size: 384000\nloss_rate: 2"));
 }
@@ -96,7 +96,7 @@ void NetsimCommand::exec(Daemon* app, const string& args) {
 			params.loss_rate = (float)atoi(value);
 		}
 		if (fmtp_get_value(parameters.c_str(), "latency", value, sizeof(value))) {
-			params.latency = atoi(value);
+			params.latency = (uint32_t)atoi(value);
 		}
 		if (fmtp_get_value(parameters.c_str(), "consecutive_loss_probability", value, sizeof(value))) {
 			params.consecutive_loss_probability = (float)atof(value);
