@@ -1,21 +1,21 @@
 /*
-register-status.cc
-Copyright (C) 2016 Belledonne Communications, Grenoble, France 
-
-This library is free software; you can redistribute it and/or modify it
-under the terms of the GNU Lesser General Public License as published by
-the Free Software Foundation; either version 2.1 of the License, or (at
-your option) any later version.
-
-This library is distributed in the hope that it will be useful, but WITHOUT
-ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
-License for more details.
-
-You should have received a copy of the GNU Lesser General Public License
-along with this library; if not, write to the Free Software Foundation,
-Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
-*/
+ * Copyright (c) 2010-2019 Belledonne Communications SARL.
+ *
+ * This file is part of Liblinphone.
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ */
 
 #include "register-status.h"
 
@@ -48,17 +48,17 @@ void RegisterStatusResponse::append(int id, const LinphoneProxyConfig* cfg) {
 
 RegisterStatusCommand::RegisterStatusCommand() :
 		DaemonCommand("register-status", "register-status <register_id>|ALL", "Return status of a registration or of all registrations.") {
-	addExample(new DaemonCommandExample("register-status 1",
+	addExample(make_unique<DaemonCommandExample>("register-status 1",
 						"Status: Ok\n\n"
 						"Id: 1\n"
 						"State: LinphoneRegistrationOk"));
-	addExample(new DaemonCommandExample("register-status ALL",
+	addExample(make_unique<DaemonCommandExample>("register-status ALL",
 						"Status: Ok\n\n"
 						"Id: 1\n"
 						"State: LinphoneRegistrationOk\n\n"
 						"Id: 2\n"
 						"State: LinphoneRegistrationFailed"));
-	addExample(new DaemonCommandExample("register-status 3",
+	addExample(make_unique<DaemonCommandExample>("register-status 3",
 						"Status: Error\n"
 						"Reason: No register with such id."));
 }
