@@ -98,7 +98,16 @@ LINPHONE_PUBLIC LinphoneChatMessage *linphone_chat_room_create_forward_message (
  * @param message #LinphoneChatMessage message to reply to. @notnil
  * @return a new #LinphoneChatMessage @notnil
  */
-LINPHONE_PUBLIC LinphoneChatMessage *linphone_chat_room_create_reply_message (LinphoneChatRoom *cr, LinphoneChatMessage *message);
+LINPHONE_PUBLIC LinphoneChatMessage *linphone_chat_room_create_reply_message (LinphoneChatRoom *chat_room, LinphoneChatMessage *message);
+
+ /**
+ * Creates a chat message with a voice recording attached to the given chat room.
+ * @warning If the recorder isn't in Closed state, it will return an empty message!
+ * @param chat_room the #LinphoneChatRoom object. @notnil
+ * @param recorder the #LinphoneRecorder object used to record the voice message. @notnil
+ * @return a new #LinphoneChatMessage @notnil
+ */
+LINPHONE_PUBLIC LinphoneChatMessage *linphone_chat_room_create_voice_recording_message (LinphoneChatRoom *chat_room, LinphoneRecorder *recorder);
 
 /**
  * Get the peer address associated to this chat room.
@@ -148,11 +157,12 @@ LINPHONE_PUBLIC void linphone_chat_room_enable_ephemeral(LinphoneChatRoom *chat_
 LINPHONE_PUBLIC bool_t linphone_chat_room_ephemeral_enabled(const LinphoneChatRoom *chat_room);
 
 /**
- * Set lifetime (in seconds) for all new ephemral messages in the chat room.
+ * Set lifetime (in seconds) for all new ephemeral messages in the chat room.
  * After the message is read, it will be deleted after "time" seconds.
  * @see linphone_chat_room_ephemeral_enabled()
  * @param chat_room #LinphoneChatRoom object @notnil
- * @param time The ephemral lifetime, default 24h, 86400s
+ * @param time The ephemeral lifetime, default is 0 (disabled)
+ * @warning A value of "time" equal to 0 disables ephemeral messages
  */
 LINPHONE_PUBLIC void linphone_chat_room_set_ephemeral_lifetime (LinphoneChatRoom *chat_room, long time);
 
@@ -165,6 +175,24 @@ LINPHONE_PUBLIC void linphone_chat_room_set_ephemeral_lifetime (LinphoneChatRoom
  */
 LINPHONE_PUBLIC long linphone_chat_room_get_ephemeral_lifetime (const LinphoneChatRoom *chat_room);
 
+/**
+ * Set the ephemeral mode of the chat room
+ * @see linphone_chat_room_ephemeral_enabled()
+ * @param chat_room #LinphoneChatRoom object @notnil
+ * @param mode The ephemeral mode #LinphoneChatRoomEphemeralMode
+ * @warning This function only changes the mode of ephemeral messages #LinphoneChatRoomEphemeralMode. It is required to manually enable ephemeral messages after setting the mode by calling linphone_chat_room_enable_ephemeral()
+ */
+LINPHONE_PUBLIC void linphone_chat_room_set_ephemeral_mode (LinphoneChatRoom *chat_room, LinphoneChatRoomEphemeralMode mode);
+
+/**
+ * Get the ephemeral mode of the chat room.
+ * @see linphone_chat_room_ephemeral_enabled()
+ * @param chat_room #LinphoneChatRoom object @notnil
+ * @return the ephemeral mode #LinphoneChatRoomEphemeralMode
+ */
+LINPHONE_PUBLIC LinphoneChatRoomEphemeralMode linphone_chat_room_get_ephemeral_mode (const LinphoneChatRoom *chat_room);
+
+
 /**
  * Uses linphone spec to check if all participants support ephemeral messages.
  * It doesn't prevent to send ephemeral messages in the room but those who don't support it
@@ -220,6 +248,13 @@ LINPHONE_PUBLIC bctbx_list_t *linphone_chat_room_get_history (LinphoneChatRoom *
  */
 LINPHONE_PUBLIC bctbx_list_t *linphone_chat_room_get_history_range (LinphoneChatRoom *chat_room, int begin, int end);
 
+/**
+ * Gets all unread messages for this chat room, sorted from oldest to most recent.
+ * @param chat_room The #LinphoneChatRoom object corresponding to the conversation for which messages should be retrieved @notnil
+ * @return A list of unread chat messages. \bctbx_list{LinphoneChatMessage} @tobefreed
+ */
+LINPHONE_PUBLIC bctbx_list_t *linphone_chat_room_get_unread_history (LinphoneChatRoom *chat_room);
+
 /**
  * Gets nb_events most recent chat message events from chat_room chat room, sorted from oldest to most recent.
  * @param chat_room The #LinphoneChatRoom object corresponding to the conversation for which events should be retrieved @notnil
@@ -359,9 +394,25 @@ LINPHONE_PUBLIC LinphoneChatRoomState linphone_chat_room_get_state (const Linpho
  * Return whether or not the chat room has been left.
  * @param chat_room #LinphoneChatRoom object @notnil
  * @return TRUE if the chat room has been left, FALSE otherwise.
+ * @deprecated 16/03/2022 use linphone_chat_room_is_read_only() instead.
  */
 LINPHONE_PUBLIC bool_t linphone_chat_room_has_been_left (const LinphoneChatRoom *chat_room);
 
+/**
+ * Return whether or not a message can be sent using this chat room.
+ * A chat room may be read only until it's created, or when it's a group you have left.
+ * @param chat_room #LinphoneChatRoom object @notnil
+ * @return TRUE if a chat message can't be sent in it, FALSE otherwise.
+ */
+LINPHONE_PUBLIC bool_t linphone_chat_room_is_read_only (const LinphoneChatRoom *chat_room);
+
+/**
+ * Return the creation time for the chat room
+ * @param chat_room #LinphoneChatRoom object @notnil
+ * @return the time at which the chat room was created
+ */
+LINPHONE_PUBLIC time_t linphone_chat_room_get_creation_time(const LinphoneChatRoom *chat_room);
+
 /**
  * Return the last updated time for the chat room
  * @param chat_room #LinphoneChatRoom object @notnil
@@ -592,6 +643,13 @@ LINPHONE_PUBLIC LINPHONE_DEPRECATED void linphone_chat_room_send_chat_message(Li
  */
 LINPHONE_PUBLIC LINPHONE_DEPRECATED LinphoneChatMessage* linphone_chat_room_create_message(LinphoneChatRoom *chat_room,const char* message);
 
+/**
+ * Converts a #LinphoneChatRoomState enum to a  string.
+ * @param state a #LinphoneChatRoomState to convert to string
+ * @return the string representation of the #LinphoneChatRoomState @notnil
+*/
+LINPHONE_PUBLIC const char* linphone_chat_room_state_to_string(const LinphoneChatRoomState state);
+
 /**
  * @}
  */
