@@ -28,6 +28,7 @@
 #include "linphone/enums/chat-room-enums.h"
 #include "linphone/enums/conference-enums.h"
 #include "linphone/enums/encryption-engine-enums.h"
+#include "linphone/enums/participant-device-enums.h"
 #include "linphone/enums/event-log-enums.h"
 #include "linphone/enums/security-event-enums.h"
 #include "linphone/utils/enum-generator.h"
@@ -158,6 +159,13 @@ typedef struct _LinphoneConferenceParams LinphoneConferenceParams;
  */
 typedef struct _LinphoneConferenceCbs LinphoneConferenceCbs;
 
+/**
+ * @brief Object defining all informations of a conference
+ *
+ * @ingroup conference
+ */
+typedef struct _LinphoneConferenceInfo LinphoneConferenceInfo;
+
 // -----------------------------------------------------------------------------
 // Participants.
 // -----------------------------------------------------------------------------
@@ -182,6 +190,15 @@ typedef struct _LinphoneParticipant LinphoneParticipant;
  */
 typedef struct _LinphoneParticipantDevice LinphoneParticipantDevice;
 
+/**
+ * @brief An object to handle the callbacks for the handling a #LinphoneParticipantDevice objects.
+ *
+ * Use linphone_factory_create_participant_device_cbs() to create an instance.
+ * Then pass the object to a #LinphoneParticipantDevice instance through linphone_participant_device_add_callbacks().
+ * @ingroup conference
+ */
+typedef struct _LinphoneParticipantDeviceCbs LinphoneParticipantDeviceCbs;
+
 /**
  * @brief This object represents the delivery/display state of a given chat message for a given participant.
  * 
@@ -250,6 +267,20 @@ typedef struct _LinphoneCallCbs LinphoneCallCbs;
 **/
 typedef struct _LinphoneCallParams LinphoneCallParams;
 
+/**
+ * @brief Object used to record the audio or video of a call.
+ * 
+ * @ingroup call_control
+**/
+typedef struct _LinphoneRecorder LinphoneRecorder;
+
+/**
+ * @brief Object containing various parameters of a #LinphoneRecorder.
+ * 
+ * @ingroup call_control
+**/
+typedef struct _LinphoneRecorderParams LinphoneRecorderParams;
+
 /**
  * @brief Object used to keep track of all calls initiated, received or missed.
  * 
@@ -373,6 +404,71 @@ typedef struct _LinphoneChatRoomCbs LinphoneChatRoomCbs;
  */
 typedef struct _LinphoneEventLog LinphoneEventLog;
 
+// -----------------------------------------------------------------------------
+// LDAP.
+// -----------------------------------------------------------------------------
+
+/**
+ * Object that represents a Linphone Ldap.
+ * Use a #LinphoneLdapParams object to configure it.
+ * @ingroup ldap
+ */
+typedef struct _LinphoneLdap LinphoneLdap;
+
+/**
+ * Object that is used to set the different parameters of a #LinphoneLdap.
+ * @ingroup ldap
+ */
+typedef struct _LinphoneLdapParams LinphoneLdapParams;
+
+/**
+ * @brief Enum Debug verbosity for OpenLdap
+ * @ingroup ldap
+**/
+typedef enum _LinphoneLdapDebugLevel {
+	LinphoneLdapDebugLevelOff = 0, /**< Set OpenLdap verbosity to none */
+	LinphoneLdapDebugLevelVerbose = 1, /**< Set OpenLdap verbosity to debug level */
+} LinphoneLdapDebugLevel;
+
+/**
+ * @brief Enum describing how the authentification will be made.
+ * @ingroup ldap
+**/
+typedef enum _LinphoneLdapAuthMethod {
+	LinphoneLdapAuthMethodAnonymous = 0, /**< Connection without passwords */
+	LinphoneLdapAuthMethodSimple = 1, /**< Connection with username/password */
+} LinphoneLdapAuthMethod;
+
+/**
+ * @brief Enum describing server certificates verification modes.
+ * @ingroup ldap
+**/
+typedef enum _LinphoneLdapCertVerificationMode {
+	LinphoneLdapCertVerificationDefault = -1, /**< Use default value defined on core */
+	LinphoneLdapCertVerificationDisabled = 0, /**< Verification is disabled*/
+	LinphoneLdapCertVerificationEnabled = 1 /**< Verification is enabled*/
+} LinphoneLdapCertVerificationMode;
+
+/**
+ * @brief Enum describing errors in LDAP parameters.
+ * @ingroup ldap
+**/
+typedef enum _LinphoneLdapCheck{
+	LinphoneLdapCheckOk = 0,						/**< No error */
+
+	LinphoneLdapCheckServerEmpty = 1,				/**< Server field is empty */
+	LinphoneLdapCheckServerNotUrl = 2,				/**< The server is not an url*/
+	LinphoneLdapCheckServerNoScheme = 4,			/**< The server doesn't contain a scheme*/
+	LinphoneLdapCheckServerNotLdap = 8,				/**< The server is not a LDAP scheme */
+	LinphoneLdapCheckServerLdaps = 16,				/**< LDAP over SSL is non-standardized and deprecated: ldaps has been specified */
+
+	LinphoneLdapCheckBaseObjectEmpty = 32,			/**< Base Object has been specified */
+
+	LinphoneLdapCheckMissingFields = 64,			/**< Some required fields are missing*/
+
+}LinphoneLdapCheck;
+
+
 // -----------------------------------------------------------------------------
 // Misc.
 // -----------------------------------------------------------------------------
@@ -441,12 +537,24 @@ typedef struct _LinphoneSearchResult LinphoneSearchResult;
 // -----------------------------------------------------------------------------
 // Digest authentication policy.
 // -----------------------------------------------------------------------------
+
 /**
  * @brief The LinphoneDigestAuthenticationPolicy holds parameters relative to digest authentication procedures.
  * @ingroup misc
  */
 typedef struct _LinphoneDigestAuthenticationPolicy LinphoneDigestAuthenticationPolicy;
 
+
+// -----------------------------------------------------------------------------
+// Friend.
+// -----------------------------------------------------------------------------
+
+/**
+ * Object that represents a #LinphoneFriend's phone number.
+ * @ingroup buddy_list
+ */
+typedef struct _LinphoneFriendPhoneNumber LinphoneFriendPhoneNumber;
+
 #ifdef __cplusplus
 	}
 #endif // ifdef __cplusplus
