@@ -92,43 +92,101 @@ LINPHONE_PUBLIC LinphoneConferenceParams *linphone_conference_params_clone(const
  * Enable audio capabilities
  * @param params A #LinphoneConferenceParams @notnil
  * @param enable If TRUE, audio will be enabled during conference
+ * @deprecated 16/12/2021 Use linphone_conference_params_enable_audio() instead.
  */
 LINPHONE_PUBLIC void linphone_conference_params_set_audio_enabled(LinphoneConferenceParams *params, bool_t enable);
 
+/**
+ * Enable audio capabilities
+ * @param params A #LinphoneConferenceParams @notnil
+ * @param enable If TRUE, audio will be enabled during conference
+ */
+LINPHONE_PUBLIC void linphone_conference_params_enable_audio(LinphoneConferenceParams *params, bool_t enable);
+
+/**
+ * Check whether audio capabilities are enabled
+ * @param params A #LinphoneConferenceParams @notnil
+ * @return TRUE if the conference supports audio capabilities, FALSE otherwise
+ * @deprecated 16/12/2021 Use linphone_conference_params_audio_enabled() instead.
+ */
+LINPHONE_PUBLIC bool_t linphone_conference_params_is_audio_enabled(const LinphoneConferenceParams *params);
+
 /**
  * Check whether audio capabilities are enabled
  * @param params A #LinphoneConferenceParams @notnil
  * @return TRUE if the conference supports audio capabilities, FALSE otherwise
  */
-LINPHONE_PUBLIC bool_t linphone_conference_params_is_audio_enabled(const LinphoneConferenceParams *params);
+LINPHONE_PUBLIC bool_t linphone_conference_params_audio_enabled(const LinphoneConferenceParams *params);
+
+/**
+ * Enable video capabilities
+ * @param params A #LinphoneConferenceParams @notnil
+ * @param enable If TRUE, video will be enabled during conference
+ * @deprecated 16/12/2021 Use linphone_conference_params_enable_video() instead.
+ */
+LINPHONE_PUBLIC void linphone_conference_params_set_video_enabled(LinphoneConferenceParams *params, bool_t enable);
 
 /**
  * Enable video capabilities
  * @param params A #LinphoneConferenceParams @notnil
  * @param enable If TRUE, video will be enabled during conference
  */
-LINPHONE_PUBLIC void linphone_conference_params_set_video_enabled(LinphoneConferenceParams *params, bool_t enable);
+LINPHONE_PUBLIC void linphone_conference_params_enable_video(LinphoneConferenceParams *params, bool_t enable);
+
+/**
+ * Check whether video capabilities are enabled
+ * @param params A #LinphoneConferenceParams @notnil
+ * @return TRUE if the conference supports video capabilities, FALSE otherwise
+ * @deprecated 16/12/2021 Use linphone_conference_params_video_enabled() instead.
+ */
+LINPHONE_PUBLIC bool_t linphone_conference_params_is_video_enabled(const LinphoneConferenceParams *params);
 
 /**
  * Check whether video capabilities are enabled
  * @param params A #LinphoneConferenceParams @notnil
  * @return TRUE if the conference supports video capabilities, FALSE otherwise
  */
-LINPHONE_PUBLIC bool_t linphone_conference_params_is_video_enabled(const LinphoneConferenceParams *params);
+LINPHONE_PUBLIC bool_t linphone_conference_params_video_enabled(const LinphoneConferenceParams *params);
+
+/**
+ * Enable chat capabilities
+ * @param params A #LinphoneConferenceParams @notnil
+ * @param enable If TRUE, chat is enabled during conference
+ * @deprecated 16/12/2021 Use linphone_conference_params_enable_chat() instead.
+ */
+LINPHONE_PUBLIC void linphone_conference_params_set_chat_enabled(LinphoneConferenceParams *params, bool_t enable);
 
 /**
  * Enable chat capabilities
  * @param params A #LinphoneConferenceParams @notnil
  * @param enable If TRUE, chat is enabled during conference
  */
-LINPHONE_PUBLIC void linphone_conference_params_set_chat_enabled(LinphoneConferenceParams *params, bool_t enable);
+LINPHONE_PUBLIC void linphone_conference_params_enable_chat(LinphoneConferenceParams *params, bool_t enable);
+
+/**
+ * Check whether chat capabilities are enabled
+ * @param params A #LinphoneConferenceParams @notnil
+ * @return TRUE if the conference supports chat capabilities, FALSE otherwise
+ * @deprecated 16/12/2021 Use linphone_conference_params_chat_enabled() instead.
+ */
+LINPHONE_PUBLIC bool_t linphone_conference_params_is_chat_enabled(const LinphoneConferenceParams *params);
 
 /**
  * Check whether chat capabilities are enabled
  * @param params A #LinphoneConferenceParams @notnil
  * @return TRUE if the conference supports chat capabilities, FALSE otherwise
  */
-LINPHONE_PUBLIC bool_t linphone_conference_params_is_chat_enabled(const LinphoneConferenceParams *params);
+LINPHONE_PUBLIC bool_t linphone_conference_params_chat_enabled(const LinphoneConferenceParams *params);
+
+/**
+ * Enable local participant to enter the conference.
+ * The local participant is the one driving the local #LinphoneCore. It uses the local sound devices.
+ * The default value is TRUE. Setting to FALSE is mostly helpful when using liblinphone on a server application.
+ * @param params A #LinphoneConferenceParams @notnil
+ * @param enable TRUE if local participant is automatically added to the conference, FALSE otherwise
+ * @deprecated 16/12/2021 Use linphone_conference_params_enable_local_participant() instead.
+ */
+LINPHONE_PUBLIC void linphone_conference_params_set_local_participant_enabled(LinphoneConferenceParams *params, bool_t enable);
 
 /**
  * Enable local participant to enter the conference.
@@ -137,29 +195,52 @@ LINPHONE_PUBLIC bool_t linphone_conference_params_is_chat_enabled(const Linphone
  * @param params A #LinphoneConferenceParams @notnil
  * @param enable TRUE if local participant is automatically added to the conference, FALSE otherwise
  */
-LINPHONE_PUBLIC void linphone_conference_params_set_local_participant_enabled(LinphoneConferenceParams *params, bool_t enable);
+LINPHONE_PUBLIC void linphone_conference_params_enable_local_participant(LinphoneConferenceParams *params, bool_t enable);
+
+/**
+ * Returns whether local participant has to enter the conference.
+ * @param params A #LinphoneConferenceParams @notnil
+ * @return TRUE if local participant is by default part of the conference, FALSE otherwise
+ * @deprecated 16/12/2021 Use linphone_conference_params_local_participant_enabled() instead.
+ */
+LINPHONE_PUBLIC bool_t linphone_conference_params_is_local_participant_enabled(const LinphoneConferenceParams *params);
 
 /**
  * Returns whether local participant has to enter the conference.
  * @param params A #LinphoneConferenceParams @notnil
  * @return TRUE if local participant is by default part of the conference, FALSE otherwise
  */
-LINPHONE_PUBLIC bool_t linphone_conference_params_is_local_participant_enabled(const LinphoneConferenceParams *params);
+LINPHONE_PUBLIC bool_t linphone_conference_params_local_participant_enabled(const LinphoneConferenceParams *params);
+
+/**
+ * Enable conference with one participant.
+ * @param params A #LinphoneConferenceParams @notnil
+ * @param enable TRUE if conference can have only one participant, FALSE otherwise
+ * @deprecated 16/12/2021 Use linphone_conference_params_enable_one_participant_conference() instead.
+ */
+LINPHONE_PUBLIC void linphone_conference_params_set_one_participant_conference_enabled(LinphoneConferenceParams *params, bool_t enable);
 
 /**
  * Enable conference with one participant.
  * @param params A #LinphoneConferenceParams @notnil
  * @param enable TRUE if conference can have only one participant, FALSE otherwise
  */
-LINPHONE_PUBLIC void linphone_conference_params_set_one_participant_conference_enabled(LinphoneConferenceParams *params, bool_t enable);
+LINPHONE_PUBLIC void linphone_conference_params_enable_one_participant_conference(LinphoneConferenceParams *params, bool_t enable);
+
+/**
+ * Returns whether conference can have only one participant
+ * @param params A #LinphoneConferenceParams @notnil
+ * @return TRUE if the conference can have only one participant, FALSE otherwise
+ * @deprecated 16/12/2021 Use linphone_conference_params_one_participant_conference_enabled() instead.
+ */
+LINPHONE_PUBLIC bool_t linphone_conference_params_is_one_participant_conference_enabled(const LinphoneConferenceParams *params);
 
 /**
  * Returns whether conference can have only one participant
  * @param params A #LinphoneConferenceParams @notnil
  * @return TRUE if the conference can have only one participant, FALSE otherwise
  */
-LINPHONE_PUBLIC bool_t linphone_conference_params_is_one_participant_conference_enabled(const LinphoneConferenceParams *params);
-
+LINPHONE_PUBLIC bool_t linphone_conference_params_one_participant_conference_enabled(const LinphoneConferenceParams *params);
 
 /**
  * Take a reference on a #LinphoneConference.
@@ -406,6 +487,14 @@ LINPHONE_PUBLIC const LinphoneAudioDevice* linphone_conference_get_input_audio_d
  */
 LINPHONE_PUBLIC const LinphoneAudioDevice* linphone_conference_get_output_audio_device(const LinphoneConference *conference);
 
+/**
+ * Retrieves the volume of a specific participant
+ * @param conference A #LinphoneConference object @notnil
+ * @param device The Participant @notnil
+ * @return The volume of the participant expressed in dbm0.
+ */
+LINPHONE_PUBLIC int linphone_conference_get_participant_device_volume(LinphoneConference *conference, LinphoneParticipantDevice *device);
+
 /**
  * Starts recording the conference.
  * @param conference A #LinphoneConference object @notnil
@@ -428,7 +517,6 @@ LINPHONE_PUBLIC int linphone_conference_stop_recording(LinphoneConference *confe
  */
 LINPHONE_PUBLIC bool_t linphone_conference_is_recording(const LinphoneConference *conference);
 
-
 /************ */
 /* DEPRECATED */
 /* ********** */
