@@ -59,6 +59,7 @@ AccountParams::AccountParams (LinphoneCore *lc) {
 	mQualityReportingInterval = lc ? linphone_config_get_default_int(lc->config, "proxy", "quality_reporting_interval", 0) : 0;
 	mContactParameters = lc ? linphone_config_get_default_string(lc->config, "proxy", "contact_parameters", "") : "";
 	mContactUriParameters = lc ? linphone_config_get_default_string(lc->config, "proxy", "contact_uri_parameters", "") : "";
+	mAllowCpimMessagesInBasicChatRooms = lc ? !!linphone_config_get_default_int(lc->config, "proxy", "cpim_in_basic_chat_rooms_enabled", false) : false;
 	
 	mAvpfMode = lc ? static_cast<LinphoneAVPFMode>(linphone_config_get_default_int(lc->config, "proxy", "avpf", LinphoneAVPFDefault)) : LinphoneAVPFDefault;
 	mAvpfRrInterval = lc ? !!linphone_config_get_default_int(lc->config, "proxy", "avpf_rr_interval", 5) : 5;
@@ -118,6 +119,16 @@ AccountParams::AccountParams (LinphoneCore *lc, int index) : AccountParams(lc) {
 	if (routes != nullptr) {
 		setRoutesFromStringList(routes);
 		bctbx_list_free_with_data(routes, (bctbx_list_free_func)bctbx_free);
+	} else {
+		// Remove default routes if the existing account doesn't have any
+		if (mRoutes) {
+			bctbx_list_free_with_data(mRoutes, (bctbx_list_free_func)linphone_address_unref);
+			mRoutes = nullptr;
+		}
+		if (mRoutesString) {
+			bctbx_list_free_with_data(mRoutesString, (bctbx_list_free_func)bctbx_free);
+			mRoutesString = nullptr;
+		}
 	}
 
 	mRealm = linphone_config_get_string(config, key, "realm", mRealm.c_str());
@@ -146,6 +157,7 @@ AccountParams::AccountParams (LinphoneCore *lc, int index) : AccountParams(lc) {
 	mDialEscapePlusEnabled = !!linphone_config_get_int(config, key, "dial_escape_plus", mDialEscapePlusEnabled);
 	mInternationalPrefix = linphone_config_get_string(config, key, "dial_prefix", mInternationalPrefix.c_str());
 	mUseInternationalPrefixForCallsAndChats = !!linphone_config_get_int(config, key, "use_dial_prefix_for_calls_and_chats", mUseInternationalPrefixForCallsAndChats);
+	mAllowCpimMessagesInBasicChatRooms = !!linphone_config_get_default_int(config, key, "cpim_in_basic_chat_rooms_enabled", mAllowCpimMessagesInBasicChatRooms);
 
 	mPrivacy = static_cast<LinphonePrivacyMask>(linphone_config_get_int(config, key, "privacy", static_cast<int>(mPrivacy)));
 
@@ -165,7 +177,7 @@ AccountParams::AccountParams (LinphoneCore *lc, int index) : AccountParams(lc) {
 		mNatPolicy = linphone_core_create_nat_policy_from_config(lc, nat_policy_ref);
 	}
 
-	mConferenceFactoryUri = linphone_config_get_string(config, key, "conference_factory_uri", mConferenceFactoryUri.c_str());
+	mConferenceFactoryUri = linphone_config_get_string(config, key, "conference_factory_uri", "");
 }
 
 AccountParams::AccountParams (const AccountParams &other) : HybridObject(other) {
@@ -181,6 +193,7 @@ AccountParams::AccountParams (const AccountParams &other) : HybridObject(other)
 	mPushNotificationAllowed = other.mPushNotificationAllowed;
 	mRemotePushNotificationAllowed = other.mRemotePushNotificationAllowed;
 	mUseInternationalPrefixForCallsAndChats = other.mUseInternationalPrefixForCallsAndChats;
+	mAllowCpimMessagesInBasicChatRooms = other.mAllowCpimMessagesInBasicChatRooms;
 
 	mUserData = other.mUserData;
 
@@ -292,6 +305,10 @@ void AccountParams::setUseInternationalPrefixForCallsAndChats (bool enable) {
 	mUseInternationalPrefixForCallsAndChats = enable;
 }
 
+void AccountParams::setCpimMessagesAllowedInBasicChatRooms (bool allow) {
+	mAllowCpimMessagesInBasicChatRooms = allow;
+}
+
 void AccountParams::setUserData (void *userData) {
 	mUserData = userData;
 }
@@ -522,6 +539,10 @@ bool AccountParams::isPushNotificationAvailable () const {
 
 }
 
+bool AccountParams::isCpimMessagesAllowedInBasicChatRooms () const {
+	return mAllowCpimMessagesInBasicChatRooms;
+}
+
 void* AccountParams::getUserData () const {
 	return mUserData;
 }
@@ -716,23 +737,23 @@ void AccountParams::writeToConfigFile (LinphoneConfig *config, int index) {
 	
 	string pushParams;
 	if (mPushNotificationAllowed || mRemotePushNotificationAllowed) {
-		bool isLegacyPush = !!linphone_config_get_int(config, "net", "use_legacy_push_notification_params", FALSE);
-		pushParams = mPushNotificationConfig->asString(mRemotePushNotificationAllowed, isLegacyPush);
+		pushParams = mPushNotificationConfig->asString(mRemotePushNotificationAllowed);
 	}
 	linphone_config_set_string(config, key, "push_parameters", pushParams.c_str());
-	linphone_config_set_int(config, key, "quality_reporting_enabled", mQualityReportingEnabled);
+	linphone_config_set_int(config, key, "quality_reporting_enabled", (int)mQualityReportingEnabled);
 	linphone_config_set_int(config, key, "quality_reporting_interval", mQualityReportingInterval);
 	linphone_config_set_int(config, key, "reg_expires", mExpires);
-	linphone_config_set_int(config, key, "reg_sendregister", mRegisterEnabled);
-	linphone_config_set_int(config, key, "publish", mPublishEnabled);
+	linphone_config_set_int(config, key, "reg_sendregister", (int)mRegisterEnabled);
+	linphone_config_set_int(config, key, "publish", (int)mPublishEnabled);
 	linphone_config_set_int(config, key, "avpf", mAvpfMode);
 	linphone_config_set_int(config, key, "avpf_rr_interval", mAvpfRrInterval);
-	linphone_config_set_int(config, key, "dial_escape_plus", mDialEscapePlusEnabled);
+	linphone_config_set_int(config, key, "dial_escape_plus", (int)mDialEscapePlusEnabled);
 	linphone_config_set_string(config,key,"dial_prefix", mInternationalPrefix.c_str());
 	linphone_config_set_int(config, key, "use_dial_prefix_for_calls_and_chats", mUseInternationalPrefixForCallsAndChats);
 	linphone_config_set_int(config, key, "privacy", (int)mPrivacy);
 	linphone_config_set_int(config, key, "push_notification_allowed", (int)mPushNotificationAllowed);
 	linphone_config_set_int(config, key, "remote_push_notification_allowed", (int)mRemotePushNotificationAllowed);
+	linphone_config_set_int(config, key, "cpim_in_basic_chat_rooms_enabled", (int)mAllowCpimMessagesInBasicChatRooms);
 	if (!mRefKey.empty()) linphone_config_set_string(config, key, "refkey", mRefKey.c_str());
 	if (!mDependsOn.empty()) linphone_config_set_string(config, key, "depends_on", mDependsOn.c_str());
 	if (!mIdKey.empty()) linphone_config_set_string(config, key, "idkey", mIdKey.c_str());
