@@ -80,6 +80,10 @@ SalStreamDir get_video_dir_from_call_params (const LinphoneCallParams *params) {
 }
 
 bool_t linphone_call_params_is_capability_negotiation_reinvite_enabled(const LinphoneCallParams *params) {
+	return linphone_call_params_capability_negotiation_reinvite_enabled(params);
+}
+
+bool_t linphone_call_params_capability_negotiation_reinvite_enabled(const LinphoneCallParams *params) {
 	return !!L_GET_PRIVATE_FROM_C_OBJECT(params)->capabilityNegotiationReInviteEnabled();
 }
 
@@ -586,6 +590,10 @@ void linphone_call_params_enable_rtp_bundle(LinphoneCallParams *params, bool_t v
 	L_GET_CPP_PTR_FROM_C_OBJECT(params)->enableRtpBundle(!!value);
 }
 
+bool_t linphone_call_params_is_recording(const LinphoneCallParams *params) {
+	return L_GET_CPP_PTR_FROM_C_OBJECT(params)->isRecording();
+}
+
 // =============================================================================
 // Reference and user data handling functions.
 // =============================================================================
