@@ -35,9 +35,7 @@ using namespace std;
 using namespace LinphonePrivate;
 
 
-// =============================================================================
-// TODO: To remove!
-// =============================================================================
+
 
 /*This function is not static because used internally in linphone-daemon project*/
 void _post_configure_audio_stream (AudioStream *st, LinphoneCore *lc, bool_t muted) {
@@ -82,60 +80,64 @@ bool_t linphone_call_get_all_muted (const LinphoneCall *call) {
 
 
 void linphone_call_notify_state_changed (LinphoneCall *call, LinphoneCallState cstate, const char *message) {
-	LINPHONE_HYBRID_OBJECT_INVOKE_CBS_WITH_C(Call, Call::toCpp(call), linphone_call_cbs_get_state_changed, cstate, message);
+	LINPHONE_HYBRID_OBJECT_INVOKE_CBS(Call, Call::toCpp(call), linphone_call_cbs_get_state_changed, cstate, message);
 	linphone_core_notify_call_state_changed(linphone_call_get_core(call), call, cstate, message);
 }
 
 void linphone_call_notify_dtmf_received (LinphoneCall *call, int dtmf) {
-	LINPHONE_HYBRID_OBJECT_INVOKE_CBS_WITH_C(Call, Call::toCpp(call), linphone_call_cbs_get_dtmf_received, dtmf);
+	LINPHONE_HYBRID_OBJECT_INVOKE_CBS(Call, Call::toCpp(call), linphone_call_cbs_get_dtmf_received, dtmf);
 	linphone_core_notify_dtmf_received(linphone_call_get_core(call), call, dtmf);
 }
 
 void linphone_call_notify_encryption_changed (LinphoneCall *call, bool_t on, const char *authentication_token) {
-	LINPHONE_HYBRID_OBJECT_INVOKE_CBS_WITH_C(Call, Call::toCpp(call), linphone_call_cbs_get_encryption_changed, on, authentication_token);
+	LINPHONE_HYBRID_OBJECT_INVOKE_CBS(Call, Call::toCpp(call), linphone_call_cbs_get_encryption_changed, on, authentication_token);
 	linphone_core_notify_call_encryption_changed(linphone_call_get_core(call), call, on, authentication_token);
 }
 
 void linphone_call_notify_transfer_state_changed (LinphoneCall *call, LinphoneCallState cstate) {
-	LINPHONE_HYBRID_OBJECT_INVOKE_CBS_WITH_C(Call, Call::toCpp(call), linphone_call_cbs_get_transfer_state_changed, cstate);
+	LINPHONE_HYBRID_OBJECT_INVOKE_CBS(Call, Call::toCpp(call), linphone_call_cbs_get_transfer_state_changed, cstate);
 	linphone_core_notify_transfer_state_changed(linphone_call_get_core(call), call, cstate);
 }
 
 void linphone_call_notify_stats_updated (LinphoneCall *call, const LinphoneCallStats *stats) {
-	LINPHONE_HYBRID_OBJECT_INVOKE_CBS_WITH_C(Call, Call::toCpp(call), linphone_call_cbs_get_stats_updated, stats);
+	LINPHONE_HYBRID_OBJECT_INVOKE_CBS(Call, Call::toCpp(call), linphone_call_cbs_get_stats_updated, stats);
 	linphone_core_notify_call_stats_updated(linphone_call_get_core(call), call, stats);
 }
 
 void linphone_call_notify_info_message_received (LinphoneCall *call, const LinphoneInfoMessage *msg) {
-	LINPHONE_HYBRID_OBJECT_INVOKE_CBS_WITH_C(Call, Call::toCpp(call), linphone_call_cbs_get_info_message_received, msg);
+	LINPHONE_HYBRID_OBJECT_INVOKE_CBS(Call, Call::toCpp(call), linphone_call_cbs_get_info_message_received, msg);
 	linphone_core_notify_info_received(linphone_call_get_core(call), call, msg);
 }
 
 void linphone_call_notify_ack_processing (LinphoneCall *call, LinphoneHeaders *msg, bool_t is_received) {
-	LINPHONE_HYBRID_OBJECT_INVOKE_CBS_WITH_C(Call, Call::toCpp(call), linphone_call_cbs_get_ack_processing, msg, is_received);
+	LINPHONE_HYBRID_OBJECT_INVOKE_CBS(Call, Call::toCpp(call), linphone_call_cbs_get_ack_processing, msg, is_received);
 }
 
 void linphone_call_notify_tmmbr_received (LinphoneCall *call, int stream_index, int tmmbr) {
-	LINPHONE_HYBRID_OBJECT_INVOKE_CBS_WITH_C(Call, Call::toCpp(call), linphone_call_cbs_get_tmmbr_received, stream_index, tmmbr);
+	LINPHONE_HYBRID_OBJECT_INVOKE_CBS(Call, Call::toCpp(call), linphone_call_cbs_get_tmmbr_received, stream_index, tmmbr);
 }
 
 void linphone_call_notify_snapshot_taken(LinphoneCall *call, const char *file_path) {
-	LINPHONE_HYBRID_OBJECT_INVOKE_CBS_WITH_C(Call, Call::toCpp(call), linphone_call_cbs_get_snapshot_taken, file_path);
+	LINPHONE_HYBRID_OBJECT_INVOKE_CBS(Call, Call::toCpp(call), linphone_call_cbs_get_snapshot_taken, file_path);
 }
 
 void linphone_call_notify_next_video_frame_decoded(LinphoneCall *call) {
-	LINPHONE_HYBRID_OBJECT_INVOKE_CBS_WITH_C_NO_ARG(Call, Call::toCpp(call), linphone_call_cbs_get_next_video_frame_decoded);
+	LINPHONE_HYBRID_OBJECT_INVOKE_CBS_NO_ARG(Call, Call::toCpp(call), linphone_call_cbs_get_next_video_frame_decoded);
 }
 
 void linphone_call_notify_camera_not_working(LinphoneCall *call, const char *camera_name) {
-	LINPHONE_HYBRID_OBJECT_INVOKE_CBS_WITH_C(Call, Call::toCpp(call), linphone_call_cbs_get_camera_not_working, camera_name);
+	LINPHONE_HYBRID_OBJECT_INVOKE_CBS(Call, Call::toCpp(call), linphone_call_cbs_get_camera_not_working, camera_name);
 }
 
 void linphone_call_notify_audio_device_changed(LinphoneCall *call, LinphoneAudioDevice *audioDevice) {
-	LINPHONE_HYBRID_OBJECT_INVOKE_CBS_WITH_C(Call, Call::toCpp(call), linphone_call_cbs_get_audio_device_changed, audioDevice);
+	LINPHONE_HYBRID_OBJECT_INVOKE_CBS(Call, Call::toCpp(call), linphone_call_cbs_get_audio_device_changed, audioDevice);
 	linphone_core_notify_audio_device_changed(linphone_call_get_core(call), audioDevice);
 }
 
+void linphone_call_notify_remote_recording(LinphoneCall *call, bool_t recording) {
+	LINPHONE_HYBRID_OBJECT_INVOKE_CBS(Call, Call::toCpp(call), linphone_call_cbs_get_remote_recording, recording);
+}
+
 // =============================================================================
 // Public functions.
 // =============================================================================
@@ -543,19 +545,19 @@ LinphoneCallStats *linphone_call_get_text_stats (LinphoneCall *call) {
 }
 
 void linphone_call_add_callbacks (LinphoneCall *call, LinphoneCallCbs *cbs) {
-	Call::toCpp(call)->addCallbacks(cbs);
+	Call::toCpp(call)->addCallbacks(CallCbs::toCpp(cbs)->getSharedFromThis());
 }
 
 void linphone_call_remove_callbacks (LinphoneCall *call, LinphoneCallCbs *cbs) {
-	Call::toCpp(call)->removeCallbacks(cbs);
+	Call::toCpp(call)->removeCallbacks(CallCbs::toCpp(cbs)->getSharedFromThis());
 }
 
 LinphoneCallCbs *linphone_call_get_current_callbacks (const LinphoneCall *call) {
-	return Call::toCpp(call)->getCurrentCallbacks();
+	return Call::toCpp(call)->getCurrentCallbacks()->toC();
 }
 
 const bctbx_list_t *linphone_call_get_callbacks_list(const LinphoneCall *call) {
-	return Call::toCpp(call)->getCallbacksList();
+	return Call::toCpp(call)->getCCallbacksList();
 }
 
 void linphone_call_set_params (LinphoneCall *call, const LinphoneCallParams *params) {
@@ -612,6 +614,10 @@ LinphoneCall *linphone_call_new_incoming_with_callid (LinphoneCore *lc, const ch
 	return lcall;
 }
 
+void linphone_call_notify_ringing(LinphoneCall *call) {
+	Call::toCpp(call)->notifyRinging();
+}
+
 void linphone_call_start_push_incoming_notification(LinphoneCall *call) {
 	Call::toCpp(call)->startPushIncomingNotification();
 }
