@@ -186,6 +186,18 @@ LinphoneChatMessage *linphone_chat_room_create_reply_message (LinphoneChatRoom *
 	return object;
 }
 
+LinphoneChatMessage *linphone_chat_room_create_voice_recording_message (LinphoneChatRoom *cr, LinphoneRecorder *recorder) {
+	LinphoneChatMessage *chat_message = linphone_chat_room_create_empty_message(cr);
+
+	LinphoneContent *c_content = linphone_recorder_create_content(recorder);
+	if (c_content != nullptr) {
+		linphone_chat_message_add_content(chat_message, c_content);
+		linphone_content_unref(c_content);
+	}
+
+	return chat_message;
+}
+
 void linphone_chat_room_send_chat_message_2 (LinphoneChatRoom *cr, LinphoneChatMessage *msg) {
 	linphone_chat_message_ref(msg);
 	L_GET_CPP_PTR_FROM_C_OBJECT(msg)->send();
@@ -221,6 +233,14 @@ void linphone_chat_room_mark_as_read (LinphoneChatRoom *cr) {
 	L_GET_CPP_PTR_FROM_C_OBJECT(cr)->markAsRead();
 }
 
+void linphone_chat_room_set_ephemeral_mode (LinphoneChatRoom *cr, LinphoneChatRoomEphemeralMode mode) {
+	L_GET_CPP_PTR_FROM_C_OBJECT(cr)->setEphemeralMode(static_cast<LinphonePrivate::AbstractChatRoom::EphemeralMode>(mode), true);
+}
+
+LinphoneChatRoomEphemeralMode linphone_chat_room_get_ephemeral_mode (const LinphoneChatRoom *cr) {
+	return static_cast<LinphoneChatRoomEphemeralMode>(L_GET_CPP_PTR_FROM_C_OBJECT(cr)->getEphemeralMode());
+}
+
 void linphone_chat_room_enable_ephemeral (LinphoneChatRoom *cr, bool_t ephem) {
 	L_GET_CPP_PTR_FROM_C_OBJECT(cr)->enableEphemeral(!!ephem, true);
 }
@@ -273,6 +293,10 @@ bctbx_list_t *linphone_chat_room_get_history (LinphoneChatRoom *cr, int nb_messa
 	return linphone_chat_room_get_history_range(cr, 0, nb_message);
 }
 
+bctbx_list_t *linphone_chat_room_get_unread_history (LinphoneChatRoom *cr) {
+	return L_GET_RESOLVED_C_LIST_FROM_CPP_LIST(L_GET_CPP_PTR_FROM_C_OBJECT(cr)->getUnreadChatMessages());
+}
+
 bctbx_list_t *linphone_chat_room_get_history_range_message_events (LinphoneChatRoom *cr, int startm, int endm) {
 	return L_GET_RESOLVED_C_LIST_FROM_CPP_LIST(L_GET_CPP_PTR_FROM_C_OBJECT(cr)->getMessageHistoryRange(startm, endm));
 }
@@ -317,6 +341,14 @@ bool_t linphone_chat_room_has_been_left (const LinphoneChatRoom *cr) {
 	return (bool_t)L_GET_CPP_PTR_FROM_C_OBJECT(cr)->hasBeenLeft();
 }
 
+bool_t linphone_chat_room_is_read_only (const LinphoneChatRoom *cr) {
+	return (bool_t)L_GET_CPP_PTR_FROM_C_OBJECT(cr)->isReadOnly();
+}
+
+time_t linphone_chat_room_get_creation_time(const LinphoneChatRoom *cr) {
+	return L_GET_CPP_PTR_FROM_C_OBJECT(cr)->getCreationTime();
+}
+
 time_t linphone_chat_room_get_last_update_time(const LinphoneChatRoom *cr) {
 	return L_GET_CPP_PTR_FROM_C_OBJECT(cr)->getLastUpdateTime();
 }
@@ -720,3 +752,27 @@ LinphoneChatRoomState linphone_conference_state_to_chat_room_state(LinphoneConfe
 	}
 	return LinphoneChatRoomStateNone;
 }
+
+const char* linphone_chat_room_state_to_string(const LinphoneChatRoomState state) {
+	switch (state) {
+		case LinphoneChatRoomStateNone:
+			return "LinphoneChatRoomStateNone";
+		case LinphoneChatRoomStateInstantiated:
+			return "LinphoneChatRoomStateInstantiated";
+		case LinphoneChatRoomStateCreationPending:
+			return "LinphoneChatRoomStateCreationPending";
+		case LinphoneChatRoomStateCreated:
+			return "LinphoneChatRoomStateCreated";
+		case LinphoneChatRoomStateCreationFailed:
+			return "LinphoneChatRoomStateCreationFailed";
+		case LinphoneChatRoomStateTerminationPending:
+			return "LinphoneChatRoomStateTerminationPending";
+		case LinphoneChatRoomStateTerminated:
+			return "LinphoneChatRoomStateTerminated";
+		case LinphoneChatRoomStateTerminationFailed:
+			return "LinphoneChatRoomStateTerminationFailed";
+		case LinphoneChatRoomStateDeleted:
+			return "LinphoneChatRoomStateDeleted";
+	}
+	return "Unknown state";
+}
