@@ -186,7 +186,7 @@ const char *linphone_content_get_name (const LinphoneContent *content) {
 	const LinphonePrivate::Content *c = L_GET_CPP_PTR_FROM_C_OBJECT(content);
 	if (c->isFile())
 		return static_cast<const LinphonePrivate::FileContent *>(c)->getFileName().c_str();
-	if (c->isFileTransfer())
+	else if (c->isFileTransfer())
 		return static_cast<const LinphonePrivate::FileTransferContent *>(c)->getFileName().c_str();
 	return content->cache.name.c_str();
 }
@@ -338,45 +338,77 @@ void linphone_content_set_authTag (LinphoneContent *content, const char *tag, co
 
 const char *linphone_content_get_file_path (const LinphoneContent *content) {
 	const LinphonePrivate::Content *c = L_GET_CPP_PTR_FROM_C_OBJECT(content);
-	if (c->isFile())
-		return static_cast<const LinphonePrivate::FileContent *>(c)->getFilePath().c_str();
-	if (c->isFileTransfer())
-		return static_cast<const LinphonePrivate::FileTransferContent *>(c)->getFilePath().c_str();
-	return content->cache.file_path.c_str();
+	if (c->isFile()) {
+		return L_STRING_TO_C(static_cast<const LinphonePrivate::FileContent *>(c)->getFilePath());
+	} else if (c->isFileTransfer()) {
+		return L_STRING_TO_C(static_cast<const LinphonePrivate::FileTransferContent *>(c)->getFilePath());
+	}
+	return L_STRING_TO_C(content->cache.file_path);
 }
 
 char *linphone_content_get_plain_file_path (const LinphoneContent *content) {
 	const LinphonePrivate::Content *c = L_GET_CPP_PTR_FROM_C_OBJECT(content);
 	if (c->isFile()) {
-		return bctbx_strdup(static_cast<const LinphonePrivate::FileContent *>(c)->getPlainFilePath().c_str());
+		return bctbx_strdup(L_STRING_TO_C(static_cast<const LinphonePrivate::FileContent *>(c)->getPlainFilePath()));
 	} else if (c->isFileTransfer()) {
-		return bctbx_strdup(static_cast<const LinphonePrivate::FileTransferContent *>(c)->getPlainFilePath().c_str());
+		return bctbx_strdup(L_STRING_TO_C(static_cast<const LinphonePrivate::FileTransferContent *>(c)->getPlainFilePath()));
 	}
 	return NULL;
 }
 
 void linphone_content_set_file_path (LinphoneContent *content, const char *file_path) {
 	LinphonePrivate::Content *c = L_GET_CPP_PTR_FROM_C_OBJECT(content);
-	if (c->isFile())
+	if (c->isFile()) {
 		static_cast<LinphonePrivate::FileContent *>(c)->setFilePath(L_C_TO_STRING(file_path));
-	if (c->isFileTransfer())
+	}
+	else if (c->isFileTransfer()) {
 		static_cast<LinphonePrivate::FileTransferContent *>(c)->setFilePath(L_C_TO_STRING(file_path));
+	}
 	content->cache.file_path = L_C_TO_STRING(file_path);
 }
 
+int linphone_content_get_file_duration (LinphoneContent *content) {
+	LinphonePrivate::Content *c = L_GET_CPP_PTR_FROM_C_OBJECT(content);
+	if (c->isFile())
+		return static_cast<LinphonePrivate::FileContent *>(c)->getFileDuration();
+	else if (c->isFileTransfer())
+		return static_cast<LinphonePrivate::FileTransferContent *>(c)->getFileDuration();
+	return -1;
+}
+
 bool_t linphone_content_is_text (const LinphoneContent *content) {
 	const LinphonePrivate::Content *c = L_GET_CPP_PTR_FROM_C_OBJECT(content);
 	return c->getContentType() == LinphonePrivate::ContentType::PlainText;
 }
 
+bool_t linphone_content_is_voice_recording (const LinphoneContent *content) {
+	const LinphonePrivate::Content *c = L_GET_CPP_PTR_FROM_C_OBJECT(content);
+	if (c->isFile()) {
+		return c->getContentType().strongEqual(LinphonePrivate::ContentType::VoiceRecording);
+	} else if (c->isFileTransfer()) {
+		return static_cast<const LinphonePrivate::FileTransferContent *>(c)->getFileContentType().strongEqual(LinphonePrivate::ContentType::VoiceRecording);
+	}
+	return false;
+}
+
+bool_t linphone_content_is_icalendar (const LinphoneContent *content) {
+	const LinphonePrivate::Content *c = L_GET_CPP_PTR_FROM_C_OBJECT(content);
+	if (c->isFile()) {
+		return c->getContentType().strongEqual(LinphonePrivate::ContentType::Icalendar);
+	} else if (c->isFileTransfer()) {
+		return static_cast<const LinphonePrivate::FileTransferContent *>(c)->getFileContentType().strongEqual(LinphonePrivate::ContentType::Icalendar);
+	}
+	return false;
+}
+
 bool_t linphone_content_is_file (const LinphoneContent *content) {
 	const LinphonePrivate::Content *c = L_GET_CPP_PTR_FROM_C_OBJECT(content);
-	return c->isFile(); // TODO FIXME this doesn't work when Content is from linphone_chat_message_get_contents() list
+	return c->isFile();
 }
 
 bool_t linphone_content_is_file_transfer (const LinphoneContent *content) {
 	const LinphonePrivate::Content *c = L_GET_CPP_PTR_FROM_C_OBJECT(content);
-	return c->isFileTransfer(); // TODO FIXME this doesn't work when Content is from linphone_chat_message_get_contents() list
+	return c->isFileTransfer();
 }
 
 bool_t linphone_content_is_file_encrypted (const LinphoneContent *content) {
@@ -472,7 +504,24 @@ SalBodyHandler *sal_body_handler_from_content (const LinphoneContent *content, b
 		size_t size = linphone_content_get_size(content);
 		char *buffer = bctbx_strdup(L_GET_CPP_PTR_FROM_C_OBJECT(content)->getBodyAsUtf8String().c_str());
 		const char *boundary = L_STRING_TO_C(contentType.getParameter("boundary").getValue());
-		belle_sip_multipart_body_handler_t *bh = belle_sip_multipart_body_handler_new_from_buffer(buffer, size, boundary);
+		belle_sip_multipart_body_handler_t *bh = NULL;
+		if( boundary)
+			bh = belle_sip_multipart_body_handler_new_from_buffer(buffer, size, boundary);
+		else if (size > 2){
+			size_t startIndex = 2, index;
+			while(startIndex < size && (buffer[startIndex] != '-' || buffer[startIndex-1] != '-' // Take accout of first "--"
+					|| (startIndex > 2 && buffer[startIndex-2] != '\n') ))	// Must be at the beginning of the line
+				++startIndex;
+			index = startIndex;
+			while(index < size && buffer[index] != '\n' && buffer[index] != '\r')
+				++index;
+			if( startIndex != index){
+				char * boundaryStr = bctbx_strndup(buffer+startIndex, (int)(index-startIndex));
+				bh = belle_sip_multipart_body_handler_new_from_buffer(buffer, size, boundaryStr);
+				bctbx_free(boundaryStr);
+			}
+		}
+		
 		bodyHandler = reinterpret_cast<SalBodyHandler *>(BELLE_SIP_BODY_HANDLER(bh));
 		bctbx_free(buffer);
 	} else {
