@@ -118,17 +118,28 @@ typedef enum {
 	SalMulticastSenderReceiver = 3
 } SalMulticastRole;
 
-#define SAL_MEDIA_DESCRIPTION_UNCHANGED						0x00
-#define SAL_MEDIA_DESCRIPTION_NETWORK_CHANGED				(1)
-#define SAL_MEDIA_DESCRIPTION_CODEC_CHANGED					(1<<1)
-#define SAL_MEDIA_DESCRIPTION_CRYPTO_KEYS_CHANGED			(1<<2)
-#define SAL_MEDIA_DESCRIPTION_CRYPTO_POLICY_CHANGED			(1<<3)
-#define SAL_MEDIA_DESCRIPTION_STREAMS_CHANGED				(1<<4)
-#define SAL_MEDIA_DESCRIPTION_NETWORK_XXXCAST_CHANGED		(1<<5) /* use to notify when switching from multicast to unicast*/
-#define SAL_MEDIA_DESCRIPTION_FORCE_STREAM_RECONSTRUCTION	(1<<6) /* use force graph reconstruction*/
-#define SAL_MEDIA_DESCRIPTION_ICE_RESTART_DETECTED			(1<<7)
-#define SAL_MEDIA_DESCRIPTION_CONFIGURATION_CHANGED			(1<<8)
-#define SAL_MEDIA_DESCRIPTION_CRYPTO_TYPE_CHANGED			(1<<9)
+typedef enum {
+	SalMediaRecordNone = 0,
+	SalMediaRecordOff = 1,
+	SalMediaRecordOn = 2,
+	SalMediaRecordPaused = 3
+} SalMediaRecord;
+
+#define SAL_MEDIA_DESCRIPTION_UNCHANGED							0x00
+#define SAL_MEDIA_DESCRIPTION_NETWORK_CHANGED					(1)
+#define SAL_MEDIA_DESCRIPTION_CODEC_CHANGED						(1<<1)
+#define SAL_MEDIA_DESCRIPTION_CRYPTO_KEYS_CHANGED				(1<<2)
+#define SAL_MEDIA_DESCRIPTION_CRYPTO_POLICY_CHANGED				(1<<3)
+#define SAL_MEDIA_DESCRIPTION_STREAMS_CHANGED					(1<<4)
+#define SAL_MEDIA_DESCRIPTION_NETWORK_XXXCAST_CHANGED			(1<<5) /* use to notify when switching from multicast to unicast*/
+#define SAL_MEDIA_DESCRIPTION_FORCE_STREAM_RECONSTRUCTION		(1<<6) /* use force graph reconstruction*/
+#define SAL_MEDIA_DESCRIPTION_ICE_RESTART_DETECTED				(1<<7)
+#define SAL_MEDIA_DESCRIPTION_CONFIGURATION_CHANGED				(1<<8)
+#define SAL_MEDIA_DESCRIPTION_CRYPTO_TYPE_CHANGED				(1<<9)
+#define SAL_MEDIA_DESCRIPTION_MIXER_TO_CLIENT_EXTENSION_CHANGED	(1<<10)
+#define SAL_MEDIA_DESCRIPTION_CLIENT_TO_MIXER_EXTENSION_CHANGED	(1<<11)
+#define SAL_MEDIA_DESCRIPTION_PTIME_CHANGED						(1<<12)
+#define SAL_MEDIA_DESCRIPTION_BANDWIDTH_CHANGED					(1<<13)
 
 #ifdef __cplusplus
 extern "C" {
@@ -138,7 +149,7 @@ const char* sal_transport_to_string(SalTransport transport);
 SalTransport sal_transport_parse(const char*);
 /* Address manipulation API*/
 LINPHONE_PUBLIC SalAddress * sal_address_new(const char *uri);
-SalAddress * sal_address_clone(const SalAddress *addr);
+LINPHONE_PUBLIC SalAddress * sal_address_clone(const SalAddress *addr);
 SalAddress * sal_address_ref(SalAddress *addr);
 LINPHONE_PUBLIC void sal_address_unref(SalAddress *addr);
 const char *sal_address_get_scheme(const SalAddress *addr);
@@ -200,6 +211,7 @@ SalMediaProto sal_media_proto_from_string(const char *type);
 SalMediaProto linphone_media_encryption_to_sal_media_proto (const LinphoneMediaEncryption media_enc, const bool_t avpf);
 LinphoneMediaEncryption sal_media_proto_to_linphone_media_encryption (const SalMediaProto proto, const bool_t haveZrtpHash);
 const char* sal_stream_dir_to_string(SalStreamDir type);
+const char* sal_media_record_to_string(SalMediaRecord record);
 
 #ifdef __cplusplus
 }
@@ -470,8 +482,8 @@ extern "C" {
 #endif
 
 SalCustomHeader *sal_custom_header_ref(SalCustomHeader *ch);
-void sal_custom_header_unref(SalCustomHeader *ch);
-SalCustomHeader *sal_custom_header_append(SalCustomHeader *ch, const char *name, const char *value);
+LINPHONE_PUBLIC void sal_custom_header_unref(SalCustomHeader *ch);
+LINPHONE_PUBLIC SalCustomHeader *sal_custom_header_append(SalCustomHeader *ch, const char *name, const char *value);
 const char *sal_custom_header_find(const SalCustomHeader *ch, const char *name);
 SalCustomHeader *sal_custom_header_remove(SalCustomHeader *ch, const char *name);
 void sal_custom_header_free(SalCustomHeader *ch);
@@ -490,6 +502,7 @@ void sal_set_log_level(OrtpLogLevel level);
 
 unsigned int sal_get_random(void);
 LINPHONE_PUBLIC char *sal_get_random_token(int size);
+LINPHONE_PUBLIC char *sal_get_random_token_lowercase(int size);
 unsigned char * sal_get_random_bytes(unsigned char *ret, size_t size);
 #if 0
 belle_sip_source_t * sal_create_timer(Sal *sal, belle_sip_source_func_t func, void *data, unsigned int timeout_value_ms, const char* timer_name);
