@@ -65,21 +65,10 @@ IceSession *Call::getIceSession () const {
 	return nullptr;
 }
 
-unsigned int Call::getAudioStartCount () const {
-	return static_pointer_cast<MediaSession>(getActiveSession())->getPrivate()->getAudioStartCount();
+const LinphoneStreamInternalStats * Call::getStreamInternalStats (LinphoneStreamType type) const {
+	return getMediaSession()->getPrivate()->getStreamInternalStats(type);
 }
 
-unsigned int Call::getAudioStopCount () const {
-	return static_pointer_cast<MediaSession>(getActiveSession())->getPrivate()->getAudioStopCount();
-}
-
-unsigned int Call::getVideoStartCount () const {
-	return static_pointer_cast<MediaSession>(getActiveSession())->getPrivate()->getVideoStartCount();
-}
-
-unsigned int Call::getTextStartCount () const {
-	return static_pointer_cast<MediaSession>(getActiveSession())->getPrivate()->getTextStartCount();
-}
 
 std::shared_ptr<MediaSession> Call::getMediaSession()const{
 	return static_pointer_cast<MediaSession>(getActiveSession());
@@ -137,6 +126,9 @@ LinphoneCallStats *Call::getPrivateStats (LinphoneStreamType type) const {
 
 void Call::initiateIncoming () {
 	getActiveSession()->initiateIncoming();
+	if (ms_snd_card_manager_reload_requested(ms_factory_get_snd_card_manager(getCore()->getCCore()->factory))) {
+		linphone_core_reload_sound_devices(getCore()->getCCore());
+	}
 	AudioDevice *outputAudioDevice = getCore()->getDefaultOutputAudioDevice();
 	if (outputAudioDevice) {
 		setOutputAudioDevicePrivate(outputAudioDevice);
@@ -154,7 +146,9 @@ void Call::initiateIncoming () {
 bool Call::initiateOutgoing () {
 	shared_ptr<CallSession> session = getActiveSession();
 	bool defer = session->initiateOutgoing();
-	
+	if (ms_snd_card_manager_reload_requested(ms_factory_get_snd_card_manager(getCore()->getCCore()->factory))) {
+		linphone_core_reload_sound_devices(getCore()->getCCore());
+	}
 	AudioDevice *outputAudioDevice = getCore()->getDefaultOutputAudioDevice();
 	if (outputAudioDevice) {
 		setOutputAudioDevicePrivate(outputAudioDevice);
@@ -177,6 +171,12 @@ void Call::iterate (time_t currentRealTime, bool oneSecondElapsed) {
 	getActiveSession()->iterate(currentRealTime, oneSecondElapsed);
 }
 
+void Call::notifyRinging () {
+	if (getState() == CallSession::State::IncomingReceived) {
+		getActiveSession()->getPrivate()->handleIncoming(true);
+	}
+}
+
 void Call::startIncomingNotification () {
 	getActiveSession()->startIncomingNotification();
 }
@@ -305,6 +305,9 @@ void Call::onCallSessionAccepting (const std::shared_ptr<CallSession> &session)
 
 void Call::onCallSessionEarlyFailed (const shared_ptr<CallSession> &session, LinphoneErrorInfo *ei) {
 	LinphoneCallLog *log = session->getLog();
+	if (session->getState() == CallSession::State::PushIncomingReceived) {
+		session->setStateToEnded();
+	}
 	linphone_core_report_early_failed_call(getCore()->getCCore(),
 		linphone_call_log_get_dir(log),
 		linphone_address_clone(linphone_call_log_get_from_address(log)),
@@ -376,16 +379,21 @@ void Call::terminateConference() {
 void Call::exitFromConference (const shared_ptr<CallSession> &session) {
 	auto cConference = getConference();
 	if (cConference) {
-		if (attachedToLocalConference(session)) {
+		if (attachedToLocalConference()) {
 			// Remove participant from local conference
 			lInfo() << "Removing terminated call (local address " << session->getLocalAddress().asString() << " remote address " << getRemoteAddress()->asString() << ") from LinphoneConference " << getConference();
 			CallSession::State sessionState = session->getState();
 			auto conference = MediaConference::Conference::toCpp(cConference)->getSharedFromThis();
 			conference->removeParticipant(session, (sessionState != LinphonePrivate::CallSession::State::End));
-		} else if (attachedToRemoteConference(session) && (getTransferState() == LinphonePrivate::CallSession::State::Idle)) {
-			// If the call has been transferred, then the conference must be kept alive
-			lInfo() << "Removing terminated call (local address " << session->getLocalAddress().asString() << " remote address " << getRemoteAddress()->asString() << ") from LinphoneConference " << getConference();
-			terminateConference();
+		} else if (attachedToRemoteConference()) {
+			if (getTransferState() == LinphonePrivate::CallSession::State::Idle) {
+				// If the call has been transferred, then the conference must be kept alive
+				lInfo() << "Removing terminated call (local address " << session->getLocalAddress().asString() << " remote address " << getRemoteAddress()->asString() << ") from LinphoneConference " << getConference();
+				terminateConference();
+			}
+		} else {
+			const auto conference = MediaConference::Conference::toCpp(cConference);
+			lError() << "Unable to determine if the call is hosting a conference or it is part of the conference hosted by other device. Nonetheless, it is linked to conference " << conference->getConferenceAddress();
 		}
 		setConference (nullptr);
 	}
@@ -399,35 +407,17 @@ void Call::changeSubjectInLocalConference(SalCallOp *op) {
 	}
 }
 
-bool Call::attachedToRemoteConference(const std::shared_ptr<CallSession> &session) const {
+bool Call::attachedToRemoteConference() const {
 	const auto & cConference = getConference();
-	if (cConference) {
-		const auto op = session->getPrivate()->getOp();
-		if (op && op->getRemoteContactAddress()) {
-			char * remoteContactAddressStr = sal_address_as_string(op->getRemoteContactAddress());
-			Address remoteContactAddress(remoteContactAddressStr);
-			ms_free(remoteContactAddressStr);
-
-			// Try to build conference address again
-			const auto & confId = session->getPrivate()->getConferenceId();
-			if (!remoteContactAddress.hasUriParam("conf-id") && !confId.empty()) {
-				remoteContactAddress.setUriParam("conf-id",confId);
-			}
-
-			const auto conference = MediaConference::Conference::toCpp(cConference);
-			return (remoteContactAddress == conference->getConferenceAddress().asAddress());
-		}
-	}
-
-	return false;
+	return !attachedToLocalConference() && cConference;
 }
 
-bool Call::attachedToLocalConference(const std::shared_ptr<CallSession> &session) const {
+bool Call::attachedToLocalConference() const {
 	const auto & cConference = getConference();
 	if (cConference) {
 		const auto conference = MediaConference::Conference::toCpp(cConference);
-		const ConferenceId localConferenceId = ConferenceId(session->getLocalAddress(), session->getLocalAddress());
-		return (localConferenceId == conference->getConferenceId());
+		const auto & me = conference->getMe();
+		return me->isFocus();
 	}
 
 	return false;
@@ -454,7 +444,7 @@ void Call::onCallSessionStateChanged (const shared_ptr<CallSession> &session, Ca
 			break;
 		case CallSession::State::Resuming:
 		{
-			if (attachedToLocalConference(session)) {
+			if (attachedToLocalConference()) {
 				// The participant left the conference and put its call in pause
 				auto conference = MediaConference::Conference::toCpp(getConference());
 				// If a call in a local conference is paused by remote, it means that the remote participant temporarely left the call
@@ -466,7 +456,7 @@ void Call::onCallSessionStateChanged (const shared_ptr<CallSession> &session, Ca
 		case CallSession::State::PausedByRemote:
 		{
 			const auto op = session->getPrivate()->getOp();
-			if (attachedToRemoteConference(session) && op && op->getRemoteContactAddress()) {
+			if (attachedToRemoteConference() && op && op->getRemoteContactAddress()) {
 				char * remoteContactAddressStr = sal_address_as_string(op->getRemoteContactAddress());
 				Address remoteContactAddress(remoteContactAddressStr);
 				ms_free(remoteContactAddressStr);
@@ -475,7 +465,7 @@ void Call::onCallSessionStateChanged (const shared_ptr<CallSession> &session, Ca
 				if (!remoteContactAddress.hasParam("isfocus")) {
 					terminateConference();
 				}
-			} else if (attachedToLocalConference(session)) {
+			} else if (attachedToLocalConference()) {
 				// The participant temporarely left the conference and put its call in pause
 				auto conference = MediaConference::Conference::toCpp(getConference());
 				// If a call in a local conference is paused by remote, it means that the remote participant temporarely left the call, hence notify that no audio and video is available
@@ -488,7 +478,7 @@ void Call::onCallSessionStateChanged (const shared_ptr<CallSession> &session, Ca
 		{
 
 			const auto op = session->getPrivate()->getOp();
-			if (attachedToLocalConference(session)) {
+			if (attachedToLocalConference()) {
 				// The remote participant requested to change subject
 				changeSubjectInLocalConference(op);
 			} else if (op && op->getRemoteContactAddress()) {
@@ -497,7 +487,7 @@ void Call::onCallSessionStateChanged (const shared_ptr<CallSession> &session, Ca
 				Address remoteContactAddress(remoteContactAddressStr);
 				ms_free(remoteContactAddressStr);
 
-				if (attachedToRemoteConference(session)) {
+				if (attachedToRemoteConference()) {
 					if (!remoteContactAddress.hasParam("isfocus")) {
 						terminateConference();
 					}
@@ -528,12 +518,12 @@ void Call::onCallSessionStateChanged (const shared_ptr<CallSession> &session, Ca
 			const auto op = session->getPrivate()->getOp();
 			const auto & confId = session->getPrivate()->getConferenceId();
 			// Try to add device to local conference
-			if (attachedToLocalConference(session)) {
+			if (attachedToLocalConference()) {
 				auto conference = MediaConference::Conference::toCpp(getConference());
 				if(!conference->addParticipantDevice(getSharedFromThis())) {
 					conference->participantDeviceMediaChanged(session);
 				}
-			} else if (attachedToRemoteConference(session)) {
+			} else if (attachedToRemoteConference()) {
 				// The participant rejoins the conference
 				auto conference = MediaConference::Conference::toCpp(getConference());
 				time_t creationTime = time(nullptr);
@@ -548,6 +538,7 @@ void Call::onCallSessionStateChanged (const shared_ptr<CallSession> &session, Ca
 					ConferenceId remoteConferenceId = ConferenceId(remoteContactAddress, getLocalAddress());
 					shared_ptr<MediaConference::Conference> conference = getCore()->findAudioVideoConference(remoteConferenceId, false);
 					shared_ptr<MediaConference::RemoteConference> remoteConf = nullptr;
+
 					// Create remote conference if no conference with the expected ID is found in the database
 					if (conference == nullptr) {
 						// It is expected that the core of the remote conference is the participant one
@@ -748,6 +739,10 @@ void Call::onStartRingtone(const shared_ptr<CallSession> &session){
 	//Already handled by tone manager.
 }
 
+void Call::onRemoteRecording(const std::shared_ptr<CallSession> &session, bool recording) {
+	linphone_call_notify_remote_recording(this->toC(), recording);
+}
+
 // =============================================================================
 
 Call::Call (
@@ -786,7 +781,6 @@ Call::Call (
 }
 
 Call::~Call () {
-	bctbx_list_free_with_data(mCallbacks, (bctbx_list_free_func)linphone_call_cbs_unref);
 }
 
 void Call::configure (
@@ -879,16 +873,36 @@ void Call::sendVfuRequest () {
 	static_pointer_cast<MediaSession>(getActiveSession())->sendVfuRequest();
 }
 
+void Call::updateRecordState(SalMediaRecord state) {
+	if (linphone_core_is_record_aware_enabled(getCore()->getCCore())
+		&& getRemoteParams()->recordAwareEnabled()) {
+		if (getState() == CallSession::State::StreamsRunning) {
+			MediaSessionParams params(*getParams());
+			params.setRecordingState(state);
+			static_pointer_cast<MediaSession>(getActiveSession())->update(&params, CallSession::UpdateMethod::Update);
+		} else {
+			lWarning() << "Recording cannot sent an update when the call is not in StreamRunning";
+		}
+	} else {
+		MediaSessionParams *params = new MediaSessionParams(*getParams());
+		params->setRecordingState(state);
+		static_pointer_cast<MediaSession>(getActiveSession())->getPrivate()->setParams(params);
+	}
+}
+
 void Call::startRecording () {
-	static_pointer_cast<MediaSession>(getActiveSession())->startRecording();
+	if (static_pointer_cast<MediaSession>(getActiveSession())->startRecording()) {
+		updateRecordState(SalMediaRecordOn);
+	}
 }
 
 void Call::stopRecording () {
 	static_pointer_cast<MediaSession>(getActiveSession())->stopRecording();
+	updateRecordState(SalMediaRecordOff);
 }
 
 bool Call::isRecording () {
-	return static_pointer_cast<MediaSession>(getActiveSession())->isRecording();
+	return static_pointer_cast<MediaSession>(getActiveSession())->getMediaParams()->isRecording();
 }
 
 LinphoneStatus Call::takePreviewSnapshot (const string &file) {
@@ -900,7 +914,11 @@ LinphoneStatus Call::takeVideoSnapshot (const string &file) {
 }
 
 LinphoneStatus Call::terminate (const LinphoneErrorInfo *ei) {
-	return getActiveSession()->terminate(ei);
+	bool cleanCall = getActiveSession()->getState() == CallSession::State::OutgoingInit;
+	LinphoneStatus status = getActiveSession()->terminate(ei);
+	if( cleanCall && !status )
+		unref();
+	return status;
 }
 
 LinphoneStatus Call::transfer (const shared_ptr<Call> &dest) {
@@ -1252,33 +1270,5 @@ void Call::setEndpoint (MSAudioEndpoint *endpoint) {
 	mEndpoint = endpoint;
 }
 
-bctbx_list_t *Call::getCallbacksList () const {
-	return mCallbacks;
-}
-
-LinphoneCallCbs *Call::getCurrentCallbacks () const{
-	return mCurrentCbs;
-}
-
-void Call::setCurrentCallbacks (LinphoneCallCbs *cbs) {
-	mCurrentCbs = cbs;
-}
-
-void Call::addCallbacks (LinphoneCallCbs *cbs) {
-	mCallbacks = bctbx_list_append(mCallbacks, belle_sip_object_ref(cbs));
-}
-
-void Call::removeCallbacks (LinphoneCallCbs *cbs) {
-	mCallbacks = bctbx_list_remove(mCallbacks, cbs);
-	belle_sip_object_unref(cbs);
-}
-
-void *Call::getUserData () const{
-	return mUserData;
-}
-
-void Call::setUserData (void *ud) {
-	mUserData = ud;
-}
 
 LINPHONE_END_NAMESPACE
