@@ -191,7 +191,7 @@ void ChatMessagePrivate::setState (ChatMessage::State newState) {
 
 
 	// 2. Update state and notify changes.
-	lInfo() << "Chat message " << sharedMessage << ": moving from " << Utils::toString(state) << " to " << Utils::toString(newState);
+	lInfo() << "Chat message " << sharedMessage << " of chat room " << (q->getChatRoom() ? q->getChatRoom()->getConferenceId() : ConferenceId()) << " : moving from " << Utils::toString(state) << " to " << Utils::toString(newState);
 	ChatMessage::State oldState = state;
 	state = newState;
 
@@ -606,6 +606,8 @@ void ChatMessagePrivate::replaceContent (Content *contentToRemove, Content *cont
 	while (it != contents.end()) {
 		Content *content = *it;
 		if (content == contentToRemove) {
+			if (!contentToRemove->getAppData("legacy").empty() && contentToAdd->getAppData("legacy").empty())// Keep appdata from losing it on replacing
+				contentToAdd->setAppData("legacy", contentToRemove->getAppData("legacy"));
 			it = contents.erase(it);
 			it = contents.insert(it, contentToAdd);
 			break;
@@ -802,6 +804,11 @@ LinphoneReason ChatMessagePrivate::receive () {
 
 	setState(ChatMessage::State::Delivered);
 
+	// Check if this is in fact an outgoing message (case where this is a message sent by us from an other device).
+	if (chatRoom->getCapabilities() & ChatRoom::Capabilities::Conference && chatRoom->getLocalAddress().asAddress().weakEqual(fromAddress.asAddress())) {
+		setDirection(ChatMessage::Direction::Outgoing);
+	}
+
 	// Check if this is a duplicate message.
 	if (chatRoom->findChatMessage(imdnId, direction)) {
 		lInfo() << "Duplicated SIP MESSAGE, ignored.";
@@ -828,12 +835,6 @@ LinphoneReason ChatMessagePrivate::receive () {
 		}
 	}
 
-	// Check if this is in fact an outgoing message (case where this is a message sent by us from an other device).
-	if (chatRoom->getCapabilities() & ChatRoom::Capabilities::Conference && chatRoom->getLocalAddress().asAddress().weakEqual(fromAddress.asAddress())) {
-		setDirection(ChatMessage::Direction::Outgoing);
-		markAsRead();
-	}
-
 	if (errorCode > 0) {
 		reason = linphone_error_code_to_reason(errorCode);
 		static_cast<ChatRoomPrivate *>(q->getChatRoom()->getPrivate())->sendDeliveryErrorNotification(
@@ -843,8 +844,19 @@ LinphoneReason ChatMessagePrivate::receive () {
 		return reason;
 	}
 
+	// If message was outgoing, mark it as read
+	if (direction == ChatMessage::Direction::Outgoing) {
+		markAsRead();
+	}
+
 	if (getContentType() != ContentType::Imdn && getContentType() != ContentType::ImIsComposing) {
-		_linphone_chat_room_notify_chat_message_should_be_stored(static_pointer_cast<ChatRoom>(q->getChatRoom())->getPrivate()->getCChatRoom(), L_GET_C_BACK_PTR(q->getSharedFromThis()));
+		// If we receive a message that is Outgoing it means we are in a flexisip based chat room and this message was sent by us from another device, storing it
+		if (direction == ChatMessage::Direction::Outgoing) {
+			toBeStored = true;
+		} else {
+			_linphone_chat_room_notify_chat_message_should_be_stored(static_pointer_cast<ChatRoom>(q->getChatRoom())->getPrivate()->getCChatRoom(), L_GET_C_BACK_PTR(q->getSharedFromThis()));
+		}
+
 		if (toBeStored) {
 			storeInDb();
 		}
@@ -863,23 +875,34 @@ void ChatMessagePrivate::handleAutoDownload() {
 	if ((currentRecvStep & ChatMessagePrivate::Step::AutoFileDownload) == ChatMessagePrivate::Step::AutoFileDownload) {
 		lInfo() << "Auto file download step already done, skipping";
 	} else {
-		for (Content *c : contents) {
-			if (c->isFileTransfer()) {
-				int max_size = linphone_core_get_max_size_for_auto_download_incoming_files(q->getCore()->getCCore());
-				if (max_size >= 0) {
+		int maxSize = linphone_core_get_max_size_for_auto_download_incoming_files(q->getCore()->getCCore());
+		bool_t autoDownloadVoiceRecordings = linphone_core_is_auto_download_voice_recordings_enabled(q->getCore()->getCCore());
+		bool_t autoDownloadIcalendars = linphone_core_is_auto_download_icalendars_enabled(q->getCore()->getCCore());
+		string downloadPath = q->getCore()->getDownloadPath();
+
+		if (downloadPath.empty()) {
+			lWarning() << "Downloading path is empty, won't be able to do auto download";
+		} else {
+			for (Content *c : contents) {
+				if (c->isFileTransfer()) {
 					FileTransferContent *ftc = static_cast<FileTransferContent *>(c);
-					if (max_size == 0 || ftc->getFileSize() <= (size_t)max_size) {
-						string downloadPath = q->getCore()->getDownloadPath();
-						if (!downloadPath.empty()) {
-							string filepath = downloadPath + ftc->getFileName();
-							lInfo() << "Downloading file to " << filepath;
-							ftc->setFilePath(filepath);
-							setAutoFileTransferDownloadInProgress(true);
-							q->downloadFile(ftc);
-							return;
-						} else {
-							lError() << "Downloading path is empty, aborting auto download !";
+					ContentType fileContentType = ftc->getFileContentType();
+					
+					if ((maxSize == 0 || (maxSize > 0 && ftc->getFileSize() <= (size_t)maxSize))
+					|| (autoDownloadVoiceRecordings && fileContentType.strongEqual(ContentType::VoiceRecording))
+					|| (autoDownloadIcalendars && fileContentType.strongEqual(ContentType::Icalendar))) {
+						ostringstream sstream;
+						size_t randomSize = 12;
+						for (size_t i = 0; i < randomSize; i++) {
+							sstream << rand() % 10;
 						}
+						string file = sstream.str();
+						string filepath = downloadPath + file;
+						lInfo() << "Automatically downloading file to " << filepath;
+						ftc->setFilePath(filepath);
+						setAutoFileTransferDownloadInProgress(true);
+						q->downloadFile(ftc);
+						return;
 					}
 				}
 			}
@@ -895,16 +918,26 @@ void ChatMessagePrivate::handleAutoDownload() {
 }
 
 void ChatMessagePrivate::restoreFileTransferContentAsFileContent() {
+	if (contents.size() == 0) {
+		lWarning() << "Contents list is empty, nothing to restore";
+		return;
+	}
+
 	// Restore FileContents and remove FileTransferContents
 	list<Content*>::iterator it = contents.begin();
 	while (it != contents.end()) {
 		Content *content = *it;
-		if (content->isFileTransfer()) {
+		if (content && content->isFileTransfer()) {
 			FileTransferContent *fileTransferContent = static_cast<FileTransferContent *>(content);
 			FileContent *fileContent = fileTransferContent->getFileContent();
-			it = contents.erase(it);
-			it = contents.insert(it, fileContent);
-			delete fileTransferContent;
+			if (fileContent) {
+				it = contents.erase(it);
+				it = contents.insert(it, fileContent);
+				delete fileTransferContent;
+			} else {
+				lWarning() << "Found FileTransferContent but no associated FileContent";
+				it++;
+			}
 		} else {
 			it++;
 		}
@@ -1021,6 +1054,10 @@ void ChatMessagePrivate::send () {
 				}
 				currentSendStep |= ChatMessagePrivate::Step::Multipart;
 			}
+		} else {
+			if (contents.size() > 1) {
+				lError() << "Chat room doesn't support multipart, but has multiple parts !";
+			}else lInfo() << "Chat room doesn't support multipart, skipping this modifier";
 		}
 
 		if (chatRoom->canHandleCpim()) {
@@ -1031,6 +1068,8 @@ void ChatMessagePrivate::send () {
 				ccmm.encode(q->getSharedFromThis(), errorCode);
 				currentSendStep |= ChatMessagePrivate::Step::Cpim;
 			}
+		} else {
+			lInfo() << "Chat room doesn't support CPIM, skipping this modifier";
 		}
 
 		if ((currentSendStep & ChatMessagePrivate::Step::Encryption) == ChatMessagePrivate::Step::Encryption) {
@@ -1051,6 +1090,8 @@ void ChatMessagePrivate::send () {
 				} else if (result == ChatMessageModifier::Result::Suspended) {
 					return;
 				}
+			} else {
+				lInfo() << "Encryption has been prevented, skipping this modifier";
 			}
 		}
 	}
@@ -1370,18 +1411,7 @@ void ChatMessagePrivate::loadContentsFromDatabase () const {
 
 bool ChatMessage::isRead () const {
 	L_D();
-
-	LinphoneImNotifPolicy *policy = linphone_core_get_im_notif_policy(getCore()->getCCore());
-	if (linphone_im_notif_policy_get_recv_imdn_displayed(policy) && d->state == State::Displayed)
-		return true;
-
-	if (
-		linphone_im_notif_policy_get_recv_imdn_delivered(policy) &&
-		(d->state == State::DeliveredToUser || d->state == State::Displayed)
-	)
-		return true;
-
-	return d->state == State::Delivered || d->state == State::Displayed || d->state == State::DeliveredToUser;
+	return d->markedAsRead || d->state == State::Displayed;
 }
 
 const IdentityAddress &ChatMessage::getAuthenticatedFromAddress () const {
@@ -1531,7 +1561,11 @@ void ChatMessage::cancelFileTransfer () {
 	L_D();
 	if (d->fileTransferChatMessageModifier.isFileTransferInProgressAndValid()) {
 		lWarning() << "Canceling file transfer on message [" << getSharedFromThis() << "]";
+		d->fileTransferChatMessageModifier.cancelFileTransfer();
+		lInfo() << "File transfer on message [" << getSharedFromThis() << "] has been cancelled";
+
 		if (d->state == State::FileTransferInProgress) {
+			lInfo() << "File transfer on message [" << getSharedFromThis() << "] was in progress, updating state";
 			// For auto download messages, set the state back to Delivered
 			if (d->isAutoFileTransferDownloadInProgress()) {
 				d->setState(State::Delivered);
@@ -1540,7 +1574,6 @@ void ChatMessage::cancelFileTransfer () {
 				d->setState(State::NotDelivered);
 			}
 		}
-		d->fileTransferChatMessageModifier.cancelFileTransfer();
 	} else {
 		lInfo() << "No existing file transfer - nothing to cancel";
 	}
