@@ -102,6 +102,8 @@ void ChatRoomPrivate::addEvent (const shared_ptr<EventLog> &eventLog) {
 		// up in the list and the user won't know why
 	} else {
 		setLastUpdateTime(eventLog->getCreationTime());
+		q->getCore()->getPrivate()->mainDb->updateChatRoomLastUpdatedTime(q->getConferenceId(), lastUpdateTime);
+		
 		if (type == EventLog::Type::ConferenceChatMessage) {
 			setIsEmpty(false);
 		}
@@ -219,6 +221,11 @@ list<shared_ptr<ChatMessage>> ChatRoomPrivate::findChatMessages (const string &m
 	return q->getCore()->getPrivate()->mainDb->findChatMessages(q->getConferenceId(), messageId);
 }
 
+list<shared_ptr<ChatMessage>> ChatRoomPrivate::findChatMessages (const list<string> &messageIds) const {
+	L_Q();
+	return q->getCore()->getPrivate()->mainDb->findChatMessages(q->getConferenceId(), messageIds);
+}
+
 // -----------------------------------------------------------------------------
 
 void ChatRoomPrivate::sendDeliveryErrorNotification (const shared_ptr<ChatMessage> &chatMessage, LinphoneReason reason) {
@@ -362,7 +369,13 @@ LinphoneReason ChatRoomPrivate::onSipMessageReceived (SalOp *op, const SalMessag
 	}else{
 		messageId << op->getCallId();
 	}
-	msg->getPrivate()->setImdnMessageId(messageId.str());
+
+	// Don't do it for flexisip backend chat rooms, we need to know if the real message id from CPIM was retrieved or not
+	// Based on that we will send IMDNs or not
+	// In case CPIM was enabled on a Basic chat room, IMDN message ID will be overwritten by real one
+	if (q->getCapabilities().isSet(ChatRoom::Capabilities::Basic)) {
+		msg->getPrivate()->setImdnMessageId(messageId.str());
+	}
 	msg->getPrivate()->setCallId(op->getCallId());
 
 	const SalCustomHeader *ch = op->getRecvCustomHeaders();
@@ -499,6 +512,10 @@ list<shared_ptr<EventLog>> ChatRoom::getMessageHistoryRange (int begin, int end)
 	return getCore()->getPrivate()->mainDb->getHistoryRange(getConferenceId(), begin, end, MainDb::Filter::ConferenceChatMessageFilter);
 }
 
+list<shared_ptr<ChatMessage>> ChatRoom::getUnreadChatMessages() const {
+	return getCore()->getPrivate()->mainDb->getUnreadChatMessages(getConferenceId());
+}
+
 int ChatRoom::getMessageHistorySize () const {
 	return getCore()->getPrivate()->mainDb->getHistorySize(getConferenceId(), MainDb::Filter::ConferenceChatMessageFilter);
 }
@@ -649,6 +666,12 @@ shared_ptr<ChatMessage> ChatRoom::createReplyMessage (const shared_ptr<ChatMessa
 
 // -----------------------------------------------------------------------------
 
+list<shared_ptr<ChatMessage>> ChatRoom::findChatMessages (const list<string> &messageIds) const {
+	L_D();
+	list<shared_ptr<ChatMessage>> chatMessages = d->findChatMessages(messageIds);
+	return chatMessages;
+}
+
 shared_ptr<ChatMessage> ChatRoom::findChatMessage (const string &messageId) const {
 	L_D();
 	list<shared_ptr<ChatMessage>> chatMessages = d->findChatMessages(messageId);
@@ -695,13 +718,22 @@ bool ChatRoom::ephemeralEnabled() const {
 }
 
 void ChatRoom::setEphemeralLifetime (long lifetime, bool updateDb) {
-	lDebug() << "Ephemeral message is only supported in conference based chat room!";
+	lError() << "Ephemeral message is only supported in conference based chat room!";
 }
 
 long ChatRoom::getEphemeralLifetime () const {
 	return 0;
 }
 
+void ChatRoom::setEphemeralMode(AbstractChatRoom::EphemeralMode mode, bool updateDb) {
+	lError() << "Ephemeral message is only supported in conference based chat room!";
+}
+
+AbstractChatRoom::EphemeralMode ChatRoom::getEphemeralMode() const {
+	lError() << "Ephemeral message is only supported in conference based chat room!";
+	return AbstractChatRoom::EphemeralMode::DeviceManaged;
+}
+
 bool ChatRoom::ephemeralSupportedByAllParticipants () const  {
 	return false;
 }
