@@ -37,6 +37,7 @@
 #include "logger/logger.h"
 #include "sal/refer-op.h"
 #include "server-group-chat-room-p.h"
+#include "sip-tools/sip-headers.h"
 
 #include "linphone/wrapper_utils.h"
 
@@ -304,8 +305,9 @@ void ServerGroupChatRoomPrivate::confirmJoining (SalCallOp *op) {
 			/* we don't accept the session yet: initializeParticipants() has launched queries for device information
 			 * that will later populate the chatroom*/
 		}else{
-			/* after creation, only subject change is allowed*/
+			/* after creation, only changes to the subject and ephemeral settings are allowed*/
 			handleSubjectChange(op);
+			handleEphemeralSettingsChange(session);
 			acceptSession(session);
  		}
  	} else {
@@ -419,6 +421,47 @@ void ServerGroupChatRoomPrivate::handleSubjectChange(SalCallOp *op){
 	}
 }
 
+void ServerGroupChatRoomPrivate::handleEphemeralSettingsChange(const shared_ptr<CallSession> &session){
+	if (capabilities & ServerGroupChatRoom::Capabilities::Ephemeral) {
+		const auto op = session->getPrivate()->getOp();
+		string ephemeralLifeTime = L_C_TO_STRING(sal_custom_header_find(op->getRecvCustomHeaders(), "Ephemeral-Life-Time"));
+		if (ephemeralLifeTime.empty()) {
+			setEphemeralMode(AbstractChatRoom::EphemeralMode::DeviceManaged, session);
+		} else {
+			setEphemeralLifetime(std::stol(ephemeralLifeTime, nullptr), session);
+		}
+	}
+}
+
+void ServerGroupChatRoomPrivate::setEphemeralMode(AbstractChatRoom::EphemeralMode mode, const shared_ptr<CallSession> &session) {
+	L_Q();
+	lInfo() << q << ": New mode is: " << mode;
+	params->setEphemeralMode(mode);
+
+	const auto device = q->getConference()->findParticipantDevice(session);
+	if (device) {
+		time_t creationTime = time(nullptr);
+		const auto eventType = (mode == AbstractChatRoom::EphemeralMode::AdminManaged) ? EventLog::Type::ConferenceEphemeralMessageManagedByAdmin : EventLog::Type::ConferenceEphemeralMessageManagedByParticipants;
+		q->getConference()->notifyEphemeralModeChanged(creationTime, false, eventType);
+	} else {
+		lWarning() << "Unable to find device among those of the participants that changed ephemeral message mode to " << mode;
+	}
+}
+
+void ServerGroupChatRoomPrivate::setEphemeralLifetime(long lifetime, const shared_ptr<CallSession> &session){
+	L_Q();
+	lInfo() << q << ": New ephemeral time: " << lifetime;
+	params->setEphemeralLifetime(lifetime);
+
+	const auto device = q->getConference()->findParticipantDevice(session);
+	if (device) {
+		time_t creationTime = time(nullptr);
+		q->getConference()->notifyEphemeralLifetimeChanged(creationTime, false, lifetime);
+	} else {
+		lWarning() << "Unable to find device among those of the participants that changed ephemeral message lifetime to " << lifetime;
+	}
+}
+
 /*
  * This function setups registration subscriptions if not already there.
  * If no registration subscription is started (because they were all running already), it returns false.
@@ -786,16 +829,23 @@ void ServerGroupChatRoomPrivate::designateAdmin () {
 	}
 }
 
-void ServerGroupChatRoomPrivate::sendMessage (const shared_ptr<Message> &message, const IdentityAddress &deviceAddr){
+void ServerGroupChatRoomPrivate::sendMessage(const shared_ptr<Message> &message, const IdentityAddress &deviceAddr) {
 	L_Q();
 
 	shared_ptr<ChatMessage> msg = q->createChatMessage();
 	copyMessageHeaders(message, msg);
-	msg->getPrivate()->addSalCustomHeader("Session-mode", "true"); // Special custom header to identify MESSAGE that belong to server group chatroom
+	// Special custom header to identify MESSAGE that belong to server group chatroom
+	msg->getPrivate()->addSalCustomHeader("Session-mode", "true");
 	msg->setInternalContent(message->content);
 	msg->getPrivate()->forceFromAddress(q->getConferenceAddress());
 	msg->getPrivate()->forceToAddress(deviceAddr);
 	msg->getPrivate()->setApplyModifiers(false);
+	if (message->fromAddr.getUsername() == msg->getToAddress().getUsername() &&
+		message->fromAddr.getDomain() == msg->getToAddress().getDomain()) {
+		// If FROM and TO are the same user (with a different device for example, gruu is not checked), set the
+		// Non-Urgent header to disable push notification for this message.
+		msg->getPrivate()->addSalCustomHeader(PriorityHeader::HeaderName, PriorityHeader::NonUrgent);
+	}
 	msg->send();
 }
 
@@ -848,6 +898,10 @@ shared_ptr<CallSession> ServerGroupChatRoomPrivate::makeSession(const std::share
 			csp.addCustomHeader("One-To-One-Chat-Room", "true");
 		if (capabilities & ServerGroupChatRoom::Capabilities::Encrypted)
 			csp.addCustomHeader("End-To-End-Encrypted", "true");
+		if (capabilities & ClientGroupChatRoom::Capabilities::Ephemeral) {
+			csp.addCustomHeader("Ephemerable", "true");
+			csp.addCustomHeader("Ephemeral-Life-Time", to_string(params->getEphemeralLifetime()));
+		}
 		//csp.addCustomContactParameter("isfocus");
 		//csp.addCustomContactParameter("text");
 		shared_ptr<Participant> participant = const_pointer_cast<Participant>(device->getParticipant()->getSharedFromThis());
@@ -993,6 +1047,7 @@ void ServerGroupChatRoomPrivate::removeParticipantDevice (const shared_ptr<Parti
 	// Notify to everyone the retirement of this device.
 	auto deviceEvent = q->getConference()->notifyParticipantDeviceRemoved(time(nullptr), false, participant, participantDevice);
 	q->getCore()->getPrivate()->mainDb->addEvent(deviceEvent);
+
 	// First set it as left, so that it may eventually trigger the destruction of the chatroom if no device are present for any participant.
 	setParticipantDeviceState(participantDevice, ParticipantDevice::State::Left);
 	participantCopy->removeDevice(deviceAddress);
@@ -1172,6 +1227,7 @@ void ServerGroupChatRoomPrivate::onCallSessionStateChanged (const shared_ptr<Cal
 			if (participant && participant->isAdmin()) {
 				/* The only thing that a participant can change with re-INVITE is the subject. */
 				handleSubjectChange(session->getPrivate()->getOp());
+				handleEphemeralSettingsChange(session);
 			}
 		}
 		break;
@@ -1213,9 +1269,19 @@ ServerGroupChatRoom::ServerGroupChatRoom (const shared_ptr<Core> &core, SalCallO
 	string endToEndEncrypted = L_C_TO_STRING(sal_custom_header_find(op->getRecvCustomHeaders(), "End-To-End-Encrypted"));
 	if (endToEndEncrypted == "true")
 		d->capabilities |= ServerGroupChatRoom::Capabilities::Encrypted;
+	string ephemerable = L_C_TO_STRING(sal_custom_header_find(op->getRecvCustomHeaders(), "Ephemerable"));
+	if (ephemerable == "true") {
+		d->capabilities |= ServerGroupChatRoom::Capabilities::Ephemeral;
+	}
 
 	d->params = ChatRoomParams::fromCapabilities(d->capabilities);
 
+	if (ephemerable == "true") {
+		string ephemeralLifeTime = L_C_TO_STRING(sal_custom_header_find(op->getRecvCustomHeaders(), "Ephemeral-Life-Time"));
+		long time = std::stol(ephemeralLifeTime, nullptr);
+		d->params->setEphemeralLifetime(time);
+	}
+
 	shared_ptr<CallSession> session = getMe()->createSession(*getConference().get(), nullptr, false, d);
 	session->configure(LinphoneCallIncoming, nullptr, op, Address(op->getFrom()), Address(op->getTo()));
 	d->protocolVersion = CorePrivate::groupChatProtocolVersion;
@@ -1338,6 +1404,10 @@ bool ServerGroupChatRoom::hasBeenLeft () const {
 	return false;
 }
 
+bool ServerGroupChatRoom::isReadOnly() const {
+	return false;
+}
+
 bool ServerGroupChatRoom::addParticipant (const IdentityAddress &participantAddress) {
 	L_D();
 
