@@ -51,20 +51,33 @@ struct X3dhServerPostContext {
 
 void LimeManager::processIoError (void *data, const belle_sip_io_error_event_t *event) noexcept {
 	X3dhServerPostContext *userData = static_cast<X3dhServerPostContext *>(data);
-	(userData->responseProcess)(0, vector<uint8_t>{});
+	try  {
+		(userData->responseProcess)(0, vector<uint8_t>{});
+	} catch (const exception &e) {
+		lError() << "Processing IoError on lime server request triggered an exception: "<<e.what();
+	}
 	delete(userData);
 }
 
 void LimeManager::processResponse (void *data, const belle_http_response_event_t *event) noexcept {
 	X3dhServerPostContext *userData = static_cast<X3dhServerPostContext *>(data);
+
 	if (event->response){
 		auto code=belle_http_response_get_status_code(event->response);
 		belle_sip_message_t *message = BELLE_SIP_MESSAGE(event->response);
 		auto body = reinterpret_cast<const uint8_t *>(belle_sip_message_get_body(message));
 		auto bodySize = belle_sip_message_get_body_size(message);
-		(userData->responseProcess)(code, vector<uint8_t>{body, body+bodySize});
+		try  { // the response processing might generate an exception, make sure it will not flow up to belle-sip otherwise it will cause an abort
+			(userData->responseProcess)(code, vector<uint8_t>{body, body+bodySize});
+		} catch (const exception &e) {
+			lError() << "Processing lime server response triggered an exception: "<<e.what();
+		}
 	} else {
-		(userData->responseProcess)(0, vector<uint8_t>{});
+		try  {
+			(userData->responseProcess)(0, vector<uint8_t>{});
+		} catch (const exception &e) {
+			lError() << "Processing empty response event on lime server request triggered an exception: "<<e.what();
+		}
 	}
 	delete(userData);
 }
@@ -357,13 +370,7 @@ ChatMessageModifier::Result LimeX3dhEncryptionEngine::processIncomingMessage (
 
 	// Check if the message is encrypted and unwrap the multipart
 	ContentType incomingContentType = internalContent->getContentType();
-	ContentType expectedContentType = ContentType::Encrypted;
-	expectedContentType.addParameter("protocol", "\"application/lime\"");
-	expectedContentType.addParameter("boundary", MultipartBoundary);
-	ContentType legacyContentType = ContentType::Encrypted; //for backward compatibility with limev2 early access
-	legacyContentType.addParameter("boundary", MultipartBoundary);
-
-	if (incomingContentType != expectedContentType && incomingContentType != legacyContentType) {
+	if ((incomingContentType.getType().compare("multipart") != 0) || (incomingContentType.getSubType().compare("encrypted") != 0) || (incomingContentType.getParameter("protocol") != HeaderParam("protocol", "\"application/lime\""))) {
 		lError() << "[LIME] unexpected content-type: " << incomingContentType;
 		// Set unencrypted content warning flag because incoming message type is unexpected
 		message->getPrivate()->setUnencryptedContentWarning(true);
@@ -468,6 +475,7 @@ ChatMessageModifier::Result LimeX3dhEncryptionEngine::processIncomingMessage (
 		 peerDeviceStatus = limeManager->decrypt(localDeviceId, recipientUserId, senderDeviceId, decodedCipherHeader, decodedCipherMessage, plainMessage);
 	} catch (const exception &e) {
 		lError() << e.what() << " while decrypting message";
+		peerDeviceStatus = lime::PeerDeviceStatus::fail;
 	}
 
 	if (peerDeviceStatus == lime::PeerDeviceStatus::fail) {
@@ -614,9 +622,6 @@ AbstractChatRoom::SecurityLevel LimeX3dhEncryptionEngine::getSecurityLevel (cons
 	lime::PeerDeviceStatus status = limeManager->get_peerDeviceStatus(deviceId);
 	switch (status) {
 		case lime::PeerDeviceStatus::unknown:
-			if (limeManager->is_localUser(deviceId)) {
-				return AbstractChatRoom::SecurityLevel::Safe;
-			}
 			return AbstractChatRoom::SecurityLevel::Encrypted;
 		case lime::PeerDeviceStatus::untrusted:
 			return AbstractChatRoom::SecurityLevel::Encrypted;
