@@ -32,6 +32,8 @@
 
 #include "file-transfer-chat-message-modifier.h"
 
+#include <cstdio>
+
 // =============================================================================
 
 using namespace std;
@@ -251,6 +253,8 @@ belle_sip_body_handler_t *FileTransferChatMessageModifier::prepare_upload_body_h
 	fileTransferContent->setContentType(ContentType::FileTransfer);
 	fileTransferContent->setFileSize(currentFileContentToTransfer->getFileSize()); // Copy file size information
 	fileTransferContent->setFilePath(currentFileContentToTransfer->getFilePath()); // Copy file path information
+	fileTransferContent->setFileDuration(currentFileContentToTransfer->getFileDuration()); // Copy file duration information
+	fileTransferContent->setFileContentType(currentFileContentToTransfer->getContentType()); // Copy file content type information
 	
 	currentFileTransferContent = fileTransferContent;
 	currentFileTransferContent->setFileContent(currentFileContentToTransfer);
@@ -306,10 +310,9 @@ belle_sip_body_handler_t *FileTransferChatMessageModifier::prepare_upload_body_h
 
 	belle_sip_body_handler_add_header(first_part_bh,
 		belle_sip_header_create("Content-disposition", first_part_header.c_str()));
-	belle_sip_body_handler_add_header(first_part_bh,
-		(belle_sip_header_t *)belle_sip_header_content_type_create(
-			currentFileContentToTransfer->getContentType().getType().c_str(),
-			currentFileContentToTransfer->getContentType().getSubType().c_str()));
+	belle_sip_body_handler_add_header(first_part_bh, 
+		(belle_sip_header_t *)belle_sip_header_content_type_parse(currentFileContentToTransfer->getContentType().asString().c_str()));
+	
 
 	// insert it in a multipart body handler which will manage the boundaries of multipart msg
 	return (BELLE_SIP_BODY_HANDLER(belle_sip_multipart_body_handler_new(_chat_message_file_transfer_on_progress, this, first_part_bh, nullptr)));
@@ -364,6 +367,11 @@ void FileTransferChatMessageModifier::processResponseFromPostFile (const belle_h
 				const unsigned char *contentAuthTag = reinterpret_cast<const unsigned char *>(currentFileTransferContent->getFileAuthTag().data());
 				size_t contentAuthTagSize = currentFileTransferContent->getFileAuthTagSize();
 
+				// Also restore the file duration if any, used for voice recording messages
+				parsedXmlFileTransferContent->setFileDuration(currentFileContentToTransfer->getFileDuration());
+				// Temporary workaround required because file transfer server removes content type parameter
+				parsedXmlFileTransferContent->setFileContentType(currentFileContentToTransfer->getContentType());
+
 				string xml_body = dumpFileTransferContentAsXmlString(parsedXmlFileTransferContent, contentKey, contentKeySize, contentAuthTag, contentAuthTagSize, currentFileContentToTransfer->getFileName());
 				delete parsedXmlFileTransferContent;
 				
@@ -641,6 +649,38 @@ static void _chat_message_on_recv_end (belle_sip_user_body_handler_t *bh, void *
 	d->onRecvEnd(bh);
 }
 
+static void renameFileAfterAutoDownload(shared_ptr<Core> core, FileContent *fileContent) {
+	string file = fileContent->getFileName();
+	size_t foundDot = file.find_last_of(".");
+	string fileName = file;
+	string fileExt = "";
+	if (foundDot != string::npos) {
+		fileName = file.substr(0, foundDot);
+		fileExt = file.substr(foundDot + 1);
+	}
+
+	int prefix = 1;
+	string downloadPath = core->getDownloadPath();
+	string filepath = downloadPath + file;
+	while (bctbx_file_exist(filepath.c_str()) == 0) {
+		std::ostringstream sstr;
+		if (fileExt == "") {
+			sstr << downloadPath << fileName << "(" << prefix << ")";
+		} else {
+			sstr << downloadPath << fileName << "(" << prefix << ")." << fileExt;
+		}
+		filepath = sstr.str();
+		prefix += 1;
+	}
+
+	lInfo() << "Renaming downloaded file from [" << fileContent->getFilePath() << "] to [" << filepath << "]";
+	if (std::rename(fileContent->getFilePath().c_str(), filepath.c_str())) {
+		lError() << "Error while renaming file! [" << strerror(errno)  << "]";
+	} else {
+		fileContent->setFilePath(filepath);
+	}
+}
+
 void FileTransferChatMessageModifier::onRecvEnd (belle_sip_user_body_handler_t *bh) {
 	shared_ptr<ChatMessage> message = chatMessage.lock();
 	if (!message)
@@ -674,18 +714,21 @@ void FileTransferChatMessageModifier::onRecvEnd (belle_sip_user_body_handler_t *
 		if (message->getState() != ChatMessage::State::FileTransferError) {
 			// Remove the FileTransferContent from the message and store the FileContent
 			FileContent *fileContent = currentFileContentToTransfer;
-			message->getPrivate()->addContent(fileContent);
 			
 			if (currentFileTransferContent != nullptr) {
 				lInfo() << "Found downloaded file transfer content [" << currentFileTransferContent << "], removing it to keep only the file content [" << fileContent << "]";
-				message->getPrivate()->removeContent(currentFileTransferContent);
+				message->getPrivate()->replaceContent(currentFileTransferContent, fileContent);
 				delete currentFileTransferContent;
 				currentFileTransferContent = nullptr;
+			} else {
+				lWarning() << "Download seems successful but file transfer content not found, adding file content [" << fileContent << "] anyway...";
+				message->getPrivate()->addContent(fileContent);
 			}
 
 			releaseHttpRequest();
 			message->getPrivate()->setState(ChatMessage::State::FileTransferDone);
 			if (message->getPrivate()->isAutoFileTransferDownloadInProgress()) {
+				renameFileAfterAutoDownload(core, fileContent);
 				message->getPrivate()->handleAutoDownload();
 			}
 		}
@@ -857,6 +900,7 @@ static void createFileContentFromFileTransferContent (FileTransferContent *fileT
 	fileContent->setFileSize(fileTransferContent->getFileSize());
 	fileContent->setFilePath(fileTransferContent->getFilePath());
 	fileContent->setContentType(fileTransferContent->getFileContentType());
+	fileContent->setFileDuration(fileTransferContent->getFileDuration());
 
 	// Link the FileContent to the FileTransferContent
 	fileTransferContent->setFileContent(fileContent);
@@ -891,7 +935,7 @@ bool FileTransferChatMessageModifier::downloadFile (
 	}
 
 	lastNotifiedPercentage = 0;
-	lInfo() << "Downloading file transfer content [" << fileTransferContent << "], removing it to keep only the file content [" << fileContent << "]";
+	lInfo() << "Downloading file transfer content [" << fileTransferContent << "], result will be available in file content [" << fileContent << "]";
 
 	belle_http_request_listener_callbacks_t cbs = { 0 };
 	cbs.process_response_headers = _chat_process_response_headers_from_get_file;
@@ -992,7 +1036,7 @@ string FileTransferChatMessageModifier::dumpFileTransferContentAsXmlString(
 {
 	stringstream fakeXml;
 	fakeXml << "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\r\n";
-	fakeXml << "<file xmlns=\"urn:gsma:params:xml:ns:rcs:rcs:fthttp\">\r\n";
+	fakeXml << "<file xmlns=\"urn:gsma:params:xml:ns:rcs:rcs:fthttp\" xmlns:am=\"urn:gsma:params:xml:ns:rcs:rcs:rram\">\r\n";
 	fakeXml << "<file-info type=\"file\">\r\n";
 	fakeXml << "<file-size>" << parsedXmlFileTransferContent->getFileSize() << "</file-size>\r\n";
 
@@ -1027,6 +1071,10 @@ string FileTransferChatMessageModifier::dumpFileTransferContentAsXmlString(
 		fakeXml << "<file-name>" << parsedXmlFileTransferContent->getFileName() << "</file-name>\r\n";
 	}
 	fakeXml << "<content-type>" << parsedXmlFileTransferContent->getFileContentType() << "</content-type>\r\n";
+	
+	if (parsedXmlFileTransferContent->getFileContentType().strongEqual(ContentType::VoiceRecording)) {
+		fakeXml << "<am:playing-length>" << parsedXmlFileTransferContent->getFileDuration() << "</am:playing-length>\r\n";
+	}
 
 	Variant variant = parsedXmlFileTransferContent->getProperty("validUntil");
 	if (variant.isValid()) {
@@ -1083,19 +1131,17 @@ void FileTransferChatMessageModifier::parseFileTransferXmlIntoContent (const cha
 						}
 						if (!xmlStrcmp(cur->name, (const xmlChar *)"content-type")) {
 							xmlChar *content_type = xmlNodeListGetString(xmlMessageBody, cur->xmlChildrenNode, 1);
-							int contentTypeIndex = 0;
-							char *type;
-							char *subtype;
-							while (content_type[contentTypeIndex] != '/' && content_type[contentTypeIndex] != '\0') {
-								contentTypeIndex++;
+							if (content_type) {
+								ContentType contentType((char*)content_type);
+								fileTransferContent->setFileContentType(contentType);
+								ms_free(content_type);
 							}
-							type = ms_strndup((char *)content_type, contentTypeIndex);
-							subtype = ms_strdup(((char *)content_type + contentTypeIndex + 1));
-							ContentType contentType(type, subtype);
-							fileTransferContent->setFileContentType(contentType);
-							ms_free(subtype);
-							ms_free(type);
-							ms_free(content_type);
+						}
+						if (!xmlStrcmp(cur->name, (const xmlChar *)"playing-length")) {
+							xmlChar *fileDuration = xmlNodeListGetString(xmlMessageBody, cur->xmlChildrenNode, 1);
+							int duration = (int) strtod((char *)fileDuration, NULL);
+							fileTransferContent->setFileDuration(duration);
+							xmlFree(fileDuration);
 						}
 						if (!xmlStrcmp(cur->name, (const xmlChar *)"data")) {
 							xmlChar *fileUrl = nullptr;
