@@ -260,6 +260,24 @@ public:
 	*/
 	virtual void onParticipantDeviceMediaChanged (const std::shared_ptr<ConferenceParticipantDeviceEvent> &event, const std::shared_ptr<ParticipantDevice> &device) {};
 
+	/*
+	* This fonction is called each time a participant device changes the ephemeral mode
+	* @param[in] event informations related to the device's participant.
+	*/
+	virtual void onEphemeralModeChanged (const std::shared_ptr<ConferenceEphemeralMessageEvent> &event) {};
+
+	/*
+	* This fonction is called each time a participant device enables or disables ephemeral messages when they are managed by admins
+	* @param[in] event informations related to the device's participant.
+	*/
+	virtual void onEphemeralMessageEnabled (const std::shared_ptr<ConferenceEphemeralMessageEvent> &event) {};
+
+	/*
+	* This fonction is called each time a participant device changes the ephemeral lifetime when ephemeral messages are managed by admins
+	* @param[in] event informations related to the device's participant.
+	*/
+	virtual void onEphemeralLifetimeChanged (const std::shared_ptr<ConferenceEphemeralMessageEvent> &event) {};
+
 	/*
 	 * This fonction is called each time a new admin is set by the focus after full state notification.
 	 * @param[in] event informations related to the new admin participant. @notnil
