@@ -36,6 +36,8 @@
 #include "local-conference-event-handler.h"
 #include "logger/logger.h"
 
+#include <xsd/cxx/xml/dom/serialization-source.hxx>
+
 // TODO: remove me.
 #include "private.h"
 
@@ -46,6 +48,7 @@ using namespace std;
 LINPHONE_BEGIN_NAMESPACE
 
 using namespace Xsd::ConferenceInfo;
+using namespace Xsd::ConferenceInfoLinphoneExtension;
 
 // =============================================================================
 
@@ -55,7 +58,7 @@ LocalConferenceEventHandler::LocalConferenceEventHandler (Conference *conference
 // -----------------------------------------------------------------------------
 
 void LocalConferenceEventHandler::notifyFullState (const string &notify, const shared_ptr<ParticipantDevice> &device) {
-	notifyParticipantDevice(notify, device);
+	notifyParticipantDevice(notify, device, (notify.find(MultipartBoundary) != std::string::npos));
 }
 
 void LocalConferenceEventHandler::notifyAllExcept (const string &notify, const shared_ptr<Participant> &exceptParticipant) {
@@ -70,11 +73,25 @@ void LocalConferenceEventHandler::notifyAll (const string &notify) {
 		notifyParticipant(notify, participant);
 }
 
-string LocalConferenceEventHandler::createNotifyFullState (bool oneToOne) {
+string LocalConferenceEventHandler::createNotifyFullState (LinphoneEvent * lev) {
+	vector<string> acceptedContents = vector<string>();
+	if (lev) {
+		const auto message = (belle_sip_message_t*)lev->op->getRecvCustomHeaders();
+		for (belle_sip_header_t *acceptHeader=belle_sip_message_get_header(message,"Accept"); acceptHeader != NULL; acceptHeader = belle_sip_header_get_next(acceptHeader)) {
+			acceptedContents.push_back(L_C_TO_STRING(belle_sip_header_get_unparsed_value(acceptHeader)));
+		}
+	}
+
+	ConferenceAddress conferenceAddress = conf->getConferenceAddress();
+	ConferenceId conferenceId(conferenceAddress, conferenceAddress);
+	// Enquire whether this conference belongs to a server group chat room
+	shared_ptr<Core> core = conf->getCore();
+	std::shared_ptr<AbstractChatRoom> chatRoom = core->findChatRoom (conferenceId);
+	const bool oneToOne = chatRoom ? !!(chatRoom->getCapabilities() & AbstractChatRoom::Capabilities::OneToOne) : false;
+	const bool ephemerable = chatRoom ? !!(chatRoom->getCapabilities() & AbstractChatRoom::Capabilities::Ephemeral) : false;
 	string entity = conf->getConferenceAddress().asString();
 	string subject = conf->getSubject();
 	ConferenceType confInfo = ConferenceType(entity);
-	UsersType users;
 	ConferenceDescriptionType confDescr = ConferenceDescriptionType();
 	confDescr.setSubject(subject);
 	const auto & confParams = conf->getCurrentParams();
@@ -85,13 +102,36 @@ string LocalConferenceEventHandler::createNotifyFullState (bool oneToOne) {
 	const auto & textEnabled = confParams.chatEnabled();
 	const LinphoneMediaDirection textDirection = textEnabled ? LinphoneMediaDirectionSendRecv : LinphoneMediaDirectionInactive;
 	addAvailableMediaCapabilities(audioDirection, videoDirection, textDirection, confDescr);
+	std::string keywordList;
 	if (oneToOne) {
-		KeywordsType keywords(sizeof(char), "one-to-one");
+		keywordList += "one-to-one ";
+	}
+	if (ephemerable) {
+		keywordList += "ephemeral ";
+	}
+	if (!keywordList.empty()) {
+		KeywordsType keywords(sizeof(char), keywordList.c_str());
 		confDescr.setKeywords(keywords);
 	}
-	confInfo.setUsers(users);
+
+	if (ephemerable && chatRoom) {
+		const ModeType mode = (chatRoom->getCurrentParams()->getEphemeralMode() == AbstractChatRoom::EphemeralMode::AdminManaged) ? "admin-managed" : "device-managed";
+
+		const auto ephemeral = Ephemeral(mode, std::to_string(chatRoom->getCurrentParams()->getEphemeralLifetime()));
+
+		auto & confDescrDOMDoc = confDescr.getDomDocument();
+
+		::xercesc::DOMElement * e (confDescrDOMDoc.createElementNS(::xsd::cxx::xml::string("linphone:xml:ns:conference-info-linphone-extension").c_str(), ::xsd::cxx::xml::string("linphone-cie:ephemeral").c_str()));
+		*e << ephemeral;
+
+		confDescr.getAny().push_back(e);
+	}
+
 	confInfo.setConferenceDescription((const ConferenceDescriptionType) confDescr);
 
+	UsersType users;
+	confInfo.setUsers(users);
+
 	std::list<std::shared_ptr<Participant>> participants(conf->getParticipants());
 
 	// Add local participant only if it is enabled
@@ -120,17 +160,30 @@ string LocalConferenceEventHandler::createNotifyFullState (bool oneToOne) {
 			if (!displayName.empty())
 				endpoint.setDisplayText(displayName);
 
+			auto protocols = Utils::parseCapabilityDescriptor(device->getCapabilityDescriptor());
+			for (const auto & protocol : protocols) {
+				std::ostringstream versionStr;
+				versionStr << protocol.second;
+				const auto ephemeralService = ServiceDescription(protocol.first, versionStr.str());
+				auto & endpointDOMDoc = endpoint.getDomDocument();
+				::xercesc::DOMElement * e (endpointDOMDoc.createElementNS(::xsd::cxx::xml::string("linphone:xml:ns:conference-info-linphone-extension").c_str(), ::xsd::cxx::xml::string("linphone-cie:service-description").c_str()));
+				*e << ephemeralService;
+//				endpoint.setAnyAttribute(e);
+			}
+
 			// Media capabilities
 			addMediaCapabilities(device, endpoint);
 
 			endpoint.setState(StateType::full);
+
 			user.getEndpoint().push_back(endpoint);
 		}
 
 		confInfo.getUsers()->getUser().push_back(user);
 	}
 
-	return createNotify(confInfo, true);
+	const auto conferenceInfoNotify = createNotify(confInfo, true);
+	return conferenceInfoNotify;
 }
 
 void LocalConferenceEventHandler::addAvailableMediaCapabilities(const LinphoneMediaDirection audioDirection, const LinphoneMediaDirection videoDirection, const LinphoneMediaDirection textDirection, ConferenceDescriptionType & confDescr) {
@@ -159,6 +212,7 @@ void LocalConferenceEventHandler::addMediaCapabilities(const std::shared_ptr<Par
 	MediaType audio = MediaType("1");
 	audio.setDisplayText("audio");
 	audio.setType("audio");
+	if (device->getSsrc() > 0) audio.setSrcId(std::to_string(device->getSsrc()));
 	audio.setStatus(LocalConferenceEventHandler::mediaDirectionToMediaStatus(audioDirection));
 	endpoint.getMedia().push_back(audio);
 
@@ -396,6 +450,17 @@ string LocalConferenceEventHandler::createNotifyParticipantDeviceAdded (const Ad
 			if (!displayName.empty())
 				endpoint.setDisplayText(displayName);
 
+			auto protocols = Utils::parseCapabilityDescriptor(participantDevice->getCapabilityDescriptor());
+			for (const auto & protocol : protocols) {
+				std::ostringstream versionStr;
+				versionStr << protocol.second;
+				const auto ephemeralService = ServiceDescription(protocol.first, versionStr.str());
+				auto & endpointDOMDoc = endpoint.getDomDocument();
+				::xercesc::DOMElement * e (endpointDOMDoc.createElementNS(::xsd::cxx::xml::string("linphone:xml:ns:conference-info-linphone-extension").c_str(), ::xsd::cxx::xml::string("linphone-cie:service-description").c_str()));
+				*e << ephemeralService;
+//				endpoint.setAnyAttribute(e);
+			}
+
 			// Media capabilities
 			addMediaCapabilities(participantDevice, endpoint);
 		}
@@ -443,7 +508,8 @@ string LocalConferenceEventHandler::createNotifyParticipantDeviceMediaChanged (c
 
 	EndpointType endpoint = EndpointType();
 	endpoint.setEntity(dAddress.asStringUriOnly());
-	shared_ptr<Participant> participant = conf->findParticipant(pAddress);
+	endpoint.setState(StateType::partial);
+	shared_ptr<Participant> participant = conf->isMe(pAddress) ? conf->getMe() : conf->findParticipant(pAddress);
 	if (participant) {
 		shared_ptr<ParticipantDevice> participantDevice = participant->findDevice(dAddress);
 		if (participantDevice) {
@@ -453,10 +519,8 @@ string LocalConferenceEventHandler::createNotifyParticipantDeviceMediaChanged (c
 
 			// Media capabilities
 			addMediaCapabilities(participantDevice, endpoint);
-
 		}
 	}
-	endpoint.setState(StateType::full);
 	user.getEndpoint().push_back(endpoint);
 
 	confInfo.getUsers()->getUser().push_back(user);
@@ -520,6 +584,7 @@ string LocalConferenceEventHandler::createNotify (ConferenceType confInfo, bool
 	stringstream notify;
 	Xsd::XmlSchema::NamespaceInfomap map;
 	map[""].name = "urn:ietf:params:xml:ns:conference-info";
+	map["linphone-cie"].name = "linphone:xml:ns:conference-info-linphone-extension";
 	serializeConferenceInfo(notify, confInfo, map);
 	return notify.str();
 }
@@ -534,6 +599,81 @@ string LocalConferenceEventHandler::createNotifySubjectChanged (const string &su
 	return createNotify(confInfo);
 }
 
+string LocalConferenceEventHandler::createNotifyEphemeralMode (const EventLog::Type & type) {
+	string entity = conf->getConferenceAddress().asString();
+	ConferenceType confInfo = ConferenceType(entity);
+	ConferenceDescriptionType confDescr = ConferenceDescriptionType();
+	std::string keywordList;
+	keywordList += "ephemeral";
+	if (!keywordList.empty()) {
+		KeywordsType keywords(sizeof(char), keywordList.c_str());
+		confDescr.setKeywords(keywords);
+	}
+
+	ConferenceAddress conferenceAddress = conf->getConferenceAddress();
+	ConferenceId conferenceId(conferenceAddress, conferenceAddress);
+	// Enquire whether this conference belongs to a server group chat room
+	shared_ptr<Core> core = conf->getCore();
+	std::shared_ptr<AbstractChatRoom> chatRoom = core->findChatRoom (conferenceId);
+
+	const ModeType mode = (type == EventLog::Type::ConferenceEphemeralMessageManagedByAdmin) ? "admin-managed" : "device-managed";
+	long lifetime = linphone_core_get_default_ephemeral_lifetime(core->getCCore());
+	if (chatRoom) {
+		lifetime = chatRoom->getCurrentParams()->getEphemeralLifetime();
+	}
+
+	const auto ephemeral = Ephemeral(mode, std::to_string(lifetime));
+	auto & confDescrDOMDoc = confDescr.getDomDocument();
+
+	::xercesc::DOMElement * e (confDescrDOMDoc.createElementNS(::xsd::cxx::xml::string("linphone:xml:ns:conference-info-linphone-extension").c_str(), ::xsd::cxx::xml::string("linphone-cie:ephemeral").c_str()));
+	*e << ephemeral;
+
+	confDescr.getAny().push_back(e);
+
+	confInfo.setConferenceDescription((const ConferenceDescriptionType)confDescr);
+
+	return createNotify(confInfo);
+}
+
+string LocalConferenceEventHandler::createNotifyEphemeralLifetime (const long & lifetime) {
+	string entity = conf->getConferenceAddress().asString();
+	ConferenceType confInfo = ConferenceType(entity);
+	ConferenceDescriptionType confDescr = ConferenceDescriptionType();
+	if (lifetime != 0) {
+		std::string keywordList;
+		keywordList += "ephemeral";
+		if (!keywordList.empty()) {
+			KeywordsType keywords(sizeof(char), keywordList.c_str());
+			confDescr.setKeywords(keywords);
+		}
+	}
+
+	ConferenceAddress conferenceAddress = conf->getConferenceAddress();
+	ConferenceId conferenceId(conferenceAddress, conferenceAddress);
+	// Enquire whether this conference belongs to a server group chat room
+	shared_ptr<Core> core = conf->getCore();
+	std::shared_ptr<AbstractChatRoom> chatRoom = core->findChatRoom (conferenceId);
+
+	auto chatRoomMode = static_cast<AbstractChatRoom::EphemeralMode>(linphone_core_chat_room_get_default_ephemeral_mode(core->getCCore()));
+	if (chatRoom) {
+		chatRoomMode = chatRoom->getCurrentParams()->getEphemeralMode();
+	}
+
+	const ModeType mode = (chatRoomMode == AbstractChatRoom::EphemeralMode::AdminManaged) ? "admin-managed" : "device-managed";
+	const auto ephemeral = Ephemeral(mode, std::to_string(lifetime));
+
+	auto & confDescrDOMDoc = confDescr.getDomDocument();
+
+	::xercesc::DOMElement * e (confDescrDOMDoc.createElementNS(::xsd::cxx::xml::string("linphone:xml:ns:conference-info-linphone-extension").c_str(), ::xsd::cxx::xml::string("linphone-cie:ephemeral").c_str()));
+	*e << ephemeral;
+
+	confDescr.getAny().push_back(e);
+
+	confInfo.setConferenceDescription((const ConferenceDescriptionType)confDescr);
+
+	return createNotify(confInfo);
+}
+
 string LocalConferenceEventHandler::createNotifyAvailableMediaChanged (const std::map<ConferenceMediaCapabilities, bool> mediaCapabilities) {
 	string entity = conf->getConferenceAddress().asString();
 	ConferenceType confInfo = ConferenceType(entity);
@@ -573,7 +713,7 @@ void LocalConferenceEventHandler::notifyParticipant (const string &notify, const
 			case ParticipantDevice::State::Present:
 			case ParticipantDevice::State::Joining:
 			case ParticipantDevice::State::ScheduledForJoining:
-				notifyParticipantDevice(notify, device);
+				notifyParticipantDevice(notify, device, (notify.find(MultipartBoundary) != std::string::npos));
 				break;
 			case ParticipantDevice::State::Leaving:
 			case ParticipantDevice::State::Left:
@@ -606,11 +746,12 @@ void LocalConferenceEventHandler::notifyParticipantDevice (const string &notify,
 		content.setContentEncoding("deflate");
 	LinphoneContent *cContent = L_GET_C_BACK_PTR(&content);
 	linphone_event_notify(ev, cContent);
+	linphone_core_notify_notify_sent(conf->getCore()->getCCore(),ev, cContent);
 }
 
 // -----------------------------------------------------------------------------
 
-void LocalConferenceEventHandler::subscribeReceived (LinphoneEvent *lev, bool oneToOne) {
+void LocalConferenceEventHandler::subscribeReceived (LinphoneEvent *lev) {
 	const LinphoneAddress *lAddr = linphone_event_get_from(lev);
 	char *addrStr = linphone_address_as_string(lAddr);
 	Address participantAddress(addrStr);
@@ -630,7 +771,8 @@ void LocalConferenceEventHandler::subscribeReceived (LinphoneEvent *lev, bool on
 	IdentityAddress contactAddr(contactAddrStr);
 	bctbx_free(contactAddrStr);
 	shared_ptr<ParticipantDevice> device = participant->findDevice(contactAddr);
-	if (!device || (device->getState() != ParticipantDevice::State::Present && device->getState() != ParticipantDevice::State::Joining)) {
+	const auto deviceState = device ? device->getState() : ParticipantDevice::State::ScheduledForJoining;
+	if (!device || ((deviceState != ParticipantDevice::State::Present) && (deviceState != ParticipantDevice::State::Joining))) {
 		lError() << "Received SUBSCRIBE for conference [" << conf->getConferenceAddress()
 			<< "], device sending subscribe [" << contactAddr << "] is not known, no NOTIFY sent";
 		linphone_event_deny_subscription(lev, LinphoneReasonDeclined);
@@ -641,17 +783,28 @@ void LocalConferenceEventHandler::subscribeReceived (LinphoneEvent *lev, bool on
 	if (linphone_event_get_subscription_state(lev) == LinphoneSubscriptionActive) {
 		unsigned int evLastNotify = static_cast<unsigned int>(Utils::stoi(linphone_event_get_custom_header(lev, "Last-Notify-Version")));
 		device->setConferenceSubscribeEvent(lev);
-		if (evLastNotify == 0 || (device->getState() == ParticipantDevice::State::Joining)) {
-			lInfo() << "Sending initial notify of conference [" << conf->getConferenceAddress() << "] to: " << device->getAddress();
-			notifyFullState(createNotifyFullState(oneToOne), device);
+		if ((evLastNotify == 0) || (deviceState == ParticipantDevice::State::Joining)) {
+			lInfo() << "Sending initial notify of conference [" << conf->getConferenceAddress() << "] to: " << device->getAddress() << " with last notif set to " << conf->getLastNotify();
+			if (deviceState == ParticipantDevice::State::Present) {
+				lInfo() << "Participant " << device->getAddress() << " is already part of conference [" << conf->getConferenceAddress() << "] hence send full state to be sure the client and the server are on the same page";
+			} else {
+				conf->setLastNotify(lastNotify+1);
+			}
+			notifyFullState(createNotifyFullState(lev), device);
+			// Do not notify everybody that a particiant has been added if it was already part of the conference. It may mean that the client and the server wanted to synchronize to each other
+			if (deviceState != ParticipantDevice::State::Present) {
+				// Notify everybody that a participant device has been added and its capabilities after receiving the SUBSCRIBE
+				notifyAllExcept(createNotifyParticipantDeviceAdded(participant->getAddress().asAddress(), device->getAddress().asAddress()), participant);
+			}
 		} else if (evLastNotify < lastNotify) {
 			lInfo() << "Sending all missed notify [" << evLastNotify << "-" << lastNotify <<
 				"] for conference [" << conf->getConferenceAddress() << "] to: " << participant->getAddress();
 			notifyParticipantDevice(createNotifyMultipart(static_cast<int>(evLastNotify)), device, true);
 		} else if (evLastNotify > lastNotify) {
-			lError() << "Last notify received by client [" << evLastNotify << "] for conference [" <<
+			lWarning() << "Last notify received by client [" << evLastNotify << "] for conference [" <<
 				conf->getConferenceAddress() <<
-				"] should not be higher than last notify sent by server [" << lastNotify << "]";
+				"] should not be higher than last notify sent by server [" << lastNotify << "] - sending a notify full state in an attempt to recover from this situation";
+			notifyFullState(createNotifyFullState(lev), device);
 		}
 	}
 }
@@ -678,12 +831,23 @@ void LocalConferenceEventHandler::subscriptionStateChanged (LinphoneEvent *lev,
 	}
 }
 
-string LocalConferenceEventHandler::getNotifyForId (int notifyId, bool oneToOne) {
+string LocalConferenceEventHandler::getNotifyForId (int notifyId, LinphoneEvent *lev) {
 	unsigned int lastNotify = conf->getLastNotify();
-	if (notifyId == 0)
-		return createNotifyFullState(oneToOne);
-	else if (notifyId < static_cast<int>(lastNotify))
+	if ((notifyId == 0) || (notifyId > static_cast<int>(lastNotify))) {
+		list<Content> contents;
+		contents.emplace_back(Content());
+		contents.back().setContentType(ContentType::ConferenceInfo);
+		auto content = createNotifyFullState(lev);
+		contents.back().setBodyFromUtf8(content);
+
+		list<Content *> contentPtrs;
+		for (auto &content : contents)
+			contentPtrs.push_back(&content);
+		auto multipart = ContentManager::contentListToMultipart(contentPtrs).getBodyAsUtf8String();
+		return multipart;
+	} else if (notifyId < static_cast<int>(lastNotify)) {
 		return createNotifyMultipart(notifyId);
+	}
 
 	return Utils::getEmptyConstRefObject<string>();
 }
@@ -722,7 +886,7 @@ void LocalConferenceEventHandler::onParticipantSetAdmin (const std::shared_ptr<C
 void LocalConferenceEventHandler::onSubjectChanged (const std::shared_ptr<ConferenceSubjectEvent> &event) {
 	// Do not send notify if conference pointer is null. It may mean that the confernece has been terminated
 	if (conf) {
-		notifyAll(createNotifySubjectChanged());
+		notifyAll(createNotifySubjectChanged(event->getSubject()));
 	} else {
 		lWarning() << __func__ << ": Not sending notification of conference subject change because pointer to conference is null";
 	}
@@ -767,6 +931,24 @@ void LocalConferenceEventHandler::onParticipantDeviceMediaChanged (const std::sh
 	}
 }
 
+void LocalConferenceEventHandler::onEphemeralModeChanged (const std::shared_ptr<ConferenceEphemeralMessageEvent> &event) {
+	// Do not send notify if conference pointer is null. It may mean that the confernece has been terminated
+	if (conf) {
+		notifyAll(createNotifyEphemeralMode(event->getType()));
+	} else {
+		lWarning() << __func__ << ": Not sending notification of ephemeral mode changed to " << event->getType();
+	}
+}
+
+void LocalConferenceEventHandler::onEphemeralLifetimeChanged (const std::shared_ptr<ConferenceEphemeralMessageEvent> &event) {
+	// Do not send notify if conference pointer is null. It may mean that the confernece has been terminated
+	if (conf) {
+		notifyAll(createNotifyEphemeralLifetime(event->getEphemeralMessageLifetime()));
+	} else {
+		lWarning() << __func__ << ": Not sending notification of ephemeral lifetime changed to " << event->getEphemeralMessageLifetime();
+	}
+}
+
 void LocalConferenceEventHandler::onStateChanged (LinphonePrivate::ConferenceInterface::State state) {
 }
 
@@ -792,4 +974,5 @@ shared_ptr<Participant> LocalConferenceEventHandler::getConferenceParticipant (c
 
 	return participant;
 }
+
 LINPHONE_END_NAMESPACE
