@@ -58,6 +58,11 @@ MS2AudioStream::MS2AudioStream(StreamsGroup &sg, const OfferAnswerContext &param
 	initializeSessions((MediaStream*)mStream);
 }
 
+static void audioStreamIsSpeakingCb (void *userData, uint32_t speakerSsrc, bool_t isSpeaking) {
+	MS2AudioStream *zis = static_cast<MS2AudioStream*>(userData);
+	zis->getMediaSession().notifySpeakingDevice(speakerSsrc, isSpeaking);
+}
+
 void MS2AudioStream::initZrtp() {
 	LinphoneCallLog *log = getMediaSession().getLog();
 	const LinphoneAddress *peerAddr = linphone_call_log_get_remote_address(log);
@@ -204,7 +209,7 @@ void MS2AudioStream::finishPrepare(){
 }
 
 MediaStream *MS2AudioStream::getMediaStream()const{
-	return &mStream->ms;
+	return mStream ? &mStream->ms : nullptr;
 }
 
 void MS2AudioStream::setupMediaLossCheck(){
@@ -218,24 +223,92 @@ void MS2AudioStream::setupMediaLossCheck(){
 		}, 1000, "Audio stream alive check");
 }
 
+
+void MS2AudioStream::audioRouteChangeCb (void* userData, bool_t needReloadSoundDevices, char* newInputDevice, char* newOutputDevice) {
+	Core *core = static_cast<Core*>(userData);
+
+	std::string newInput, newOutput;
+	if (newInputDevice) newInput = std::string(newInputDevice);
+	if (newOutputDevice) newOutput = std::string(newOutputDevice);
+	
+	core->doLater([core, newInput, newOutput, needReloadSoundDevices]() {
+		if (needReloadSoundDevices) {
+			linphone_core_reload_sound_devices(core->getCCore());
+		}
+		
+		// Make sure that the current device the core is using match the reality of the IOS audio route. If not, set it properly
+		bool inputRequiresUpdate = !newInput.empty();
+		bool outputRequiresUpdate = !newOutput.empty();
+		
+		bctbx_list_t * deviceIt = linphone_core_get_extended_audio_devices(core->getCCore());
+		while ( deviceIt != NULL && (inputRequiresUpdate || outputRequiresUpdate) ) {
+			LinphoneAudioDevice * pDevice = (LinphoneAudioDevice *) deviceIt->data;
+			std::string deviceName(linphone_audio_device_get_device_name(pDevice));
+			
+			if (inputRequiresUpdate && newInput == deviceName) {
+				linphone_core_set_input_audio_device(core->getCCore(), pDevice);
+				inputRequiresUpdate = false;
+			}
+			if (outputRequiresUpdate && newOutput == deviceName) {
+				linphone_core_set_output_audio_device(core->getCCore(), pDevice);
+				outputRequiresUpdate = false;
+			}
+			deviceIt = deviceIt->next;
+		}
+		bctbx_list_free_with_data(deviceIt, (void (*)(void *))linphone_audio_device_unref);
+		
+		if (inputRequiresUpdate) {
+			ms_warning("Current audio route input is '%s', but we could not find the matching device in the linphone devices list", newInput.c_str());
+		}
+		if (outputRequiresUpdate) {
+			ms_warning("Current audio route output is '%s', but we could not find the matching device in the linphone devices list", newOutput.c_str());
+		}
+		
+		// Notify the filter that the audio route changed
+		core->soundcardAudioRouteChanged();
+	});
+}
+
 void MS2AudioStream::render(const OfferAnswerContext &params, CallSession::State targetState){
 	const auto & stream = params.getResultStreamDescription();
 	CallSessionListener *listener = getMediaSessionPrivate().getCallSessionListener();
 	
 	bool basicChangesHandled = handleBasicChanges(params, targetState);
 
+	AudioDevice *outputAudioDevice = getMediaSessionPrivate().getCurrentOutputAudioDevice();
+	MS2AudioMixer *audioMixer = getAudioMixer();
+	MSSndCard *playcard = nullptr;
+	// try to get currently used playcard if it was already set
+	if (outputAudioDevice) {
+		playcard = outputAudioDevice->getSoundCard();
+	}
+
+	auto expectedStreamType = (targetState == CallSession::State::IncomingEarlyMedia) ? MS_SND_CARD_STREAM_RING : MS_SND_CARD_STREAM_VOICE;
+
 	if (basicChangesHandled) {
 		if (getState() == Running) {
-			if(mRestartStreamRequired) {
-				stop();
-				mRestartStreamRequired = false;
-			}else{
-				bool muted = mMuted;
-				MS2Stream::render(params, targetState); // MS2Stream::render() may decide to unmute.
-				if (muted && !mMuted) {
+
+			bool muted = mMuted;
+			MS2Stream::render(params, targetState); // MS2Stream::render() may decide to unmute.
+			if (muted && !mMuted) {
+				if (audioMixer){
+					lInfo() << "Early media finished, unmuting audio input and will connect audio to conference.";
+					mRestartStreamRequired = true;
+				}else{
 					lInfo() << "Early media finished, unmuting audio input...";
 					enableMic(micEnabled());
 				}
+			}
+
+			if (playcard) {
+				auto streamType = ms_snd_card_get_stream_type(playcard);
+				mRestartStreamRequired |= (streamType != expectedStreamType);
+			}
+
+			if (mRestartStreamRequired) {
+				stop();
+				mRestartStreamRequired = false;
+			} else {
 				return;
 			}
 		}else{
@@ -244,7 +317,7 @@ void MS2AudioStream::render(const OfferAnswerContext &params, CallSession::State
 		}
 	}
 
-	MS2AudioMixer *audioMixer = getAudioMixer();
+	
 	int usedPt = -1;
 	string onHoldFile = "";
 	RtpProfile *audioProfile = makeProfile(params.resultMediaDescription, stream, &usedPt);
@@ -266,14 +339,6 @@ void MS2AudioStream::render(const OfferAnswerContext &params, CallSession::State
 	else if (stream.getDirection() == SalStreamSendRecv)
 		media_stream_set_direction(&mStream->ms, MediaStreamSendRecv);
 
-	AudioDevice *outputAudioDevice = getMediaSessionPrivate().getCurrentOutputAudioDevice();
-	MSSndCard *playcard = nullptr;
-
-	// try to get currently used playcard if it was already set
-	if (outputAudioDevice) {
-		playcard = outputAudioDevice->getSoundCard();
-	}
-
 	// If stream doesn't have a playcard associated with it, then use the default values
 	if (!playcard)
 		playcard = getCCore()->sound_conf.lsd_card ? getCCore()->sound_conf.lsd_card : getCCore()->sound_conf.play_sndcard;
@@ -329,15 +394,17 @@ void MS2AudioStream::render(const OfferAnswerContext &params, CallSession::State
 	if (listener && !listener->areSoundResourcesAvailable(getMediaSession().getSharedFromThis())) {
 		lInfo() << "Sound resources are used by another CallSession, not using soundcard";
 		captcard = playcard = nullptr;
+		if (targetState == CallSession::State::OutgoingEarlyMedia){
+			// Restart will be required upon transitionning to StreamsRunning state to take into account that sound resources
+			// may have been released meanwhile.
+			mRestartStreamRequired = true;
+			lInfo() << "Soundcard usage will be checked again when moving to StreamsRunning.";
+		}
 	}
 
 	if (playcard) {
-		if (targetState == CallSession::State::IncomingEarlyMedia) {
-			lInfo() << "Incoming early-media call state, using ring stream";
-			ms_snd_card_set_stream_type(playcard, MS_SND_CARD_STREAM_RING);
-		} else {
-			ms_snd_card_set_stream_type(playcard, MS_SND_CARD_STREAM_VOICE);
-		}
+		lInfo() << "Call state " << targetState << ", using " << ((expectedStreamType == MS_SND_CARD_STREAM_RING) ? "ring" : "voice") << " stream";
+		ms_snd_card_set_stream_type(playcard, expectedStreamType);
 	}
 
 	configureAudioStream();
@@ -400,14 +467,27 @@ void MS2AudioStream::render(const OfferAnswerContext &params, CallSession::State
 		mCurrentPlaybackCard = ms_media_resource_get_soundcard(&io.output);
 		if (mCurrentCaptureCard) mCurrentCaptureCard = ms_snd_card_ref(mCurrentCaptureCard);
 		if (mCurrentPlaybackCard) mCurrentPlaybackCard = ms_snd_card_ref(mCurrentPlaybackCard);
+		
+		const auto streamCfg = stream.getActualConfiguration();
+		if (streamCfg.getMixerToClientExtensionId() > 0) {
+			// This has to be called before audio_stream_start so that the AudioStream can configure it's filters properly
+			audio_stream_set_mixer_to_client_extension_id(mStream, streamCfg.getMixerToClientExtensionId());
+		}
+		if (streamCfg.getClientToMixerExtensionId() > 0) {
+			// This has to be called before audio_stream_start so that the AudioStream can configure it's filters properly
+			audio_stream_set_client_to_mixer_extension_id(mStream, streamCfg.getClientToMixerExtensionId());
+		}
 
+		audio_stream_set_is_speaking_callback(mStream, audioStreamIsSpeakingCb, this);
+		
+		audio_stream_set_audio_route_changed_callback(mStream, &MS2AudioStream::audioRouteChangeCb, &getCore());
 		int err = audio_stream_start_from_io(mStream, audioProfile, dest.rtpAddr.c_str(), dest.rtpPort,
 			dest.rtcpAddr.c_str(), dest.rtcpPort, usedPt, &io);
 		VideoStream *vs = getPeerVideoStream();
 		if (vs) audio_stream_link_video(mStream, vs);
 		if (err == 0)
 			postConfigureAudioStream((mMuted || mMicMuted) && (listener && !listener->isPlayingRingbackTone(getMediaSession().getSharedFromThis())));
-		mStartCount++;
+		mInternalStats.number_of_starts++;
 	}
 	
 	if ((targetState == CallSession::State::Paused) && !captcard && !playfile.empty()) {
@@ -417,7 +497,7 @@ void MS2AudioStream::render(const OfferAnswerContext &params, CallSession::State
 	if (listener && listener->isPlayingRingbackTone(getMediaSession().getSharedFromThis()))
 		setupRingbackPlayer();
 	
-	if (audioMixer){
+	if (audioMixer && !mMuted){
 		mConferenceEndpoint = ms_audio_endpoint_get_from_stream(mStream, TRUE);
 		audioMixer->connectEndpoint(this, mConferenceEndpoint, (stream.getDirection() == SalStreamRecvOnly));
 	}
@@ -585,24 +665,18 @@ void MS2AudioStream::configureFlowControl(AudioStream *as, LinphoneCore *lc){
 	}
 }
 
-void MS2AudioStream::postConfigureAudioStream(AudioStream *as, LinphoneCore *lc, bool muted){
-	audio_stream_enable_mic(as, !muted);
-	
-	float recvGain = lc->sound_conf.soft_play_lev;
-	if (static_cast<int>(recvGain)){
-		if (as->volrecv)
-			ms_filter_call_method(as->volrecv, MS_VOLUME_SET_DB_GAIN, &recvGain);
-		else
-			lWarning() << "Could not apply playback gain: gain control wasn't activated";
-	}
+void MS2AudioStream::enableMicOnAudioStream(AudioStream *as, LinphoneCore *lc, bool enabled){
+	enabled = enabled && linphone_core_mic_enabled(lc);
+	if (!enabled) bctbx_message("AudioStream[%p]: mic is muted.", as);
+	audio_stream_enable_mic(as, enabled);
+}
 
-	float micGain = lc->sound_conf.soft_mic_lev;
-	if (static_cast<int>(micGain)){
-		if (as->volsend)
-			ms_filter_call_method(as->volsend, MS_VOLUME_SET_DB_GAIN, &micGain);
-		else
-			lWarning() << "Could not apply microphone gain: gain control wasn't activated";
-	}
+void MS2AudioStream::postConfigureAudioStream(AudioStream *as, LinphoneCore *lc, bool muted){
+	/* Set soft gains */
+	audio_stream_set_mic_gain_db(as, lc->sound_conf.soft_mic_lev);
+	audio_stream_set_spk_gain_db(as, lc->sound_conf.soft_play_lev);
+	/* Set microphone enablement */
+	enableMicOnAudioStream(as, lc, !muted);
 
 	LinphoneConfig *config = linphone_core_get_config(lc);
 	float ngThres = linphone_config_get_float(config, "sound", "ng_thres", 0.05f);
@@ -633,7 +707,7 @@ void MS2AudioStream::postConfigureAudioStream(AudioStream *as, LinphoneCore *lc,
 	}
 	if (as->volrecv) {
 		/* Parameters for a limited noise-gate effect, using echo limiter threshold */
-		float floorGain = (float)(1 / pow(10, micGain / 10));
+		float floorGain = (float)(1 / pow(10, lc->sound_conf.soft_mic_lev / 10));
 		int spkAgc = linphone_config_get_int(config, "sound", "speaker_agc_enabled", 0);
 		MSFilter *f = as->volrecv;
 		ms_filter_call_method(f, MS_VOLUME_ENABLE_AGC, &spkAgc);
@@ -687,7 +761,7 @@ void MS2AudioStream::handleEvent(const OrtpEvent *ev){
 
 void MS2AudioStream::enableMic(bool value){
 	mMicMuted = !value;
-	audio_stream_enable_mic(mStream, value);
+	enableMicOnAudioStream(mStream, getCCore(), value);
 }
 
 bool MS2AudioStream::micEnabled()const{
@@ -707,17 +781,23 @@ void MS2AudioStream::sendDtmf(int dtmf){
 	audio_stream_send_dtmf(mStream, (char)dtmf);
 }
 
-void MS2AudioStream::startRecording(){
+bool MS2AudioStream::startRecording(){
 	if (getMediaSessionPrivate().getParams()->getRecordFilePath().empty()) {
 		lError() << "MS2AudioStream::startRecording(): no output file specified. Use MediaSessionParams::setRecordFilePath()";
-		return;
+		return false;
 	}
 	if (getMediaSessionPrivate().getParams()->getPrivate()->getInConference()){
 		lWarning() << "MS2AudioStream::startRecording(): not supported in conference.";
-		return;
+		return false;
 	}
-	if (media_stream_get_state(&mStream->ms) == MSStreamStarted) audio_stream_mixed_record_start(mStream);
-	mRecordActive = true;
+	if (media_stream_get_state(&mStream->ms) == MSStreamStarted) {
+		if (audio_stream_mixed_record_start(mStream) != -1) {
+			mRecordActive = true;
+			return true;
+		}
+	}
+
+	return false;
 }
 
 void MS2AudioStream::stopRecording(){
@@ -785,11 +865,31 @@ bool MS2AudioStream::echoCancellationEnabled()const{
 	ms_filter_call_method(mStream->ec, MS_ECHO_CANCELLER_GET_BYPASS_MODE, &val);
 	return !val;
 }
-	
+
+void MS2AudioStream::setSoundCardType(MSSndCard *soundcard) {
+	if (soundcard) {
+		auto expectedStreamType = MS_SND_CARD_STREAM_VOICE;
+		switch (getMediaSession().getState()){
+			case CallSession::State::IncomingReceived:
+			case CallSession::State::IncomingEarlyMedia:
+				expectedStreamType = MS_SND_CARD_STREAM_RING;
+			break;
+			default:
+				expectedStreamType = MS_SND_CARD_STREAM_VOICE;
+			break;
+		}
+		lInfo() << "[MS2AudioStream] setting type of soundcard " << soundcard << " to " << ((expectedStreamType == MS_SND_CARD_STREAM_RING) ? "ring" : "voice");
+		ms_snd_card_set_stream_type(soundcard, expectedStreamType);
+	}
+}
+
 void MS2AudioStream::setInputDevice(AudioDevice *audioDevice) {
 	if(!mStream) return;
-	if(audio_stream_set_input_ms_snd_card(mStream, (audioDevice?audioDevice->getSoundCard():NULL)) < 0 ){
+	auto soundcard = audioDevice ? audioDevice->getSoundCard() : nullptr;
+	setSoundCardType(soundcard);
+	if(audio_stream_set_input_ms_snd_card(mStream, (soundcard?soundcard:NULL)) < 0 ){
 		if(getState() == Running){// New device couldn't update the stream, request to stop it
+			// Due to missing implementation of MS_AUDIO_CAPTURE_SET_INTERNAL_ID and MS_AUDIO_PLAYBACK_SET_INTERNAL_ID 
 			mRestartStreamRequired = true;
 			lInfo() << "[MS2AudioStream] restart stream required for updating input";
 		}
@@ -798,8 +898,11 @@ void MS2AudioStream::setInputDevice(AudioDevice *audioDevice) {
 
 void MS2AudioStream::setOutputDevice(AudioDevice *audioDevice) {
 	if(!mStream) return;
-	if(audio_stream_set_output_ms_snd_card(mStream, (audioDevice?audioDevice->getSoundCard():NULL)) < 0 ){
+	auto soundcard = audioDevice ? audioDevice->getSoundCard() : nullptr;
+	setSoundCardType(soundcard);
+	if(audio_stream_set_output_ms_snd_card(mStream, (soundcard?soundcard:NULL)) < 0 ){
 		if(getState() == Running){// New device couldn't update the stream, request to stop it
+			// Due to missing implementation of MS_AUDIO_CAPTURE_SET_INTERNAL_ID and MS_AUDIO_PLAYBACK_SET_INTERNAL_ID 
 			mRestartStreamRequired = true;
 			lInfo() << "[MS2AudioStream] restart stream required for updating output";
 		}
@@ -821,8 +924,9 @@ AudioDevice* MS2AudioStream::getOutputDevice() const {
 void MS2AudioStream::finish(){
 	if (mStream){
 		stopRecording();	// ensure to stop recording if recording
-		audio_stream_stop(mStream);
+		auto oldStream = mStream;
 		mStream = nullptr;
+		audio_stream_stop(oldStream);
 	}
 	MS2Stream::finish();
 }
