@@ -41,8 +41,10 @@ LINPHONE_BEGIN_NAMESPACE
 // =============================================================================
 
 int CallSessionPrivate::computeDuration () const {
-	if (log->connected_date_time == 0)
-		return 0;
+	if (log->connected_date_time == 0) {
+		if (log->start_date_time == 0) return 0; 
+		return (int)(ms_time(nullptr) - log->start_date_time);
+	}
 	return (int)(ms_time(nullptr) - log->connected_date_time);
 }
 
@@ -142,13 +144,17 @@ void CallSessionPrivate::setState (CallSession::State newState, const string &me
 			lError() << "You must fill a reason when changing call state (from " <<
 				Utils::toString(prevState) << " to " << Utils::toString(state) << ")";
 		}
+
+		// So call log duration will be available in those states in the app listener
+		if ((newState == CallSession::State::End) || (newState == CallSession::State::Error)) {
+			setTerminated();
+		}
+
 		if (listener)
 			listener->onCallSessionStateChanged(q->getSharedFromThis(), newState, message);
 
 		if (newState == CallSession::State::Released) {
 			setReleased(); /* Shall be performed after app notification */
-		} else if ((newState == CallSession::State::End) || (newState == CallSession::State::Error)) {
-			setTerminated();
 		}
 	}
 }
@@ -183,6 +189,16 @@ void CallSessionPrivate::setTransferState (CallSession::State newState) {
 		listener->onCallSessionTransferStateChanged(q->getSharedFromThis(), newState);
 }
 
+void CallSessionPrivate::handleIncoming (bool tryStartRingtone) {
+	L_Q();
+
+	if (tryStartRingtone) { // The state is still in IncomingReceived state. Start ringing if it was needed
+		listener->onStartRingtone(q->getSharedFromThis());
+	}
+
+	handleIncomingReceivedStateInIncomingNotification();
+}
+
 void CallSessionPrivate::startIncomingNotification () {
 	L_Q();
 	bool_t tryStartRingtone = TRUE;// Try to start a tone if this notification is not a PushIncomingReceived and have listener
@@ -198,11 +214,9 @@ void CallSessionPrivate::startIncomingNotification () {
 	if (listener)
 		listener->onBackgroundTaskToBeStopped(q->getSharedFromThis());
 
-	if (state == CallSession::State::IncomingReceived || state == CallSession::State::IncomingEarlyMedia) { // If early media was accepted during setState callback above
-		if (tryStartRingtone) { // The state is still in IncomingReceived state. Start ringing if it was needed
-			listener->onStartRingtone(q->getSharedFromThis());
-		}
-		handleIncomingReceivedStateInIncomingNotification();
+	if ((state == CallSession::State::IncomingReceived && linphone_core_auto_send_ringing_enabled(q->getCore()->getCCore()))
+		|| state == CallSession::State::IncomingEarlyMedia) { // If early media was accepted during setState callback above
+		handleIncoming(tryStartRingtone);
 	}
 
 	if (q->mIsAccepting && listener) {
@@ -719,9 +733,10 @@ LinphoneStatus CallSessionPrivate::startAcceptUpdate (CallSession::State nextSta
 	return 0;
 }
 
-LinphoneStatus CallSessionPrivate::startUpdate (const string &subject) {
+LinphoneStatus CallSessionPrivate::startUpdate (const CallSession::UpdateMethod method, const string &subject) {
 	L_Q();
 	string newSubject(subject);
+
 	if (newSubject.empty()) {
 		if (isInConference())
 			newSubject = "Conference";
@@ -745,7 +760,16 @@ LinphoneStatus CallSessionPrivate::startUpdate (const string &subject) {
 		op->setContactAddress(contactAddress.getInternalAddress());
 	} else
 		op->setContactAddress(nullptr);
-	return op->update(newSubject.c_str(), q->getParams()->getPrivate()->getNoUserConsent());
+
+	bool noUserConsent = q->getParams()->getPrivate()->getNoUserConsent();
+	if (method != CallSession::UpdateMethod::Default) {
+		noUserConsent = method == CallSession::UpdateMethod::Update;
+	}
+	
+	// Update custom headers
+	op->setSentCustomHeaders(params->getPrivate()->getCustomHeaders());
+
+	return op->update(newSubject.c_str(), noUserConsent);
 }
 
 void CallSessionPrivate::terminate () {
@@ -918,7 +942,7 @@ LinphoneAddress * CallSessionPrivate::getFixedContact () const {
 void CallSessionPrivate::reinviteToRecoverFromConnectionLoss () {
 	L_Q();
 	lInfo() << "CallSession [" << q << "] is going to be updated (reINVITE) in order to recover from lost connectivity";
-	q->update(params);
+	q->update(params, CallSession::UpdateMethod::Invite);
 }
 
 void CallSessionPrivate::repairByInviteWithReplaces () {
@@ -927,10 +951,13 @@ void CallSessionPrivate::repairByInviteWithReplaces () {
 	string callId = op->getCallId();
 	string fromTag = op->getLocalTag();
 	string toTag = op->getRemoteTag();
+	// Restore INVITE body if any, for example while creating a chat room
+	Content content = Content(op->getLocalBody());
+
 	op->killDialog();
 	createOp();
 	op->setReplaces(callId.c_str(), fromTag, toTag.empty()?"0":toTag); // empty tag is set to 0 as defined by rfc3891
-	q->startInvite(nullptr);
+	q->startInvite(nullptr, subject, &content); // Don't forget to set subject from call-session (and not from OP)
 }
 
 void CallSessionPrivate::repairIfBroken () {
@@ -1055,6 +1082,10 @@ void CallSession::setListener(CallSessionListener *listener){
 	d->listener = listener;
 }
 
+void CallSession::setStateToEnded() {
+	L_D();
+	d->setState(CallSession::State::End, "Call ended");
+}
 
 void CallSession::acceptDefault(){
 	accept();
@@ -1433,7 +1464,7 @@ LinphoneStatus CallSession::transfer (const string &dest) {
 	return transfer(address);
 }
 
-LinphoneStatus CallSession::update (const CallSessionParams *csp, const string &subject, const Content *content) {
+LinphoneStatus CallSession::update (const CallSessionParams *csp, const UpdateMethod method, const string &subject, const Content *content) {
 	L_D();
 	CallSession::State nextState;
 	CallSession::State initialState = d->state;
@@ -1445,7 +1476,7 @@ LinphoneStatus CallSession::update (const CallSessionParams *csp, const string &
 		d->setParams(new CallSessionParams(*csp));
 
 	d->op->setLocalBody(content ? *content : Content());
-	LinphoneStatus result = d->startUpdate(subject);
+	LinphoneStatus result = d->startUpdate(method, subject);
 	if (result && (d->state != initialState)) {
 		/* Restore initial state */
 		d->setState(initialState, "Restore initial state");
@@ -1478,9 +1509,9 @@ int CallSession::getDuration () const {
 		case CallSession::State::End:
 		case CallSession::State::Error:
 		case CallSession::State::Released:
-			return d->log->duration;
+			return d->log->connected_date_time == 0 ? 0 : d->log->duration;
 		default:
-			return d->computeDuration();
+			return d->log->connected_date_time == 0 ? 0 : d->computeDuration();
 	}
 }
 
