@@ -199,7 +199,6 @@ void MS2Stream::fillLocalMediaDescription(OfferAnswerContext & ctx){
 	auto & localDesc = const_cast<SalStreamDescription &>(ctx.getLocalStreamDescription());
 	localDesc.rtp_addr = getPublicIp();
 	localDesc.rtcp_addr = getPublicIp();
-	
 	if (localDesc.rtp_port == SAL_STREAM_DESCRIPTION_PORT_TO_BE_DETERMINED && !localDesc.getPayloads().empty()){
 		/* Don't fill ports if no codecs are defined. The stream is not valid and should be disabled.*/
 		if (linphone_core_is_zero_rtp_port_for_stream_inactive_enabled(getCCore()) && (localDesc.getDirection() == SalStreamInactive)) {
@@ -223,6 +222,13 @@ void MS2Stream::fillLocalMediaDescription(OfferAnswerContext & ctx){
 	
 	localDesc.cfgs[localDesc.getChosenConfigurationIndex()].rtp_ssrc = rtp_session_get_send_ssrc(mSessions.rtp_session);
 
+	if (getMediaSessionPrivate().getOp() && getMediaSessionPrivate().getOp()->getRemoteContactAddress()) {
+		char *c_address = sal_address_as_string(getMediaSessionPrivate().getOp()->getRemoteContactAddress());
+		Address address(c_address);
+		if (address.hasParam("isfocus")) localDesc.cfgs[localDesc.getChosenConfigurationIndex()].conference_ssrc = rtp_session_get_send_ssrc(mSessions.rtp_session);
+		ms_free(c_address);
+	}
+
 	// The negotiated encryption must remain unchanged if:
 	// - internal update
 	// - pausing a call
@@ -248,6 +254,7 @@ void MS2Stream::fillLocalMediaDescription(OfferAnswerContext & ctx){
 
 		localDesc.setZrtpHash(enableZrtpHash, zrtphash);
 	}
+
 	if (localDesc.hasDtls()) {
 		/* Get the self fingerprint from call (it's computed at stream init) */
 		/* If we are offering, SDP will have actpass setup attribute when role is unset, if we are responding the result mediadescription will be set to SalDtlsRoleIsClient */
@@ -540,8 +547,22 @@ bool MS2Stream::handleBasicChanges(const OfferAnswerContext &params, CallSession
 			updateCryptoParameters(params);
 			changesToHandle &= ~SAL_MEDIA_DESCRIPTION_CRYPTO_KEYS_CHANGED;
 		}
+		if (params.resultStreamDescriptionChanges & SAL_MEDIA_DESCRIPTION_PTIME_CHANGED && canIgnorePtimeChange(params)){
+			lInfo() << "Ignoring ptime change - does not effect current stream";
+			changesToHandle &= ~SAL_MEDIA_DESCRIPTION_PTIME_CHANGED;
+		}
+		if (params.resultStreamDescriptionChanges & SAL_MEDIA_DESCRIPTION_BANDWIDTH_CHANGED && stream.bandwidth == 0){
+			lInfo() << "Ignoring bandwidth change - does not effect current stream";
+			changesToHandle &= ~SAL_MEDIA_DESCRIPTION_BANDWIDTH_CHANGED;
+		}
 		// SAL_MEDIA_DESCRIPTION_STREAMS_CHANGED monitors the number of streams, it is ignored here.
 		changesToHandle &= ~SAL_MEDIA_DESCRIPTION_STREAMS_CHANGED;
+
+		if (params.resultStreamDescriptionChanges & SAL_MEDIA_DESCRIPTION_MIXER_TO_CLIENT_EXTENSION_CHANGED){
+			stop();
+			changesToHandle &= ~SAL_MEDIA_DESCRIPTION_MIXER_TO_CLIENT_EXTENSION_CHANGED;
+			return false;
+		}
 		
 		if (changesToHandle == 0){
 			// We've handled everything.
@@ -723,9 +744,14 @@ void MS2Stream::initDtlsParams (MediaStream *ms) {
 	}
 }
 
+void MS2Stream::startDtls(){
+	const OfferAnswerContext & ctx = getGroup().getCurrentOfferAnswerContext();
+	ctx.scopeStreamToIndex(getIndex());
+	startDtls(ctx);
+}
+
 void MS2Stream::startDtls(const OfferAnswerContext &params){
 	if (mDtlsStarted) {
-		lWarning() << "DTLS engine on stream session [" << &mSessions << "] is already started";
 		return;
 	}
 	const auto & resultStreamDesc = params.getResultStreamDescription();
@@ -748,6 +774,43 @@ void MS2Stream::startDtls(const OfferAnswerContext &params){
 		ms_dtls_srtp_set_role(mSessions.dtls_context, (resultStreamDesc.getChosenConfiguration().dtls_role == SalDtlsRoleIsClient) ? MSDtlsSrtpRoleIsClient : MSDtlsSrtpRoleIsServer); /* Set the role to client */
 		ms_dtls_srtp_start(mSessions.dtls_context); /* Then start the engine, it will send the DTLS client Hello */
 		mDtlsStarted = true;
+		mInternalStats.number_of_dtls_starts++;
+	}
+}
+
+void MS2Stream::configureRtpTransport(RtpSession *session){
+	if (getCCore()->rtptf) {
+		RtpTransport *meta_rtp;
+		RtpTransport *meta_rtcp;
+		rtp_session_get_transports(session, &meta_rtp, &meta_rtcp);
+		LinphoneCoreRtpTransportFactoryFunc rtpFunc = nullptr, rtcpFunc = nullptr;
+		void *rtpFuncData = nullptr, *rtcpFuncData = nullptr;
+		
+		switch(getType()){
+			case SalAudio:
+				rtpFunc = getCCore()->rtptf->audio_rtp_func;
+				rtpFuncData = getCCore()->rtptf->audio_rtp_func_data;
+				rtcpFunc = getCCore()->rtptf->audio_rtcp_func;
+				rtcpFuncData = getCCore()->rtptf->audio_rtcp_func_data;
+			break;
+			case SalVideo:
+				rtpFunc = getCCore()->rtptf->video_rtp_func;
+				rtpFuncData = getCCore()->rtptf->video_rtp_func_data;
+				rtcpFunc = getCCore()->rtptf->video_rtcp_func;
+				rtcpFuncData = getCCore()->rtptf->video_rtcp_func_data;
+			break;
+			case SalText:
+			break;
+			case SalOther:
+			break;
+		}
+		
+		if (!meta_rtp_transport_get_endpoint(meta_rtp)) {
+			lInfo() << *this << " using custom RTP transport endpoint";
+			meta_rtp_transport_set_endpoint(meta_rtp, rtpFunc(rtpFuncData, mPortConfig.rtpPort));
+		}
+		if (!meta_rtp_transport_get_endpoint(meta_rtcp))
+			meta_rtp_transport_set_endpoint(meta_rtcp, rtcpFunc(rtcpFuncData, mPortConfig.rtcpPort));
 	}
 }
 
@@ -760,13 +823,14 @@ void MS2Stream::initializeSessions(MediaStream *stream){
 	}
 	
 	configureRtpSession(stream->sessions.rtp_session);
-	setupDtlsParams(stream);
 	
+	setupDtlsParams(stream);
 	if (mPortConfig.rtpPort == -1){
 		// Case where we requested random ports from the system. Now that they are allocated, get them.
 		mPortConfig.rtpPort = rtp_session_get_local_port(stream->sessions.rtp_session);
 		mPortConfig.rtcpPort = rtp_session_get_local_rtcp_port(stream->sessions.rtp_session);
 	}
+	configureRtpTransport(stream->sessions.rtp_session);
 	int dscp = -1;
 	switch(getType()){
 		case SalAudio:
@@ -796,7 +860,7 @@ void MS2Stream::setupSrtp(const OfferAnswerContext &params) {
 
 	if (resultStreamDesc.hasSrtp()){
 		// Valid local tags are > 0
-		int cryptoIdx = Sal::findCryptoIndexFromTag(localStreamDesc.getChosenConfiguration().crypto, static_cast<unsigned char>(resultStreamDesc.getChosenConfiguration().crypto_local_tag));
+		int cryptoIdx = Sal::findCryptoIndexFromTag(localStreamDesc.getChosenConfiguration().crypto, resultStreamDesc.getChosenConfiguration().crypto_local_tag);
 		if (cryptoIdx >= 0) {
 			MSCryptoSuite algo = resultStreamDesc.getChosenConfiguration().crypto[0].algo;
 			ms_media_stream_sessions_set_srtp_send_key_b64(&ms->sessions, algo, L_STRING_TO_C(localStreamDesc.getChosenConfiguration().crypto[(size_t)cryptoIdx].master_key));
@@ -859,6 +923,18 @@ void MS2Stream::updateDestinations(const OfferAnswerContext &params) {
 	rtp_session_set_remote_addr_full(mSessions.rtp_session, rtpAddr.c_str(), resultStreamDesc.rtp_port, rtcpAddr.c_str(), resultStreamDesc.rtcp_port);
 }
 
+bool MS2Stream::canIgnorePtimeChange(const OfferAnswerContext &params) {
+	const auto & resultStreamDesc = params.getResultStreamDescription();
+	const PayloadType *pt = getMediaSessionPrivate().getCurrentParams()->getUsedAudioCodec();
+	if (pt != nullptr && pt->send_fmtp != NULL) {
+		char tmp[30];
+		if (fmtp_get_value(pt->send_fmtp,"ptime",tmp,sizeof(tmp))) {
+			return resultStreamDesc.getChosenConfiguration().ptime == atoi(tmp);
+		}
+	}
+	return false;
+}
+
 void MS2Stream::startEventHandling(){
 	if (mTimer) return;
 	mTimer = getCore().createTimer([this](){
@@ -875,39 +951,6 @@ void MS2Stream::stopEventHandling(){
 }
 
 bool MS2Stream::prepare(){
-	if (getCCore()->rtptf) {
-		RtpTransport *meta_rtp;
-		RtpTransport *meta_rtcp;
-		rtp_session_get_transports(mSessions.rtp_session, &meta_rtp, &meta_rtcp);
-		LinphoneCoreRtpTransportFactoryFunc rtpFunc = nullptr, rtcpFunc = nullptr;
-		void *rtpFuncData = nullptr, *rtcpFuncData = nullptr;
-		
-		switch(getType()){
-			case SalAudio:
-				rtpFunc = getCCore()->rtptf->audio_rtp_func;
-				rtpFuncData = getCCore()->rtptf->audio_rtp_func_data;
-				rtcpFunc = getCCore()->rtptf->audio_rtcp_func;
-				rtcpFuncData = getCCore()->rtptf->audio_rtcp_func_data;
-			break;
-			case SalVideo:
-				rtpFunc = getCCore()->rtptf->video_rtp_func;
-				rtpFuncData = getCCore()->rtptf->video_rtp_func_data;
-				rtcpFunc = getCCore()->rtptf->video_rtcp_func;
-				rtcpFuncData = getCCore()->rtptf->video_rtcp_func_data;
-			break;
-			case SalText:
-			break;
-			case SalOther:
-			break;
-		}
-		
-		if (!meta_rtp_transport_get_endpoint(meta_rtp)) {
-			lInfo() << this << " using custom RTP transport endpoint";
-			meta_rtp_transport_set_endpoint(meta_rtp, rtpFunc(rtpFuncData, mPortConfig.rtpPort));
-		}
-		if (!meta_rtp_transport_get_endpoint(meta_rtcp))
-			meta_rtp_transport_set_endpoint(meta_rtcp, rtcpFunc(rtcpFuncData, mPortConfig.rtcpPort));
-	}
 	setIceCheckList(mIceCheckList);
 	startEventHandling();
 	Stream::prepare();
@@ -1153,7 +1196,7 @@ void MS2Stream::dtlsEncryptionChanged(){
 }
 
 void MS2Stream::handleEvents () {
-	MediaStream *ms = getMediaStream(), *newMs = ms;
+	MediaStream *ms = getMediaStream();
 	if (ms) {
 		switch(ms->type){
 			case MSAudio:
@@ -1192,6 +1235,7 @@ void MS2Stream::handleEvents () {
 		}
 		if (ms)
 			linphone_call_stats_fill(mStats, ms, ev);
+		bool isIceEvent = false;
 		switch(evt){
 			case ORTP_EVENT_ZRTP_ENCRYPTION_CHANGED:
 				if (getType() != SalAudio || !isMain()){
@@ -1201,24 +1245,48 @@ void MS2Stream::handleEvents () {
 			case ORTP_EVENT_DTLS_ENCRYPTION_CHANGED:
 				dtlsEncryptionChanged();
 			break;
+			case ORTP_EVENT_ICE_CHECK_LIST_DEFAULT_CANDIDATE_VERIFIED:
+				mInternalStats.number_of_ice_check_list_relay_pair_verified++;
+				isIceEvent = true;
+				/* DTLS can start immediately since media path should be established */
+				startDtls();
+			break;
+			case ORTP_EVENT_ICE_CHECK_LIST_PROCESSING_FINISHED:
+				/*same*/
+				mInternalStats.number_of_ice_check_list_processing_finished++;
+				startDtls();
+				isIceEvent = true;
+			break;
 			case ORTP_EVENT_ICE_SESSION_PROCESSING_FINISHED:
 			case ORTP_EVENT_ICE_GATHERING_FINISHED:
 			case ORTP_EVENT_ICE_LOSING_PAIRS_COMPLETED:
 			case ORTP_EVENT_ICE_RESTART_NEEDED:
-				/* ICE events are notified directly to the IceService. */
-				getIceService().handleIceEvent(ev);
-				newMs = getMediaStream();// Ice can change the stream and free the old one. Ensure to have an existing stream.
+				isIceEvent = true;
 			break;
 		}
+		if (isIceEvent){
+			/* ICE events are deferred to the IceService asynchronously because some ICE events can indirectly
+			 restart the ms2 stream.
+			 However, due to asynchronism, the MediaSession may have release the Streams or be released itself.
+			 We protect against this by taking a shared_ptr on the mediaSession and taking the IceService directly
+			 from the MediaSession, without using 'this'.
+			 */
+			weak_ptr<MediaSession> mediaSession = static_pointer_cast<MediaSession>(getMediaSession().getSharedFromThis());
+			getCore().doLater([mediaSession, ev](){
+				auto sp = mediaSession.lock();
+				/* make sure the MediaSession (and thus the IceService) is still there by verifying the weak_ptr of the media session. */
+				if (sp){
+					sp->getStreamsGroup().getIceService().handleIceEvent(ev);
+				}// Otherwise we can safely ignore the event.
+				ortp_event_destroy(ev);
+			});
+			continue; // Go to next event.
+		}
 		notifyStatsUpdated();
 	
 		/* Let subclass handle the event.*/
 		handleEvent(ev);
 		ortp_event_destroy(ev);
-		if( newMs != ms){// Stream have been changed. Rehandle events with this one
-			handleEvents();
-			return;
-		}
 	}
 }
 
@@ -1384,7 +1452,6 @@ MS2Stream::~MS2Stream(){
 	finish();
 	linphone_call_stats_unref(mStats);
 	mStats = nullptr;
-	
 }
 
 LINPHONE_END_NAMESPACE
