@@ -301,7 +301,6 @@ void ToneManager::scheduleRingStreamDestruction(){
 		}
 		/* otherwise the ring stream is no longer needed, destroy it. */
 		lInfo() << "RingStream no longer needed.";
-		mStats.number_of_stopTone++;
 		destroyRingStream();
 		return false;
 	} , 1000, "Tone player cleanup");
@@ -314,9 +313,11 @@ void ToneManager::destroyRingStream(){
 		ring_stop(mRingStream);
 		mRingStream = nullptr;
 	}
+	
 	if (mRingStreamTimer){
 		getCore().destroyTimer(mRingStreamTimer);
 		mRingStreamTimer = nullptr;
+		mStats.number_of_stopTone++;
 	}
 }
 
@@ -380,7 +381,7 @@ void ToneManager::freeAudioResources(){
 		linphone_ringtoneplayer_stop(lc->ringtoneplayer);
 	}
 	destroyRingStream();
-	
+	getPlatformHelpers(lc)->stopRinging();
 }
 
 
@@ -529,6 +530,10 @@ void ToneManager::notifyIncomingCall(const std::shared_ptr<CallSession> &session
 			lInfo() << "Callkit mode is enabled, will not play ring tone from liblinphone.";
 			return;
 		}
+		/*
+		 For ios, only one write sound card is allowed. To ensure this, free audio resources before a new incoming call.
+		 */
+		freeAudioResources();
 		startRingtone();
 		/* Setup the way this incoming call notification has to be stopped */
 		mSessionRingingStopFunction = [this](){
@@ -577,6 +582,7 @@ shared_ptr<CallSession> ToneManager::lookupRingingSession() const{
 void ToneManager::cleanPauseTone(){
 	if (mSessionPaused){
 		stopTone();
+		destroyRingStream(); // the "pause" tone is exclusively played by the RingStream API.
 		mSessionPaused = nullptr;
 	}
 }
@@ -659,6 +665,9 @@ void ToneManager::notifyState(const std::shared_ptr<CallSession> &callSession, C
 			cleanPauseTone();
 			notifyIncomingCall(session);
 		break;
+		case CallSession::State::OutgoingProgress:
+			cleanPauseTone();
+		break;
 		case CallSession::State::OutgoingRinging:
 			cleanPauseTone();
 			notifyOutgoingCallRinging(session);
@@ -679,7 +688,14 @@ void ToneManager::notifyState(const std::shared_ptr<CallSession> &callSession, C
 		break;
 		case CallSession::State::End:
 		case CallSession::State::Error:
-			notifyToneIndication(session->getReason());
+		{
+			LinphoneReason reason = session->getReason();
+			CallSession::State pState = session->getPreviousState();
+			// Do not play tone for incoming calls when declining them with Busy or DoNotDisturb reason or incoming calls not connected
+			if (session->getDirection() == LinphoneCallOutgoing || (pState != CallSession::State::IncomingReceived && pState != CallSession::State::IncomingEarlyMedia && pState != CallSession::State::PushIncomingReceived && reason != LinphoneReasonBusy && reason != LinphoneReasonDoNotDisturb)) {
+				notifyToneIndication(reason);
+			}
+		}
 		break;
 		default:
 		break;
