@@ -163,12 +163,15 @@ shared_ptr<AbstractChatRoom> CorePrivate::createClientGroupChatRoom (
 	const string &subject,
 	const ConferenceId &conferenceId,
 	const Content &content,
-	bool encrypted
+	bool encrypted,
+	AbstractChatRoom::EphemeralMode ephemerableMode,
+	long ephemeralLifeTime
 ) {
 #ifdef HAVE_ADVANCED_IM
 	L_Q();
 
-	shared_ptr<ChatRoomParams> params = ChatRoomParams::create(subject, encrypted, true, ChatRoomParams::ChatRoomBackend::FlexisipChat);
+	shared_ptr<ChatRoomParams> params = ChatRoomParams::create(subject, encrypted, true, ephemerableMode, ChatRoomParams::ChatRoomBackend::FlexisipChat);
+	params->setEphemeralLifetime(ephemeralLifeTime);
 	shared_ptr<ClientGroupChatRoom> clientGroupChatRoom(new ClientGroupChatRoom(
 										    q->getSharedFromThis(),
 										    conferenceId.getPeerAddress(),
@@ -239,6 +242,9 @@ shared_ptr<AbstractChatRoom> CorePrivate::searchChatRoom (const shared_ptr<ChatR
 		ChatRoom::CapabilitiesMask capabilities = chatRoom->getCapabilities();
 
 		if (params) {
+			if (params->getChatRoomBackend() != chatRoom->getCurrentParams()->getChatRoomBackend())
+				continue;
+
 			if (!params->isGroup() && !(capabilities & ChatRoom::Capabilities::OneToOne))
 				continue;
 
@@ -479,11 +485,12 @@ void CorePrivate::handleEphemeralMessages (time_t currentTime) {
 }
 
 void CorePrivate::initEphemeralMessages () {
+	L_Q();
 	if (mainDb && mainDb->isInitialized()) {
 		ephemeralMessages.clear();
 		ephemeralMessages = mainDb->getEphemeralMessages();
 		if (!ephemeralMessages.empty()) {
-			lInfo() << "[Ephemeral] list initiated";
+			lInfo() << "[Ephemeral] list initiated on core " << linphone_core_get_identity(q->getCCore());
 			shared_ptr<ChatMessage> msg = ephemeralMessages.front();
 			startEphemeralMessageTimer(msg->getEphemeralExpireTime());
 		}
@@ -557,7 +564,8 @@ shared_ptr<AbstractChatRoom> CorePrivate::findExhumableOneToOneChatRoom (
 				&& */capabilities & ChatRoom::Capabilities::Conference
 				&& capabilities & ChatRoom::Capabilities::OneToOne
 				&& encrypted == bool(capabilities & ChatRoom::Capabilities::Encrypted)) {
-			if (localAddress.getAddressWithoutGruu() == curLocalAddress.getAddressWithoutGruu()
+			if (chatRoom->getParticipants().size() > 0 
+					&& localAddress.getAddressWithoutGruu() == curLocalAddress.getAddressWithoutGruu()
 					&& participantAddress.getAddressWithoutGruu() == chatRoom->getParticipants().front()->getAddress().getAddressWithoutGruu()) {
 				return chatRoom;
 			}
@@ -779,7 +787,7 @@ shared_ptr<AbstractChatRoom> Core::getOrCreateBasicChatRoom (const IdentityAddre
 		capabilities |= ChatRoom::Capabilities::Migratable;
 	}
 	chatRoom = d->createBasicChatRoom(
-	       ConferenceId(peerAddress, localAddress),
+	       ConferenceId(peerAddress, (localAddress.isValid()?localAddress : d->getDefaultLocalAddress(&peerAddress, false) )),
 	       capabilities,
 	       ChatRoomParams::fromCapabilities(capabilities)
 	);
@@ -819,4 +827,16 @@ void Core::deleteChatRoom (const shared_ptr<const AbstractChatRoom> &chatRoom) {
 	}
 }
 
+const std::string Core::groupChatVersionAsString() {
+	std::ostringstream os;
+	os << CorePrivate::groupChatProtocolVersion;
+	return os.str();
+}
+
+const std::string Core::ephemeralVersionAsString() {
+	std::ostringstream os;
+	os << CorePrivate::ephemeralProtocolVersion;
+	return os.str();
+}
+
 LINPHONE_END_NAMESPACE
