@@ -49,6 +49,7 @@
 #include "core/core-listener.h"
 #include "core/core-p.h"
 #include "chat/chat-room/chat-room-p.h"
+#include "../ldap/ldap.h"
 #include "logger/logger.h"
 #include "paths/paths.h"
 #include "linphone/utils/utils.h"
@@ -77,12 +78,13 @@ using namespace std;
 LINPHONE_BEGIN_NAMESPACE
 
 const Utils::Version CorePrivate::groupChatProtocolVersion(1, 1);
+const Utils::Version CorePrivate::ephemeralProtocolVersion(1, 1);
 
 void CorePrivate::init () {
 	L_Q();
 
 	mainDb.reset(new MainDb(q->getSharedFromThis()));
-	toneManager = makeUnique<ToneManager>(*getPublic());
+	getToneManager(); // Forces instanciation of the ToneManager.
 #ifdef HAVE_ADVANCED_IM
 	remoteListEventHandler = makeUnique<RemoteConferenceListEventHandler>(q->getSharedFromThis());
 	localListEventHandler = makeUnique<LocalConferenceListEventHandler>(q->getSharedFromThis());
@@ -215,7 +217,7 @@ bool CorePrivate::isShutdownDone() {
 
 	for (auto it = chatRoomsById.begin(); it != chatRoomsById.end(); it++) {
 		const auto &chatRoom = dynamic_pointer_cast<ChatRoom>(it->second);
-		if (chatRoom && (chatRoom->getPrivate()->getImdnHandler()->hasUndeliveredImdnMessage() 
+		if (chatRoom && (chatRoom->getPrivate()->getImdnHandler()->isCurrentlySendingImdnMessages() 
 			|| !chatRoom->getPrivate()->getTransientChatMessages().empty())) {
 			return false;
 		}
@@ -312,6 +314,7 @@ void CorePrivate::uninit() {
 	noCreatedClientGroupChatRooms.clear();
 	listeners.clear();
 	pushReceivedBackgroundTaskEnded();
+	mLdapServers.clear();
 
 #ifdef HAVE_ADVANCED_IM
 	remoteListEventHandler.reset();
@@ -319,10 +322,14 @@ void CorePrivate::uninit() {
 #endif
 
 	Address::clearSipAddressesCache();
+
+	/* The toneManager is kept until destructor, we may need it because of calls ended during linphone_core_destroy(). */
+}
+
+void CorePrivate::disconnectMainDb () {
 	if (mainDb != nullptr) {
 		mainDb->disconnect();
 	}
-	/* The toneManager is kept until destructor, we may need it because of calls ended during linphone_core_destroy(). */
 }
 
 // -----------------------------------------------------------------------------
@@ -418,7 +425,7 @@ LinphoneCore *CorePrivate::getCCore() const {
 }
 
 void CorePrivate::doLater(const std::function<void ()> &something){
-	belle_sip_main_loop_cpp_do_later(getMainLoop(), something);
+	return belle_sip_main_loop_cpp_do_later(getMainLoop(), something);
 }
 
 void CorePrivate::enableFriendListsSubscription(bool enable) {
@@ -441,6 +448,7 @@ CorePrivate::CorePrivate() : authStack(*this), pushReceivedBackgroundTaskId(0) {
 }
 
 ToneManager & CorePrivate::getToneManager() {
+	if (!toneManager) toneManager = makeUnique<ToneManager>(*getPublic());
 	return *toneManager.get();
 }
 
@@ -965,12 +973,14 @@ void Core::setOutputAudioDeviceBySndCard(MSSndCard *card){
 	if (card) {
 		AudioDevice * audioDevice = findAudioDeviceMatchingMsSoundCard(card);
 		if (audioDevice) {
+			lInfo() << "[ " << __func__ << " ] on device: " << audioDevice->getDeviceName();
 			d->setOutputAudioDevice(audioDevice);
 			return;
 		}
 	}
 	AudioDevice * defaultAudioDevice = getDefaultOutputAudioDevice();
 	if (defaultAudioDevice) {
+		lInfo() << "[ " << __func__ << " ] on default device: " << defaultAudioDevice->getDeviceName();
 		d->setOutputAudioDevice(defaultAudioDevice);
 		return;
 	}
@@ -979,11 +989,14 @@ void Core::setOutputAudioDeviceBySndCard(MSSndCard *card){
 	if (defaultCard) {
 		AudioDevice * audioDevice = findAudioDeviceMatchingMsSoundCard(defaultCard);
 		if (audioDevice) {
+			lInfo() << "[ " << __func__ << " ] on device matching playback capture card: " << audioDevice->getDeviceName();
 			d->setOutputAudioDevice(audioDevice);
 			return;
 		}
-	} else // No cards available : remove the device. This will allow to restart it if a new one is detected.
+	} else { // No cards available : remove the device. This will allow to restart it if a new one is detected.
+		lInfo() << "[ " << __func__ << " ] remove output device";
 		d->setOutputAudioDevice(nullptr);
+	}
 	if(card)// Having no device when a card is requested is an error
 		lError() << "[ " << __func__ << " ] Unable to find suitable output audio device";
 }
@@ -994,12 +1007,14 @@ void Core::setInputAudioDeviceBySndCard(MSSndCard *card){
 	if (card) {
 		AudioDevice * audioDevice = findAudioDeviceMatchingMsSoundCard(card);
 		if (audioDevice) {
+			lInfo() << "[ " << __func__ << " ] on device: " << audioDevice->getDeviceName();
 			d->setInputAudioDevice(audioDevice);
 			return;
 		}
 	}
 	AudioDevice * defaultAudioDevice = getDefaultInputAudioDevice();
 	if (defaultAudioDevice) {
+		lInfo() << "[ " << __func__ << " ] on default device: " << defaultAudioDevice->getDeviceName();
 		d->setInputAudioDevice(defaultAudioDevice);
 		return;
 	}
@@ -1008,11 +1023,14 @@ void Core::setInputAudioDeviceBySndCard(MSSndCard *card){
 	if (defaultCard) {
 		AudioDevice * audioDevice = findAudioDeviceMatchingMsSoundCard(defaultCard);
 		if (audioDevice) {
+			lInfo() << "[ " << __func__ << " ] on device matching default capture card: " << audioDevice->getDeviceName();
 			d->setInputAudioDevice(audioDevice);
 			return;
 		}
-	}else// No cards available : remove the device. This will allow to restart it if a new one is detected.
+	}else {// No cards available : remove the device. This will allow to restart it if a new one is detected.
+		lInfo() << "[ " << __func__ << " ] remove input device";
 		d->setInputAudioDevice(nullptr);
+	}
 	if (card) // Having no device when a card is requested is an error
 		lError() << "[ " << __func__ << " ] Unable to find suitable input audio device";
 }
@@ -1226,6 +1244,61 @@ std::shared_ptr<ChatMessage> Core::findChatMessageFromCallId (const std::string
 	return chatMessages.empty() ? nullptr : chatMessages.front();
 }
 
+// -----------------------------------------------------------------------------
+// Ldap.
+// -----------------------------------------------------------------------------
+
+std::list<std::shared_ptr<Ldap>> Core::getLdapList() {
+	return getPrivate()->mLdapServers;
+}
+
+std::list<std::shared_ptr<Ldap>>::iterator Core::getLdapIterator(int index){
+	return std::find_if( getPrivate()->mLdapServers.begin(), getPrivate()->mLdapServers.end(), [index](std::shared_ptr<Ldap> a){
+		return a->getIndex() == index;
+	});
+}
+
+void CorePrivate::reloadLdapList() {
+	std::list<std::shared_ptr<Ldap>> ldapList;
+	auto lpConfig = linphone_core_get_config(getCCore());
+	bctbx_list_t * bcSections = linphone_config_get_sections_names_list(lpConfig);
+	// Loop on all sections and load configuration. If this is not a LDAP configuration, the model is discarded.
+	for(auto itSections = bcSections; itSections; itSections=itSections->next) {
+		std::string section = static_cast<char *>(itSections->data);
+		std::shared_ptr<Ldap> ldap = Ldap::create(getPublic()->getSharedFromThis(), section);
+		if( ldap)
+			ldapList.push_back(ldap);
+	}
+	if( bcSections)
+		bctbx_list_free(bcSections);
+	ldapList.sort([](std::shared_ptr<Ldap> a, std::shared_ptr<Ldap> b) {
+		return a->getIndex() < b->getIndex();
+	});
+	mLdapServers = ldapList;
+}
+
+void Core::addLdap(std::shared_ptr<Ldap> ldap) {
+	if(ldap->getLdapParams()) {
+		ldap->writeToConfigFile();
+		auto itLdapStored = getLdapIterator(ldap->getIndex());
+		if(itLdapStored == getPrivate()->mLdapServers.end()) {	// New
+			getPrivate()->mLdapServers.push_back(ldap);
+			getPrivate()->mLdapServers.sort([](std::shared_ptr<Ldap> a, std::shared_ptr<Ldap> b) {
+				return a->getIndex() < b->getIndex();
+			});
+		}else{	// Update
+			*itLdapStored = ldap;
+		}
+	}
+}
+
+void Core::removeLdap(std::shared_ptr<Ldap> ldap){
+	auto itLdapStored = getLdapIterator(ldap->getIndex());
+	if(itLdapStored != getPrivate()->mLdapServers.end()){
+		getPrivate()->mLdapServers.erase(itLdapStored);
+		ldap->removeFromConfigFile();
+	}
+}
 // -----------------------------------------------------------------------------
 
 Address Core::interpretUrl (const std::string &url) const {
