@@ -73,10 +73,18 @@ public:
 
 	void enableAutoIterate (bool autoIterateEnabled) override;
 
+	void onRecordingStarted () const override;
+	void onRecordingPaused () const override;
+	void stopRinging () const override;
+
+	void setDeviceRotation (int orientation) const override;
+
 	void _setPreviewVideoWindow(jobject window);
 	void _setVideoWindow(jobject window);
 	string getDownloadPath() override;
 
+	void disableAudioRouteChanges(bool disable);
+
 private:
 	int callVoidMethod (jmethodID id);
 	static jmethodID getMethodId (JNIEnv *env, jclass klass, const char *method, const char *signature);
@@ -108,6 +116,8 @@ private:
 	jmethodID mOnWifiOnlyEnabledId = nullptr;
 	jmethodID mIsActiveNetworkWifiOnlyCompliantId = nullptr;
 	jmethodID mUpdateNetworkReachabilityId = nullptr;
+	jmethodID mRotateVideoPreviewId = nullptr;
+	jmethodID mDisableAudioRouteChangesId = nullptr;
 
 	// CoreManager methods
 	jmethodID mCoreManagerDestroyId = nullptr;
@@ -117,6 +127,9 @@ private:
 	jmethodID mStopAudioForEchoTestOrCalibrationId = nullptr;
 	jmethodID mStartAutoIterateId = nullptr;
 	jmethodID mStopAutoIterateId = nullptr;
+	jmethodID mSetAudioManagerCommunicationMode = nullptr;
+	jmethodID mSetAudioManagerNormalMode = nullptr;
+	jmethodID mStopRingingId = nullptr;
 
 	bool mNetworkReachable = false;
 };
@@ -167,6 +180,9 @@ void AndroidPlatformHelpers::createCoreManager (std::shared_ptr<LinphonePrivate:
 	mStopAudioForEchoTestOrCalibrationId = getMethodId(env, klass, "stopAudioForEchoTestOrCalibration", "()V");
 	mStartAutoIterateId = getMethodId(env, klass, "startAutoIterate", "()V");
 	mStopAutoIterateId = getMethodId(env, klass, "stopAutoIterate", "()V");
+	mSetAudioManagerCommunicationMode = getMethodId(env, klass, "setAudioManagerInCommunicationMode", "()V");
+	mSetAudioManagerNormalMode = getMethodId(env, klass, "setAudioManagerInNormalMode", "()V");
+	mStopRingingId = getMethodId(env, klass, "stopRinging", "()V");
 
 	lInfo() << "[Android Platform Helper] CoreManager is fully initialised.";
 }
@@ -217,6 +233,8 @@ AndroidPlatformHelpers::AndroidPlatformHelpers (std::shared_ptr<LinphonePrivate:
 	mOnWifiOnlyEnabledId = getMethodId(env, klass, "onWifiOnlyEnabled", "(Z)V");
 	mIsActiveNetworkWifiOnlyCompliantId = getMethodId(env, klass, "isActiveNetworkWifiOnlyCompliant", "()Z");
 	mUpdateNetworkReachabilityId = getMethodId(env, klass, "updateNetworkReachability", "()V");
+	mRotateVideoPreviewId = getMethodId(env, klass, "rotateVideoPreview", "()V");
+	mDisableAudioRouteChangesId = getMethodId(env, klass, "disableAudioRouteChanges", "(Z)V");
 
 	jobject pm = env->CallObjectMethod(mJavaHelper, mGetPowerManagerId);
 	belle_sip_wake_lock_init(env, pm);
@@ -228,6 +246,11 @@ AndroidPlatformHelpers::AndroidPlatformHelpers (std::shared_ptr<LinphonePrivate:
 	mPreviewVideoWindow = nullptr;
 	mVideoWindow = nullptr;
 	mNetworkReachable = false;
+
+	LinphoneConfig *config = linphone_core_get_config(getCore()->getCCore());
+	if (linphone_config_get_bool(config, "sound", "android_disable_audio_route_changes", FALSE) == TRUE) {
+		disableAudioRouteChanges(true);
+	}
 }
 
 AndroidPlatformHelpers::~AndroidPlatformHelpers () {
@@ -487,6 +510,33 @@ void AndroidPlatformHelpers::enableAutoIterate(bool autoIterateEnabled) {
 	}
 }
 
+void AndroidPlatformHelpers::onRecordingStarted() const {
+	
+}
+
+void AndroidPlatformHelpers::onRecordingPaused() const {
+	
+}
+
+void AndroidPlatformHelpers::stopRinging () const {
+	LinphoneCore *lc = getCore()->getCCore();
+	if (linphone_core_is_native_ringing_enabled(lc) == TRUE) {
+		JNIEnv *env = ms_get_jni_env();
+		if (env) {
+			if (mJavaCoreManager) {
+				env->CallVoidMethod(mJavaCoreManager, mStopRingingId);
+			}
+		}
+	}
+}
+
+void AndroidPlatformHelpers::setDeviceRotation (int orientation) const {
+	JNIEnv *env = ms_get_jni_env();
+	if (env && mJavaHelper) {
+		env->CallVoidMethod(mJavaHelper, mRotateVideoPreviewId);
+	}
+}
+
 // -----------------------------------------------------------------------------
 
 void AndroidPlatformHelpers::_setPreviewVideoWindow(jobject window) {
@@ -519,6 +569,13 @@ void AndroidPlatformHelpers::_setVideoWindow(jobject window) {
 	_linphone_core_set_native_video_window_id(lc, (void *)mVideoWindow);
 }
 
+void AndroidPlatformHelpers::disableAudioRouteChanges(bool disable) {
+	JNIEnv *env = ms_get_jni_env();
+	if (env && mJavaHelper) {
+		env->CallVoidMethod(mJavaHelper, mDisableAudioRouteChangesId, disable);
+	}
+}
+
 // -----------------------------------------------------------------------------
 
 int AndroidPlatformHelpers::callVoidMethod (jmethodID id) {
