@@ -35,7 +35,7 @@
 #include "c-wrapper/c-wrapper.h"
 
 #include "logger/logger.h"
-#include "platform-helpers.h"
+#include "mac-platform-helpers.h"
 
 // TODO: Remove me
 #include "private.h"
@@ -49,26 +49,16 @@ using namespace std;
 
 LINPHONE_BEGIN_NAMESPACE
 
-class IosPlatformHelpers : public GenericPlatformHelpers {
+class IosPlatformHelpers : public MacPlatformHelpers {
 public:
 	IosPlatformHelpers (std::shared_ptr<LinphonePrivate::Core> core, void *systemContext);
 	~IosPlatformHelpers () {
 		[mAppDelegate dealloc];
 	}
 
-	void acquireWifiLock () override {}
-	void releaseWifiLock () override {}
-	void acquireMcastLock () override {}
-	void releaseMcastLock () override {}
 	void acquireCpuLock () override;
 	void releaseCpuLock () override;
 
-	string getConfigPath () const override { return ""; }
-	string getDataPath () const override { return ""; }
-	string getDataResource (const string &filename) const override;
-	string getImageResource (const string &filename) const override;
-	string getRingResource (const string &filename) const override;
-	string getSoundResource (const string &filename) const override;
 	void * getPathContext () override;
 
 	NetworkType getNetworkType()const override;
@@ -83,7 +73,6 @@ public:
 	void onWifiOnlyEnabled (bool enabled) override;
 	bool isActiveNetworkWifiOnlyCompliant () const override;
 	void setDnsServers () override;
-	void setHttpProxy (const string &host, int port) override;
 	bool startNetworkMonitoring() override;
 	void stopNetworkMonitoring() override;
 
@@ -105,22 +94,22 @@ public:
 	void didRegisterForRemotePushWithStringifiedToken(const char *token) override;
 	void enableAutoIterate (bool autoIterateEnabled) override;
 
-private:
-	string toUTF8String(CFStringRef str);
-	void kickOffConnectivity();
-	void getHttpProxySettings(void);
+	void onRecordingStarted () const override;
+	void onRecordingPaused () const override;
+	void stopRinging () const override;
 
+	void setDeviceRotation (int orientation) const override;
+
+private:
+	void kickOffConnectivity();
 	void bgTaskTimeout ();
 	static void sBgTaskTimeout (void *data);
-	static string getResourceDirPath (const string &framework, const string &resource);
-	static string getResourcePath (const string &framework, const string &resource);
     
 	long int mCpuLockTaskId;
 	int mCpuLockCount;
 	SCNetworkReachabilityRef reachabilityRef = NULL;
 	SCNetworkReachabilityFlags mCurrentFlags = 0;
 	bool mNetworkMonitoringEnabled = false;
-	static const string Framework;
 
 	IosAppDelegate *mAppDelegate = NULL; /* auto didEnterBackground/didEnterForeground and other callbacks */
 	bool mStart = false; /* generic platformhelper's funcs only work when mStart is true */
@@ -132,9 +121,8 @@ static void sNetworkChangeCallback(CFNotificationCenterRef center, void *observe
 
 // =============================================================================
 
-const string IosPlatformHelpers::Framework = "org.linphone.linphone";
 
-IosPlatformHelpers::IosPlatformHelpers (std::shared_ptr<LinphonePrivate::Core> core, void *systemContext) : GenericPlatformHelpers(core) {
+IosPlatformHelpers::IosPlatformHelpers (std::shared_ptr<LinphonePrivate::Core> core, void *systemContext) : MacPlatformHelpers(core) {
 	mUseAppDelgate = core->getCCore()->is_main_core;
 	if (mUseAppDelgate) {
 		mAppDelegate = [[IosAppDelegate alloc] initWithCore:core];
@@ -147,34 +135,7 @@ void IosPlatformHelpers::start (std::shared_ptr<LinphonePrivate::Core> core) {
 	mCpuLockTaskId = 0;
 	mNetworkReachable = 0; // wait until monitor to give a status;
 	mSharedCoreHelpers = createIosSharedCoreHelpers(core);
-	
-
-	string cpimPath = getResourceDirPath(Framework, "cpim_grammar");
-	if (!cpimPath.empty())
-		belr::GrammarLoader::get().addPath(cpimPath);
-	else
-		ms_error("IosPlatformHelpers did not find cpim grammar resource directory...");
-
-	string identityPath = getResourceDirPath(Framework, "identity_grammar");
-	if (!identityPath.empty())
-		belr::GrammarLoader::get().addPath(identityPath);
-	else
-		ms_error("IosPlatformHelpers did not find identity grammar resource directory...");
-
-#ifdef VCARD_ENABLED
-	string vcardPath = getResourceDirPath("org.linphone.belcard", "vcard_grammar");
-	if (!vcardPath.empty())
-		belr::GrammarLoader::get().addPath(vcardPath);
-	else
-		ms_message("IosPlatformHelpers did not find vcard grammar resource directory...");
-#endif
-
-	string sdpPath = getResourceDirPath("org.linphone.belle-sip", "sdp_grammar");
-	if (!sdpPath.empty())
-		belr::GrammarLoader::get().addPath(sdpPath);
-	else
-		ms_error("IosPlatformHelpers did not find sdp grammar resource directory...");
-	
+		
 	ms_message("IosPlatformHelpers is fully started");
 	mStart = true;
 	[mAppDelegate onStopAsyncEnd:false];
@@ -214,23 +175,20 @@ void IosPlatformHelpers::enableAutoIterate(bool autoIterateEnabled) {
 	}
 }
 
-//Safely get an UTF-8 string from the given CFStringRef
-string IosPlatformHelpers::toUTF8String(CFStringRef str) {
-	string ret;
+void IosPlatformHelpers::onRecordingStarted() const {
+
+}
+
+void IosPlatformHelpers::onRecordingPaused() const {
+
+}
+
+void IosPlatformHelpers::stopRinging () const {
+	
+}
+
+void IosPlatformHelpers::setDeviceRotation (int orientation) const {
 
-	if (str == NULL) {
-		return ret;
-	}
-	CFIndex length = CFStringGetLength(str);
-	CFIndex maxSize = CFStringGetMaximumSizeForEncoding(length, kCFStringEncodingUTF8) + 1;
-	char *buffer = (char *) malloc((size_t) maxSize);
-	if (buffer) {
-		if (CFStringGetCString(str, buffer, maxSize, kCFStringEncodingUTF8)) {
-			ret = buffer;
-		}
-		free(buffer);
-	}
-	return ret;
 }
 
 // -----------------------------------------------------------------------------
@@ -276,51 +234,6 @@ void IosPlatformHelpers::releaseCpuLock () {
 	mCpuLockTaskId = 0;
 }
 
-// -----------------------------------------------------------------------------
-
-string IosPlatformHelpers::getDataResource (const string &filename) const {
-	return getResourcePath(Framework, filename);
-}
-
-string IosPlatformHelpers::getImageResource (const string &filename) const {
-	return getResourcePath(Framework, filename);
-}
-
-string IosPlatformHelpers::getRingResource (const string &filename) const {
-	return getResourcePath(Framework, filename);
-}
-
-string IosPlatformHelpers::getSoundResource (const string &filename) const {
-	return getResourcePath(Framework, filename);
-}
-
-// -----------------------------------------------------------------------------
-
-string IosPlatformHelpers::getResourceDirPath (const string &framework, const string &resource) {
-	CFStringEncoding encodingMethod = CFStringGetSystemEncoding();
-	CFStringRef cfFramework = CFStringCreateWithCString(nullptr, framework.c_str(), encodingMethod);
-	CFStringRef cfResource = CFStringCreateWithCString(nullptr, resource.c_str(), encodingMethod);
-	CFBundleRef bundle = CFBundleGetBundleWithIdentifier(cfFramework);
-	CFURLRef resourceUrl = CFBundleCopyResourceURL(bundle, cfResource, nullptr, nullptr);
-	string path("");
-	if (resourceUrl) {
-		CFURLRef resourceUrlDirectory = CFURLCreateCopyDeletingLastPathComponent(nullptr, resourceUrl);
-		CFStringRef resourcePath = CFURLCopyFileSystemPath(resourceUrlDirectory, kCFURLPOSIXPathStyle);
-		path = CFStringGetCStringPtr(resourcePath, encodingMethod);
-		CFRelease(resourcePath);
-		CFRelease(resourceUrlDirectory);
-		CFRelease(resourceUrl);
-	}
-
-	CFRelease(cfResource);
-	CFRelease(cfFramework);
-	return path;
-}
-
-string IosPlatformHelpers::getResourcePath (const string &framework, const string &resource) {
-	return getResourceDirPath(framework, resource) + "/" + resource;
-}
-
 void *IosPlatformHelpers::getPathContext () {
 	return getSharedCoreHelpers()->getPathContext();
 }
@@ -382,53 +295,6 @@ void IosPlatformHelpers::setDnsServers () {
 	//Nothing to do here, already handled by core for IOS platforms
 }
 
-//Set proxy settings on core
-void IosPlatformHelpers::setHttpProxy (const string &host, int port) {
-	if (!mStart) return;
-
-	linphone_core_set_http_proxy_host(getCore()->getCCore(), host.c_str());
-	linphone_core_set_http_proxy_port(getCore()->getCCore(), port);
-}
-
-//Get global proxy settings from system and set variables mHttpProxy{Host,Port,Enabled}.
-void IosPlatformHelpers::getHttpProxySettings(void) {
-	CFDictionaryRef proxySettings = CFNetworkCopySystemProxySettings();
-
-	if (proxySettings) {
-		CFNumberRef enabled = (CFNumberRef) CFDictionaryGetValue(proxySettings, kCFNetworkProxiesHTTPEnable);
-		if (enabled != NULL) {
-			int val = 0;
-			CFNumberGetValue(enabled, kCFNumberIntType, &val);
-			mHttpProxyEnabled = !!val;
-		}
-		if (mHttpProxyEnabled) {
-			CFStringRef proxyHost = (CFStringRef) CFDictionaryGetValue(proxySettings, kCFNetworkProxiesHTTPProxy);
-			if (proxyHost != NULL) {
-				mHttpProxyHost = toUTF8String(proxyHost);
-				if (mHttpProxyHost.empty()) {
-					mHttpProxyEnabled = false;
-				}
-			} else {
-				mHttpProxyEnabled = false;
-			}
-		}
-		if (mHttpProxyEnabled) {
-			CFNumberRef proxyPort = (CFNumberRef) CFDictionaryGetValue(proxySettings, kCFNetworkProxiesHTTPPort);
-			if (proxyPort != NULL) {
-				if (!CFNumberGetValue(proxyPort, kCFNumberIntType, &mHttpProxyPort)) {
-					mHttpProxyEnabled = false;
-				}
-			} else {
-				mHttpProxyEnabled = false;
-			}
-		}
-		CFRelease(proxySettings);
-	}
-	if (!mHttpProxyEnabled) {
-		mHttpProxyPort = 0;
-		mHttpProxyHost.clear();
-	}
-}
 
 static void showNetworkFlags(SCNetworkReachabilityFlags flags) {
 	ms_message("Network connection flags:");
@@ -551,7 +417,11 @@ void IosPlatformHelpers::networkChangeCallback() {
         }
 #endif
 	}
-	getHttpProxySettings();
+	if (!!linphone_core_automatic_http_proxy_detection_enabled(getCore()->getCCore())) {
+		ms_message("Do not try to get HTTP proxy as automatic proxy detection is enabled");
+	} else {
+		getHttpProxySettings();
+	}
 	if (mHttpProxyEnabled) {
 		ms_message("Update HTTP proxy settings: using [%s:%d]", mHttpProxyHost.c_str(), mHttpProxyPort);
 	} else {
@@ -559,10 +429,10 @@ void IosPlatformHelpers::networkChangeCallback() {
 	}
 	const char *currentProxyHostCstr = linphone_core_get_http_proxy_host(getCore()->getCCore());
 	string currentProxyHost;
-	int currentProxyPort = linphone_core_get_http_proxy_port(getCore()->getCCore());
 	if (currentProxyHostCstr) {
 		currentProxyHost = currentProxyHostCstr;
 	}
+	int currentProxyPort = linphone_core_get_http_proxy_port(getCore()->getCCore());
 	if (mHttpProxyEnabled == currentProxyHost.empty() || currentProxyPort != mHttpProxyPort || currentProxyHost.compare(mHttpProxyHost)) {
 		//Empty host is considered as no proxy
 		changed = true;
