@@ -49,14 +49,6 @@ using namespace std;
 
 LINPHONE_BEGIN_NAMESPACE
 
-typedef enum {
-	noCoreStarted,
-	mainCoreStarted,
-	executorCoreStarted,
-	executorCoreStopping, // A Main Core needs to start. Executor Cores have to stop.
-	executorCoreStopped // A Main Core has stopped the Executor Cores. Only a Main Core can start here.
-} SharedCoreState;
-
 string sharedStateToString(int state) {
    switch(state) {
       case noCoreStarted:
@@ -110,11 +102,12 @@ public:
 	void putMsgInUserDefaults(LinphoneChatMessage *msg);
 	void onMsgWrittenInUserDefaults() override;
 
+	SharedCoreState getSharedCoreState() override;
+
 private:
 	// shared core
 	void setupSharedCore(struct _LpConfig *config);
 	bool isSharedCoreStarted();
-	SharedCoreState getSharedCoreState();
 	static SharedCoreState getSharedCoreState(const string &appGroupId);
 	void setSharedCoreState(SharedCoreState sharedCoreState);
 	static void setSharedCoreState(SharedCoreState sharedCoreState, const string &appGroupId);
@@ -414,9 +407,18 @@ void on_msg_written_in_user_defaults(CFNotificationCenterRef center, void *obser
 	}
 }
 
+
 // The message has been received by the main core and we will just fetch it into the user defaults
 shared_ptr<PushNotificationMessage> IosSharedCoreHelpers::getMsgFromMainCore(const string &callId) {
+	
+	shared_ptr<PushNotificationMessage> msg = fetchUserDefaultsMsg(callId);
+	if (msg) {
+		lInfo() << "[push] message was already found in user defaults, no need to subscribe to notifications";
+		return msg;
+	}
+	
 	lInfo() << "[push] subscribe to main core notif: receive a notif when msg is written in user defaults";
+	
 	CFNotificationCenterRef notification = CFNotificationCenterGetDarwinNotifyCenter();
 	CFStringRef notificationName;
 
@@ -424,9 +426,6 @@ shared_ptr<PushNotificationMessage> IosSharedCoreHelpers::getMsgFromMainCore(con
 
 	CFNotificationCenterAddObserver(notification, (__bridge const void *)(this), on_msg_written_in_user_defaults, notificationName, NULL, CFNotificationSuspensionBehaviorDeliverImmediately);
 
-	shared_ptr<PushNotificationMessage> msg = fetchUserDefaultsMsg(callId);
-	if (msg) return msg;
-
 	reinitTimer();
 	while (ms_get_cur_time_ms() - mTimer < mMaxIterationTimeMs && !mMsgWrittenInUserDefaults) {
 		lInfo() << "[push] wait for msg to be written in user defaults";
@@ -581,6 +580,14 @@ void IosSharedCoreHelpers::reinitTimer() {
 	mTimer = ms_get_cur_time_ms();
 }
 
+static void on_push_notification_chat_room_joined(LinphoneChatRoom *cr, const LinphoneEventLog *evlog){
+	LinphoneCore *lc = linphone_chat_room_get_core(cr);
+	PlatformHelpers *platform_helper = static_cast<LinphonePrivate::PlatformHelpers*>(lc->platform_helper);
+	IosSharedCoreHelpers *shared_core_helper = static_cast<LinphonePrivate::IosSharedCoreHelpers*>(platform_helper->getSharedCoreHelpers().get());
+	lInfo() << "[push] the chat room associated with the push is joined.";
+	shared_core_helper->setChatRoomInvite(static_pointer_cast<ChatRoom>(L_GET_CPP_PTR_FROM_C_OBJECT(cr)));
+}
+
 static void on_push_notification_chat_room_invite_received(LinphoneCore *lc, LinphoneChatRoom *cr, LinphoneChatRoomState state) {
 	if (state == LinphoneChatRoomStateCreated) {
 		PlatformHelpers *platform_helper = static_cast<LinphonePrivate::PlatformHelpers*>(lc->platform_helper);
@@ -591,8 +598,11 @@ static void on_push_notification_chat_room_invite_received(LinphoneCore *lc, Lin
 		lInfo() << "[push] we are added to the chat room " << cr_peer_addr;
 
 		if (cr_peer_addr && strcmp(cr_peer_addr, shared_core_helper->getChatRoomAddr().c_str()) == 0) {
-			lInfo() << "[push] the chat room associated with the push is found";
-			shared_core_helper->setChatRoomInvite(static_pointer_cast<ChatRoom>(L_GET_CPP_PTR_FROM_C_OBJECT(cr)));
+			lInfo() << "[push] the chat room associated with the push is found, now waiting for being joined.";
+			LinphoneChatRoomCbs *cbs = linphone_factory_create_chat_room_cbs(linphone_factory_get());
+			linphone_chat_room_cbs_set_conference_joined(cbs, on_push_notification_chat_room_joined);
+			linphone_chat_room_add_callbacks(cr, cbs);
+			linphone_chat_room_cbs_unref(cbs);
 		}
 	}
 }
@@ -616,7 +626,7 @@ shared_ptr<ChatRoom> IosSharedCoreHelpers::getChatRoomFromAddr(const string &crA
 	uint64_t iterationTimer = ms_get_cur_time_ms();
 
 	/* if the chatroom is received, iterate for 2 sec otherwise iterate mMaxIterationTimeMs seconds*/
-	while ((ms_get_cur_time_ms() - iterationTimer < mMaxIterationTimeMs && !mChatRoomInvite) || (mChatRoomInvite && ms_get_cur_time_ms() - mTimer < 2000)) {
+	while ((ms_get_cur_time_ms() - iterationTimer < mMaxIterationTimeMs) && !mChatRoomInvite) {
 		lInfo() << "[push] wait chatRoom";
 		linphone_core_iterate(getCore()->getCCore());
 
@@ -625,7 +635,7 @@ shared_ptr<ChatRoom> IosSharedCoreHelpers::getChatRoomFromAddr(const string &crA
 			return nullptr;
 		}
 
-		ms_usleep(50000);
+		ms_usleep(20000);
 	}
 
 	return mChatRoomInvite;
