@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2021 Belledonne Communications SARL.
+ * Copyright (c) 2021-2022 Belledonne Communications SARL.
  *
  * This file is part of Liblinphone.
  *
@@ -23,6 +23,10 @@
 #include "ldap-contact-search.h"
 #include "ldap-contact-fields.h"
 #include "contact_providers_priv.h"
+#include "linphone/api/c-types.h"
+#include "ldap.h"
+#include "ldap-params.h"
+#include "../search/search-result.h"
 
 #include <algorithm>
 #include <cstdlib>
@@ -40,14 +44,15 @@ LINPHONE_BEGIN_NAMESPACE
 
 //*******************************************	CREATION
 
-LdapContactProvider::LdapContactProvider(const std::shared_ptr<Core> &core, const std::map<std::string,std::string> &config ){
+LdapContactProvider::LdapContactProvider(const std::shared_ptr<Core> &core, std::shared_ptr<Ldap> ldap) {
 	mAwaitingMessageId = 0;
 	mConnected = FALSE;
 	mCore = core;
 	mLd = nullptr;
+	mLdapServer = ldap;
 	mSalContext = NULL;
 	mServerUri = NULL;
-
+	const std::map<std::string,std::string> &config = ldap->getLdapParams()->getConfig();
 	// register our hook into iterate so that LDAP can do its magic asynchronously.
 	mIteration = mCore->createTimer(std::bind(&LdapContactProvider::iterate, this), 50, "LdapContactProvider");
 	if( !LdapConfigKeys::validConfig(config) ) {
@@ -57,6 +62,7 @@ LdapContactProvider::LdapContactProvider(const std::shared_ptr<Core> &core, cons
 		mConfig = LdapConfigKeys::loadConfig(config, &mNameAttributes, &mSipAttributes, &mAttributes);
 		mCurrentAction = ACTION_NONE;
 	}
+	
 }
 
 LdapContactProvider::~LdapContactProvider(){
@@ -64,8 +70,6 @@ LdapContactProvider::~LdapContactProvider(){
 		mCore->destroyTimer(mIteration);
 		mIteration = nullptr;
 	}
-// Wait for bind thread to end
-	mLock.lock();
 	if (mSalContext) {
 		belle_sip_resolver_context_cancel(mSalContext);
 		belle_sip_object_unref(mSalContext);
@@ -81,47 +85,102 @@ LdapContactProvider::~LdapContactProvider(){
 		belle_sip_object_unref(mServerUri);
 		mServerUri = NULL;
 	}
-	mLock.unlock();
 }
 
 std::vector<std::shared_ptr<LdapContactProvider> > LdapContactProvider::create(const std::shared_ptr<Core> &core){
 	std::vector<std::shared_ptr<LdapContactProvider> > providers;
-	LpConfig * lConfig = linphone_core_get_config(core->getCCore());
-// Read configuration
-	const bctbx_list_t * bcSections = linphone_config_get_sections_names_list(lConfig);
-	for(auto itSections = bcSections; itSections; itSections=itSections->next) {
-		std::string section = static_cast<char *>(itSections->data);
-		std::string sectionName;
-		size_t sectionNameIndex = section.length()-1;
-		while(sectionNameIndex > 0 && section[sectionNameIndex] != '_')// Get the name strip number
-			--sectionNameIndex;
-		if( sectionNameIndex > 0 ){
-			sectionName = section.substr(0,sectionNameIndex);
-		}else
-			sectionName = section;
-		if(sectionName == "ldap"){
-			std::map<std::string, std::string> config;
-			const bctbx_list_t * keys = linphone_config_get_keys_names_list(lConfig, section.c_str());
-			for(auto itKeys = keys ; itKeys ; itKeys=itKeys->next){
-				std::string key = static_cast<char *>(itKeys->data);
-				config[key] = linphone_config_get_string(lConfig, section.c_str(), key.c_str(), "");
-			}
-			if(config["enable"] == "1")
-				providers.push_back(std::make_shared<LdapContactProvider>(core, config));
-		}
+	auto ldapList = core->getLdapList();
+
+	for(auto itLdap : ldapList){
+		auto params = itLdap->getLdapParams();
+		if(params->getEnabled())
+			providers.push_back(std::make_shared<LdapContactProvider>(core, itLdap));
 	}
 	return providers;
 }
 
+void LdapContactProvider::ldapTlsConnection(){
+	std::string srText;
+	void * value = LDAP_OPT_ON;
+	int ldapReturnStatus;
+	int resultStatus;
+	int timeout = getTimeout() ;
+// 1) Start TLS 
+	if(mTlsConnectionId < 0) {// Start TLS
+		ldap_set_option(mLd, LDAP_OPT_CONNECT_ASYNC, value);// If not Async, ldap_start_tls can block on connect.
+		ldapReturnStatus = ldap_start_tls( mLd, NULL, NULL, &mTlsConnectionId );// Try to open a socket.
+		if( ldapReturnStatus != LDAP_SUCCESS && difftime(time(NULL),mTlsConnectionTimeout) > timeout ) {
+			ms_error("[LDAP] Cannot start TLS connection (%s)", ldap_err2string(ldapReturnStatus));
+			mCurrentAction = ACTION_ERROR;
+			mTlsConnectionId = -1;
+		}// mTlsConnectionId is not -1 only on success.
+	}// Not 'else' : we try to get a result without having to wait an iteration
+// 2) Wait for connection
+	if( mTlsConnectionId >= 0){
+		LDAPMessage	*resultMessage = NULL;
+		struct timeval	tv = {0,0};// Do not block
+		ldapReturnStatus = ldap_result( mLd, mTlsConnectionId, LDAP_MSG_ALL, &tv, &resultMessage );
+		switch ( ldapReturnStatus ) {
+		case -1:
+			ms_error("[LDAP] Cannot start TLS connection : Remote server is down");
+			mCurrentAction = ACTION_ERROR;
+			break;
+		case 0: {	// Retry on the next iteration.
+			if( difftime(time(NULL),mTlsConnectionTimeout) > timeout){
+				ms_error("[LDAP] Cannot start TLS connection : timeout (%ds)", timeout );
+				mCurrentAction = ACTION_ERROR;
+			}
+			return;
+		}
+		case LDAP_RES_EXTENDED :
+			ldapReturnStatus = ldap_parse_extended_result( mLd, resultMessage, NULL, NULL , 0 );
+			if ( ldapReturnStatus == LDAP_SUCCESS ) {
+				ldapReturnStatus = ldap_parse_result( mLd, resultMessage, &resultStatus, NULL, NULL, NULL, NULL, 1 );
+				resultMessage = NULL; // Freed by ldap_parse_result
+	
+				if ( ldapReturnStatus == LDAP_SUCCESS ) {
+					ldapReturnStatus = resultStatus;
+				}
+				if ( ldapReturnStatus == LDAP_SUCCESS ) {
+					ldapReturnStatus = ldap_install_tls( mLd );
+					if( ldapReturnStatus == LDAP_SUCCESS || ldapReturnStatus == LDAP_LOCAL_ERROR){
+						mCurrentAction = ACTION_BIND;
+					}else{
+						ldap_get_option(mLd, LDAP_OPT_RESULT_CODE, &resultStatus);
+						ms_error("[LDAP] Cannot install the TLS handler (%s), resultStatus %x (%s)", ldap_err2string(ldapReturnStatus), resultStatus, ldap_err2string(resultStatus));
+						mCurrentAction = ACTION_ERROR;
+					}
+	
+				} else if ( ldapReturnStatus == LDAP_REFERRAL ) {
+					ms_error("[LDAP] Unwilling to chase referral returned by Start TLS exop");
+					mCurrentAction = ACTION_ERROR;
+				}
+			}
+			break;
+		default:
+			ms_warning("[LDAP] Unknown response to StartTLS request : ExtendedResponse is expected");
+			break;
+		}
+		if ( resultMessage != NULL ) {
+			ldap_msgfree( resultMessage );
+		}
+	}
+}
+
 void LdapContactProvider::initializeLdap(){
 	int proto_version = LDAP_VERSION3;
 	int ret = ldap_set_option(NULL, LDAP_OPT_PROTOCOL_VERSION, &proto_version);
 	int debLevel = 0;
+	struct timeval timeout = { getTimeout(), 0 };
 	mCurrentAction = ACTION_NONE;
+	
 	if( ret != LDAP_SUCCESS )
 		ms_error( "[LDAP] Problem initializing default Protocol version to 3 : %x (%s)", ret, ldap_err2string(ret));
+	ret = ldap_set_option(NULL, LDAP_OPT_NETWORK_TIMEOUT, &timeout);
+	if( ret != LDAP_SUCCESS )
+		ms_error( "[LDAP] Problem initializing default timeout to %d : %x (%s)", (int)timeout.tv_sec, ret, ldap_err2string(ret));
 // Setting global options for the next initialization. These options cannot be done with the LDAP instance directly.
-	if(mConfig.count("debug")>0 && mConfig["debug"] == "1")
+	if(mConfig.count("debug")>0 && LinphoneLdapDebugLevelVerbose == static_cast<LinphoneLdapDebugLevel>(atoi(mConfig["debug"].c_str())))
 		debLevel = 7;
 	ret = ldap_set_option(NULL, LDAP_OPT_DEBUG_LEVEL, &debLevel);
 	if( ret != LDAP_SUCCESS )
@@ -155,33 +214,38 @@ void LdapContactProvider::initializeLdap(){
 	} else if( (ret = ldap_set_option(mLd, LDAP_OPT_PROTOCOL_VERSION, &proto_version)) != LDAP_SUCCESS ){
 		ms_error( "[LDAP] Problem setting protocol version %d: %x (%s)", proto_version,ret, ldap_err2string(ret));
 		mCurrentAction = ACTION_ERROR;
-	} else {
-		
-		if(mConfig.count("use_tls")>0 && mConfig["use_tls"] == "1"){
-			if(mConfig.count("use_sal")>0 && mConfig["use_sal"] == "1"){// Using Sal give an IP for a domain. So check the domain rather than the IP.
-				belle_generic_uri_t *serverUri = belle_generic_uri_parse(mConfig["server"].c_str());
-				std::string hostname = belle_generic_uri_get_host(serverUri);
-				std::vector<char> cHostname(hostname.c_str(), hostname.c_str() + hostname.size() + 1);
-				ldap_set_option(mLd, LDAP_OPT_X_TLS_PEER_CN, &cHostname[0]);
-			}
-			ret = ldap_start_tls_s(mLd, NULL, NULL);
-		}
-		if( ret == LDAP_SUCCESS ) {
-			ms_debug("[LDAP] Initialization success");
-			mConnected = 1;
-		}else {
-			int err;
-			ldap_get_option(mLd, LDAP_OPT_RESULT_CODE, &err);
-			ms_error("[LDAP] Cannot initialize address to %s : %x, err %x (%s)",mConfig["server"].c_str(), ret, err, ldap_err2string(err));
-			mCurrentAction = ACTION_ERROR;
+	} else if( ret != LDAP_SUCCESS){
+		int err;
+		ldap_get_option(mLd, LDAP_OPT_RESULT_CODE, &err);
+		ms_error("[LDAP] Cannot initialize address to %s : %x (%s), err %x (%s)",mConfig["server"].c_str(), ret, ldap_err2string(ret), err, ldap_err2string(err));
+		mCurrentAction = ACTION_ERROR;
+	}else if(mConfig.count("use_tls")>0 && mConfig["use_tls"] == "1"){
+		if(mConfig.count("use_sal")>0 && mConfig["use_sal"] == "1"){// Using Sal give an IP for a domain. So check the domain rather than the IP.
+			belle_generic_uri_t *serverUri = belle_generic_uri_parse(mConfig["server"].c_str());
+			std::string hostname = belle_generic_uri_get_host(serverUri);
+			ldap_set_option(mLd, LDAP_OPT_X_TLS_PEER_CN, &hostname[0]);
 		}
+		mTlsConnectionId = -1;
+		mCurrentAction = ACTION_WAIT_TLS_CONNECT;
+		mTlsConnectionTimeout = time(NULL);
+	}else {
+		ms_debug("[LDAP] Initialization success");
+		mConnected = 1;
 	}
 }
 
+int LdapContactProvider::getMinChars() const {
+	return mConfig.count("min_chars") > 0 ? atoi(mConfig.at("min_chars").c_str()) : 0;
+}
+
 int LdapContactProvider::getTimeout() const{
 	return atoi(mConfig.at("timeout").c_str());
 }
 
+int LdapContactProvider::getDelay() const{
+	return mConfig.count("delay") > 0 ? atoi(mConfig.at("delay").c_str()) : 500;
+}
+
 std::string LdapContactProvider::getFilter()const{
 	return mConfig.at("filter");
 }
@@ -189,23 +253,54 @@ std::string LdapContactProvider::getFilter()const{
 int LdapContactProvider::getCurrentAction()const{
 	return mCurrentAction;
 }
+
+std::shared_ptr<Ldap> LdapContactProvider::getLdapServer(){
+	return mLdapServer;
+}
+
+void LdapContactProvider::computeLastRequestTime(const std::list<SearchRequest>& requestHistory) {
+// Find the first LDAP search.
+	std::list<SearchRequest>::const_iterator itRequest = requestHistory.begin();
+	mLastRequestTime = 0; // No search in history: do not delay
+	
+	do{
+		itRequest = std::find_if(itRequest, requestHistory.end(), [](const SearchRequest& r){
+			return (r.getSourceFlags() & LinphoneMagicSearchSourceLdapServers) == LinphoneMagicSearchSourceLdapServers;
+		});
+		if(itRequest != requestHistory.end()){
+			if( mLastRequestTime == 0)
+				mLastRequestTime = itRequest->getStartTime(); // There was one search. Store the time and loop on next LDAP searches.
+			else{
+				uint64_t t = itRequest->getStartTime();
+				if( t - mLastRequestTime > (uint64_t) getDelay())	// This last search should be start as it's superior from timeout. Take it account.
+					mLastRequestTime = t;
+			}
+			// Continue with the next LDAP search
+			++itRequest;
+		}
+	}while(itRequest != requestHistory.end() );
+}
 //*******************************************	SEARCH
 
 // Create a search object and store the request to be used when the provider is ready
-void LdapContactProvider::search(const std::string& predicate, ContactSearchCallback cb, void* cbData){
-	std::shared_ptr<LdapContactSearch> request = std::make_shared<LdapContactSearch>(this, predicate, cb, cbData );
-	mLock.lock();
-	if( request != NULL ) {
-		mRequests.push_back(request);
-	}
-	mLock.unlock();
+bool LdapContactProvider::search(const std::string& predicate, ContactSearchCallback cb, void* cbData, const std::list<SearchRequest>& requestHistory){
+	if( getMinChars() <= (int)predicate.length()){
+		std::shared_ptr<LdapContactSearch> request = std::make_shared<LdapContactSearch>(this, predicate, cb, cbData );
+		if( request != NULL ) {
+			mRequests.push_back(request);
+		}
+		computeLastRequestTime(requestHistory);
+		return true;
+	}else
+		return false;
 }
 
 // Start the search
 int LdapContactProvider::search(std::shared_ptr<LdapContactSearch> request){
 	int ret = -1;
 	struct timeval timeout = { atoi(mConfig["timeout"].c_str()), 0 };
-
+	int maxResults = atoi(mConfig["max_results"].c_str());
+	if( maxResults > 0) ++maxResults;	// +1 to know if there is more than limit
 	if( request->mMsgId == 0 ){
 		ret = ldap_search_ext(mLd,
 						mConfig["base_object"].c_str(),// base from which to start
@@ -216,7 +311,7 @@ int LdapContactProvider::search(std::shared_ptr<LdapContactSearch> request){
 						NULL,
 						NULL,
 						&timeout,        // server timeout for the search
-						atoi(mConfig["max_results"].c_str()),// max result number
+						maxResults,
 						&request->mMsgId );
 		if( ret != LDAP_SUCCESS ){
 			ms_error("[LDAP] Error ldap_search_ext returned %d (%s)", ret, ldap_err2string(ret));
@@ -279,7 +374,10 @@ int LdapContactProvider::completeContact( LdapContactFields* contact, const char
 				if(mConfig.count("sip_domain")>0 && mConfig.at("sip_domain") != "")
 					linphone_address_set_domain(la, mConfig.at("sip_domain").c_str());
 				char *newSip = linphone_address_as_string(la);
-				contact->mSip[newSip] = 0;
+				char *phoneNumber = linphone_account_normalize_phone_number(linphone_core_get_default_account(mCore->getCCore()), attributeValueLocale.c_str());
+				if(contact->mSip.count(newSip)==0 || contact->mSip[newSip] == "")
+					contact->mSip[newSip] = (phoneNumber ? phoneNumber : "");
+				if(phoneNumber) ms_free(phoneNumber);
 				ms_free(newSip);
 				linphone_address_unref(la);
 			}
@@ -293,7 +391,7 @@ int LdapContactProvider::completeContact( LdapContactFields* contact, const char
 }
 
 //*******************************************	ASYNC PROCESSING
-// ACTION_NONE => ACTION_INIT => (ACTION_WAIT_DNS) => ACTION_INITIALIZE => ACTION_BIND => ACTION_WAIT_BIND => ACTION_WAIT_REQUEST
+// ACTION_NONE => ACTION_INIT => (ACTION_WAIT_DNS) => ACTION_INITIALIZE => (ACTION_WAIT_TLS_CONNECT) => ACTION_BIND => ACTION_WAIT_BIND => ACTION_WAIT_REQUEST
 bool LdapContactProvider::iterate(void *data) {
 	struct timeval pollTimeout = {0,0};
 	LDAPMessage* results = NULL;
@@ -305,8 +403,7 @@ bool LdapContactProvider::iterate(void *data) {
 		// not using switch is wanted : we can do severals steps in one iteration if wanted.
 		if(provider->mCurrentAction == ACTION_NONE){
 			ms_debug("[LDAP] ACTION_NONE");
-			provider->mLock.lock();
-			if( provider->mRequests.size() > 0){
+			if( provider->mRequests.size() > 0 && provider->isReadyForStart()){
 				if( provider->mCurrentAction != ACTION_ERROR){
 					if( provider->mConnected != 1)
 						provider->mCurrentAction = ACTION_INIT;
@@ -314,7 +411,6 @@ bool LdapContactProvider::iterate(void *data) {
 						provider->mCurrentAction = ACTION_BIND;
 				}
 			}
-			provider->mLock.unlock();
 		}
 
 		if(provider->mCurrentAction == ACTION_INIT){
@@ -329,7 +425,8 @@ bool LdapContactProvider::iterate(void *data) {
 					std::string domain = belle_generic_uri_get_host(provider->mServerUri);
 					int port = belle_generic_uri_get_port(provider->mServerUri);
 					if(port  <= 0){
-						if( belle_generic_uri_get_scheme(provider->mServerUri) == std::string("ldap"))
+						std::string scheme = Utils::stringToLower(belle_generic_uri_get_scheme(provider->mServerUri));
+						if( scheme == "ldap")
 							port = 389;
 						else
 							port = 636;
@@ -365,14 +462,17 @@ bool LdapContactProvider::iterate(void *data) {
 				provider->mServerUri = NULL;
 			}
 		}
+		
+		if( provider->mCurrentAction == ACTION_WAIT_TLS_CONNECT )
+			provider->ldapTlsConnection();
 
 		if(provider->mCurrentAction == ACTION_BIND){ // Careful : Binds are not thread-safe
 			ms_debug("[LDAP] ACTION_BIND");
-			std::string auth_mechanism = provider->mConfig.at("auth_method");
+			LinphoneLdapAuthMethod auth_mechanism = static_cast<LinphoneLdapAuthMethod>(atoi(provider->mConfig.at("auth_method").c_str()));
 			int ret=0;
-			if( (auth_mechanism == "ANONYMOUS") || (auth_mechanism == "SIMPLE") ) {
+			if( (auth_mechanism == LinphoneLdapAuthMethodAnonymous) || (auth_mechanism == LinphoneLdapAuthMethodSimple) ) {
 				std::string bindDn, password;
-				if( auth_mechanism == "SIMPLE" && provider->mConfig.count("bind_dn") > 0) {
+				if( auth_mechanism == LinphoneLdapAuthMethodSimple && provider->mConfig.count("bind_dn") > 0) {
 					bindDn = provider->mConfig.at("bind_dn");
 					password = provider->mConfig.at("password");
 				}//else : anonymous connection
@@ -384,7 +484,7 @@ bool LdapContactProvider::iterate(void *data) {
 				} else {
 					int err=0;
 					ldap_get_option(provider->mLd, LDAP_OPT_RESULT_CODE, &err);
-					ms_error("[LDAP] ldap_sasl_bind error returned %x, err %x (%s), auth_method: %s", ret, err, ldap_err2string(err), auth_mechanism.c_str() );
+					ms_error("[LDAP] ldap_sasl_bind error returned %x, err %x (%s), auth_method: %d", ret, err, ldap_err2string(err), auth_mechanism );
 					provider->mCurrentAction = ACTION_ERROR;
 					provider->mAwaitingMessageId = 0;
 				}
@@ -417,7 +517,6 @@ bool LdapContactProvider::iterate(void *data) {
 			size_t requestSize = 0;
 			if( provider->mLd && provider->mConnected ){
 				// check for pending searches
-				provider->mLock.lock();
 				for(auto it = provider->mRequests.begin() ; it != provider->mRequests.end() ; ){
 					if(!(*it))
 						it = provider->mRequests.erase(it);
@@ -433,7 +532,6 @@ bool LdapContactProvider::iterate(void *data) {
 						++it;
 				}
 				requestSize = provider->mRequests.size();
-				provider->mLock.unlock();
 			}
 			if( requestSize > 0 ){// No need to check connectivity as it is checked before
 				// never block
@@ -499,19 +597,14 @@ void LdapContactProvider::ldapServerResolved(void *data, belle_sip_resolver_resu
 		}else{
 			provider->mServerUrl = provider->mConfig["server"];
 		}
-		provider->mLock.lock();
 		provider->mCurrentAction = ACTION_INITIALIZE;
-		provider->mLock.unlock();
 	} else {
 		ms_error("[LDAP] Server resolution failed, no address can be found.");
-		provider->mLock.lock();
 		provider->mCurrentAction = ACTION_ERROR;
-		provider->mLock.unlock();
 	}
 }
 
 void LdapContactProvider::handleSearchResult( LDAPMessage* message ) {
-	mLock.lock();
 	if(message){
 		int msgtype = ldap_msgtype(message);
 		LdapContactSearch* req = requestSearch(ldap_msgid(message));
@@ -539,14 +632,29 @@ void LdapContactProvider::handleSearchResult( LDAPMessage* message ) {
 					attr = ldap_next_attribute(mLd, entry, ber);
 				}
 				if( contact_complete ) {
+					LinphoneFriend *lfriend = linphone_core_create_friend(lc);
+					linphone_friend_set_name(lfriend, ldapData.mName.first.c_str());
+
 					for(auto sipAddress : ldapData.mSip) {
 						LinphoneAddress* la = linphone_core_interpret_url(lc, sipAddress.first.c_str());
 						if( la ){
 							linphone_address_set_display_name(la, ldapData.mName.first.c_str());
-							req->mFoundEntries = bctbx_list_append(req->mFoundEntries, la);
-							++req->mFoundCount;
+							linphone_friend_add_address(lfriend, la);
+							linphone_friend_add_phone_number(lfriend, L_STRING_TO_C(sipAddress.second));
+
+							int maxResults = atoi(mConfig["max_results"].c_str());
+							if( maxResults == 0 || req->mFoundCount < (unsigned int) maxResults) {
+								std::shared_ptr<SearchResult> searchResult = SearchResult::create((unsigned int)0, la, sipAddress.second, lfriend, LinphoneMagicSearchSourceLdapServers);
+								req->mFoundEntries.push_back(searchResult);
+								++req->mFoundCount;
+							}else{// Have more result (requested max_results+1). Do not store this result to avoid missunderstanding from user.
+								req->mHaveMoreResults = TRUE;
+							}
+							linphone_address_unref(la);
 						}
 					}
+
+					linphone_friend_unref(lfriend);
 				}
 				if( ber ) ber_free(ber, 0);
 				if(attr) ldap_memfree(attr);
@@ -568,8 +676,10 @@ void LdapContactProvider::handleSearchResult( LDAPMessage* message ) {
 		}
 		mRequests.clear();
 	}
-	mLock.unlock();
 }
 
+bool LdapContactProvider::isReadyForStart(){
+	return mLastRequestTime + (uint64_t)getDelay() < bctbx_get_cur_time_ms();
+}
 
 LINPHONE_END_NAMESPACE
