@@ -378,11 +378,11 @@ void SalCallOp::sdpProcess () {
 				mResult->streams[i].rtcp_addr = mRemoteMedia->streams[i].rtcp_addr;
 				mResult->streams[i].rtcp_port = mRemoteMedia->streams[i].rtcp_port;
 				if (mResult->streams[i].hasSrtp()) {
-					int cryptoIdx = Sal::findCryptoIndexFromTag(mRemoteMedia->streams[i].getCryptos(), static_cast<unsigned char>(mResult->streams[i].getCryptoAtIndex(0).tag));
+					int cryptoIdx = Sal::findCryptoIndexFromTag(mRemoteMedia->streams[i].getCryptos(), mResult->streams[i].getCryptoAtIndex(0).tag);
 					if (cryptoIdx >= 0)
 						mResult->streams[i].setCrypto(0, mRemoteMedia->streams[i].getCryptoAtIndex(static_cast<size_t>(cryptoIdx)));
 					else
-						lError() << "Failed to find crypto algo with tag: " << mResult->streams[i].getChosenConfiguration().crypto_local_tag << "from resulting description [" << mResult << "]";
+						lError() << "Failed to find crypto algo with tag: " << mResult->streams[i].getChosenConfiguration().crypto_local_tag << " from resulting description [" << mResult << "]";
 				}
 			}
 		}
@@ -688,7 +688,7 @@ void SalCallOp::processTransactionTerminatedCb (void *userCtx, const belle_sip_t
 
 	string method = belle_sip_request_get_method(request);
 	if ((op->mState == State::Terminating)
-		&& (method == "BYE")
+		&& (method == "BYE" || method == "INVITE")
 		&& (!response
 			|| ((belle_sip_response_get_status_code(response) != 401)
 				&& (belle_sip_response_get_status_code(response) != 407)
@@ -977,6 +977,8 @@ void SalCallOp::processRequestEventCb (void *userCtx, const belle_sip_request_ev
 				op->resetDescriptions();
 				if (op->processBodyForInvite(request) == SalReasonNone)
 					op->mRoot->mCallbacks.call_updating(op, true);
+			} else if (method == "NOTIFY") {
+				op->processNotify(event, serverTransaction);
 			} else {
 				lError() << "Unexpected method [" << method << "] for dialog state BELLE_SIP_DIALOG_EARLY";
 				unsupportedMethod(serverTransaction, request);
@@ -1482,6 +1484,9 @@ int SalCallOp::update (const string &subject, bool noUserConsent, bool withSDP,
 	}
 	if (update) {
 		belle_sip_message_add_header(BELLE_SIP_MESSAGE(update), belle_sip_header_create("Subject", subject.c_str()));
+		if (mRoot->mSupportedHeader) {
+			belle_sip_message_add_header(BELLE_SIP_MESSAGE(update), mRoot->mSupportedHeader);
+		}
 		fillSessionExpiresHeaders(update, BELLE_SIP_HEADER_SESSION_EXPIRES_UAC, delta);
 		if (withSDP) fillInvite(update);
 		return sendRequestWithContact(update, true);
