@@ -168,7 +168,11 @@ PayloadType * OfferAnswerEngine::findPayloadTypeBestMatch(MSFactory *factory, co
 	// When a stream is inactive, refpt->mime_type might be null
 	if (refpt->mime_type && (ctx = ms_factory_create_offer_answer_context(factory, refpt->mime_type))) {
 		ms_message("Doing offer/answer processing with specific provider for codec [%s]", refpt->mime_type); 
-		ret = ms_offer_answer_context_match_payload(ctx, Utils::listToBctbxList(local_payloads), refpt, Utils::listToBctbxList(remote_payloads), reading_response);
+		auto local_payloads_list =  Utils::listToBctbxList(local_payloads);
+		auto remote_payloads_list =  Utils::listToBctbxList(remote_payloads);
+		ret = ms_offer_answer_context_match_payload(ctx, local_payloads_list, refpt, remote_payloads_list, reading_response);
+		bctbx_list_free(local_payloads_list);
+		bctbx_list_free(remote_payloads_list);
 		ms_offer_answer_context_destroy(ctx);
 		return ret;
 	}
@@ -237,22 +241,24 @@ std::list<OrtpPayloadType*> OfferAnswerEngine::matchPayloads(MSFactory *factory,
 	}
 	if (reading_response){
 		/* add remaning local payload as CAN_RECV only so that if we are in front of a non-compliant equipment we are still able to decode the RTP stream*/
+		bool found=false;
 		for (const auto & p1 : local) {
-			bool found=false;
 			for (const auto & p2 : remote) {
 				if (payload_type_get_number(p2)==payload_type_get_number(p1)){
 					found=true;
 					break;
 				}
 			}
-			if (!found){
-				ms_message("Adding %s/%i for compatibility, just in case.",p1->mime_type,p1->clock_rate);
-				PayloadType *cloned_p1=payload_type_clone(p1);
-				payload_type_set_flag(cloned_p1, PAYLOAD_TYPE_FLAG_CAN_RECV);
-				payload_type_set_flag(cloned_p1, PAYLOAD_TYPE_FROZEN_NUMBER);
-				res.push_back(cloned_p1);
-			}
 		}
+		if (!found){
+			const auto & p1 = local.front();
+			ms_message("Adding %s/%i for compatibility, just in case.",p1->mime_type,p1->clock_rate);
+			PayloadType *cloned_p1=payload_type_clone(p1);
+			payload_type_set_flag(cloned_p1, PAYLOAD_TYPE_FLAG_CAN_RECV);
+			payload_type_set_flag(cloned_p1, PAYLOAD_TYPE_FROZEN_NUMBER);
+			res.push_back(cloned_p1);
+		}
+
 	}
 	return res;
 }
@@ -269,7 +275,6 @@ bool OfferAnswerEngine::matchCryptoAlgo(const std::vector<SalSrtpCryptoAlgo> &lo
 				result.algo = rc.algo;
 				/* We're answering an SDP offer. Supply our master key, associated with the remote supplied tag */
 				if (use_local_key) {
-
 					result.master_key = lc.master_key;
 					result.tag = rc.tag;
 					choosen_local_tag = lc.tag;
@@ -280,7 +285,6 @@ bool OfferAnswerEngine::matchCryptoAlgo(const std::vector<SalSrtpCryptoAlgo> &lo
 					result.tag = lc.tag;
 					choosen_local_tag = lc.tag;
 				}
-
 				return true;
 			}
 		}
@@ -525,6 +529,10 @@ std::pair<SalStreamConfiguration, bool> OfferAnswerEngine::initiateOutgoingConfi
 		}
 	}
 
+	resultCfg.mixer_to_client_extension_id = remoteCfg.mixer_to_client_extension_id;
+	resultCfg.client_to_mixer_extension_id = remoteCfg.client_to_mixer_extension_id;
+	resultCfg.conference_ssrc = remoteCfg.conference_ssrc;
+
 	if (!resultCfg.payloads.empty() && !OfferAnswerEngine::onlyTelephoneEvent(resultCfg.payloads)){
 		resultCfg.ptime=remoteCfg.ptime;
 		resultCfg.maxptime=remoteCfg.maxptime;
@@ -721,10 +729,10 @@ std::pair<SalStreamConfiguration, bool> OfferAnswerEngine::initiateIncomingConfi
 	resultCfg.rtcp_mux = remoteCfg.rtcp_mux && localCfg.rtcp_mux;
 	
 	/* Handle RTP bundle negociation */
-	if (!remoteCfg.mid.empty() && !bundle_owner_mid.empty()){
+	if (!remoteCfg.mid.empty() && !bundle_owner_mid.empty() && remoteCfg.mid_rtp_ext_header_id != 0) {
 		resultCfg.mid = remoteCfg.mid;
 		resultCfg.mid_rtp_ext_header_id = remoteCfg.mid_rtp_ext_header_id;
-		
+
 		if (remoteCfg.mid.compare(bundle_owner_mid) != 0){
 			/* The stream is a secondary one part of a bundle.
 			 * In this case it must set the bundle-only attribute, and set port to zero.*/
@@ -733,6 +741,10 @@ std::pair<SalStreamConfiguration, bool> OfferAnswerEngine::initiateIncomingConfi
 		resultCfg.rtcp_mux = true; /* RTCP mux must be enabled in bundle mode. */
 	}
 
+	resultCfg.mixer_to_client_extension_id = remoteCfg.mixer_to_client_extension_id;
+	resultCfg.client_to_mixer_extension_id = remoteCfg.client_to_mixer_extension_id;
+	resultCfg.conference_ssrc = localCfg.conference_ssrc;
+
 	if (resultCfg.hasSrtp() == true) {
 		const auto srtpFound = std::find(availableEncs.cbegin(), availableEncs.cend(), LinphoneMediaEncryptionSRTP);
 		if (srtpFound == availableEncs.cend()) {
@@ -869,6 +881,10 @@ std::shared_ptr<SalMediaDescription> OfferAnswerEngine::initiateOutgoing(MSFacto
 		ms_error("Remote answerer is proposing bundles, which we did not offer.");
 	}
 
+	if (local_offer->record != SalMediaRecordNone && remote_answer->record != SalMediaRecordNone) {
+		result->record = remote_answer->record;
+	}
+
 	return result;
 }
 
@@ -889,6 +905,10 @@ std::shared_ptr<SalMediaDescription> OfferAnswerEngine::initiateIncoming(MSFacto
 		result->bundles = remote_offer->bundles;
 	}
 
+	if (remote_offer->record != SalMediaRecordNone && local_capabilities->record != SalMediaRecordNone) {
+		result->record = local_capabilities->record;
+	}
+
 	const bool capabilityNegotiation = result->supportCapabilityNegotiation();
 	for(i=0;i<remote_offer->streams.size();++i){
 
