@@ -65,6 +65,8 @@ SalMediaDescription::SalMediaDescription(const SalMediaDescription & other) {
 	accept_bundles = other.accept_bundles;
 	bundles = other.bundles;
 
+	record = other.record;
+
 	set_nortpproxy = other.set_nortpproxy;
 
 	capabilityNegotiationSupported = other.capabilityNegotiationSupported;
@@ -132,6 +134,17 @@ SalMediaDescription::SalMediaDescription(belle_sdp_session_description_t  *sdp)
 	value=belle_sdp_session_description_get_attribute_value(sdp,"lime-Ik");
 	if (value) haveLimeIk = true;
 
+	value=belle_sdp_session_description_get_attribute_value(sdp,"record");
+	if (value) {
+		if (strcmp(value, "on") == 0) {
+			record = SalMediaRecordOn;
+		} else if (strcmp(value, "off") == 0) {
+			record = SalMediaRecordOff;
+		} else if (strcmp(value, "paused") == 0) {
+			record = SalMediaRecordPaused;
+		}
+	}
+
 	/* Get the custom attributes, parse some of them that are relevant */
 	for (custom_attribute_it = belle_sdp_session_description_get_attributes(sdp); custom_attribute_it != NULL; custom_attribute_it = custom_attribute_it->next) {
 		belle_sdp_attribute_t *attr = (belle_sdp_attribute_t *)custom_attribute_it->data;
@@ -363,9 +376,9 @@ bool SalMediaDescription::hasSrtp() const {
 	if (streams.empty()) return false;
 	for(const auto & stream : streams){
 		if (!stream.enabled()) continue;
-		if (stream.hasSrtp()) return true;
+		if (stream.hasSrtp() != true) return false;
 	}
-	return false;
+	return true;
 }
 
 bool SalMediaDescription::hasDtls() const {
@@ -453,7 +466,7 @@ int SalMediaDescription::globalEqual(const SalMediaDescription & otherMd) const
 	if (addr.empty() == false && otherMd.addr.empty() == false && ms_is_multicast(L_STRING_TO_C(addr)) != ms_is_multicast(L_STRING_TO_C(otherMd.addr)))
 		result |= SAL_MEDIA_DESCRIPTION_NETWORK_XXXCAST_CHANGED;
 	if (streams.size() != otherMd.streams.size()) result |= SAL_MEDIA_DESCRIPTION_STREAMS_CHANGED;
-	if (bandwidth != otherMd.bandwidth) result |= SAL_MEDIA_DESCRIPTION_CODEC_CHANGED;
+	if (bandwidth != otherMd.bandwidth) result |= SAL_MEDIA_DESCRIPTION_BANDWIDTH_CHANGED;
 
 	/* ICE */
 	if (ice_ufrag.compare(otherMd.ice_ufrag) != 0 && !otherMd.ice_ufrag.empty()) result |= SAL_MEDIA_DESCRIPTION_ICE_RESTART_DETECTED;
@@ -504,6 +517,22 @@ const std::string SalMediaDescription::printDifferences(int result) {
 		out.append("STREAM_CONFIGURATION_CHANGED ");
 		result &= ~SAL_MEDIA_DESCRIPTION_CONFIGURATION_CHANGED;
 	}
+	if (result & SAL_MEDIA_DESCRIPTION_MIXER_TO_CLIENT_EXTENSION_CHANGED) {
+		out.append("MIXER_TO_CLIENT_CHANGED ");
+		result &= ~SAL_MEDIA_DESCRIPTION_MIXER_TO_CLIENT_EXTENSION_CHANGED;
+	}
+	if (result & SAL_MEDIA_DESCRIPTION_CLIENT_TO_MIXER_EXTENSION_CHANGED) {
+		out.append("CLIENT_TO_MIXER_CHANGED ");
+		result &= ~SAL_MEDIA_DESCRIPTION_CLIENT_TO_MIXER_EXTENSION_CHANGED;
+	}
+	if (result & SAL_MEDIA_DESCRIPTION_PTIME_CHANGED) {
+		out.append("PTIME_CHANGED ");
+		result &= ~SAL_MEDIA_DESCRIPTION_PTIME_CHANGED;
+	}
+	if (result & SAL_MEDIA_DESCRIPTION_BANDWIDTH_CHANGED) {
+		out.append("BANDWIDTH_CHANGED ");
+		result &= ~SAL_MEDIA_DESCRIPTION_BANDWIDTH_CHANGED;
+	}
 	if (result){
 		ms_fatal("There are unhandled result bitmasks in SalMediaDescription::printDifferences(), fix it");
 	}
@@ -591,6 +620,10 @@ belle_sdp_session_description_t * SalMediaDescription::toSdp() const {
 		bundle.addToSdp(session_desc);
 	}
 
+	if (record != SalMediaRecordNone) {
+		belle_sdp_session_description_add_attribute(session_desc, belle_sdp_attribute_create("record", sal_media_record_to_string(record)));
+	}
+
 	if (custom_sdp_attributes) {
 		belle_sdp_session_description_t *custom_desc = (belle_sdp_session_description_t *)custom_sdp_attributes;
 		belle_sip_list_t *l = belle_sdp_session_description_get_attributes(custom_desc);
