@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2010-2021 Belledonne Communications SARL.
+ * Copyright (c) 2010-2022 Belledonne Communications SARL.
  *
  * This file is part of Liblinphone.
  *
@@ -31,6 +31,7 @@
 #include "linphone/dictionary.h"
 #include "logger/logger.h"
 #include "private.h"
+#include "../ldap/ldap.h"
 
 //#include "linphone/belle-sip/object.h"
 
@@ -131,29 +132,18 @@ void MagicSearch::resetSearchCache () {
 	}
 }
 
-static string getDisplayNameFromSearchResult (const SearchResult &sr) {
-	const char *name = NULL;
-	if (sr.getFriend()) {
-		name = linphone_friend_get_name(sr.getFriend());
-	}
-	if (!name && sr.getAddress()){
-		name = linphone_address_get_display_name(sr.getAddress()) ?
-			linphone_address_get_display_name(sr.getAddress()) : linphone_address_get_username(sr.getAddress());
-	}
-	if (!name) {
-		return sr.getPhoneNumber();
-	}
-	return name;
-}
 #ifdef LDAP_ENABLED
 class LdapCbData : public SearchAsyncData::CbData{
 public:
-	LdapCbData(){}
+	LdapCbData(){
+		mSourceFlags = LinphoneMagicSearchSourceLdapServers;
+	}
 	virtual ~LdapCbData(){}
 	virtual void cancel() override{
 		mProvider = nullptr;// Just remove shared pointer. When there is no reference on it, it will be destroyed (aka cancelled)
 	}
 	std::shared_ptr<LdapContactProvider> mProvider;
+	
 };
 #endif
 
@@ -161,25 +151,38 @@ public:
 // STATE_START => (STATE_WAIT) => STATE_SEND [<=] => STATE_END
 bool MagicSearch::iterate(void){
 	L_D();
-	std::pair<std::string, std::string> request;
+	SearchRequest request;
 	bool continueLoop = d->mAsyncData.getCurrentRequest(&request);
 	
 	if(mState == STATE_START){
-		if(!getContactListFromFilterStartAsync(request.first,request.second, &d->mAsyncData)){
-			d->mAsyncData.initStartTime();
+		if(!getContactListFromFilterStartAsync(request, &d->mAsyncData)){
 			mState = STATE_WAIT;
 		}else
 			mState = STATE_SEND;
+		d->mAsyncData.initStartTime();
 	}
 	if( mState == STATE_WAIT){
 		if(getAddressIsEndAsync(&d->mAsyncData)){
-			mergeResults(request.first, request.second, &d->mAsyncData);
+			mergeResults(request, &d->mAsyncData);
 			mState = STATE_SEND;
 		}
 	}
-	if( mState == STATE_SEND){
-		processResults (d->mAsyncData.mSearchResults);
-		_linphone_magic_search_notify_search_results_received(L_GET_C_BACK_PTR(this));
+	if( mState == STATE_SEND || mState == STATE_CANCEL){
+		if( mState == STATE_SEND) {
+			processResults (d->mAsyncData.mSearchResults);
+			_linphone_magic_search_notify_search_results_received(L_GET_C_BACK_PTR(this));
+#ifdef LDAP_ENABLED
+			for(size_t i = 0 ; i < d->mAsyncData.getData().size() ; ++i){
+				auto data = d->mAsyncData.getData()[i];
+				if( data->mHaveMoreResults && (data->mSourceFlags & LinphoneMagicSearchSourceLdapServers) == LinphoneMagicSearchSourceLdapServers){
+					std::shared_ptr<Ldap> ldap = dynamic_cast<LdapCbData*>(data.get())->mProvider->getLdapServer();
+					_linphone_magic_search_notify_ldap_have_more_results(L_GET_C_BACK_PTR(this), ldap->toC());
+				}
+			}
+#endif
+		} else {
+			lInfo() << "[Magic Search] Cancelling : " << request.getFilter().c_str();
+		}
 		d->mAsyncData.clear();
 		if(d->mAsyncData.keepOneRequest()){
 			if(d->mAutoResetCache)
@@ -197,27 +200,33 @@ bool MagicSearch::iterate(void){
 }
 
 //Public
-void MagicSearch::getContactListFromFilterAsync (const string &filter, const string &withDomain) {
+void MagicSearch::getContactListFromFilterAsync (const string &filter, const string &withDomain, int sourceFlags, LinphoneMagicSearchAggregation aggregation) {
 	L_D();
-	if( d->mAsyncData.pushRequest({filter,withDomain}) == 1){
+	lDebug() << "[Magic Search] New async search: " << filter;
+	if( d->mAsyncData.pushRequest(SearchRequest(filter, withDomain, sourceFlags, aggregation)) == 1){// This is a new request.
 		if(d->mAutoResetCache){
 			resetSearchCache();
 		}
 		mState = STATE_START;
 		d->mIteration = this->getCore()->createTimer(std::bind(&MagicSearch::iterate, this), 100, "MagicSearch");
-	}
+	}else// A request is already computing. Enter in cancelling state.
+		mState = STATE_CANCEL;
 }
 
 //Public
-list<SearchResult> MagicSearch::getContactListFromFilter (const string &filter, const string &withDomain) {
+list<std::shared_ptr<SearchResult>> MagicSearch::getContactListFromFilter (const string &filter, const string &withDomain, int sourceFlags, LinphoneMagicSearchAggregation aggregation) {
 	L_D();
-	std::shared_ptr<list<SearchResult> > resultList;
-
+	lDebug() << "[Magic Search] New search: " << filter;
+	std::shared_ptr<list<std::shared_ptr<SearchResult>> > resultList;
+	SearchRequest request(filter, withDomain, sourceFlags, aggregation);
+	d->mAsyncData.setSearchRequest(request);
+	if(d->mAutoResetCache)
+		resetSearchCache();
 	if (getSearchCache() != nullptr && !filter.empty()) {
 		resultList = continueSearch(filter, withDomain);
 		resetSearchCache();
 	} else {
-		resultList = beginNewSearch(filter, withDomain);
+		resultList = beginNewSearch(filter, withDomain, sourceFlags);
 	}
 	d->mFilter = filter;
 
@@ -225,29 +234,88 @@ list<SearchResult> MagicSearch::getContactListFromFilter (const string &filter,
 }
 
 // Private : used from iterate. This is an auto start. 
-bool MagicSearch::getContactListFromFilterStartAsync (const string &filter, const string &withDomain, SearchAsyncData * asyncData) {
+bool MagicSearch::getContactListFromFilterStartAsync (const SearchRequest& request, SearchAsyncData * asyncData) {
 	L_D();
-	std::shared_ptr<list<SearchResult>> returnList = nullptr;
-
-	if (getSearchCache() != nullptr && !filter.empty()) {
-		returnList = continueSearch(filter, withDomain);
+	std::shared_ptr<list<std::shared_ptr<SearchResult>>> returnList = nullptr;
+	if (getSearchCache() != nullptr && !request.getFilter().empty()) {
+		returnList = continueSearch(request.getFilter(), request.getWithDomain());
 		resetSearchCache();
 	} else {
-		beginNewSearchAsync(filter, withDomain, asyncData);
+		beginNewSearchAsync(request, asyncData);
 	}
-	d->mFilter = filter;
+	d->mFilter = request.getFilter();
 	return asyncData->setSearchResults(returnList);
 }
 
-list<SearchResult> MagicSearch::processResults(std::shared_ptr<list<SearchResult>> pResultList) {
-   uniqueItemsList(*pResultList.get());
-   setSearchCache(pResultList);
-   return getLastSearch();
+static int compareStringItems(const char *a, const char *b) {
+	if (a == nullptr) a = "";
+	if (b == nullptr) b = "";
+	return strcasecmp(a, b);
 }
 
-std::list<SearchResult> MagicSearch::getLastSearch()const{
+static void sortResultsList(std::shared_ptr<list<std::shared_ptr<SearchResult>>> resultList) {
+	lDebug() << "[Magic Search] Sorting " << resultList->size() << " results";
+	resultList->sort([](const std::shared_ptr<SearchResult>& lsr, const std::shared_ptr<SearchResult>& rsr) {
+		const char* name1 = lsr->getDisplayName();
+		const char* name2 = rsr->getDisplayName();
+		int nameComp = compareStringItems(name1, name2);
+
+		// Check in order: Friend's display name, address username, address domain, phone number
+		if (nameComp == 0) {
+			if (lsr->getAddress() && rsr->getAddress()) {
+				int usernameComp = compareStringItems(linphone_address_get_username(lsr->getAddress()), linphone_address_get_username(rsr->getAddress()));
+				if (usernameComp == 0) {
+					int domainComp = compareStringItems(linphone_address_get_domain(lsr->getAddress()), linphone_address_get_domain(rsr->getAddress()));
+					if (domainComp == 0) {
+						if (!lsr->getPhoneNumber().empty() && !rsr->getPhoneNumber().empty()) {
+							int phoneComp = strcmp(lsr->getPhoneNumber().c_str(), rsr->getPhoneNumber().c_str());
+							if (phoneComp == 0) {
+								return true;
+							} else {
+								return phoneComp < 0;
+							}
+						}
+					} else {
+						return domainComp < 0;
+					}
+				} else {
+					return usernameComp < 0;
+				}
+			}
+		}
+
+		return nameComp < 0;
+	});
+}
+
+static void sortResultsByFriendInList(std::shared_ptr<list<std::shared_ptr<SearchResult>>> resultList) {
+	lDebug() << "[Magic Search] Sorting " << resultList->size() << " results by Friend";
+	resultList->sort([](const std::shared_ptr<SearchResult>& lsr, const std::shared_ptr<SearchResult>& rsr) {
+		const char* name1 = linphone_friend_get_name(lsr->getFriend());
+		const char* name2 = linphone_friend_get_name(rsr->getFriend());
+		int nameComp = compareStringItems(name1, name2);
+		return nameComp < 0;
+	});
+}
+
+list<std::shared_ptr<SearchResult>> MagicSearch::processResults(std::shared_ptr<list<std::shared_ptr<SearchResult>>> pResultList) {
 	L_D();
-	list<SearchResult> returnList = *getSearchCache();
+
+	if (d->mAsyncData.mSearchRequest.getAggregation() == LinphoneMagicSearchAggregationFriend) {
+		sortResultsByFriendInList(pResultList);
+		uniqueFriendsInList(pResultList);
+	}
+
+	sortResultsList(pResultList);
+	uniqueItemsList(pResultList);
+	setSearchCache(pResultList);
+	
+   	return getLastSearch();
+}
+
+std::list<std::shared_ptr<SearchResult>> MagicSearch::getLastSearch() const {
+	L_D();
+	list<std::shared_ptr<SearchResult>> returnList = *getSearchCache();
 	LinphoneProxyConfig *proxy = nullptr;
 	if (getLimitedSearch() && returnList.size() > getSearchLimit()) {
 		auto limitIterator = returnList.begin();
@@ -255,17 +323,18 @@ std::list<SearchResult> MagicSearch::getLastSearch()const{
 		returnList.erase(limitIterator, returnList.end());
 	}
 
-	if (!d->mFilter.empty()) {
+	if (!d->mFilter.empty() && ((d->mAsyncData.mSearchRequest.getSourceFlags() & LinphoneMagicSearchSourceRequest) == LinphoneMagicSearchSourceRequest)) {
 		proxy = linphone_core_get_default_proxy_config(this->getCore()->getCCore());
 		// Adding last item if proxy exist
 		if (proxy) {
 			const char *domain = linphone_proxy_config_get_domain(proxy);
 			if (domain) {
 				string strTmp = d->mFilter;
+				setlocale(LC_ALL, "");
 				transform(strTmp.begin(), strTmp.end(), strTmp.begin(), [](unsigned char c){ return tolower(c); });
 				LinphoneAddress *lastResult = linphone_core_interpret_url(this->getCore()->getCCore(), strTmp.c_str());
 				if (lastResult) {
-					returnList.push_back(SearchResult(0, lastResult, "", nullptr));
+					returnList.push_back(SearchResult::create((unsigned int)0, lastResult, "", nullptr, LinphoneMagicSearchSourceRequest));
 					linphone_address_unref(lastResult);
 				}
 			}
@@ -273,35 +342,31 @@ std::list<SearchResult> MagicSearch::getLastSearch()const{
 	}
 	return returnList;
 }
+
 void MagicSearch::setAutoResetCache(const bool_t& enable){
 	L_D();
 	d->mAutoResetCache = enable;
 }
-static int compareStringItems(const char *a, const char *b) {
-	if (a == nullptr) a = "";
-	if (b == nullptr) b = "";
-	return strcmp(a, b);
-}
 
 /////////////////////
 // Private Methods //
 /////////////////////
 
-std::shared_ptr<list<SearchResult> > MagicSearch::getSearchCache () const {
+std::shared_ptr<list<std::shared_ptr<SearchResult>> > MagicSearch::getSearchCache () const {
 	L_D();
 	return d->mCacheResult;
 }
 
-void MagicSearch::setSearchCache (std::shared_ptr<list<SearchResult>> cache) {
+void MagicSearch::setSearchCache (std::shared_ptr<list<std::shared_ptr<SearchResult>>> cache) {
 	L_D();
 	if (d->mCacheResult != cache)
 		d->mCacheResult = cache;
 }
 
-static bool findAddress (const list<SearchResult> &list, const LinphoneAddress *addr) {
+static bool findAddress (const list<std::shared_ptr<SearchResult>> &list, const LinphoneAddress *addr) {
 	for (auto r : list) {
-		if (r.getAddress()) {
-			if (linphone_address_weak_equal(r.getAddress(), addr)) {
+		if (r->getAddress()) {
+			if (linphone_address_weak_equal(r->getAddress(), addr)) {
 				return true;
 			}
 		}
@@ -309,12 +374,12 @@ static bool findAddress (const list<SearchResult> &list, const LinphoneAddress *
 	return false;
 }
 
-list<SearchResult> MagicSearch::getAddressFromCallLog (
+list<std::shared_ptr<SearchResult>> MagicSearch::getAddressFromCallLog (
 	const string &filter,
 	const string &withDomain,
-	const list<SearchResult> &currentList
+	const list<std::shared_ptr<SearchResult>> &currentList
 ) const {
-	list<SearchResult> resultList;
+	list<std::shared_ptr<SearchResult>> resultList;
 	const bctbx_list_t *callLog = linphone_core_get_call_logs(this->getCore()->getCCore());
 
 	// For all call log or when we reach the search limit
@@ -325,26 +390,27 @@ list<SearchResult> MagicSearch::getAddressFromCallLog (
 		if (addr && linphone_call_log_get_status(log) != LinphoneCallAborted) {
 			if (filter.empty() && withDomain.empty()) {
 				if (findAddress(currentList, addr)) continue;
-				resultList.push_back(SearchResult(0, addr, "", nullptr));
+				resultList.push_back(SearchResult::create((unsigned int)0, addr, "", nullptr, LinphoneMagicSearchSourceCallLogs));
 			} else {
 				unsigned int weight = searchInAddress(addr, filter, withDomain);
 				if (weight > getMinWeight()) {
 					if (findAddress(currentList, addr)) continue;
-					resultList.push_back(SearchResult(weight, addr, "", nullptr));
+					resultList.push_back(SearchResult::create(weight, addr, "", nullptr, LinphoneMagicSearchSourceCallLogs));
 				}
 			}
 		}
 	}
 
+	lInfo() << "[Magic Search] Found " << resultList.size() << " results in call logs";
 	return resultList;
 }
 
-list<SearchResult> MagicSearch::getAddressFromGroupChatRoomParticipants (
+list<std::shared_ptr<SearchResult>> MagicSearch::getAddressFromGroupChatRoomParticipants (
 	const string &filter,
 	const string &withDomain,
-	const list<SearchResult> &currentList
+	const list<std::shared_ptr<SearchResult>> &currentList
 ) const {
-	list<SearchResult> resultList;
+	list<std::shared_ptr<SearchResult>> resultList;
 	const bctbx_list_t *chatRooms = linphone_core_get_chat_rooms(this->getCore()->getCCore());
 
 	// For all call log or when we reach the search limit
@@ -356,13 +422,19 @@ list<SearchResult> MagicSearch::getAddressFromGroupChatRoomParticipants (
 				LinphoneParticipant *participant = static_cast<LinphoneParticipant*>(p->data);
 				const LinphoneAddress *addr = linphone_address_clone(linphone_participant_get_address(participant));
 				if (filter.empty() && withDomain.empty()) {
-					if (findAddress(currentList, addr)) continue;
-					resultList.push_back(SearchResult(0, addr, "", nullptr));
+					if (findAddress(currentList, addr)) {
+						linphone_address_unref(const_cast<LinphoneAddress *>(addr));
+						continue;
+					}
+					resultList.push_back(SearchResult::create((unsigned int)0, addr, "", nullptr, LinphoneMagicSearchSourceChatRooms));
 				} else {
 					unsigned int weight = searchInAddress(addr, filter, withDomain);
 					if (weight > getMinWeight()) {
-						if (findAddress(currentList, addr)) continue;
-						resultList.push_back(SearchResult(weight, addr, "", nullptr));
+						if (findAddress(currentList, addr)) {
+							linphone_address_unref(const_cast<LinphoneAddress *>(addr));
+							continue;
+						}
+						resultList.push_back(SearchResult::create(weight, addr, "", nullptr, LinphoneMagicSearchSourceChatRooms));
 					}
 				}
 				if (addr) {
@@ -371,21 +443,31 @@ list<SearchResult> MagicSearch::getAddressFromGroupChatRoomParticipants (
 			}
 			bctbx_list_free_with_data(participants, (bctbx_list_free_func)linphone_participant_unref);
 		} else if (linphone_chat_room_get_capabilities(room) & LinphoneChatRoomCapabilitiesBasic) {
-			LinphoneAddress *addr = linphone_address_clone(linphone_chat_room_get_peer_address(room));
-			if (filter.empty()) {
-				if (findAddress(currentList, addr)) continue;
-				resultList.push_back(SearchResult(0, addr, "", nullptr));
-			} else {
-				unsigned int weight = searchInAddress(addr, filter, withDomain);
-				if (weight > getMinWeight()) {
-					if (findAddress(currentList, addr)) continue;
-					resultList.push_back(SearchResult(weight, addr, "", nullptr));
+			const LinphoneAddress* peerAddress = linphone_chat_room_get_peer_address(room);// Can return NULL if getPeerAddress() is not valid
+			if( peerAddress){
+				LinphoneAddress *addr = linphone_address_clone(peerAddress);
+				if (filter.empty()) {
+					if (findAddress(currentList, addr)) {
+						linphone_address_unref(addr);		
+						continue;
+					}
+					resultList.push_back(SearchResult::create((unsigned int)0, addr, "", nullptr, LinphoneMagicSearchSourceChatRooms));
+				} else {
+					unsigned int weight = searchInAddress(addr, filter, withDomain);
+					if (weight > getMinWeight()) {
+						if (findAddress(currentList, addr)) {
+							linphone_address_unref(addr);
+							continue;
+						}
+						resultList.push_back(SearchResult::create(weight, addr, "", nullptr, LinphoneMagicSearchSourceChatRooms));
+					}
 				}
+				linphone_address_unref(addr);
 			}
-			linphone_address_unref(addr);
 		}
 	}
 
+	lInfo() << "[Magic Search] Found " << resultList.size() << " results in chat rooms";
 	return resultList;
 }
 
@@ -395,7 +477,6 @@ void MagicSearch::getAddressFromLDAPServerStartAsync (
 	const string &withDomain,
 	SearchAsyncData * asyncData
 )const {
-	std::string predicate = (filter.empty()?"*":filter);
 	std::vector<std::shared_ptr<LdapContactProvider> > providers = LdapContactProvider::create(this->getCore());
 // Requests
 	for(size_t i = 0 ; i < providers.size() ; ++i){
@@ -407,7 +488,7 @@ void MagicSearch::getAddressFromLDAPServerStartAsync (
 			data->mParent = this;
 			data->mFilter = filter;
 			data->mWithDomain = withDomain;
-			data->mProvider->search(predicate, LdapCbData::resultsCb, data.get());
+			data->mEnd = !data->mProvider->search(filter, LdapCbData::resultsCb, data.get(), asyncData->getRequestHistory());
 		}else
 			data->mEnd = TRUE;
 		asyncData->pushData(data);
@@ -436,12 +517,15 @@ bool MagicSearch::getAddressIsEndAsync(SearchAsyncData* asyncData)const{
 #ifdef LDAP_ENABLED
 // Synchronous search by iterate directly on main loop if there are async processes
 // Provided for convenience
-std::list<list<SearchResult>> MagicSearch::getAddressFromLDAPServer (
+std::list<list<std::shared_ptr<SearchResult>>> MagicSearch::getAddressFromLDAPServer (
 	const string &filter,
 	const string &withDomain
 ) {
 	SearchAsyncData asyncData;
 // Start async search
+	SearchRequest request(filter, withDomain, LinphoneMagicSearchSourceAll, LinphoneMagicSearchAggregationNone);
+	asyncData.pushRequest(request);
+	asyncData.setSearchRequest(request);
 	getAddressFromLDAPServerStartAsync(filter, withDomain, &asyncData);
 	asyncData.initStartTime();
 // Loop in core iterate till having all (good/bad) results
@@ -453,158 +537,92 @@ std::list<list<SearchResult>> MagicSearch::getAddressFromLDAPServer (
 #endif
 
 // List all searchs to be done. Provider order will prioritize results : next contacts will be removed if already exist in results
-void MagicSearch::beginNewSearchAsync (const string &filter, const string &withDomain, SearchAsyncData * asyncData) const{
-	const bctbx_list_t *friend_lists = linphone_core_get_friends_lists(this->getCore()->getCCore());
+void MagicSearch::beginNewSearchAsync (const SearchRequest& request, SearchAsyncData * asyncData) const{
 	asyncData->clear();
-	list<SearchResult> friendsList;
-	for (const bctbx_list_t *fl = friend_lists ; fl != nullptr ; fl = bctbx_list_next(fl)) {
-		LinphoneFriendList *fList = static_cast<LinphoneFriendList*>(fl->data);
-		// For all friends or when we reach the search limit
-		for (bctbx_list_t *f = fList->friends ; f != nullptr ; f = bctbx_list_next(f)) {
-			list<SearchResult> fResults = searchInFriend(static_cast<LinphoneFriend*>(f->data), filter, withDomain);
-			addResultsToResultsList(fResults, friendsList);
+	asyncData->setSearchRequest(request);
+	if( (request.getSourceFlags() & LinphoneMagicSearchSourceFriends) == LinphoneMagicSearchSourceFriends){
+		const bctbx_list_t *friend_lists = linphone_core_get_friends_lists(this->getCore()->getCCore());
+		list<std::shared_ptr<SearchResult>> friendsList;
+		for (const bctbx_list_t *fl = friend_lists ; fl != nullptr ; fl = bctbx_list_next(fl)) {
+			LinphoneFriendList *fList = static_cast<LinphoneFriendList*>(fl->data);
+			// For all friends or when we reach the search limit
+			for (bctbx_list_t *f = fList->friends ; f != nullptr ; f = bctbx_list_next(f)) {
+				list<std::shared_ptr<SearchResult>> fResults = searchInFriend(static_cast<LinphoneFriend*>(f->data), request.getFilter(), request.getWithDomain());
+				addResultsToResultsList(fResults, friendsList);
+			}
 		}
+		lInfo() << "[Magic Search] Found " << friendsList.size() << " results in friends";
+		asyncData->createResult(friendsList);
 	}
-	asyncData->createResult(friendsList);
 #ifdef LDAP_ENABLED
-	getAddressFromLDAPServerStartAsync(filter, withDomain, asyncData);
+	if( (request.getSourceFlags() & LinphoneMagicSearchSourceLdapServers) == LinphoneMagicSearchSourceLdapServers && linphone_core_is_network_reachable(this->getCore()->getCCore()))
+		getAddressFromLDAPServerStartAsync(request.getFilter(), request.getWithDomain(), asyncData);
 #endif
-	asyncData->createResult(getAddressFromCallLog(filter, withDomain, list<SearchResult>()));
-	asyncData->createResult(getAddressFromGroupChatRoomParticipants(filter, withDomain, list<SearchResult>()));
+	if( (request.getSourceFlags() & LinphoneMagicSearchSourceCallLogs) == LinphoneMagicSearchSourceCallLogs)
+		asyncData->createResult(getAddressFromCallLog(request.getFilter(), request.getWithDomain(), list<std::shared_ptr<SearchResult>>()));
+	if( (request.getSourceFlags() & LinphoneMagicSearchSourceChatRooms) == LinphoneMagicSearchSourceChatRooms)
+		asyncData->createResult(getAddressFromGroupChatRoomParticipants(request.getFilter(), request.getWithDomain(), list<std::shared_ptr<SearchResult>>()));
 }
 
-void MagicSearch::mergeResults (const std::string& filter, const std::string withDomain, SearchAsyncData * asyncData) {
-	std::shared_ptr<list<SearchResult>> resultList = std::make_shared<list<SearchResult>>();
+void MagicSearch::mergeResults (const SearchRequest& request, SearchAsyncData * asyncData) {
+	std::shared_ptr<list<std::shared_ptr<SearchResult>>> resultList = std::make_shared<list<std::shared_ptr<SearchResult>>>();
 	for(auto it = asyncData->mProviderResults.begin() ; it != asyncData->mProviderResults.end() ; ++it){
-		addResultsToResultsList(*it, *resultList, filter, withDomain);
+		addResultsToResultsList(*it, *resultList, request.getFilter(), request.getWithDomain());
 	}
-	resultList->sort([](const SearchResult& lsr, const SearchResult& rsr) {
-		string name1 = getDisplayNameFromSearchResult(lsr);
-		string name2 = getDisplayNameFromSearchResult(rsr);
-
-		// Check in order: Friend's display name, address username, address domain, phone number
-		if (name1 == name2) {
-			if (lsr.getAddress() && rsr.getAddress()) {
-				int usernameComp = compareStringItems(linphone_address_get_username(lsr.getAddress()), linphone_address_get_username(rsr.getAddress()));
-				if (usernameComp == 0) {
-					int domainComp = compareStringItems(linphone_address_get_domain(lsr.getAddress()), linphone_address_get_domain(rsr.getAddress()));
-					if (domainComp == 0) {
-						if (!lsr.getPhoneNumber().empty() && !rsr.getPhoneNumber().empty()) {
-							int phoneComp = strcmp(lsr.getPhoneNumber().c_str(), rsr.getPhoneNumber().c_str());
-							if (phoneComp == 0) {
-								return true;
-							} else {
-								return phoneComp < 0;
-							}
-						}
-					} else {
-						return domainComp < 0;
-					}
-				} else {
-					return usernameComp < 0;
-				}
-			}
-		}
-		unsigned int cpt = 0;
-		while (name1.size() > cpt && name2.size() > cpt) {
-			int char1 = tolower(name1.at(cpt));
-			int char2 = tolower(name2.at(cpt));
-			if (char1 < char2) {
-				return true;
-			} else if (char1 > char2) {
-				return false;
-			}
-			cpt++;
-		}
-		return name1.size() < name2.size();
-	});
 	asyncData->setSearchResults(resultList);
 }
 
-std::shared_ptr<list<SearchResult>> MagicSearch::beginNewSearch (const string &filter, const string &withDomain) {
-	list<SearchResult> clResults, crResults;
-	list<list<SearchResult>> multiClResults;
-	std::shared_ptr<list<SearchResult>> resultList = std::make_shared<list<SearchResult>>();
-	const bctbx_list_t *friend_lists = linphone_core_get_friends_lists(this->getCore()->getCCore());
+std::shared_ptr<list<std::shared_ptr<SearchResult>>> MagicSearch::beginNewSearch (const string &filter, const string &withDomain, int sourceFlags) {
+	list<std::shared_ptr<SearchResult>> clResults, crResults;
+	list<list<std::shared_ptr<SearchResult>>> multiClResults;
+	std::shared_ptr<list<std::shared_ptr<SearchResult>>> resultList = std::make_shared<list<std::shared_ptr<SearchResult>>>();
+	
+	if( (sourceFlags & LinphoneMagicSearchSourceFriends) == LinphoneMagicSearchSourceFriends){
+		const bctbx_list_t *friend_lists = linphone_core_get_friends_lists(this->getCore()->getCCore());
 
-	for (const bctbx_list_t *fl = friend_lists ; fl != nullptr ; fl = bctbx_list_next(fl)) {
-		LinphoneFriendList *fList = static_cast<LinphoneFriendList*>(fl->data);
-		// For all friends or when we reach the search limit
-		for (bctbx_list_t *f = fList->friends ; f != nullptr ; f = bctbx_list_next(f)) {
-			list<SearchResult> fResults = searchInFriend(static_cast<LinphoneFriend*>(f->data), filter, withDomain);
-			addResultsToResultsList(fResults, *resultList);
+		for (const bctbx_list_t *fl = friend_lists ; fl != nullptr ; fl = bctbx_list_next(fl)) {
+			LinphoneFriendList *fList = static_cast<LinphoneFriendList*>(fl->data);
+			// For all friends or when we reach the search limit
+			for (bctbx_list_t *f = fList->friends ; f != nullptr ; f = bctbx_list_next(f)) {
+				list<std::shared_ptr<SearchResult>> fResults = searchInFriend(static_cast<LinphoneFriend*>(f->data), filter, withDomain);
+				addResultsToResultsList(fResults, *resultList);
+			}
 		}
 	}
 #ifdef LDAP_ENABLED
-	multiClResults = getAddressFromLDAPServer(filter, withDomain);
-	for(auto it = multiClResults.begin() ; it != multiClResults.end() ; ++it)
-		addResultsToResultsList(*it, *resultList, filter, withDomain);
+	if( (sourceFlags & LinphoneMagicSearchSourceLdapServers) == LinphoneMagicSearchSourceLdapServers && linphone_core_is_network_reachable(this->getCore()->getCCore())){
+		multiClResults = getAddressFromLDAPServer(filter, withDomain);
+		for(auto it = multiClResults.begin() ; it != multiClResults.end() ; ++it)
+			addResultsToResultsList(*it, *resultList, filter, withDomain);
+	}
 #endif
-	clResults = getAddressFromCallLog(filter, withDomain, *resultList);
-	addResultsToResultsList(clResults, *resultList);
-	crResults = getAddressFromGroupChatRoomParticipants(filter, withDomain, *resultList);
-	addResultsToResultsList(crResults, *resultList);
-
-	resultList->sort([](const SearchResult& lsr, const SearchResult& rsr) {
-		string name1 = getDisplayNameFromSearchResult(lsr);
-		string name2 = getDisplayNameFromSearchResult(rsr);
-
-		// Check in order: Friend's display name, address username, address domain, phone number
-		if (name1 == name2) {
-			if (lsr.getAddress() && rsr.getAddress()) {
-				int usernameComp = compareStringItems(linphone_address_get_username(lsr.getAddress()), linphone_address_get_username(rsr.getAddress()));
-				if (usernameComp == 0) {
-					int domainComp = compareStringItems(linphone_address_get_domain(lsr.getAddress()), linphone_address_get_domain(rsr.getAddress()));
-					if (domainComp == 0) {
-						if (!lsr.getPhoneNumber().empty() && !rsr.getPhoneNumber().empty()) {
-							int phoneComp = strcmp(lsr.getPhoneNumber().c_str(), rsr.getPhoneNumber().c_str());
-							if (phoneComp == 0) {
-								return true;
-							} else {
-								return phoneComp < 0;
-							}
-						}
-					} else {
-						return domainComp < 0;
-					}
-				} else {
-					return usernameComp < 0;
-				}
-			}
-		}
-
-		unsigned int cpt = 0;
-		while (name1.size() > cpt && name2.size() > cpt) {
-			int char1 = tolower(name1.at(cpt));
-			int char2 = tolower(name2.at(cpt));
-			if (char1 < char2) {
-				return true;
-			} else if (char1 > char2) {
-				return false;
-			}
-			cpt++;
-		}
-		return name1.size() < name2.size();
-	});
+	if( (sourceFlags & LinphoneMagicSearchSourceCallLogs) == LinphoneMagicSearchSourceCallLogs){
+		clResults = getAddressFromCallLog(filter, withDomain, *resultList);
+		addResultsToResultsList(clResults, *resultList);
+	}
+	if( (sourceFlags & LinphoneMagicSearchSourceChatRooms) == LinphoneMagicSearchSourceChatRooms){
+		crResults = getAddressFromGroupChatRoomParticipants(filter, withDomain, *resultList);
+		addResultsToResultsList(crResults, *resultList);
+	}
 
 	return resultList;
 }
 
-std::shared_ptr<list<SearchResult>> MagicSearch::continueSearch (const string &filter, const string &withDomain) const {
-	std::shared_ptr<list<SearchResult>> resultList = std::make_shared<list<SearchResult>>();
-	const std::shared_ptr<list <SearchResult>> cacheList = getSearchCache();
+std::shared_ptr<list<std::shared_ptr<SearchResult>>> MagicSearch::continueSearch (const string &filter, const string &withDomain) const {
+	std::shared_ptr<list<std::shared_ptr<SearchResult>>> resultList = std::make_shared<list<std::shared_ptr<SearchResult>>>();
+	const std::shared_ptr<list<std::shared_ptr<SearchResult>>> cacheList = getSearchCache();
 
 	const LinphoneFriend *previousFriend = nullptr;
 	for (const auto &sr : *cacheList) {
-		if (sr.getAddress() || !sr.getPhoneNumber().empty()) {
-			if (sr.getFriend() && (!previousFriend || sr.getFriend() != previousFriend)) {
-				list<SearchResult> results = searchInFriend(sr.getFriend(), filter, withDomain);
+		if (sr->getAddress() || !sr->getPhoneNumber().empty()) {
+			if (sr->getFriend() && (!previousFriend || sr->getFriend() != previousFriend)) {
+				list<std::shared_ptr<SearchResult>> results = searchInFriend(sr->getFriend(), filter, withDomain);
 				addResultsToResultsList(results, *resultList);
-				previousFriend = sr.getFriend();
-			} else if (!sr.getFriend()) {
-				unsigned int weight = searchInAddress(sr.getAddress(), filter, withDomain);
+				previousFriend = sr->getFriend();
+			} else if (!sr->getFriend()) {
+				unsigned int weight = searchInAddress(sr->getAddress(), filter, withDomain);
 				if (weight > getMinWeight()) {
-					resultList->push_back(SearchResult(weight, sr.getAddress(), sr.getPhoneNumber(), nullptr));
+					resultList->push_back(SearchResult::create(weight, sr->getAddress(), sr->getPhoneNumber(), nullptr, sr->getSourceFlags()));
 				}
 			}
 		}
@@ -613,8 +631,8 @@ std::shared_ptr<list<SearchResult>> MagicSearch::continueSearch (const string &f
 	return resultList;
 }
 
-list<SearchResult> MagicSearch::searchInFriend (const LinphoneFriend *lFriend, const string &filter, const string &withDomain) const{
-	list<SearchResult> friendResult;
+list<std::shared_ptr<SearchResult>> MagicSearch::searchInFriend (const LinphoneFriend *lFriend, const string &filter, const string &withDomain) const{
+	list<std::shared_ptr<SearchResult>> friendResult;
 	string phoneNumber = "";
 	unsigned int weight = getMinWeight();
 
@@ -642,7 +660,7 @@ list<SearchResult> MagicSearch::searchInFriend (const LinphoneFriend *lFriend, c
 		unsigned int weightAddress = searchInAddress(lAddress, filter, withDomain) * 1;
 
 		if ((weightAddress + weight) > getMinWeight()) {
-			friendResult.push_back(SearchResult(weight + weightAddress, lAddress, phoneNumber, lFriend));
+			friendResult.push_back(SearchResult::create(weight + weightAddress, lAddress, phoneNumber, lFriend, LinphoneMagicSearchSourceFriends));
 		}
 	}
 
@@ -670,7 +688,7 @@ list<SearchResult> MagicSearch::searchInFriend (const LinphoneFriend *lFriend, c
 					if (withDomain.empty() || withDomain == "*" || compareStringItems(linphone_address_get_domain(tmpAdd), withDomain.c_str()) == 0) {
 						weightNumber += getWeight(contact, filter) * 2;
 						if ((weightNumber + weight) > getMinWeight()) {
-							friendResult.push_back(SearchResult(weight + weightNumber, tmpAdd, phoneNumber, lFriend));
+							friendResult.push_back(SearchResult::create(weight + weightNumber, tmpAdd, phoneNumber, lFriend, LinphoneMagicSearchSourceFriends));
 						}
 						linphone_address_unref(tmpAdd);
 						bctbx_free(contact);
@@ -679,7 +697,7 @@ list<SearchResult> MagicSearch::searchInFriend (const LinphoneFriend *lFriend, c
 			}
 		} else {
 			if ((weightNumber + weight) > getMinWeight() && withDomain.empty()) {
-				friendResult.push_back(SearchResult(weight + weightNumber, nullptr, phoneNumber, lFriend));
+				friendResult.push_back(SearchResult::create(weight + weightNumber, nullptr, phoneNumber, lFriend, LinphoneMagicSearchSourceFriends));
 			}
 		}
 		phoneNumbers = phoneNumbers->next;
@@ -706,6 +724,7 @@ unsigned int MagicSearch::searchInAddress (const LinphoneAddress *lAddress, cons
 
 unsigned int MagicSearch::getWeight (const string &stringWords, const string &filter) const {
 	locale loc;
+	setlocale(LC_ALL, "");
 	string filterLC = filter;
 	string stringWordsLC = stringWords;
 	size_t weight = string::npos;
@@ -772,37 +791,55 @@ bool MagicSearch::checkDomain (const LinphoneFriend *lFriend, const LinphoneAddr
 	return soFarSoGood;
 }
 
-void MagicSearch::addResultsToResultsList (std::list<SearchResult> &results, std::list<SearchResult> &srL) const {
+void MagicSearch::addResultsToResultsList (std::list<std::shared_ptr<SearchResult>> &results, std::list<std::shared_ptr<SearchResult>> &srL) const {
 	if (!results.empty()) {
 		srL.splice(srL.end(), results);
 	}
 }
 
-void MagicSearch::addResultsToResultsList (std::list<SearchResult> &results, std::list<SearchResult> &srL, const std::string filter, const std::string& withDomain) const {
-	results.remove_if(
-				[srL](SearchResult n){ return findAddress(srL, n.getAddress()); }
-				);
+void MagicSearch::addResultsToResultsList (std::list<std::shared_ptr<SearchResult>> &results, std::list<std::shared_ptr<SearchResult>> &srL, const std::string filter, const std::string& withDomain) const {
+	auto itResult = results.begin();
+	while(itResult != results.end()){// Merge addresses that are already in srL
+		const LinphoneAddress * addr = (*itResult)->getAddress();
+		auto srLAddress = std::find_if(srL.begin(), srL.end(), [addr](const std::shared_ptr<SearchResult>& r){
+									return r->getAddress() && linphone_address_weak_equal(r->getAddress(), addr);
+							});
+		if( srLAddress != srL.end()){
+			(*srLAddress)->merge(*itResult);
+			itResult = results.erase(itResult);
+		}else
+			++itResult;
+	}
 	if (!results.empty()) {
 		srL.splice(srL.end(), results);
 	}
 }
 
-void MagicSearch::uniqueItemsList (list<SearchResult> &list) const {
-	list.unique([](const SearchResult& lsr, const SearchResult& rsr){
+void MagicSearch::uniqueItemsList (std::shared_ptr<list<std::shared_ptr<SearchResult>>> list) const {
+	lDebug() << "[Magic Search] List size before unique = " << list->size();
+	list->unique([](const std::shared_ptr<SearchResult>& lsr, const std::shared_ptr<SearchResult>& rsr){
 		bool sip_addresses = false;
-		const LinphoneAddress *left = lsr.getAddress();
-		const LinphoneAddress *right = rsr.getAddress();
+		const LinphoneAddress *left = lsr->getAddress();
+		const LinphoneAddress *right = rsr->getAddress();
 		if (left == nullptr && right == nullptr) {
 			sip_addresses = true;
 		} else if (left != nullptr && right != nullptr) {
 			sip_addresses = linphone_address_weak_equal(left, right);
 		}
-
-		bool phone_numbers = lsr.getPhoneNumber() == rsr.getPhoneNumber();
-		bool capabilities = lsr.getCapabilities() == rsr.getCapabilities();
-
-		return sip_addresses && phone_numbers && capabilities;
+		return sip_addresses 
+				&& lsr->getCapabilities() == rsr->getCapabilities() 
+				&& lsr->getPhoneNumber() == rsr->getPhoneNumber() 
+				&& (compareStringItems(lsr->getDisplayName(), rsr->getDisplayName()) == 0);
 	});
+	lDebug() << "[Magic Search] List size after unique = " << list->size();
+}
+
+void MagicSearch::uniqueFriendsInList (std::shared_ptr<list<std::shared_ptr<SearchResult>>> list) const {
+	lDebug() << "[Magic Search] List size before friend unique = " << list->size();
+	list->unique([](const std::shared_ptr<SearchResult>& lsr, const std::shared_ptr<SearchResult>& rsr){
+		return lsr->getFriend() == rsr->getFriend();
+	});
+	lDebug() << "[Magic Search] List size after friend unique = " << list->size();
 }
 
 LINPHONE_END_NAMESPACE
