@@ -1,23 +1,24 @@
 /*
-	liblinphone_tester - liblinphone test suite
-	Copyright (C) 2013  Belledonne Communications SARL
-
-	This program is free software: you can redistribute it and/or modify
-	it under the terms of the GNU General Public License as published by
-	the Free Software Foundation, either version 2 of the License, or
-	(at your option) any later version.
-
-	This program is distributed in the hope that it will be useful,
-	but WITHOUT ANY WARRANTY; without even the implied warranty of
-	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-	GNU General Public License for more details.
-
-	You should have received a copy of the GNU General Public License
-	along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+ * Copyright (c) 2010-2019 Belledonne Communications SARL.
+ *
+ * This file is part of Liblinphone.
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ */
 
 #include "liblinphone_tester.h"
-#include "private.h"
+#include "tester_utils.h"
 #include "audio_bypass_wav_header.h" // This is a copy of mediastreamer2/src/audiofilters/wav_header.h
 
 /**********************************************************************
@@ -68,9 +69,7 @@ int audio_bypass_read_wav_header_from_fd(wave_header_t *header,int fd){
 	format_t *format_chunk=&header->format_chunk;
 	data_t *data_chunk=&header->data_chunk;
 
-	unsigned long len=0;
-
-	len = read(fd, (char*)riff_chunk, sizeof(riff_t)) ;
+	ssize_t len = read(fd, (char*)riff_chunk, sizeof(riff_t)) ;
 	if (len != sizeof(riff_t)){
 		goto not_a_wav;
 	}
@@ -85,7 +84,7 @@ int audio_bypass_read_wav_header_from_fd(wave_header_t *header,int fd){
 		goto not_a_wav;
 	}
 
-	if ((skip=le_uint32(format_chunk->len)-0x10)>0)
+	if ((skip=(int)le_uint32(format_chunk->len)-0x10)>0)
 	{
 		lseek(fd,skip,SEEK_CUR);
 	}
@@ -158,7 +157,7 @@ static void audio_bypass_snd_read_preprocess(MSFilter *f) {
 	return;
 }
 
-static void swap_bytes(unsigned char *bytes, int len){
+static void swap_bytes(unsigned char *bytes, ssize_t len){
 	int i;
 	unsigned char tmp;
 	for(i=0;i<len;i+=2){
@@ -171,7 +170,7 @@ static void swap_bytes(unsigned char *bytes, int len){
 static void audio_bypass_snd_read_process(MSFilter *f) {
 	PlayerData *d=(PlayerData*)f->data;
 	int nsamples=(f->ticker->interval*d->rate*d->nchannels)/1000;
-	int bytes;
+	ssize_t bytes;
 	/*send an even number of samples each tick. At 22050Hz the number of samples per 10 ms chunk is odd.
 	Odd size buffer of samples cause troubles to alsa. Fixing in alsa is difficult, so workaround here.
 	*/
@@ -186,7 +185,7 @@ static void audio_bypass_snd_read_process(MSFilter *f) {
 	ms_filter_lock(f);
 	if (d->state==MSPlayerPlaying){
 		{
-			int err;
+			ssize_t err;
 			mblk_t *om=allocb(bytes,0);
 			if (d->pause_time>0){
 				err=bytes;
@@ -223,7 +222,7 @@ static void audio_bypass_snd_read_process(MSFilter *f) {
 					}
 				}
 			}else{
-				ms_warning("Fail to read %i bytes: %s",bytes,strerror(errno));
+				ms_warning("Fail to read %zi bytes: %s",bytes,strerror(errno));
 			}
 		}
 	}
@@ -386,6 +385,8 @@ static MSFilter* audio_bypass_snd_card_create_writer(MSSndCard *sndcard) {
 
 static void audio_bypass_snd_card_detect(MSSndCardManager *m);
 
+#define AUDIO_BYPASS_SOUNDCARD "audioBypass: audio bypass sound card"
+
 MSSndCardDesc audio_bypass_snd_card_desc = {
 	"audioBypass",
 	audio_bypass_snd_card_detect,
@@ -406,6 +407,7 @@ MSSndCardDesc audio_bypass_snd_card_desc = {
 static MSSndCard* create_audio_bypass_snd_card(void) {
 	MSSndCard* sndcard;
 	sndcard = ms_snd_card_new(&audio_bypass_snd_card_desc);
+	sndcard->id = ms_strdup(AUDIO_BYPASS_SOUNDCARD);
 	sndcard->data = NULL;
 	sndcard->name = ms_strdup("audio bypass sound card");
 	sndcard->capabilities = MS_SND_CARD_CAP_PLAYBACK | MS_SND_CARD_CAP_CAPTURE;
@@ -413,8 +415,6 @@ static MSSndCard* create_audio_bypass_snd_card(void) {
 	return sndcard;
 }
 
-#define AUDIO_BYPASS_SOUNDCARD "audioBypass: audio bypass sound card"
-
 static void audio_bypass_snd_card_detect(MSSndCardManager *m) {
 	ms_snd_card_manager_add_card(m, create_audio_bypass_snd_card());
 }
@@ -438,7 +438,7 @@ static void only_enable_payload(LinphoneCore *lc, const char *mime, int rate, in
  * This is important so that the audio comparison is succesful*/
 static void set_jitter_buffer_params(LinphoneCore *lc){
 	int jitter_buffer_ms = 300;
-	lp_config_set_int(lc->config, "rtp", "jitter_buffer_min_size", jitter_buffer_ms);
+	linphone_config_set_int(linphone_core_get_config(lc), "rtp", "jitter_buffer_min_size", jitter_buffer_ms);
 	linphone_core_set_audio_jittcomp(lc, jitter_buffer_ms);
 }
 
@@ -459,13 +459,15 @@ static void audio_bypass(void) {
 	double similar=1;
 	const double threshold = 0.85;
 
-	lp_config_set_string(marie_lc->config, "sound", "features", "None");
-	lp_config_set_string(pauline_lc->config, "sound", "features", "None");
+	linphone_config_set_string(linphone_core_get_config(marie_lc), "sound", "features", "None");
+	linphone_config_set_string(linphone_core_get_config(pauline_lc), "sound", "features", "None");
 
 	/*make sure the record file doesn't already exists, otherwise this test will append new samples to it*/
 	unlink(recordpath);
 
 	// Enable L16 audio codec
+	linphone_core_set_mtu(marie_lc, 4000);
+	linphone_core_set_mtu(pauline_lc, 4000);
 	only_enable_payload(marie_lc, "L16", 44100, 1);
 	only_enable_payload(pauline_lc, "L16", 44100, 1);
 
@@ -484,14 +486,14 @@ static void audio_bypass(void) {
 	BC_ASSERT_STRING_EQUAL(linphone_core_get_playback_device(pauline_lc), AUDIO_BYPASS_SOUNDCARD);
 
 	set_jitter_buffer_params(pauline_lc);
-	linphone_core_use_files(pauline_lc, TRUE);
+	linphone_core_set_use_files(pauline_lc, TRUE);
 	linphone_core_set_play_file(pauline_lc, NULL);
 	linphone_core_set_record_file(pauline_lc, recordpath);
 
 	call_ok = call(marie, pauline);
 	BC_ASSERT_TRUE(call_ok);
 	if (!call_ok) goto end;
-	
+
 
 	BC_ASSERT_STRING_EQUAL(linphone_call_params_get_used_audio_codec(linphone_call_get_current_params(linphone_core_get_current_call(marie_lc)))->mime_type, "L16");
 
