@@ -38,7 +38,8 @@ static void call_with_ice_in_ipv4_with_v6_enabled(void) {
 		marie = linphone_core_manager_new("marie_v4proxy_rc");
 		pauline = linphone_core_manager_new("pauline_v4proxy_rc");
 
-		_call_with_ice_base(marie,pauline,TRUE,TRUE,TRUE,TRUE);
+		_call_with_ice_base(marie,pauline,TRUE,TRUE,TRUE,TRUE,FALSE);
+		_call_with_ice_base(marie,pauline,TRUE,TRUE,TRUE,TRUE,TRUE);
 		linphone_core_manager_destroy(marie);
 		linphone_core_manager_destroy(pauline);
 	} else ms_warning("Test skipped, need both ipv6 and v4 available");
@@ -52,7 +53,8 @@ static void call_with_ice_ipv4_to_ipv6(void) {
 		marie = linphone_core_manager_new("marie_v4proxy_rc");
 		pauline = linphone_core_manager_new("pauline_tcp_rc");
 
-		_call_with_ice_base(marie,pauline,TRUE,TRUE,TRUE,TRUE);
+		_call_with_ice_base(marie,pauline,TRUE,TRUE,TRUE,TRUE,FALSE);
+		_call_with_ice_base(marie,pauline,TRUE,TRUE,TRUE,TRUE,TRUE);
 		linphone_core_manager_destroy(marie);
 		linphone_core_manager_destroy(pauline);
 	} else ms_warning("Test skipped, need both ipv6 and v4 available");
@@ -66,7 +68,8 @@ static void call_with_ice_ipv6_to_ipv4(void) {
 		marie = linphone_core_manager_new("marie_rc");
 		pauline = linphone_core_manager_new("pauline_v4proxy_rc");
 
-		_call_with_ice_base(marie, pauline,TRUE,TRUE,TRUE,TRUE);
+		_call_with_ice_base(marie, pauline,TRUE,TRUE,TRUE,TRUE,FALSE);
+		_call_with_ice_base(marie, pauline,TRUE,TRUE,TRUE,TRUE,TRUE);
 		linphone_core_manager_destroy(marie);
 		linphone_core_manager_destroy(pauline);
 	} else ms_warning("Test skipped, need both ipv6 and v4 available");
@@ -80,7 +83,8 @@ static void call_with_ice_ipv6_to_ipv6(void) {
 		marie = linphone_core_manager_new("marie_rc");
 		pauline = linphone_core_manager_new("pauline_tcp_rc");
 
-		_call_with_ice_base(marie, pauline,TRUE,TRUE,TRUE,TRUE);
+		_call_with_ice_base(marie, pauline,TRUE,TRUE,TRUE,TRUE,FALSE);
+		_call_with_ice_base(marie, pauline,TRUE,TRUE,TRUE,TRUE,TRUE);
 		linphone_core_manager_destroy(marie);
 		linphone_core_manager_destroy(pauline);
 	} else ms_warning("Test skipped, need both ipv6 and v4 available");
@@ -242,18 +246,18 @@ static bool_t is_matching_a_local_address(const std::string &ip, const bctbx_lis
 	return FALSE;
 }
 
+
+
 /*
- * this test checks the 'dont_default_to_stun_candidates' mode, where the c= line is left to host
- * ip instead of stun candidate when ice is enabled*/
-static void _call_with_ice_with_default_candidate_not_stun(bool_t with_ipv6_prefered){
+ * this test checks that default candidates are correct (c= line shall be set to the ICE default candidate).
+ */
+static void _call_with_ice_with_default_candidate(bool_t dont_default_to_stun_candidates, bool_t with_ipv6_prefered){
 	LinphoneCoreManager * marie = linphone_core_manager_new( "marie_rc");
 	LinphoneCoreManager *pauline = linphone_core_manager_new(transport_supported(LinphoneTransportTls) ? "pauline_rc" : "pauline_tcp_rc");
-	char localip[LINPHONE_IPADDR_SIZE]={0};
-	char localip6[LINPHONE_IPADDR_SIZE]={0};
-	bctbx_list_t *local_addresses = linphone_fetch_local_addresses();
+	
 	LinphoneCall *pauline_call, *marie_call;
 
-	linphone_config_set_int(linphone_core_get_config(marie->lc), "net", "dont_default_to_stun_candidates", 1);
+	linphone_config_set_int(linphone_core_get_config(marie->lc), "net", "dont_default_to_stun_candidates", dont_default_to_stun_candidates);
 	linphone_config_set_int(linphone_core_get_config(marie->lc), "rtp", "prefer_ipv6", (int)with_ipv6_prefered);
 
 	enable_stun_in_core(marie, TRUE);
@@ -262,9 +266,6 @@ static void _call_with_ice_with_default_candidate_not_stun(bool_t with_ipv6_pref
 	enable_stun_in_core(pauline, TRUE);
 	linphone_core_manager_wait_for_stun_resolution(pauline);
 
-	linphone_core_get_local_ip(marie->lc, AF_INET, NULL, localip);
-	linphone_core_get_local_ip(marie->lc, AF_INET6, NULL, localip6);
-
 	marie_call = linphone_core_invite_address(marie->lc, pauline->identity);
 	BC_ASSERT_TRUE(wait_for(marie->lc, pauline->lc, &marie->stat.number_of_LinphoneCallOutgoingRinging, 1));
 	BC_ASSERT_TRUE(wait_for(marie->lc, pauline->lc, &pauline->stat.number_of_LinphoneCallIncomingReceived, 1));
@@ -274,33 +275,41 @@ static void _call_with_ice_with_default_candidate_not_stun(bool_t with_ipv6_pref
 		linphone_call_accept(pauline_call);
 		BC_ASSERT_TRUE(wait_for(marie->lc, pauline->lc, &marie->stat.number_of_LinphoneCallStreamsRunning, 1));
 		/*check immmediately that the offer has a c line with the expected family.*/
-		if (with_ipv6_prefered){
-			/* the address in the c line shall be an ipv6 one.*/
-			BC_ASSERT_TRUE(_linphone_call_get_local_desc(linphone_core_get_current_call(marie->lc))->getConnectionAddress().find(':') != std::string::npos);
+		if (dont_default_to_stun_candidates){
+			/* the address in the c line shall be of requested type */
+			if (with_ipv6_prefered && liblinphone_tester_ipv6_available()){
+				BC_ASSERT_TRUE(_linphone_call_get_local_desc(linphone_core_get_current_call(marie->lc))->getConnectionAddress().find(':') != std::string::npos);
+			}else{
+				BC_ASSERT_TRUE(_linphone_call_get_local_desc(linphone_core_get_current_call(marie->lc))->getConnectionAddress().find(':') == std::string::npos);
+			}
 		}else{
-			BC_ASSERT_TRUE(_linphone_call_get_local_desc(linphone_core_get_current_call(marie->lc))->getConnectionAddress().find(':') == std::string::npos);
+			BC_ASSERT_TRUE(_linphone_call_get_local_desc(linphone_core_get_current_call(marie->lc))->getStreamIdx(0).getRtpAddress().find(':') == std::string::npos);
 		}
+		liblinphone_tester_check_ice_default_candidates(marie,  dont_default_to_stun_candidates ?  TesterIceCandidateHost : TesterIceCandidateSflrx,
+								pauline, TesterIceCandidateSflrx);
+		
 		BC_ASSERT_TRUE(wait_for(marie->lc, pauline->lc, &pauline->stat.number_of_LinphoneCallStreamsRunning, 2));
 		BC_ASSERT_TRUE(wait_for(marie->lc, pauline->lc, &marie->stat.number_of_LinphoneCallStreamsRunning, 2));
 		check_ice(marie, pauline, LinphoneIceStateHostConnection);
-		BC_ASSERT_TRUE(is_matching_a_local_address(_linphone_call_get_local_desc(linphone_core_get_current_call(marie->lc))->getConnectionAddress(), local_addresses));
-		BC_ASSERT_TRUE(is_matching_a_local_address(_linphone_call_get_local_desc(linphone_core_get_current_call(marie->lc))->getStreamIdx(0).getRtpAddress(), local_addresses));
-		BC_ASSERT_TRUE(is_matching_a_local_address(_linphone_call_get_local_desc(linphone_core_get_current_call(pauline->lc))->getStreamIdx(0).getRtpAddress(), local_addresses)
-				|| is_matching_a_local_address(_linphone_call_get_local_desc(linphone_core_get_current_call(pauline->lc))->getConnectionAddress(), local_addresses)
-		);
+		
+		
 	}
 	end_call(marie, pauline);
-	bctbx_list_free_with_data(local_addresses, bctbx_free);
+	
 	linphone_core_manager_destroy(marie);
 	linphone_core_manager_destroy(pauline);
 }
 
 static void call_with_ice_with_default_candidate_not_stun(void){
-	_call_with_ice_with_default_candidate_not_stun(TRUE);
+	_call_with_ice_with_default_candidate(TRUE, TRUE);
 }
 
 static void call_with_ice_with_default_candidate_not_stun_ipv4_prefered(void){
-	_call_with_ice_with_default_candidate_not_stun(FALSE);
+	_call_with_ice_with_default_candidate(TRUE, FALSE);
+}
+
+static void call_with_ice_with_default_candidate_relay_or_stun(void){
+	_call_with_ice_with_default_candidate(FALSE, FALSE);
 }
 
 static void call_with_ice_without_stun(void){
@@ -309,7 +318,8 @@ static void call_with_ice_without_stun(void){
 
 	linphone_core_set_stun_server(marie->lc, NULL);
 	linphone_core_set_stun_server(pauline->lc, NULL);
-	_call_with_ice_base(marie, pauline, TRUE, TRUE, TRUE, FALSE);
+	_call_with_ice_base(marie, pauline, TRUE, TRUE, TRUE, FALSE, FALSE);
+	_call_with_ice_base(marie, pauline, TRUE, TRUE, TRUE, FALSE, TRUE);
 
 	linphone_core_manager_destroy(marie);
 	linphone_core_manager_destroy(pauline);
@@ -321,7 +331,8 @@ static void call_with_ice_without_stun2(void){
 
 	//linphone_core_set_stun_server(marie->lc, NULL);
 	linphone_core_set_stun_server(pauline->lc, NULL);
-	_call_with_ice_base(marie, pauline, TRUE, TRUE, TRUE, FALSE);
+	_call_with_ice_base(marie, pauline, TRUE, TRUE, TRUE, FALSE, FALSE);
+	_call_with_ice_base(marie, pauline, TRUE, TRUE, TRUE, FALSE, TRUE);
 
 	linphone_core_manager_destroy(marie);
 	linphone_core_manager_destroy(pauline);
@@ -335,7 +346,7 @@ static void call_with_ice_stun_not_responding(void){
 	linphone_core_set_stun_server(marie->lc, "belledonne-communications.com:443");
 	linphone_core_set_stun_server(pauline->lc, "belledonne-communications.com:443");
 	/*we expect ICE to continue without stun candidates*/
-	_call_with_ice_base(marie, pauline, TRUE, TRUE, TRUE, FALSE);
+	_call_with_ice_base(marie, pauline, TRUE, TRUE, TRUE, FALSE, FALSE);
 
 	/*retry but with nat policy instead of core */
 	linphone_core_set_stun_server(marie->lc, NULL);
@@ -343,7 +354,8 @@ static void call_with_ice_stun_not_responding(void){
 	linphone_nat_policy_set_stun_server(linphone_core_get_nat_policy(marie->lc), "belledonne-communications.com:443");
 	linphone_nat_policy_set_stun_server(linphone_core_get_nat_policy(pauline->lc), "belledonne-communications.com:443");
 	/*we expect ICE to continue without stun candidates*/
-	_call_with_ice_base(marie, pauline, TRUE, TRUE, TRUE, FALSE);
+	_call_with_ice_base(marie, pauline, TRUE, TRUE, TRUE, FALSE, FALSE);
+	_call_with_ice_base(marie, pauline, TRUE, TRUE, TRUE, FALSE, TRUE);
 
 	linphone_core_manager_destroy(marie);
 	linphone_core_manager_destroy(pauline);
@@ -358,7 +370,8 @@ static void _call_with_ice(bool_t caller_with_ice, bool_t callee_with_ice, bool_
 	}
 	linphone_core_manager_start(marie, TRUE);
 	linphone_core_manager_start(pauline, TRUE);
-	_call_with_ice_base(pauline,marie,caller_with_ice,callee_with_ice,random_ports,forced_relay);
+	_call_with_ice_base(pauline,marie,caller_with_ice,callee_with_ice,random_ports,forced_relay, FALSE);
+	_call_with_ice_base(pauline,marie,caller_with_ice,callee_with_ice,random_ports,forced_relay, TRUE);
 	linphone_core_manager_destroy(marie);
 	linphone_core_manager_destroy(pauline);
 }
@@ -386,7 +399,8 @@ static void call_with_ice_ufrag_and_password_set_in_sdp_m_line(void){
 	linphone_core_manager_start(pauline, TRUE);
 	linphone_config_set_int(linphone_core_get_config(marie->lc), "sip", "ice_password_ufrag_in_media_description", 1);
 
-	_call_with_ice_base(pauline,marie,TRUE,TRUE,TRUE,FALSE);
+	_call_with_ice_base(pauline,marie,TRUE,TRUE,TRUE,FALSE,FALSE);
+	_call_with_ice_base(pauline,marie,TRUE,TRUE,TRUE,FALSE,TRUE);
 	linphone_core_manager_destroy(marie);
 	linphone_core_manager_destroy(pauline);
 }
@@ -402,7 +416,8 @@ static void call_with_ice_ufrag_and_password_set_in_sdp_m_line_2(void){
 	linphone_core_manager_start(pauline, TRUE);
 	linphone_config_set_int(linphone_core_get_config(pauline->lc), "sip", "ice_password_ufrag_in_media_description", 1);
 
-	_call_with_ice_base(pauline,marie,TRUE,TRUE,TRUE,FALSE);
+	_call_with_ice_base(pauline,marie,TRUE,TRUE,TRUE,FALSE,FALSE);
+	_call_with_ice_base(pauline,marie,TRUE,TRUE,TRUE,FALSE,TRUE);
 	linphone_core_manager_destroy(marie);
 	linphone_core_manager_destroy(pauline);
 }
@@ -419,7 +434,8 @@ static void call_with_ice_ufrag_and_password_set_in_sdp_m_line_3(void){
 	linphone_config_set_int(linphone_core_get_config(pauline->lc), "sip", "ice_password_ufrag_in_media_description", 1);
 	linphone_config_set_int(linphone_core_get_config(marie->lc), "sip", "ice_password_ufrag_in_media_description", 1);
 
-	_call_with_ice_base(pauline,marie,TRUE,TRUE,TRUE,FALSE);
+	_call_with_ice_base(pauline,marie,TRUE,TRUE,TRUE,FALSE,FALSE);
+	_call_with_ice_base(pauline,marie,TRUE,TRUE,TRUE,FALSE,TRUE);
 	linphone_core_manager_destroy(marie);
 	linphone_core_manager_destroy(pauline);
 }
@@ -649,6 +665,63 @@ static void dtls_srtp_call_paused_resumed_with_both_ice_and_rtcp_mux() {
 	call_paused_resumed_with_ice(LinphoneMediaEncryptionDTLS, TRUE, TRUE, TRUE);
 }
 
+static void call_with_ice_and_dual_stack_stun_server(void){
+	LinphoneCoreManager * marie = linphone_core_manager_new( "marie_rc");
+	LinphoneCoreManager *pauline = linphone_core_manager_new(transport_supported(LinphoneTransportTls) ? "pauline_rc" : "pauline_tcp_rc");
+	bctbx_list_t *local_addresses = linphone_fetch_local_addresses();
+	LinphoneCall *pauline_call, *marie_call;
+	LinphoneNatPolicy *pol;
+	
+	pol = linphone_core_get_nat_policy(marie->lc);
+	pol = linphone_nat_policy_clone(pol);
+	linphone_nat_policy_set_stun_server(pol, "sip.example.org"); /* this host has ipv4 and ipv6 address.*/
+	linphone_nat_policy_enable_stun(pol, TRUE);
+	linphone_nat_policy_enable_ice(pol, TRUE);
+	linphone_core_set_nat_policy(marie->lc, pol);
+	linphone_nat_policy_unref(pol);
+	linphone_core_manager_wait_for_stun_resolution(marie);
+
+	enable_stun_in_core(pauline, TRUE);
+	linphone_core_manager_wait_for_stun_resolution(pauline);
+
+
+	marie_call = linphone_core_invite_address(marie->lc, pauline->identity);
+	BC_ASSERT_TRUE(wait_for(marie->lc, pauline->lc, &marie->stat.number_of_LinphoneCallOutgoingRinging, 1));
+	BC_ASSERT_TRUE(wait_for(marie->lc, pauline->lc, &pauline->stat.number_of_LinphoneCallIncomingReceived, 1));
+	pauline_call = linphone_core_get_current_call(pauline->lc);
+
+	if (marie_call && pauline_call){
+		std::string paulineConnectionAddress = _linphone_call_get_local_desc(linphone_core_get_current_call(marie->lc))->getStreamIdx(0).getRtpAddress();
+		std::string marieConnectionAddress = _linphone_call_get_local_desc(linphone_core_get_current_call(marie->lc))->getStreamIdx(0).getRtpAddress();
+		
+		/* The stun server shall provide marie with an IPv4 address, that we should find in c= of SDP.*/
+		BC_ASSERT_TRUE(marieConnectionAddress.find(':') == std::string::npos);
+		
+		/* Pauline has an IPv4-only stun server, that is expected to work. */
+		bool isBehindNat = !is_matching_a_local_address(paulineConnectionAddress, local_addresses);
+		
+		linphone_call_accept(pauline_call);
+		
+		BC_ASSERT_TRUE(wait_for(marie->lc, pauline->lc, &marie->stat.number_of_LinphoneCallStreamsRunning, 1));
+		
+		if (isBehindNat){
+			/*check immmediately that the offer has a c line with a v4 IP address that is not the local one, which means
+			that STUN discovery was successful.*/
+			BC_ASSERT_FALSE(is_matching_a_local_address(marieConnectionAddress, local_addresses));
+		}else{
+			ms_warning("Test skipped, the tester is not behind a NAT.");
+		}
+		
+		BC_ASSERT_TRUE(wait_for(marie->lc, pauline->lc, &pauline->stat.number_of_LinphoneCallStreamsRunning, 2));
+		BC_ASSERT_TRUE(wait_for(marie->lc, pauline->lc, &marie->stat.number_of_LinphoneCallStreamsRunning, 2));
+		check_ice(marie, pauline, LinphoneIceStateHostConnection);
+	}
+	end_call(marie, pauline);
+	bctbx_list_free_with_data(local_addresses, bctbx_free);
+	linphone_core_manager_destroy(marie);
+	linphone_core_manager_destroy(pauline);
+}
+
 static test_t call_with_ice_tests[] = {
 	TEST_ONE_TAG("Call with ICE in IPv4 with IPv6 enabled", call_with_ice_in_ipv4_with_v6_enabled, "ICE"),
 	TEST_ONE_TAG("Call with ICE IPv4 to IPv6", call_with_ice_ipv4_to_ipv6, "ICE"),
@@ -676,6 +749,7 @@ static test_t call_with_ice_tests[] = {
 	TEST_ONE_TAG("Call with ICE and rtcp-mux not accepted", call_with_ice_and_rtcp_mux_not_accepted,"ICE"),
 	TEST_ONE_TAG("Call with ICE with default candidate not stun", call_with_ice_with_default_candidate_not_stun, "ICE"),
 	TEST_ONE_TAG("Call with ICE with default candidate not stun and ipv4 prefered", call_with_ice_with_default_candidate_not_stun_ipv4_prefered, "ICE"),
+	TEST_ONE_TAG("Call with ICE with default default candidate", call_with_ice_with_default_candidate_relay_or_stun, "ICE"),
 	TEST_ONE_TAG("Call with ICE without stun server", call_with_ice_without_stun, "ICE"),
 	TEST_ONE_TAG("Call with ICE without stun server one side", call_with_ice_without_stun2, "ICE"),
 	TEST_ONE_TAG("Call with ICE and stun server not responding", call_with_ice_stun_not_responding, "ICE"),
@@ -690,7 +764,8 @@ static test_t call_with_ice_tests[] = {
 	TEST_ONE_TAG("Call with ICE pause and resume with both ice and rtcp mux", call_paused_resumed_with_both_ice_and_rtcp_mux, "ICE"),
 	TEST_TWO_TAGS("DTLS SRTP Call with ICE pause and resume with caller ice and rtcp mux", dtls_srtp_call_paused_resumed_with_caller_ice_and_rtcp_mux, "ICE", "DTLS"),
 	TEST_TWO_TAGS("DTLS SRTP Call with ICE pause and resume with callee ice and rtcp mux", dtls_srtp_call_paused_resumed_with_callee_ice_and_rtcp_mux, "ICE", "DTLS"),
-	TEST_TWO_TAGS("DTLS SRTP Call with ICE pause and resume with both ice and rtcp mux", dtls_srtp_call_paused_resumed_with_both_ice_and_rtcp_mux, "ICE", "DTLS")
+	TEST_TWO_TAGS("DTLS SRTP Call with ICE pause and resume with both ice and rtcp mux", dtls_srtp_call_paused_resumed_with_both_ice_and_rtcp_mux, "ICE", "DTLS"),
+	TEST_ONE_TAG("Call with ICE using dual-stack stun server", call_with_ice_and_dual_stack_stun_server, "ICE")
 };
 
 test_suite_t call_with_ice_test_suite = {"Call with ICE", NULL, NULL, liblinphone_tester_before_each, liblinphone_tester_after_each,
