@@ -1,33 +1,34 @@
 /*
-	liblinphone_tester - liblinphone test suite
-	Copyright (C) 2014  Belledonne Communications SARL
-
-	This program is free software: you can redistribute it and/or modify
-	it under the terms of the GNU General Public License as published by
-	the Free Software Foundation, either version 2 of the License, or
-	(at your option) any later version.
-
-	This program is distributed in the hope that it will be useful,
-	but WITHOUT ANY WARRANTY; without even the implied warranty of
-	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-	GNU General Public License for more details.
-
-	You should have received a copy of the GNU General Public License
-	along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+ * Copyright (c) 2010-2019 Belledonne Communications SARL.
+ *
+ * This file is part of Liblinphone.
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ */
 
 
 #include "liblinphone_tester.h"
+#include "tester_utils.h"
 #include "linphone/core.h"
 #include "belle-sip/belle-sip.h"
 
-
-static void call_multicast_base(bool_t video) {
+static void call_multicast_base(const char *marie_rc_file, const char *pauline_rc_file, bool_t video) {
 	LinphoneCoreManager *marie, *pauline;
 	LinphoneVideoPolicy marie_policy, pauline_policy;
 
-	marie = linphone_core_manager_new( "marie_rc");
-	pauline = linphone_core_manager_new( "pauline_tcp_rc");
+	marie = linphone_core_manager_new(marie_rc_file);
+	pauline = linphone_core_manager_new(pauline_rc_file);
 
 	if (video) {
 		linphone_core_enable_video_capture(marie->lc, TRUE);
@@ -54,7 +55,7 @@ static void call_multicast_base(bool_t video) {
 		BC_ASSERT_GREATER(linphone_core_manager_get_max_audio_down_bw(marie),70,int,"%d");
 		if (video) {
 			/*check video path*/
-			linphone_call_set_next_video_frame_decoded_callback(linphone_core_get_current_call(marie->lc),linphone_call_iframe_decoded_cb,marie->lc);
+			liblinphone_tester_set_next_video_frame_decoded_cb(linphone_core_get_current_call(marie->lc));
 			linphone_call_send_vfu_request(linphone_core_get_current_call(marie->lc));
 			BC_ASSERT_TRUE( wait_for(marie->lc,pauline->lc,&marie->stat.number_of_IframeDecoded,1));
 		}
@@ -65,15 +66,20 @@ static void call_multicast_base(bool_t video) {
 	linphone_core_manager_destroy(pauline);
 }
 
-static void call_multicast(void)  {
-	call_multicast_base(FALSE);
+static void call_multicast_with_user_defined_rtp_ports(void)  {
+	call_multicast_base("marie_rtp_port_range_rc", "pauline_rtp_port_range_rc", FALSE);
 }
+
+static void call_multicast_with_os_defined_rtp_ports(void)  {
+	call_multicast_base("marie_os_defined_rtp_ports_rc", "pauline_os_defined_rtp_ports_rc", FALSE);
+}
+
 static void multicast_audio_with_pause_resume(void) {
-	call_paused_resumed_base(TRUE,FALSE);
+	call_paused_resumed_base(TRUE,FALSE,FALSE);
 }
 #ifdef VIDEO_ENABLED
 static void call_multicast_video(void)  {
-	call_multicast_base(TRUE);
+	call_multicast_base("marie_rc", "pauline_tcp_rc", TRUE);
 }
 #endif
 static void early_media_with_multicast_base(bool_t video) {
@@ -90,7 +96,7 @@ static void early_media_with_multicast_base(bool_t video) {
 	pauline2 = linphone_core_manager_new("pauline_tcp_rc");
 
 	marie_lp=linphone_core_get_config(marie->lc);
-	lp_config_set_int(marie_lp,"misc","real_early_media",1);
+	linphone_config_set_int(marie_lp,"misc","real_early_media",1);
 
 	if (video) {
 		linphone_core_enable_video_capture(pauline->lc, FALSE);
@@ -144,22 +150,22 @@ static void early_media_with_multicast_base(bool_t video) {
 	BC_ASSERT_TRUE(wait_for_list(lcs, &marie->stat.number_of_LinphoneCallOutgoingRinging,1,1000));
 
 
-	if (linphone_core_inc_invite_pending(pauline->lc)) {
+	if (linphone_core_is_incoming_invite_pending(pauline->lc)) {
 		/* send a 183 to initiate the early media */
 		if (video) {
 			/*check video path*/
-			linphone_call_set_next_video_frame_decoded_callback(linphone_core_get_current_call(pauline->lc),linphone_call_iframe_decoded_cb,pauline->lc);
+			liblinphone_tester_set_next_video_frame_decoded_cb(linphone_core_get_current_call(pauline->lc));
 		}
 		linphone_call_accept_early_media(linphone_core_get_current_call(pauline->lc));
 
 		BC_ASSERT_TRUE( wait_for_list(lcs, &pauline->stat.number_of_LinphoneCallIncomingEarlyMedia,1,2000) );
 		BC_ASSERT_TRUE( wait_for_list(lcs, &marie->stat.number_of_LinphoneCallOutgoingEarlyMedia,1,2000) );
 
-		if (linphone_core_inc_invite_pending(pauline2->lc)) {
+		if (linphone_core_is_incoming_invite_pending(pauline2->lc)) {
 				/* send a 183 to initiate the early media */
 				if (video) {
 					/*check video path*/
-					linphone_call_set_next_video_frame_decoded_callback(linphone_core_get_current_call(pauline2->lc),linphone_call_iframe_decoded_cb,pauline2->lc);
+					liblinphone_tester_set_next_video_frame_decoded_cb(linphone_core_get_current_call(pauline2->lc));
 				}
 				linphone_call_accept_early_media(linphone_core_get_current_call(pauline2->lc));
 
@@ -192,9 +198,9 @@ static void early_media_with_multicast_base(bool_t video) {
 
 		linphone_call_accept(linphone_core_get_current_call(pauline->lc));
 
-		BC_ASSERT_TRUE(wait_for_list(lcs, &marie->stat.number_of_LinphoneCallConnected, 1,1000));
-		BC_ASSERT_TRUE(wait_for_list(lcs, &marie->stat.number_of_LinphoneCallStreamsRunning, 1,1000));
-		BC_ASSERT_TRUE(wait_for_list(lcs, &pauline2->stat.number_of_LinphoneCallEnd, 1,1000));
+		BC_ASSERT_TRUE(wait_for_list(lcs, &marie->stat.number_of_LinphoneCallConnected, 1,5000));
+		BC_ASSERT_TRUE(wait_for_list(lcs, &marie->stat.number_of_LinphoneCallStreamsRunning, 1,5000));
+		BC_ASSERT_TRUE(wait_for_list(lcs, &pauline2->stat.number_of_LinphoneCallEnd, 1,5000));
 
 		BC_ASSERT_TRUE(linphone_call_params_audio_multicast_enabled(linphone_call_get_current_params(linphone_core_get_current_call(pauline->lc))));
 		BC_ASSERT_TRUE(linphone_call_params_audio_multicast_enabled(linphone_call_get_current_params(linphone_core_get_current_call(marie->lc))));
@@ -214,7 +220,7 @@ static void early_media_with_multicast_base(bool_t video) {
 		linphone_call_update(linphone_core_get_current_call(pauline->lc), params);
 		linphone_call_params_unref(params);
 
-		BC_ASSERT_TRUE(wait_for_list(lcs, &pauline->stat.number_of_LinphoneCallStreamsRunning, 2,1000));
+		BC_ASSERT_TRUE(wait_for_list(lcs, &pauline->stat.number_of_LinphoneCallStreamsRunning, 2,5000));
 
 		BC_ASSERT_FALSE(linphone_call_params_audio_multicast_enabled(linphone_call_get_current_params(linphone_core_get_current_call(pauline->lc))));
 		BC_ASSERT_FALSE(linphone_call_params_audio_multicast_enabled(linphone_call_get_current_params(linphone_core_get_current_call(marie->lc))));
@@ -246,7 +252,7 @@ static void early_media_with_multicast_audio(void) {
 	early_media_with_multicast_base(FALSE);
 }
 static void unicast_incoming_with_multicast_audio_on(void) {
-	simple_call_base(TRUE);
+	simple_call_base(TRUE, FALSE, FALSE);
 }
 #ifdef VIDEO_ENABLED
 static void early_media_with_multicast_video(void) {
@@ -255,7 +261,8 @@ static void early_media_with_multicast_video(void) {
 #endif
 
 test_t multicast_call_tests[] = {
-	TEST_NO_TAG("Multicast audio call",call_multicast),
+	TEST_NO_TAG("Multicast audio call with user defined RTP ports",call_multicast_with_user_defined_rtp_ports),
+	TEST_NO_TAG("Multicast audio call with OS defined rtp ports",call_multicast_with_os_defined_rtp_ports),
 	TEST_NO_TAG("Multicast call with pause/resume",multicast_audio_with_pause_resume),
 	TEST_NO_TAG("Early media multicast audio call",early_media_with_multicast_audio),
 	TEST_NO_TAG("Unicast incoming call with multicast activated",unicast_incoming_with_multicast_audio_on),
