@@ -38,6 +38,33 @@ static void srtp_call(void) {
 	call_base(LinphoneMediaEncryptionSRTP,FALSE,FALSE,LinphonePolicyNoFirewall,FALSE);
 }
 
+static void srtp_call_non_zero_tag(void) {
+	LinphoneCoreManager* marie = linphone_core_manager_new("marie_rc");
+	linphone_core_set_media_encryption(marie->lc,LinphoneMediaEncryptionSRTP);
+	linphone_core_set_media_encryption_mandatory(marie->lc, TRUE);
+
+	LinphoneCoreManager* pauline = linphone_core_manager_new(transport_supported(LinphoneTransportTls) ? "pauline_rc" : "pauline_tcp_rc");
+	linphone_core_set_media_encryption(pauline->lc,LinphoneMediaEncryptionSRTP);
+	linphone_core_set_media_encryption_mandatory(pauline->lc, TRUE);
+	linphone_config_set_int(linphone_core_get_config(pauline->lc), "sip", "crypto_suite_tag_starting_value", 264);
+
+	linphone_core_invite_address(pauline->lc,marie->identity);
+	BC_ASSERT_TRUE(wait_for(marie->lc, pauline->lc, &pauline->stat.number_of_LinphoneCallOutgoingInit, 1));
+	BC_ASSERT_TRUE(wait_for(marie->lc, pauline->lc, &pauline->stat.number_of_LinphoneCallOutgoingProgress, 1));
+	BC_ASSERT_TRUE(wait_for(marie->lc, pauline->lc, &marie->stat.number_of_LinphoneCallIncomingReceived,1));
+	BC_ASSERT_TRUE(wait_for(marie->lc, pauline->lc, &pauline->stat.number_of_LinphoneCallOutgoingRinging,1));
+	linphone_call_accept(linphone_core_get_current_call(marie->lc));
+	liblinphone_tester_check_rtcp(marie, pauline);
+	BC_ASSERT_TRUE(wait_for(marie->lc, pauline->lc, &marie->stat.number_of_LinphoneCallConnected,1));
+	BC_ASSERT_TRUE(wait_for(marie->lc, pauline->lc, &marie->stat.number_of_LinphoneCallStreamsRunning,1));
+	BC_ASSERT_TRUE(wait_for(marie->lc, pauline->lc, &pauline->stat.number_of_LinphoneCallConnected,1));
+	BC_ASSERT_TRUE(wait_for(marie->lc, pauline->lc, &pauline->stat.number_of_LinphoneCallStreamsRunning,1));
+	end_call(pauline, marie);
+
+	linphone_core_manager_destroy(pauline);
+	linphone_core_manager_destroy(marie);
+}
+
 /*
  *Purpose of this test is to check that even if caller and callee does not have exactly the same crypto suite configured, the matching crypto suite is used.
  */
@@ -331,6 +358,14 @@ static void dtls_srtp_call(void) {
 	call_base(LinphoneMediaEncryptionDTLS,FALSE,FALSE,LinphonePolicyNoFirewall,FALSE);
 }
 
+static void dtls_srtp_call_with_ice(void) {
+	call_base(LinphoneMediaEncryptionDTLS,FALSE,FALSE,LinphonePolicyUseIce,FALSE);
+}
+
+static void dtls_srtp_call_with_ice_and_dtls_start_immediate(void) {
+	call_base_with_configfile(LinphoneMediaEncryptionDTLS, FALSE, FALSE, LinphonePolicyUseIce, FALSE, "marie_dtls_srtp_immediate_rc", "pauline_dtls_srtp_immediate_rc");
+}
+
 static void dtls_srtp_call_with_media_realy(void) {
 	call_base(LinphoneMediaEncryptionDTLS,FALSE,TRUE,LinphonePolicyNoFirewall,FALSE);
 }
@@ -857,8 +892,83 @@ static void dtls_srtp_audio_call_with_rtcp_mux_not_accepted(void){
 	_dtls_srtp_audio_call_with_rtcp_mux(TRUE);
 }
 
+#ifdef VIDEO_ENABLED
+void call_with_several_video_switches_base(const LinphoneMediaEncryption caller_encryption, const LinphoneMediaEncryption callee_encryption) {
+	int dummy = 0;
+	LinphoneCoreManager* marie = linphone_core_manager_new("marie_rc");
+	LinphoneCoreManager* pauline = linphone_core_manager_new(transport_supported(LinphoneTransportTls) ? "pauline_rc" : "pauline_tcp_rc");
+	bool_t call_ok;
+
+	if (linphone_core_media_encryption_supported(marie->lc, caller_encryption) && linphone_core_media_encryption_supported(marie->lc, callee_encryption)) {
+		linphone_core_set_media_encryption(marie->lc, callee_encryption);
+		linphone_core_set_media_encryption(pauline->lc, caller_encryption);
+
+		BC_ASSERT_TRUE(call_ok=call(pauline,marie));
+		if (!call_ok) goto end;
+
+		liblinphone_tester_check_rtcp(marie, pauline);
+
+		BC_ASSERT_TRUE(request_video(pauline,marie, TRUE));
+		wait_for_until(pauline->lc,marie->lc,&dummy,1,1000); /* Wait for VFU request exchanges to be finished. */
+		BC_ASSERT_TRUE(remove_video(pauline,marie));
+		BC_ASSERT_TRUE(request_video(pauline,marie, TRUE));
+		wait_for_until(pauline->lc,marie->lc,&dummy,1,1000); /* Wait for VFU request exchanges to be finished. */
+		BC_ASSERT_TRUE(remove_video(pauline,marie));
+		/**/
+		end_call(pauline, marie);
+	} else {
+		ms_warning("Not tested because either callee doesn't support %s or caller doesn't support %s.", linphone_media_encryption_to_string(callee_encryption), linphone_media_encryption_to_string(caller_encryption));
+	}
+end:
+	linphone_core_manager_destroy(marie);
+	linphone_core_manager_destroy(pauline);
+}
+
+static void srtp_call_with_several_video_switches(void) {
+	call_with_several_video_switches_base(LinphoneMediaEncryptionSRTP, LinphoneMediaEncryptionSRTP);
+}
+
+static void none_to_srtp_call_with_several_video_switches(void) {
+	call_with_several_video_switches_base(LinphoneMediaEncryptionNone, LinphoneMediaEncryptionSRTP);
+}
+
+static void srtp_to_none_call_with_several_video_switches(void) {
+	call_with_several_video_switches_base(LinphoneMediaEncryptionSRTP, LinphoneMediaEncryptionNone);
+}
+
+static void zrtp_call_with_several_video_switches(void) {
+	call_with_several_video_switches_base(LinphoneMediaEncryptionZRTP, LinphoneMediaEncryptionZRTP);
+}
+
+static void none_to_zrtp_call_with_several_video_switches(void) {
+	call_with_several_video_switches_base(LinphoneMediaEncryptionNone, LinphoneMediaEncryptionZRTP);
+}
+
+static void zrtp_to_none_call_with_several_video_switches(void) {
+	call_with_several_video_switches_base(LinphoneMediaEncryptionZRTP, LinphoneMediaEncryptionNone);
+}
+
+static void dtls_srtp_call_with_several_video_switches(void) {
+	call_with_several_video_switches_base(LinphoneMediaEncryptionDTLS, LinphoneMediaEncryptionDTLS);
+}
+
+static void none_to_dtls_srtp_call_with_several_video_switches(void) {
+	call_with_several_video_switches_base(LinphoneMediaEncryptionNone, LinphoneMediaEncryptionDTLS);
+}
+
+static void dtls_srtp_to_none_call_with_several_video_switches(void) {
+	call_with_several_video_switches_base(LinphoneMediaEncryptionDTLS, LinphoneMediaEncryptionNone);
+}
+#endif // VIDEO_ENABLED
+
 test_t call_secure_tests[] = {
 	TEST_NO_TAG("SRTP call", srtp_call),
+	TEST_NO_TAG("SRTP call with non zero crypto suite tag", srtp_call_non_zero_tag),
+#ifdef VIDEO_ENABLED
+	TEST_NO_TAG("SRTP call with several video switches", srtp_call_with_several_video_switches),
+	TEST_NO_TAG("SRTP to none call with several video switches", srtp_to_none_call_with_several_video_switches),
+	TEST_NO_TAG("None to SRTP call with several video switches", none_to_srtp_call_with_several_video_switches),
+#endif // VIDEO_ENABLED
 	TEST_NO_TAG("SRTP call with different crypto suite", srtp_call_with_different_crypto_suite),
 	TEST_NO_TAG("SRTP call with crypto suite parameters", srtp_call_with_crypto_suite_parameters),
 	TEST_NO_TAG("SRTP call with crypto suite parameters 2", srtp_call_with_crypto_suite_parameters_2),
@@ -867,11 +977,23 @@ test_t call_secure_tests[] = {
 	TEST_NO_TAG("SRTP call with crypto suite parameters and mandatory encryption 3", srtp_call_with_crypto_suite_parameters_and_mandatory_encryption_3),
 	TEST_NO_TAG("SRTP call with crypto suite parameters and mandatory encryption 4", srtp_call_with_crypto_suite_parameters_and_mandatory_encryption_4),
 	TEST_NO_TAG("ZRTP call", zrtp_call),
+#ifdef VIDEO_ENABLED
+	TEST_NO_TAG("ZRTP call with several video switches", zrtp_call_with_several_video_switches),
+	TEST_NO_TAG("ZRTP to none call with several video switches", zrtp_to_none_call_with_several_video_switches),
+	TEST_NO_TAG("None to ZRTP call with several video switches", none_to_zrtp_call_with_several_video_switches),
+#endif // VIDEO_ENABLED
 	TEST_NO_TAG("ZRTP silent call", zrtp_silent_call),
 	TEST_NO_TAG("ZRTP SAS call", zrtp_sas_call),
 	TEST_NO_TAG("ZRTP Cipher call", zrtp_cipher_call),
 	TEST_NO_TAG("ZRTP Key Agreement call", zrtp_key_agreement_call),
 	TEST_ONE_TAG("DTLS SRTP call", dtls_srtp_call, "DTLS"),
+#ifdef VIDEO_ENABLED
+	TEST_ONE_TAG("DTLS SRTP call with several video switches", dtls_srtp_call_with_several_video_switches, "DTLS"),
+	TEST_ONE_TAG("DTLS SRTP to none call with several video switches", dtls_srtp_to_none_call_with_several_video_switches, "DTLS"),
+	TEST_ONE_TAG("None to DTLS SRTP call with several video switches", none_to_dtls_srtp_call_with_several_video_switches, "DTLS"),
+#endif // VIDEO_ENABLED
+	TEST_ONE_TAG("DTLS SRTP call with ICE", dtls_srtp_call_with_ice, "DTLS"),
+	TEST_ONE_TAG("DTLS SRTP call with ICE and dtls start immediatly", dtls_srtp_call_with_ice_and_dtls_start_immediate, "DTLS"),
 	TEST_ONE_TAG("DTLS SRTP call with media relay", dtls_srtp_call_with_media_realy, "DTLS"),
 	TEST_NO_TAG("SRTP call with declined srtp", call_with_declined_srtp),
 	TEST_NO_TAG("SRTP call paused and resumed", call_srtp_paused_and_resumed),
