@@ -1,32 +1,24 @@
 /*
-	liblinphone_tester - liblinphone test suite
-	Copyright (C) 2013  Belledonne Communications SARL
-
-	This program is free software: you can redistribute it and/or modify
-	it under the terms of the GNU General Public License as published by
-	the Free Software Foundation, either version 2 of the License, or
-	(at your option) any later version.
-
-	This program is distributed in the hope that it will be useful,
-	but WITHOUT ANY WARRANTY; without even the implied warranty of
-	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-	GNU General Public License for more details.
-
-	You should have received a copy of the GNU General Public License
-	along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+ * Copyright (c) 2010-2019 Belledonne Communications SARL.
+ *
+ * This file is part of Liblinphone.
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ */
 
 #include "liblinphone_tester.h"
-#include "private.h"
-
-void dtmf_received(LinphoneCore *lc, LinphoneCall *call, int dtmf) {
-	stats* counters = get_stats(lc);
-	char** dst = &counters->dtmf_list_received;
-	*dst = *dst ?
-				ms_strcat_printf(*dst, "%c", dtmf)
-				: ms_strdup_printf("%c", dtmf);
-	counters->dtmf_count++;
-}
+#include "tester_utils.h"
 
 void send_dtmf_base(LinphoneCoreManager **pmarie, LinphoneCoreManager **ppauline, bool_t use_rfc2833, bool_t use_sipinfo, char dtmf, char* dtmf_seq, bool_t use_opus) {
 	char* expected = NULL;
@@ -37,7 +29,7 @@ void send_dtmf_base(LinphoneCoreManager **pmarie, LinphoneCoreManager **ppauline
 
 	if (use_opus) {
 		//if (!ms_filter_codec_supported("opus")) {
-		if(!ms_factory_codec_supported(marie->lc->factory, "opus") && !ms_factory_codec_supported(pauline->lc->factory, "opus")){
+		if(!ms_factory_codec_supported(linphone_core_get_ms_factory(marie->lc), "opus") && !ms_factory_codec_supported(linphone_core_get_ms_factory(pauline->lc), "opus")){
 
 			ms_warning("Opus not supported, skipping test.");
 			return;
@@ -69,7 +61,7 @@ void send_dtmf_base(LinphoneCoreManager **pmarie, LinphoneCoreManager **ppauline
 	}
 
 	if (dtmf_seq != NULL) {
-		int dtmf_delay_ms = lp_config_get_int(marie_call->core->config,"net","dtmf_delay_ms",200);
+		int dtmf_delay_ms = linphone_config_get_int(linphone_core_get_config(linphone_call_get_core(marie_call)),"net","dtmf_delay_ms",200);
 		dtmf_count_prev = pauline->stat.dtmf_count;
 		linphone_call_send_dtmfs(marie_call, dtmf_seq);
 
@@ -92,8 +84,8 @@ void send_dtmf_base(LinphoneCoreManager **pmarie, LinphoneCoreManager **ppauline
 void send_dtmf_cleanup(LinphoneCoreManager *marie, LinphoneCoreManager *pauline) {
 	LinphoneCall *marie_call = linphone_core_get_current_call(marie->lc);
 	if (marie_call) {
-		BC_ASSERT_PTR_NULL(marie_call->dtmfs_timer);
-		BC_ASSERT_PTR_NULL(marie_call->dtmf_sequence);
+		BC_ASSERT_PTR_NULL(_linphone_call_get_dtmf_timer(marie_call));
+		BC_ASSERT_FALSE(_linphone_call_has_dtmf_sequence(marie_call));
 
 		/*just to sleep*/
 		linphone_core_terminate_all_calls(pauline->lc);
