@@ -46,6 +46,7 @@ extern test_suite_t account_creator_local_test_suite;
 extern test_suite_t account_creator_flexiapi_test_suite;
 extern test_suite_t account_creator_xmlrpc_test_suite;
 extern test_suite_t call_test_suite;
+extern test_suite_t call_not_established_test_suite;
 extern test_suite_t push_incoming_call_test_suite;
 
 #if VIDEO_ENABLED
@@ -59,6 +60,7 @@ extern test_suite_t conference_event_test_suite;
 extern test_suite_t conference_test_suite;
 extern test_suite_t contents_test_suite;
 extern test_suite_t cpim_test_suite;
+extern test_suite_t ics_test_suite;
 extern test_suite_t dtmf_test_suite;
 extern test_suite_t event_test_suite;
 extern test_suite_t main_db_test_suite;
@@ -66,13 +68,19 @@ extern test_suite_t flexisip_test_suite;
 extern test_suite_t group_chat_test_suite;
 extern test_suite_t group_chat2_test_suite;
 extern test_suite_t secure_group_chat_test_suite;
+extern test_suite_t secure_message_test_suite;
 extern test_suite_t ephemeral_group_chat_test_suite;
+extern test_suite_t ephemeral_group_chat_basic_test_suite;
 extern test_suite_t log_collection_test_suite;
 extern test_suite_t message_test_suite;
+extern test_suite_t lime_message_test_suite;
+extern test_suite_t rtt_message_test_suite;
 extern test_suite_t session_timers_test_suite;
 extern test_suite_t multi_call_test_suite;
 extern test_suite_t multicast_call_test_suite;
-extern test_suite_t audio_video_conference_test_suite;
+extern test_suite_t audio_conference_basic_test_suite;
+extern test_suite_t audio_conference_advanced_test_suite;
+extern test_suite_t video_conference_test_suite;
 extern test_suite_t multipart_test_suite;
 extern test_suite_t flexiapiclient_suite;
 extern test_suite_t offeranswer_test_suite;
@@ -83,6 +91,7 @@ extern test_suite_t property_container_test_suite;
 extern test_suite_t proxy_config_test_suite;
 extern test_suite_t account_test_suite;
 extern test_suite_t quality_reporting_test_suite;
+extern test_suite_t recorder_test_suite;
 extern test_suite_t register_test_suite;
 extern test_suite_t remote_provisioning_test_suite;
 extern test_suite_t setup_test_suite;
@@ -92,10 +101,17 @@ extern test_suite_t upnp_test_suite;
 extern test_suite_t utils_test_suite;
 extern test_suite_t video_test_suite;
 extern test_suite_t capability_negotiation_test_suite;
+extern test_suite_t capability_negotiation_no_sdp_test_suite;
 extern test_suite_t srtp_capability_negotiation_test_suite;
+extern test_suite_t srtp_capability_negotiation_basic_test_suite;
 extern test_suite_t zrtp_capability_negotiation_test_suite;
+extern test_suite_t zrtp_capability_negotiation_basic_test_suite;
 extern test_suite_t dtls_srtp_capability_negotiation_test_suite;
+extern test_suite_t dtls_srtp_capability_negotiation_basic_test_suite;
 extern test_suite_t ice_capability_negotiation_test_suite;
+extern test_suite_t srtp_ice_capability_negotiation_test_suite;
+extern test_suite_t zrtp_ice_capability_negotiation_test_suite;
+extern test_suite_t dtls_srtp_ice_capability_negotiation_test_suite;
 extern test_suite_t call_recovery_test_suite;
 extern test_suite_t call_with_ice_test_suite;
 extern test_suite_t call_secure_test_suite;
@@ -123,6 +139,7 @@ extern int manager_count;
 extern const char * liblinphone_tester_ipv6_probing_address;
 extern int liblinphone_tester_ipv6_available(void);
 extern int liblinphone_tester_ipv4_available(void);
+extern const int liblinphone_tester_sip_timeout;
 
 /**
  * @brief Tells the tester whether or not to clean the accounts it has created between runs.
@@ -180,8 +197,12 @@ extern const char* lime_server_c25519_tlsauth_opt_url;
 extern const char* lime_server_c448_tlsauth_opt_url;
 extern const char* lime_server_c25519_tlsauth_req_url;
 extern const char* lime_server_c448_tlsauth_req_url;
+extern const char* lime_server_c25519_dual_auth_url;
+extern const char* lime_server_c448_dual_auth_url;
 extern const char* lime_server_c25519_external_url;
 extern const char* lime_server_c448_external_url;
+extern const char* lime_server_c25519_external_dual_auth_url;
+extern const char* lime_server_c448_external_dual_auth_url;
 extern bool_t liblinphone_tester_keep_uuid;
 extern bool_t liblinphone_tester_tls_support_disabled;
 extern const MSAudioDiffParams audio_cmp_params;
@@ -190,6 +211,7 @@ extern const char *liblinphone_tester_static_image_id;
 extern bool_t liblinphonetester_ipv6;
 extern bool_t liblinphonetester_show_account_manager_logs;
 extern bool_t liblinphonetester_no_account_creator;
+extern  unsigned int liblinphone_tester_max_cpu_count;
 
 typedef struct _stats {
 	int number_of_LinphoneRegistrationNone;
@@ -260,6 +282,9 @@ typedef struct _stats {
 	int number_of_LinphoneFileTransfer;
 
 	int number_of_LinphoneChatRoomConferenceJoined;
+	int number_of_LinphoneChatRoomEphemeralLifetimeChanged;
+	int number_of_LinphoneChatRoomEphemeralMessageEnabled;
+	int number_of_LinphoneChatRoomEphemeralMessageDisabled;
 	int number_of_LinphoneChatRoomEphemeralTimerStarted;
 	int number_of_LinphoneChatRoomEphemeralDeleted;
 	int number_of_X3dhUserCreationSuccess;
@@ -268,6 +293,7 @@ typedef struct _stats {
 	int number_of_IframeDecoded;
 
 	int number_of_NewSubscriptionRequest;
+	int number_of_NotifySent;
 	int number_of_NotifyReceived;
 	int number_of_NotifyPresenceReceived;
 	int number_of_NotifyPresenceReceivedForUriOrTel;
@@ -387,6 +413,20 @@ typedef struct _stats {
 	int number_of_LinphoneCoreLastCallEnded;
 	int number_of_LinphoneCoreAudioDeviceChanged;
 	int number_of_LinphoneCoreAudioDevicesListUpdated;
+	int number_of_LinphoneCoreVersionUpdateCheck;
+
+	int number_of_LinphoneConferenceInfoOnParticipantSent;
+	int number_of_LinphoneConferenceInfoOnParticipantError;
+	int number_of_LinphoneConferenceInfoOnSent;
+
+	int number_of_LinphoneRemoteRecordingEnabled;
+	int number_of_LinphoneRemoteRecordingDisabled;
+	
+	int number_of_LinphoneParticipantDeviceStartSpeaking;
+	int number_of_LinphoneParticipantDeviceStopSpeaking;
+	
+	int number_of_LinphoneMagicSearchResultReceived;
+	int number_of_LinphoneMagicSearchLdapHaveMoreResults;
 }stats;
 
 typedef struct _LinphoneCoreManager {
@@ -451,6 +491,7 @@ void linphone_core_manager_wait_for_stun_resolution(LinphoneCoreManager *mgr);
 void linphone_core_manager_destroy(LinphoneCoreManager* mgr);
 void linphone_core_manager_destroy_after_stop_async(LinphoneCoreManager* mgr);
 void linphone_core_manager_delete_chat_room (LinphoneCoreManager *mgr, LinphoneChatRoom *cr, bctbx_list_t *coresList);
+void linphone_core_manager_delete_all_chat_rooms(LinphoneCoreManager *mgr, bctbx_list_t *coresList);
 bctbx_list_t * init_core_for_conference(bctbx_list_t *coreManagerList);
 bctbx_list_t * init_core_for_conference_with_factori_uri(bctbx_list_t *coreManagerList, const char *factoryUri);
 void start_core_for_conference(bctbx_list_t *coreManagerList);
@@ -470,6 +511,7 @@ LinphoneBuffer * tester_file_transfer_send(LinphoneChatMessage *message, Linphon
 void tester_file_transfer_send_2(LinphoneChatMessage *message, LinphoneContent* content, size_t offset, size_t size, LinphoneBuffer *buffer);
 LinphoneChatMessage *_send_message_ephemeral(LinphoneChatRoom *chatRoom, const char *message, bool_t ephemeral);
 LinphoneChatMessage *_send_message(LinphoneChatRoom *chatRoom, const char *message);
+void set_ephemeral_cbs (bctbx_list_t *history);
 void _send_file_plus_text(LinphoneChatRoom* cr, const char *sendFilepath, const char *sendFilepath2, const char *text, bool_t use_buffer);
 void _send_file(LinphoneChatRoom* cr, const char *sendFilepath, const char *sendFilepath2, bool_t use_buffer);
 void _receive_file(bctbx_list_t *coresList, LinphoneCoreManager *lcm, stats *receiverStats, const char *receive_filepath, const char *sendFilepath, const char *sendFilepath2, bool_t use_buffer);
@@ -483,6 +525,7 @@ void info_message_received(LinphoneCore *lc, LinphoneCall *call, const LinphoneI
 void new_subscription_requested(LinphoneCore *lc, LinphoneFriend *lf, const char *url);
 void linphone_subscription_state_change(LinphoneCore *lc, LinphoneEvent *ev, LinphoneSubscriptionState state);
 void linphone_publish_state_changed(LinphoneCore *lc, LinphoneEvent *ev, LinphonePublishState state);
+void linphone_notify_sent(LinphoneCore *lc, LinphoneEvent *lev, const LinphoneContent *content);
 void linphone_notify_received(LinphoneCore *lc, LinphoneEvent *lev, const char *eventname, const LinphoneContent *content);
 void linphone_subscribe_received(LinphoneCore *lc, LinphoneEvent *lev, const char *eventname, const LinphoneContent *content);
 void linphone_configuration_status(LinphoneCore *lc, LinphoneConfiguringState status, const char *message);
@@ -519,6 +562,7 @@ bool_t call_with_params2(LinphoneCoreManager* caller_mgr
 
 bool_t call(LinphoneCoreManager* caller_mgr,LinphoneCoreManager* callee_mgr);
 bool_t request_video(LinphoneCoreManager* caller,LinphoneCoreManager* callee, bool_t use_accept_call_update);
+bool_t remove_video(LinphoneCoreManager *caller, LinphoneCoreManager *callee);
 void end_call(LinphoneCoreManager *m1, LinphoneCoreManager *m2);
 void disable_all_audio_codecs_except_one(LinphoneCore *lc, const char *mime, int rate);
 void disable_all_video_codecs_except_one(LinphoneCore *lc, const char *mime);
@@ -553,18 +597,19 @@ void configure_core_for_callbacks(LinphoneCoreManager *lcm, LinphoneCoreCbs *cbs
 void liblinphone_tester_set_next_video_frame_decoded_cb(LinphoneCall *call);
 void call_paused_resumed_base(bool_t multicast,bool_t with_losses,bool_t accept_video);
 void simple_call_base(bool_t enable_multicast_recv_side, bool_t disable_soundcard, bool_t use_multipart_invite_body);
-void simple_call_base_with_rcs(const char *caller_rc, const char *callee_rc, bool_t enable_multicast_recv_side, bool_t disable_soundcard, bool_t use_multipart_invite_body);
+void simple_call_base_with_rcs(const char *caller_rc, const char *callee_rc, bool_t enable_multicast_recv_side, bool_t disable_soundcard, bool_t use_multipart_invite_body, bool_t double_call);
 void _call_with_rtcp_mux(bool_t caller_rtcp_mux, bool_t callee_rtcp_mux, bool_t with_ice,bool_t with_ice_reinvite);
 void call_base_with_configfile(LinphoneMediaEncryption mode, bool_t enable_video,bool_t enable_relay,LinphoneFirewallPolicy policy,bool_t enable_tunnel, const char *marie_rc, const char *pauline_rc);
 void call_base_with_configfile_play_nothing(LinphoneMediaEncryption mode, bool_t enable_video,bool_t enable_relay,LinphoneFirewallPolicy policy,bool_t enable_tunnel, const char *marie_rc, const char *pauline_rc);
 void call_base(LinphoneMediaEncryption mode, bool_t enable_video,bool_t enable_relay,LinphoneFirewallPolicy policy,bool_t enable_tunnel);
+void call_with_several_video_switches_base(const LinphoneMediaEncryption caller_encryption, const LinphoneMediaEncryption callee_encryption);
 bool_t call_with_caller_params(LinphoneCoreManager* caller_mgr,LinphoneCoreManager* callee_mgr, const LinphoneCallParams *params);
 bool_t pause_call_1(LinphoneCoreManager* mgr_1,LinphoneCall* call_1,LinphoneCoreManager* mgr_2,LinphoneCall* call_2);
 LinphoneAudioDevice * change_device(bool_t enable, LinphoneCoreManager* mgr, LinphoneAudioDevice *current_dev, LinphoneAudioDevice *dev0, LinphoneAudioDevice *dev1);
 LinphoneAudioDevice* pause_call_changing_device(bool_t enable, bctbx_list_t *lcs, LinphoneCall *call, LinphoneCoreManager* mgr_pausing, LinphoneCoreManager* mgr_paused, LinphoneCoreManager* mgr_change_device, LinphoneAudioDevice *current_dev, LinphoneAudioDevice *dev0, LinphoneAudioDevice *dev1);
 void compare_files(const char *path1, const char *path2);
 void check_media_direction(LinphoneCoreManager* mgr, LinphoneCall *call, MSList* lcs,LinphoneMediaDirection audio_dir, LinphoneMediaDirection video_dir);
-void _call_with_ice_base(LinphoneCoreManager* pauline,LinphoneCoreManager* marie, bool_t caller_with_ice, bool_t callee_with_ice, bool_t random_ports, bool_t forced_relay);
+void _call_with_ice_base(LinphoneCoreManager* pauline,LinphoneCoreManager* marie, bool_t caller_with_ice, bool_t callee_with_ice, bool_t random_ports, bool_t forced_relay, bool_t quick_cancel);
 void record_call(const char *filename, bool_t enableVideo, const char *video_codec);
 
 #define AUDIO_START	0
@@ -577,9 +622,9 @@ void check_stream_encryption(LinphoneCall * call);
 int get_stream_stop_count(LinphoneCall * call);
 bool_t search_matching_srtp_suite(LinphoneCoreManager* caller_mgr,LinphoneCoreManager* callee_mgr);
 
-LinphoneChatRoom * create_chat_room_client_side(bctbx_list_t *lcs, LinphoneCoreManager *lcm, stats *initialStats, bctbx_list_t *participantsAddresses, const char* initialSubject, bool_t encrypted);
-LinphoneChatRoom * create_chat_room_with_params(bctbx_list_t *lcs, LinphoneCoreManager *lcm, stats *initialStats, bctbx_list_t *participantsAddresses, const char* initialSubject, LinphoneChatRoomParams *params);
-LinphoneChatRoom * create_chat_room_client_side_with_expected_number_of_participants(bctbx_list_t *lcs, LinphoneCoreManager *lcm, stats *initialStats, bctbx_list_t *participantsAddresses, const char* initialSubject, int expectedParticipantSize, bool_t encrypted);
+LinphoneChatRoom * create_chat_room_client_side(bctbx_list_t *lcs, LinphoneCoreManager *lcm, stats *initialStats, bctbx_list_t *participantsAddresses, const char* initialSubject, bool_t encrypted, LinphoneChatRoomEphemeralMode mode);
+LinphoneChatRoom * create_chat_room_client_side_with_params(bctbx_list_t *lcs, LinphoneCoreManager *lcm, stats *initialStats, bctbx_list_t *participantsAddresses, const char* initialSubject, LinphoneChatRoomParams *params);
+LinphoneChatRoom * create_chat_room_client_side_with_expected_number_of_participants(bctbx_list_t *lcs, LinphoneCoreManager *lcm, stats *initialStats, bctbx_list_t *participantsAddresses, const char* initialSubject, int expectedParticipantSize, bool_t encrypted, LinphoneChatRoomEphemeralMode mode);
 LinphoneChatRoom * check_creation_chat_room_client_side(bctbx_list_t *lcs, LinphoneCoreManager *lcm, stats *initialStats, const LinphoneAddress *confAddr, const char* subject, int participantNumber, bool_t isAdmin);
 void configure_core_for_conference (LinphoneCore *core, const char* username, const LinphoneAddress *factoryAddr, bool_t server);
 void _configure_core_for_conference (LinphoneCoreManager *lcm, LinphoneAddress *factoryAddr);
