@@ -1,36 +1,42 @@
 /*
-	Linphone
-	Copyright (C) 2014  Belledonne Communications SARL
-
-	This program is free software: you can redistribute it and/or modify
-	it under the terms of the GNU General Public License as published by
-	the Free Software Foundation, either version 2 of the License, or
-	(at your option) any later version.
-
-	This program is distributed in the hope that it will be useful,
-	but WITHOUT ANY WARRANTY; without even the implied warranty of
-	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-	GNU General Public License for more details.
-
-	You should have received a copy of the GNU General Public License
-	along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+ * Copyright (c) 2010-2019 Belledonne Communications SARL.
+ *
+ * This file is part of Liblinphone.
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ */
 
 #ifndef _XOPEN_SOURCE
 	#define _XOPEN_SOURCE 700 // To have definition of strptime, snprintf and getline
 #endif
 #include <time.h>
 #include "linphone/core.h"
-#include "private.h"
 #include "liblinphone_tester.h"
+#include "tester_utils.h"
 
 #ifdef HAVE_ZLIB
 #include <zlib.h>
 #endif
 
+#ifdef __ANDROID__
+#include "android/api-level.h"
+#endif
 
 /*getline is POSIX 2008, not available on many systems.*/
-#if (defined(__ANDROID__) && !defined(__LP64__)) || defined(_WIN32) || defined(__QNX__)
+
+/*It is declared since NDK14 unified headers, that can be detected by the presence of __ANDROID_API_O__ define*/
+#if (defined(__ANDROID__) &&  __ANDROID_API__ < 18) || defined(_WIN32) || defined(__QNX__)
 /* This code is public domain -- Will Hartung 4/9/09 */
 static ssize_t getline(char **lineptr, size_t *n, FILE *stream) {
 	char *bufptr = NULL;
@@ -108,7 +114,7 @@ static LinphoneCoreManager* setup(LinphoneLogCollectionState log_collection_stat
 	collect_init();
 	linphone_core_enable_log_collection(log_collection_state);
 
-	marie = linphone_core_manager_new2("marie_rc", 0);
+	marie = linphone_core_manager_new_with_proxies_check("marie_rc", FALSE);
 	// wait a few seconds to generate some traffic
 	while (--timeout){
 		// Generate some logs - error logs because we must ensure that
@@ -214,7 +220,7 @@ static time_t check_file(LinphoneCoreManager* mgr)  {
 		ms_free(filepath);
 
 
-		timediff = labs((long int)log_time - (long int)cur_time);
+		timediff = (uint32_t) labs((long int)log_time - (long int)cur_time);
 #ifndef _WIN32
 		BC_ASSERT_LOWER(timediff, 1, unsigned, "%u");
 		if( !(timediff <= 1) ){
@@ -289,6 +295,22 @@ static void logCollectionUploadStateChangedCb(LinphoneCore *lc, LinphoneCoreLogC
 			break;
 	}
 }
+
+static void upload_wrong_url(void) {
+	LinphoneCoreManager* marie = setup(LinphoneLogCollectionEnabled);
+
+	LinphoneCoreCbs *cbs = linphone_factory_create_core_cbs(linphone_factory_get());
+	linphone_core_cbs_set_log_collection_upload_state_changed(cbs, logCollectionUploadStateChangedCb);
+	linphone_core_add_callbacks(marie->lc, cbs);
+	linphone_core_cbs_unref(cbs);
+
+	linphone_core_set_log_collection_upload_server_url(marie->lc,"text");
+	linphone_core_upload_log_collection(marie->lc);
+	BC_ASSERT_TRUE(wait_for_until(marie->lc,marie->lc,&marie->stat.number_of_LinphoneCoreLogCollectionUploadStateNotDelivered, 1, 10000));
+
+	collect_cleanup(marie);
+}
+
 static void upload_collected_traces(void)  {
 	if (transport_supported(LinphoneTransportTls)) {
 		LinphoneCoreManager* marie = setup(LinphoneLogCollectionEnabled);
@@ -299,7 +321,7 @@ static void upload_collected_traces(void)  {
 		linphone_core_cbs_unref(cbs);
 
 		linphone_core_set_log_collection_max_file_size(5000);
-		linphone_core_set_log_collection_upload_server_url(marie->lc,"https://www.linphone.org:444/lft.php");
+		linphone_core_set_log_collection_upload_server_url(marie->lc, file_transfer_url);
 		// Generate some logs
 		while (--waiting) ms_error("(test error)Waiting %d...", waiting);
 		ms_free(linphone_core_compress_log_collection());
@@ -322,6 +344,7 @@ test_t log_collection_tests[] = {
 	TEST_NO_TAG("Collect files filled when enabled", collect_files_filled),
 	TEST_NO_TAG("Logs collected into small file", collect_files_small_size),
 	TEST_NO_TAG("Logs collected when decreasing max size", collect_files_changing_size),
+	TEST_NO_TAG("Log upload to wrong URL", upload_wrong_url),
 	TEST_NO_TAG("Upload collected traces", upload_collected_traces)
 };
 
