@@ -1,247 +1,53 @@
 /*
-    liblinphone_tester - liblinphone test suite
-    Copyright (C) 2013  Belledonne Communications SARL
-
-    This program is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+ * Copyright (c) 2010-2019 Belledonne Communications SARL.
+ *
+ * This file is part of Liblinphone.
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ */
 
 
 #include "linphone/core.h"
-#include "private.h"
 #include "liblinphone_tester.h"
+#include "tester_utils.h"
+
 
 static LinphoneCoreManager* presence_linphone_core_manager_new_with_rc_name(char* username, char * rc_name) {
-	LinphoneCoreManager* mgr= linphone_core_manager_new2( rc_name, FALSE);
+	LinphoneCoreManager* mgr= linphone_core_manager_new_with_proxies_check( rc_name, FALSE);
+	LinphoneSipTransports tr = {0};
+	tr.udp_port = -1; /*random port*/
+	linphone_core_set_sip_transports(mgr->lc, &tr);
+	linphone_core_get_sip_transports_used(mgr->lc, &tr);
 	char* identity_char;
 	mgr->identity= linphone_core_get_primary_contact_parsed(mgr->lc);
 	linphone_address_set_username(mgr->identity,username);
+	linphone_address_set_port(mgr->identity, tr.udp_port);
 	identity_char=linphone_address_as_string(mgr->identity);
 	linphone_core_set_primary_contact(mgr->lc,identity_char);
 	ms_free(identity_char);
 	return mgr;
 }
+
 static LinphoneCoreManager* presence_linphone_core_manager_new(char* username) {
 	return presence_linphone_core_manager_new_with_rc_name(username, "empty_rc");
 }
 
-
-void new_subscription_requested(LinphoneCore *lc, LinphoneFriend *lf, const char *url){
-	stats* counters;
-	const LinphoneAddress *addr = linphone_friend_get_address(lf);
-	if (addr != NULL) {
-		char* from=linphone_address_as_string(addr);
-		ms_message("New subscription request from [%s] url [%s]",from,url);
-		ms_free(from);
-	}
-	counters = get_stats(lc);
-	counters->number_of_NewSubscriptionRequest++;
-	linphone_core_add_friend(lc,lf); /*accept subscription*/
-}
-
-void notify_presence_received(LinphoneCore *lc, LinphoneFriend * lf) {
-	stats* counters;
-	unsigned int i;
-	const LinphoneAddress *addr = linphone_friend_get_address(lf);
-	if (addr != NULL) {
-		char* from=linphone_address_as_string(addr);
-		ms_message("New Notify request from [%s] ",from);
-		ms_free(from);
-	}
-	counters = get_stats(lc);
-	counters->number_of_NotifyPresenceReceived++;
-	counters->last_received_presence = linphone_friend_get_presence_model(lf);
-	if (linphone_presence_model_get_basic_status(counters->last_received_presence) == LinphonePresenceBasicStatusOpen) {
-		counters->number_of_LinphonePresenceBasicStatusOpen++;
-	} else if (linphone_presence_model_get_basic_status(counters->last_received_presence) == LinphonePresenceBasicStatusClosed) {
-		counters->number_of_LinphonePresenceBasicStatusClosed++;
-	} else {
-		ms_error("Unexpected basic status [%i]",linphone_presence_model_get_basic_status(counters->last_received_presence));
-	}
-	if (linphone_presence_model_get_nb_activities(counters->last_received_presence) > 0) {
-		for (i=0;counters->last_received_presence&&i<linphone_presence_model_get_nb_activities(counters->last_received_presence); i++) {
-			LinphonePresenceActivity *activity = linphone_presence_model_get_nth_activity(counters->last_received_presence, i);
-			switch (linphone_presence_activity_get_type(activity)) {
-				case LinphonePresenceActivityAppointment:
-					counters->number_of_LinphonePresenceActivityAppointment++; break;
-				case LinphonePresenceActivityAway:
-					counters->number_of_LinphonePresenceActivityAway++; break;
-				case LinphonePresenceActivityBreakfast:
-					counters->number_of_LinphonePresenceActivityBreakfast++; break;
-				case LinphonePresenceActivityBusy:
-					counters->number_of_LinphonePresenceActivityBusy++; break;
-				case LinphonePresenceActivityDinner:
-					counters->number_of_LinphonePresenceActivityDinner++; break;
-				case LinphonePresenceActivityHoliday:
-					counters->number_of_LinphonePresenceActivityHoliday++; break;
-				case LinphonePresenceActivityInTransit:
-					counters->number_of_LinphonePresenceActivityInTransit++; break;
-				case LinphonePresenceActivityLookingForWork:
-					counters->number_of_LinphonePresenceActivityLookingForWork++; break;
-				case LinphonePresenceActivityLunch:
-					counters->number_of_LinphonePresenceActivityLunch++; break;
-				case LinphonePresenceActivityMeal:
-					counters->number_of_LinphonePresenceActivityMeal++; break;
-				case LinphonePresenceActivityMeeting:
-					counters->number_of_LinphonePresenceActivityMeeting++; break;
-				case LinphonePresenceActivityOnThePhone:
-					counters->number_of_LinphonePresenceActivityOnThePhone++; break;
-				case LinphonePresenceActivityOther:
-					counters->number_of_LinphonePresenceActivityOther++; break;
-				case LinphonePresenceActivityPerformance:
-					counters->number_of_LinphonePresenceActivityPerformance++; break;
-				case LinphonePresenceActivityPermanentAbsence:
-					counters->number_of_LinphonePresenceActivityPermanentAbsence++; break;
-				case LinphonePresenceActivityPlaying:
-					counters->number_of_LinphonePresenceActivityPlaying++; break;
-				case LinphonePresenceActivityPresentation:
-					counters->number_of_LinphonePresenceActivityPresentation++; break;
-				case LinphonePresenceActivityShopping:
-					counters->number_of_LinphonePresenceActivityShopping++; break;
-				case LinphonePresenceActivitySleeping:
-					counters->number_of_LinphonePresenceActivitySleeping++; break;
-				case LinphonePresenceActivitySpectator:
-					counters->number_of_LinphonePresenceActivitySpectator++; break;
-				case LinphonePresenceActivitySteering:
-					counters->number_of_LinphonePresenceActivitySteering++; break;
-				case LinphonePresenceActivityTravel:
-					counters->number_of_LinphonePresenceActivityTravel++; break;
-				case LinphonePresenceActivityTV:
-					counters->number_of_LinphonePresenceActivityTV++; break;
-				case LinphonePresenceActivityUnknown:
-					counters->number_of_LinphonePresenceActivityUnknown++; break;
-				case LinphonePresenceActivityVacation:
-					counters->number_of_LinphonePresenceActivityVacation++; break;
-				case LinphonePresenceActivityWorking:
-					counters->number_of_LinphonePresenceActivityWorking++; break;
-				case LinphonePresenceActivityWorship:
-					counters->number_of_LinphonePresenceActivityWorship++; break;
-			}
-		}
-	} else {
-		if (linphone_presence_model_get_basic_status(counters->last_received_presence) == LinphonePresenceBasicStatusOpen)
-			counters->number_of_LinphonePresenceActivityOnline++;
-		else
-			counters->number_of_LinphonePresenceActivityOffline++;
-	}
-}
-
-void notify_presence_received_for_uri_or_tel(LinphoneCore *lc, LinphoneFriend *lf, const char *uri_or_tel, const LinphonePresenceModel *presence) {
-	stats *counters = get_stats(lc);
-	ms_message("Presence notification for URI or phone number [%s]", uri_or_tel);
-	counters->number_of_NotifyPresenceReceivedForUriOrTel++;
-}
-
-static void simple_publish_with_expire(int expires) {
-	LinphoneCoreManager* marie = linphone_core_manager_new( "marie_rc");
-	LinphoneProxyConfig* proxy;
-	LinphonePresenceModel* presence;
-	LinphoneCoreCbs *cbs = linphone_factory_create_core_cbs(linphone_factory_get());
-	
-	linphone_core_cbs_set_publish_state_changed(cbs, linphone_publish_state_changed);
-	_linphone_core_add_callbacks(marie->lc, cbs, TRUE);
-	linphone_core_cbs_unref(cbs);
-
-	proxy = linphone_core_get_default_proxy_config(marie->lc);
-	linphone_proxy_config_edit(proxy);
-	if (expires > 0) {
-		linphone_proxy_config_set_publish_expires(proxy,expires);
-	}
-	linphone_proxy_config_enable_publish(proxy,TRUE);
-	linphone_proxy_config_done(proxy);
-
-	BC_ASSERT_TRUE(wait_for(marie->lc,marie->lc,&marie->stat.number_of_LinphonePublishProgress,1));
-	BC_ASSERT_TRUE(wait_for(marie->lc,marie->lc,&marie->stat.number_of_LinphonePublishOk,1));
-
-	presence = linphone_presence_model_new();
-	linphone_presence_model_set_basic_status(presence, LinphonePresenceBasicStatusClosed);
-	linphone_core_set_presence_model(marie->lc,presence);
-	linphone_presence_model_unref(presence);
-
-	BC_ASSERT_TRUE(wait_for(marie->lc,marie->lc,&marie->stat.number_of_LinphonePublishProgress,2));
-	BC_ASSERT_TRUE(wait_for(marie->lc,marie->lc,&marie->stat.number_of_LinphonePublishOk,2));
-
-	linphone_proxy_config_edit(proxy);
-	linphone_proxy_config_done(proxy);
-	/*make sure no publish is sent*/
-	BC_ASSERT_FALSE(wait_for_until(marie->lc,marie->lc,&marie->stat.number_of_LinphonePublishProgress,3,2000));
-
-	linphone_proxy_config_edit(proxy);
-	linphone_proxy_config_enable_publish(proxy,FALSE);
-	linphone_proxy_config_done(proxy);
-
-
-	/*fixme PUBLISH state machine is too simple, clear state should only be propagated at API level  when 200ok is received*/
-	/*BC_ASSERT_TRUE(wait_for(marie->lc,marie->lc,&marie->stat.number_of_LinphonePublishProgress,3));*/
-	wait_for_until(marie->lc,marie->lc,NULL,0,2000);
-	BC_ASSERT_TRUE(wait_for(marie->lc,marie->lc,&marie->stat.number_of_LinphonePublishCleared,1));
-
-	linphone_proxy_config_edit(proxy);
-	linphone_proxy_config_enable_publish(proxy,TRUE);
-	linphone_proxy_config_done(proxy);
-	BC_ASSERT_TRUE(wait_for(marie->lc,marie->lc,&marie->stat.number_of_LinphonePublishProgress,3));
-	BC_ASSERT_TRUE(wait_for(marie->lc,marie->lc,&marie->stat.number_of_LinphonePublishOk,3));
-
-	linphone_proxy_config_edit(proxy);
-	linphone_proxy_config_set_publish_expires(proxy, linphone_proxy_config_get_publish_expires(proxy)+1);
-	linphone_proxy_config_done(proxy);
-	BC_ASSERT_TRUE(wait_for(marie->lc,marie->lc,&marie->stat.number_of_LinphonePublishProgress,4));
-	BC_ASSERT_TRUE(wait_for(marie->lc,marie->lc,&marie->stat.number_of_LinphonePublishOk,4));
-
-	linphone_core_manager_stop(marie);
-	BC_ASSERT_EQUAL(marie->stat.number_of_LinphonePublishCleared,3,int,"%i"); /*yes it is 3 because when we change the expires, a new LinphoneEvent is created*/
-	BC_ASSERT_EQUAL(marie->stat.number_of_LinphonePublishOk,4,int,"%i");
-	linphone_core_manager_destroy(marie);
-}
-
-static void simple_publish(void) {
-	simple_publish_with_expire(-1);
-}
-
-static void publish_with_expires(void) {
-	simple_publish_with_expire(2);
-}
-
-static void publish_with_dual_identity(void) {
-	LinphoneCoreManager* pauline = linphone_core_manager_new("multi_account_rc");
-	const bctbx_list_t* proxies;
-	LinphoneCoreCbs *cbs = linphone_factory_create_core_cbs(linphone_factory_get());
-	
-	linphone_core_cbs_set_publish_state_changed(cbs, linphone_publish_state_changed);
-	_linphone_core_add_callbacks(pauline->lc, cbs, TRUE);
-	linphone_core_cbs_unref(cbs);
-	
-	for (proxies = linphone_core_get_proxy_config_list(pauline->lc); proxies!=NULL; proxies = proxies->next) {
-		LinphoneProxyConfig *proxy = (LinphoneProxyConfig *) proxies->data;
-		linphone_proxy_config_edit(proxy);
-		linphone_proxy_config_enable_publish(proxy,TRUE);
-		linphone_proxy_config_done(proxy);
-	}
-	
-	BC_ASSERT_TRUE(wait_for(pauline->lc,pauline->lc,&pauline->stat.number_of_LinphonePublishProgress,4));
-	BC_ASSERT_TRUE(wait_for(pauline->lc,pauline->lc,&pauline->stat.number_of_LinphonePublishOk,4));
-	
-	linphone_core_manager_stop(pauline);
-	BC_ASSERT_EQUAL(pauline->stat.number_of_LinphonePublishCleared,4,int,"%i");
-	BC_ASSERT_EQUAL(pauline->stat.number_of_LinphonePublishOk,4,int,"%i");
-	linphone_core_manager_destroy(pauline);
-	
-}
 static bool_t subscribe_to_callee_presence(LinphoneCoreManager* caller_mgr,LinphoneCoreManager* callee_mgr) {
 	stats initial_caller=caller_mgr->stat;
 	stats initial_callee=callee_mgr->stat;
 	bool_t result=FALSE;
-	char* identity=linphone_address_as_string_uri_only(callee_mgr->identity);
+	char* identity=linphone_address_as_string(callee_mgr->identity);
 
 
 	LinphoneFriend* friend=linphone_core_create_friend_with_address(caller_mgr->lc,identity);
@@ -282,11 +88,11 @@ static void subscribe_failure_handle_by_app(void) {
 	BC_ASSERT_TRUE(subscribe_to_callee_presence(marie,pauline));
 	wait_for(marie->lc,pauline->lc,&pauline->stat.number_of_NewSubscriptionRequest,1); /*just to wait for unsubscription even if not notified*/
 
-	sal_set_recv_error(marie->lc->sal, 0); /*simulate an error*/
+	sal_set_recv_error(linphone_core_get_sal(marie->lc), 0); /*simulate an error*/
 
 	BC_ASSERT_TRUE(wait_for(marie->lc,pauline->lc,&marie->stat.number_of_LinphoneRegistrationProgress,2));
 	BC_ASSERT_EQUAL(linphone_proxy_config_get_error(config),LinphoneReasonIOError, int, "%d");
-	sal_set_recv_error(marie->lc->sal, 1);
+	sal_set_recv_error(linphone_core_get_sal(marie->lc), 1);
 
 	lf = linphone_core_get_friend_by_address(marie->lc,lf_identity);
 	ms_free(lf_identity);
@@ -333,7 +139,7 @@ static void simple_subscribe_with_early_notify(void) {
 	LinphoneFriend* marie_s_friend=linphone_core_create_friend_with_address(marie->lc,pauline_identity);
 
 	pauline_lp = linphone_core_get_config(pauline->lc);
-	lp_config_set_int(pauline_lp,"sip","notify_pending_state",1);
+	linphone_config_set_int(pauline_lp,"sip","notify_pending_state",1);
 
 	linphone_friend_edit(marie_s_friend);
 	linphone_friend_enable_subscribes(marie_s_friend,TRUE);
@@ -344,9 +150,10 @@ static void simple_subscribe_with_early_notify(void) {
 
 	/*to simulate pending state.*/
 
-	linphone_address_set_port(marie_identity_addr,0);
+	linphone_address_set_port(marie_identity_addr, 0); /*we remove the port because friends aren't supposed to have port numbers*/
 	marie_identity=linphone_address_as_string_uri_only(marie_identity_addr);
 	pauline_s_friend=linphone_core_create_friend_with_address(pauline->lc,marie_identity);
+	linphone_friend_enable_subscribes(pauline_s_friend, FALSE);
 	linphone_core_add_friend(pauline->lc,pauline_s_friend);
 
 	ms_free(marie_identity);
@@ -544,7 +351,7 @@ static void subscribe_presence_expired(void){
 	lcs = bctbx_list_append(lcs, marie->lc);
 	lcs = bctbx_list_append(lcs, pauline1->lc);
 
-	lp_config_set_int(marie->lc->config, "sip", "subscribe_expires", 10);
+	linphone_config_set_int(linphone_core_get_config(marie->lc), "sip", "subscribe_expires", 10);
 
 	lf = linphone_core_create_friend(marie->lc);
 	linphone_friend_set_address(lf, pauline1->identity);
@@ -558,13 +365,13 @@ static void subscribe_presence_expired(void){
 	lf = linphone_core_find_friend(pauline1->lc, marie->identity);
 	BC_ASSERT_PTR_NOT_NULL(lf);
 	if (lf) {
-		BC_ASSERT_PTR_NOT_NULL(lf->insubs);
+		BC_ASSERT_PTR_NOT_NULL(linphone_friend_get_insubs(lf));
 
 		/*marie comes offline suddenly*/
 		linphone_core_set_network_reachable(marie->lc, FALSE);
 		/*after a certain time, pauline shall see the incoming SUBSCRIBE expired*/
 		wait_for_list(lcs,NULL, 0, 11000);
-		BC_ASSERT_PTR_NULL(lf->insubs);
+		BC_ASSERT_PTR_NULL(linphone_friend_get_insubs(lf));
 
 		/*just make network reachable so that marie can unregister properly*/
 		linphone_core_set_network_reachable(marie->lc, TRUE);
@@ -606,13 +413,10 @@ test_t presence_tests[] = {
 	TEST_ONE_TAG("Simple Subscribe", simple_subscribe,"presence"),
 	TEST_ONE_TAG("Simple Subscribe with early NOTIFY", simple_subscribe_with_early_notify,"presence"),
 	TEST_NO_TAG("Simple Subscribe with friend from rc", simple_subscribe_with_friend_from_rc),
-	TEST_NO_TAG("Simple Publish", simple_publish),
-	TEST_NO_TAG("Publish with 2 identities", publish_with_dual_identity),
-	TEST_NO_TAG("Simple Publish with expires", publish_with_expires),
 	/*TEST_ONE_TAG("Call with presence", call_with_presence, "LeaksMemory"),*/
 	TEST_NO_TAG("Unsubscribe while subscribing", unsubscribe_while_subscribing),
 	TEST_NO_TAG("Presence information", presence_information),
-	TEST_NO_TAG("App managed presence failure", subscribe_failure_handle_by_app),
+	TEST_ONE_TAG("App managed presence failure", subscribe_failure_handle_by_app,"presence"),
 	TEST_NO_TAG("Presence SUBSCRIBE forked", subscribe_presence_forked),
 	TEST_NO_TAG("Presence SUBSCRIBE expired", subscribe_presence_expired),
 };
