@@ -28,11 +28,22 @@ extern "C" {
 
 bool_t check_ice(LinphoneCoreManager* caller, LinphoneCoreManager* callee, LinphoneIceState state);
 bool_t check_ice_sdp (LinphoneCall *call);
+
+typedef enum _TesterIceCandidateType{
+	TesterIceCandidateHost,
+	TesterIceCandidateSflrx,
+	TesterIceCandidateRelay
+} TesterIceCandidateType;
+void liblinphone_tester_check_ice_default_candidates(LinphoneCoreManager *marie, TesterIceCandidateType marie_expected_type, LinphoneCoreManager *pauline, TesterIceCandidateType pauline_expected_type);
 bool_t is_srtp_secured (LinphoneCall *call, LinphoneStreamType ctype);
 void check_media_stream(LinphoneCall *call, bool_t is_null);
 void check_local_desc_stream (LinphoneCall *call);
 void check_result_desc_rtp_rtcp_ports (LinphoneCall *call, int rtp_port, int rtcp_port);
 
+int liblinphone_tester_send_data(const void *buffer, size_t length, const char *dest_ip, int dest_port, int sock_type);
+
+bool_t linphone_conference_type_is_full_state(const char * text);
+
 #ifdef __cplusplus
 }
 #endif
