@@ -1,3 +1,21 @@
+#
+# Copyright (c) 2010-2019 Belledonne Communications SARL.
+#
+# This file is part of Liblinphone.
+#
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program. If not, see <http://www.gnu.org/licenses/>.
+#
 from datetime import timedelta, datetime
 from nose.tools import assert_equals
 from copy import deepcopy
@@ -183,6 +201,7 @@ class CoreManagerStats:
         self.number_of_auth_info_requested = 0
 
         self.number_of_LinphoneCallIncomingReceived = 0
+        self.number_of_LinphoneCallPushIncomingReceived = 0
         self.number_of_LinphoneCallOutgoingInit = 0
         self.number_of_LinphoneCallOutgoingProgress = 0
         self.number_of_LinphoneCallOutgoingRinging = 0
