@@ -271,7 +271,11 @@ class CsharpTranslator:
 				listenerDict['delegate']['params'] += ', '
 
 				if normalType == dllImportType:
-					listenerDict['delegate']['params'] += argName
+					if normalType == "string":
+						dllImportType = "IntPtr"
+						listenerDict['delegate']['params'] += "PtrToStringSafe(" + argName + ")"
+					else:
+						listenerDict['delegate']['params'] += argName
 				else:
 					if normalType == "bool":
 						listenerDict['delegate']['params'] += argName + " == 0"
@@ -443,7 +447,7 @@ def render(renderer, item, path):
 
 if __name__ == '__main__':
 	import subprocess
-	git_version = subprocess.check_output(["git", "describe"]).strip()
+	git_version = os.environ.get("LIBLINPHONE_VERSION") or subprocess.check_output(["git", "describe"]).strip()
 
 	argparser = argparse.ArgumentParser(description='Generate source files for the C# wrapper')
 	argparser.add_argument('xmldir', type=str, help='Directory where the XML documentation of the Linphone\'s API generated by Doxygen is placed')
