@@ -109,6 +109,7 @@ public class AndroidPlatformHelper {
         mMainHandler = new Handler(mContext.getMainLooper());
 
         MediastreamerAndroidContext.setContext(mContext);
+
         Log.i("[Platform Helper] Created, wifi only mode is " + (mWifiOnly ? "enabled" : "disabled"));
 
         WifiManager wifiMgr = (WifiManager) mContext.getSystemService(Context.WIFI_SERVICE);
@@ -310,10 +311,12 @@ public class AndroidPlatformHelper {
         String mPauseSoundFile = basePath + "/share/sounds/linphone/rings/dont_wait_too_long.mkv";
         String mErrorToneFile = basePath + "/share/sounds/linphone/incoming_chat.wav";
         String mGrammarCpimFile = basePath + "/share/belr/grammars/cpim_grammar";
+        String mGrammarIcsFile = basePath + "/share/belr/grammars/ics_grammar";
         String mGrammarIdentityFile = basePath + "/share/belr/grammars/identity_grammar";
         String mGrammarVcardFile = basePath + "/share/belr/grammars/vcard_grammar";
 
         copyEvenIfExists(getResourceIdentifierFromName("cpim_grammar"), mGrammarCpimFile);
+        copyEvenIfExists(getResourceIdentifierFromName("ics_grammar"), mGrammarIcsFile);
         copyEvenIfExists(getResourceIdentifierFromName("identity_grammar"), mGrammarIdentityFile);
         copyEvenIfExists(getResourceIdentifierFromName("vcard_grammar"), mGrammarVcardFile);
         copyEvenIfExists(getResourceIdentifierFromName("rootca"), mLinphoneRootCaFile);
@@ -749,4 +752,13 @@ public class AndroidPlatformHelper {
 
         mMonitoringEnabled = false;
     }
+
+    public synchronized void disableAudioRouteChanges(boolean disable) {
+        if (disable) {
+            Log.i("[Platform Helper] Disabling audio route changes in mediastreamer2");
+        } else {
+            Log.i("[Platform Helper] Enabling audio route changes in mediastreamer2");
+        }
+        MediastreamerAndroidContext.disableAudioRouteChanges(disable);
+    }
 };
