@@ -28,9 +28,12 @@ import android.content.IntentFilter;
 import android.content.pm.PackageInfo;
 import android.content.pm.PackageManager;
 import android.content.pm.ServiceInfo;
+import android.hardware.display.DisplayManager;
 import android.os.Build;
 import android.os.Handler;
 import android.os.Looper;
+import android.view.Display;
+import android.view.Surface;
 
 import org.linphone.core.AudioDevice;
 import org.linphone.core.Call;
@@ -46,6 +49,7 @@ import org.linphone.core.tools.compatibility.DeviceUtils;
 import org.linphone.core.tools.receiver.ShutdownReceiver;
 import org.linphone.mediastream.Version;
 
+import java.lang.Error;
 import java.lang.reflect.Constructor;
 import java.util.Timer;
 import java.util.TimerTask;
@@ -64,7 +68,7 @@ public class CoreManager {
 
     public static CoreManager instance() {
         if (isReady()) return sInstance;
-
+        Log.e("[Core Manager] Trying to access instance that doesn't exists!");
         throw new RuntimeException("CoreManager not instantiated yet");
     }
 
@@ -81,15 +85,19 @@ public class CoreManager {
     private BluetoothHelper mBluetoothHelper;
     private ShutdownReceiver mShutdownReceiver;
 
-	// These methods will make sure the real core.<method> will be called on the same thread as the core.iterate()
+    private Handler mHandler;
+    private DisplayManager mDisplayManager;
+    private DisplayManager.DisplayListener mDisplayListener;
+
+    // These methods will make sure the real core.<method> will be called on the same thread as the core.iterate()
     private native void updatePushNotificationInformation(long ptr, String appId, String token);
-	private native void stopCore(long ptr);
-	private native void leaveConference(long ptr);
-	private native void pauseAllCalls(long ptr);
-	private native void reloadSoundDevices(long ptr);
-	private native void enterBackground(long ptr);
-	private native void enterForeground(long ptr);
-	private native void ensureRegistered(long ptr);
+    private native void stopCore(long ptr);
+    private native void leaveConference(long ptr);
+    private native void pauseAllCalls(long ptr);
+    private native void reloadSoundDevices(long ptr);
+    private native void enterBackground(long ptr);
+    private native void enterForeground(long ptr);
+    private native void ensureRegistered(long ptr);
 
     public CoreManager(Object context, Core core) {
         mContext = ((Context) context).getApplicationContext();
@@ -116,9 +124,35 @@ public class CoreManager {
             mAudioHelper = new AudioHelper(mContext);
         } else {
             Log.w("[Core Manager] Do you have a dependency on androidx.media:media:1.2.0 or newer?");
+            if (core.isNativeRingingEnabled()) {
+                Log.e("[Core Manager] Native ringing was enabled but condition isn't met (androidx.media:media dependency), disabling it.");
+                core.setNativeRingingEnabled(false);
+            }
         }
         mBluetoothHelper = new BluetoothHelper(mContext);
 
+        mDisplayListener = new DisplayManager.DisplayListener() {
+            @Override
+            public void onDisplayAdded(int displayId) {
+                Log.d("[Core Manager] Display added: ", displayId);
+            }
+
+            @Override
+            public void onDisplayChanged(int displayId) {
+                Log.d("[Core Manager] Display changed: ", displayId);
+                updateOrientation(displayId);
+            }
+
+            @Override
+            public void onDisplayRemoved(int displayId) {
+                Log.d("[Core Manager] Display removed: ", displayId);
+            }
+        };
+        mDisplayManager = (DisplayManager) mContext.getSystemService(Context.DISPLAY_SERVICE);
+        mHandler = new Handler(Looper.getMainLooper());
+        mDisplayManager.registerDisplayListener(mDisplayListener, mHandler);
+        updateOrientation(Display.DEFAULT_DISPLAY);
+
         IntentFilter shutdownIntentFilter = new IntentFilter(Intent.ACTION_SHUTDOWN);
         // Without that the broadcast timeout might be reached before we were called
         shutdownIntentFilter.setPriority(IntentFilter.SYSTEM_HIGH_PRIORITY - 1);
@@ -156,18 +190,25 @@ public class CoreManager {
             mAudioHelper = null;
         }
 
+        if (mDisplayManager != null && mDisplayListener != null) {
+            mDisplayManager.unregisterDisplayListener(mDisplayListener);
+            mDisplayListener = null;
+            mDisplayManager = null;
+        }
+
         mServiceClass = null;
         mContext = null;
         sInstance = null;
+        Log.i("[Core Manager] Destroyed");
     }
 
     public Core getCore() {
         return mCore;
     }
 
-	public void ensureRegistered() {
-		ensureRegistered(mCore.getNativePointer());
-	}
+    public void ensureRegistered() {
+        ensureRegistered(mCore.getNativePointer());
+    }
 
     public void onLinphoneCoreStart() {
         if (mCore.isAutoIterateEnabled()) {
@@ -234,9 +275,7 @@ public class CoreManager {
                             Log.w("[Core Manager] Incoming call is early media and ringing is disabled, stop ringing");
                             mAudioHelper.stopRinging();
                         } else {
-                            Log.w("[Core Manager] Incoming call is early media and ringing is disabled, release ringing audio focus but acquire call audio focus");
-                            mAudioHelper.releaseRingingAudioFocus();
-                            mAudioHelper.requestCallAudioFocus();
+                            Log.i("[Core Manager] Incoming call is early media and ringing is disabled, keep ringing audio focus as sound card will be using RING stream");
                         }
                     }
                 } else if (state == Call.State.Connected) {
@@ -252,10 +291,10 @@ public class CoreManager {
                     mAudioHelper.requestRingingAudioFocus();
                 } else if (state == Call.State.StreamsRunning) {
                     Log.i("[Core Manager] Call active, ensure audio focus granted");
-                    mAudioHelper.requestCallAudioFocus();
+                    mAudioHelper.requestCallAudioFocus(false);
                 } else if (state == Call.State.Resuming) {
                     Log.i("[Core Manager] Call resuming, ensure audio focus granted");
-                    mAudioHelper.requestCallAudioFocus();
+                    mAudioHelper.requestCallAudioFocus(false);
                 }
             }
         };
@@ -350,12 +389,25 @@ public class CoreManager {
         }
     }
 
+    public void onBluetoothAdapterTurnedOn() {
+        if (DeviceUtils.isBluetoothConnectPermissionGranted(mContext)) {
+            onBluetoothHeadsetStateChanged();
+        } else {
+            Log.w("[Core Manager] Bluetooth Connect permission isn't granted, waiting longer before reloading sound devices to increase chances to get bluetooth device");
+            onBluetoothHeadsetStateChanged(5000);
+        }
+    }
+
+
     public void onBluetoothHeadsetStateChanged() {
+        onBluetoothHeadsetStateChanged(500);
+    }
+
+    private void onBluetoothHeadsetStateChanged(int delay) {
         GlobalState globalState = mCore.getGlobalState();
         if (globalState == GlobalState.On || globalState == GlobalState.Ready) {
-            Log.i("[Core Manager] Bluetooth headset state changed, waiting for 500ms before reloading sound devices");
-            final Handler handler = new Handler(Looper.getMainLooper());
-            handler.postDelayed(new Runnable() {
+            Log.i("[Core Manager] Bluetooth headset state changed, waiting for " + delay + " ms before reloading sound devices");
+            mHandler.postDelayed(new Runnable() {
                 @Override
                 public void run() {
                     Log.i("[Core Manager] Reloading sound devices");
@@ -363,7 +415,7 @@ public class CoreManager {
                         reloadSoundDevices(mCore.getNativePointer());
                     }
                 }
-            }, 500);
+            }, delay);
         } else {
             Log.w("[Core Manager] Bluetooth headset state changed but current global state is ", globalState.name(), ", skipping...");
         }
@@ -373,8 +425,7 @@ public class CoreManager {
         GlobalState globalState = mCore.getGlobalState();
         if (globalState == GlobalState.On || globalState == GlobalState.Ready) {
             Log.i("[Core Manager] Headset state changed, waiting for 500ms before reloading sound devices");
-            final Handler handler = new Handler(Looper.getMainLooper());
-            handler.postDelayed(new Runnable() {
+            mHandler.postDelayed(new Runnable() {
                 @Override
                 public void run() {
                     Log.i("[Core Manager] Reloading sound devices");
@@ -411,6 +462,18 @@ public class CoreManager {
         }
     }
 
+    public void setAudioManagerInCommunicationMode() {
+        if (mAudioHelper != null) mAudioHelper.setAudioManagerInCommunicationMode();
+    }
+
+    public void setAudioManagerInNormalMode() {
+        if (mAudioHelper != null) mAudioHelper.setAudioManagerInNormalMode();
+    }
+
+	public void stopRinging() {
+		if (mAudioHelper != null) mAudioHelper.stopRinging();
+	}
+
     private Class getServiceClass() {
         // Inspect services in package to get the class name of the Service that extends LinphoneService, assume first one
         try {
@@ -418,14 +481,21 @@ public class CoreManager {
             ServiceInfo[] services = packageInfo.services;
             for (ServiceInfo service : services) {
                 String serviceName = service.name;
-                Class serviceClass = Class.forName(serviceName);
-                if (CoreService.class.isAssignableFrom(serviceClass)) {
-                    Log.i("[Core Manager] Found a service that herits from org.linphone.core.tools.service.CoreService: ", serviceName);
-                    return serviceClass;
+                try {
+                    Class serviceClass = Class.forName(serviceName);
+                    if (CoreService.class.isAssignableFrom(serviceClass)) {
+                        Log.i("[Core Manager] Found a service that herits from org.linphone.core.tools.service.CoreService: ", serviceName);
+                        return serviceClass;
+                    }
+                } catch (Exception exception) {
+                    Log.e("[Core Manager] Exception trying to get Class from name [", serviceName, "]: ", exception);
+                } catch (Error error) {
+                    Log.e("[Core Manager] Error trying to get Class from name [", serviceName, "]: ", error);
                 }
             }
         } catch (Exception e) {
-            Log.e("[Core Manager] Couldn't find Service class: ", e);
+            Log.e("[Core Manager] Exception thrown while trying to find available Services: ", e);
+            return null;
         }
 
         Log.w("[Core Manager] Failed to find a valid Service, continuing without it...");
@@ -468,6 +538,7 @@ public class CoreManager {
         Log.i("MODEL=" + Build.MODEL);
         Log.i("MANUFACTURER=" + Build.MANUFACTURER);
         Log.i("ANDROID SDK=" + Build.VERSION.SDK_INT);
+        Log.i("PERFORMANCE CLASS=" + DeviceUtils.getPerformanceClass());
         StringBuilder sb = new StringBuilder();
         sb.append("ABIs=");
         for (String abi : Version.getCpuAbis()) {
@@ -491,4 +562,27 @@ public class CoreManager {
         Log.i("BUILD TYPE=", org.linphone.core.BuildConfig.BUILD_TYPE);
         Log.i("=========================================");
     }
+
+    private void updateOrientation(int displayId) {
+        Display display = mDisplayManager.getDisplay(displayId);
+        if (display == null) {
+            Log.e("[Core Manager] Failed to get display from id: ", displayId);
+            return;
+        }
+
+        int degrees = 270;
+        int orientation = display.getRotation();
+        if (orientation == Surface.ROTATION_0) {
+            degrees = 0;
+        } else if (orientation == Surface.ROTATION_90) {
+            degrees = 270;
+        } else if (orientation == Surface.ROTATION_180) {
+            degrees = 180;
+        } else if (orientation == Surface.ROTATION_270) {
+            degrees = 90;
+        }
+        Log.i("[Core Manager] Device orientation is ", degrees, " (raw value is ", orientation, ")");
+        int rotation = (360 - degrees) % 360;
+        mCore.setDeviceRotation(rotation);
+    }
 }
